@@ -245,10 +245,6 @@ TEST_F(Test_Filebuf, Filebuf_open) {
 		Filebuf file;
 		ASSERT_NE(OK, file.Open(fname, FMODE_None));
 	}
-	{
-		Filebuf file;
-		ASSERT_NE(OK, file.Open(fname, FMODE_Memory));
-	}
 	{
 		Filebuf file;
 		ASSERT_EQ(OK, file.Open(fname, FMODE_Create));
@@ -403,5 +399,5 @@ TEST_P(Test_FilebufGetline, filesize) {
 	}
 }
 
-INSTANTIATE_TEST_CASE_P(smallbuf, Test_FilebufGetline,
-                        ::testing::Values(1000, 100, 10));
+INSTANTIATE_TEST_SUITE_P(smallbuf, Test_FilebufGetline,
+                         ::testing::Values(1000, 100, 10));
