@@ -300,7 +300,7 @@ TEST_F(Test_Scidbase, getGamePos1) {
 	ASSERT_STREQ(parseLog.log.c_str(), "");
 
 	scidBaseT dbase;
-	ASSERT_EQ(OK, dbase.Open(ICodecDatabase::MEMORY, FMODE_Memory));
+	ASSERT_EQ(OK, dbase.open("MEMORY", FMODE_Create, "Memory"));
 	ASSERT_EQ(OK, dbase.saveGame(&game));
 	ASSERT_NE(nullptr, dbase.getIndexEntry_bounds(0));
 
@@ -327,7 +327,7 @@ TEST_F(Test_Scidbase, getGamePos2) {
 	ASSERT_STREQ(parseLog.log.c_str(), "");
 
 	scidBaseT dbase;
-	ASSERT_EQ(OK, dbase.Open(ICodecDatabase::MEMORY, FMODE_Memory));
+	ASSERT_EQ(OK, dbase.open("MEMORY", FMODE_Create, "Memory"));
 	ASSERT_EQ(OK, dbase.saveGame(&game));
 	ASSERT_NE(nullptr, dbase.getIndexEntry_bounds(0));
 
@@ -343,7 +343,7 @@ TEST_F(Test_Scidbase, getGamePos3) {
 	ASSERT_STREQ(parseLog.log.c_str(), "");
 
 	scidBaseT dbase;
-	ASSERT_EQ(OK, dbase.Open(ICodecDatabase::MEMORY, FMODE_Memory));
+	ASSERT_EQ(OK, dbase.open("MEMORY", FMODE_Create, "Memory"));
 	ASSERT_EQ(OK, dbase.saveGame(&game));
 	ASSERT_NE(nullptr, dbase.getIndexEntry_bounds(0));
 
@@ -362,7 +362,7 @@ TEST_F(Test_Scidbase, saveGame) {
 	ASSERT_STREQ(parseLog.log.c_str(), "");
 
 	scidBaseT dbase;
-	ASSERT_EQ(OK, dbase.Open(ICodecDatabase::MEMORY, FMODE_Memory));
+	ASSERT_EQ(OK, dbase.open("MEMORY", FMODE_Create, "Memory"));
 	EXPECT_EQ(nullptr, dbase.getIndexEntry_bounds(0));
 	HFilter dbfilter = dbase.getFilter("dbfilter");
 	EXPECT_EQ(0U, dbfilter->size());
@@ -421,7 +421,7 @@ TEST_F(Test_Scidbase, importGames) {
 
 
 	scidBaseT srcBase;
-	ASSERT_EQ(OK, srcBase.Open(ICodecDatabase::MEMORY, FMODE_Memory));
+	ASSERT_EQ(OK, srcBase.open("MEMORY", FMODE_Create, "Memory"));
 	ASSERT_EQ(OK, srcBase.saveGame(&game0));
 	ASSERT_EQ(OK, srcBase.saveGame(&game1));
 	ASSERT_EQ(OK, srcBase.saveGame(&game1));
@@ -430,55 +430,38 @@ TEST_F(Test_Scidbase, importGames) {
 	srcFilter->erase(1);
 
 	scidBaseT dbase;
-	ASSERT_EQ(OK, dbase.Open(ICodecDatabase::MEMORY, FMODE_Memory));
+	ASSERT_EQ(OK, dbase.open("MEMORY", FMODE_Create, "Memory"));
 	EXPECT_EQ(nullptr, dbase.getIndexEntry_bounds(0));
 	HFilter dbfilter = dbase.getFilter("dbfilter");
 
-	EXPECT_EQ(ERROR_BadArg, dbase.importGame(&dbase, 0));
 	EXPECT_EQ(ERROR_BadArg, dbase.importGames(&dbase, dbfilter, Progress()));
-	EXPECT_EQ(ERROR_BadArg, dbase.importGame(&srcBase, 3));
 	EXPECT_EQ(0U, dbase.numGames());
 	EXPECT_EQ(0U, dbfilter->size());
 
-	{
-		EXPECT_EQ(OK, dbase.importGame(&srcBase, 1));
-		EXPECT_EQ(1U, dbase.numGames());
-		EXPECT_EQ(1U, dbfilter->size());
-		auto ie0 = dbase.getIndexEntry_bounds(0);
-		auto ie1 = dbase.getIndexEntry_bounds(1);
-		EXPECT_NE(nullptr, ie0);
-		EXPECT_EQ(nullptr, ie1);
-		EXPECT_NE(ie0, ie1);
-		auto gamepos = collectPositions(dbase, 0);
-		EXPECT_EQ(test_pgnLong, encodePgn(gamepos));
-	}
 	{
 		EXPECT_EQ(OK, dbase.importGames(&srcBase, srcFilter, Progress()));
-		EXPECT_EQ(3U, dbase.numGames());
-		EXPECT_EQ(3U, dbfilter->size());
+		EXPECT_EQ(2U, dbase.numGames());
+		EXPECT_EQ(2U, dbfilter->size());
 		auto ie0 = dbase.getIndexEntry_bounds(0);
 		auto ie1 = dbase.getIndexEntry_bounds(1);
 		auto ie2 = dbase.getIndexEntry_bounds(2);
 		EXPECT_NE(nullptr, ie0);
 		EXPECT_NE(nullptr, ie1);
-		EXPECT_NE(nullptr, ie2);
+		EXPECT_EQ(nullptr, ie2);
 		EXPECT_NE(ie0, ie1);
-		EXPECT_NE(ie0, ie2);
 		auto gamepos = collectPositions(dbase, 0);
-		EXPECT_EQ(test_pgnLong, encodePgn(gamepos));
-		gamepos = collectPositions(dbase, 1);
 		EXPECT_EQ(test_pgnShort, encodePgn(gamepos));
-		gamepos = collectPositions(dbase, 2);
+		gamepos = collectPositions(dbase, 1);
 		EXPECT_EQ(test_pgnLong, encodePgn(gamepos));
 	}
 }
 
 TEST_F(Test_Scidbase, new_compose_delete_get_Filter) {
 	scidBaseT dbase;
-	ASSERT_EQ(OK, dbase.Open(ICodecDatabase::MEMORY, FMODE_Memory));
+	ASSERT_EQ(OK, dbase.open("MEMORY", FMODE_Create, "Memory"));
 
 	std::vector<std::pair<std::string, bool>> tests = {
-	    {" dbfilter", false},   {"dbfilter ", false}, {"+dbfilter+", true},
+	    {" dbfilter", false},   {"dbfilter ", false}, {"dbfilter", true},
 	    {"tree", true},         {"+dbfilter", false}, {"++dbfilter", false},
 	    {"++dbfilter+", false}, {"", false},          {"+", false},
 	    {"++", false},          {"+++", false},       {" +", false},
@@ -494,10 +477,12 @@ TEST_F(Test_Scidbase, new_compose_delete_get_Filter) {
 			auto composed = dbase.composeFilter(e.first, mask);
 			EXPECT_EQ(valid, dbase.getFilter(composed) != nullptr);
 			if (valid) {
+				auto [f1, f2] = dbase.getFilterComponents(composed);
+				EXPECT_EQ(f1, e.first);
+				EXPECT_EQ(f2, mask);
+				EXPECT_EQ(e.first, dbase.composeFilter(composed, ""));
+
 				mask = e.first;
-				if (e.first[0] != '+') {
-					EXPECT_EQ(e.first, dbase.composeFilter(composed, ""));
-				}
 			}
 		}
 	};
