@@ -47,19 +47,12 @@ namespace {
  */
 const char* NAMEBASE_MAGIC = "Scid.sn";
 
-/**
- * Read a SCIDv4 NameBase file into memory.
- * @param filename: the full path of the file to open.
- * @param fMode:    a valid file mode.
- * @param nb:       reference to the object where the names will be stored.
- * @returns OK if successful or an error code.
- */
+/// Read a SCIDv4 NameBase file into memory.
+/// @param filename: the full path of the file to open.
+/// @param fMode:    a valid file mode.
+/// @param nb:       reference to the object where the names will be stored.
+/// @returns OK if successful or an error code.
 errorT namefileRead(const char* filename, fileModeT fmode, NameBase& nb) {
-	auto nb_data = nb.getData();
-	auto& map = std::get<0>(nb_data);
-	auto& names = std::get<1>(nb_data);
-	auto& eloV = std::get<2>(nb_data);
-
 	Filebuf file;
 	if (file.Open(filename, fmode) != OK)
 		return ERROR_FileOpen;
@@ -89,9 +82,7 @@ errorT namefileRead(const char* filename, fileModeT fmode, NameBase& nb) {
 	obsolete_maxFreq[NAME_ROUND] = file.ReadThreeBytes();
 	// ***
 
-	eloV.resize(Header_numNames[NAME_PLAYER], 0);
 	for (nameT nt : {NAME_PLAYER, NAME_EVENT, NAME_SITE, NAME_ROUND}) {
-		names[nt].resize(Header_numNames[nt]);
 		idNumberT id;
 		std::string prevName;
 		for (idNumberT i = 0; i < Header_numNames[nt]; i++) {
@@ -120,56 +111,24 @@ errorT namefileRead(const char* filename, fileModeT fmode, NameBase& nb) {
 			if (prefix > length)
 				return ERROR_Corrupt;
 
-			char* name = new char[length + 1];
-			std::copy_n(prevName.c_str(), prefix, name);
-			std::streamsize extra_chars = length - prefix;
-			if (extra_chars != file.sgetn(name + prefix, extra_chars)) {
-				delete[] name;
+			prevName.resize(length);
+			const auto new_chars = length - prefix;
+			if (new_chars != file.sgetn(prevName.data() + prefix, new_chars))
 				return ERROR_FileRead;
-			}
-			name[length] = 0;
-			prevName.assign(name, length);
 
-			if (id < Header_numNames[nt] && names[nt][id] == 0) {
-				names[nt][id].reset(name);
-				map[nt].insert(map[nt].end(), std::make_pair(name, id));
-			} else {
-				delete[] name;
+			if (id >= Header_numNames[nt] ||
+			    !nb.insert(prevName.c_str(), length, nt, id))
 				return ERROR_Corrupt;
-			}
 		}
-
-		if (map[nt].size() != names[nt].size())
-			return ERROR_Corrupt;
 	}
 
 	return OK;
 }
 
-bool assert_sorted(const char* str1, const char* str2) {
-	// *** Compatibility ***
-	// Older code used a custom StrTree class with a peculiar sorting:
-	// - the first char was interpreted as an unsigned char;
-	// - the remaining part was compared with the function
-	// strComapare(),
-	//   which converts the chars to ints, and is not consistent with
-	//   the standard function strcmp().
-	// The old StrTree class did also have unpredictable behaviors when
-	// fed with names not sorted according to that criteria, for example
-	// it could create Namebase objects with duplicate entries.
-	// ***
-	if (*str1 == *str2)
-		return strCompare(str1, str2) < 0;
-
-	return static_cast<uint>(*str1) < static_cast<uint>(*str2);
-}
-
-/**
- * Write a SCIDv4 NameBase file.
- * @param filename: the full path of the file to open.
- * @param nb:       reference to the object where the names will be stored.
- * @returns OK if successful or an error code.
- */
+/// Write a SCIDv4 NameBase file.
+/// @param filename: the full path of the file to open.
+/// @param nb:       reference to the object where the names will be stored.
+/// @returns OK if successful or an error code.
 template <typename TCont, typename TFreq>
 errorT namefileWrite(const char* filename, const TCont& names_ids,
                      const TFreq& freq) {
@@ -210,7 +169,20 @@ errorT namefileWrite(const char* filename, const TCont& names_ids,
 			const char* name = it.first;
 			idNumberT id = it.second;
 
-			ASSERT(prevName == nullptr || assert_sorted(prevName, name));
+			// *** Compatibility ***
+			// Older code used a custom StrTree class with a peculiar sorting:
+			// - the first char was interpreted as an unsigned char;
+			// - the remaining part was compared with strComapare(),
+			//   which converts the chars to ints, and is not consistent with
+			//   the standard function strcmp().
+			// The old StrTree class did also have unpredictable behaviors when
+			// fed with names not sorted according to that criteria, for example
+			// it could create Namebase objects with duplicate entries.
+			// ***
+			ASSERT(prevName == nullptr ||
+			       static_cast<uint>(*prevName) < static_cast<uint>(*name) ||
+			       (static_cast<uint>(*prevName) == static_cast<uint>(*name) &&
+			        strCompare(prevName, name) < 0));
 
 			// write idNumber in 2 bytes if possible, otherwise 3.
 			if (numNames >= 65536) {
@@ -245,16 +217,108 @@ errorT namefileWrite(const char* filename, const TCont& names_ids,
 	return OK;
 }
 
-} // namespace
-
 /**
- * Decode SCID4 (or SCID3) data into an IndexEntry object.
- * @param buf_it:  pointer to the buffer containing the data
- *                 (should contain INDEX_ENTRY_SIZE chars)
- * @param version: 400 for SCID4 or 300 for SCID3.
- * @param ie:      pointer to the IndexEntry object where the data will be
- *                 stored.
+ * An Index file starts with an header of 182 bytes containing:
+ * - index_magic (8 bytes): identifies the file format.
+ * - version (2 bytes): 300 or 400
+ * - baseType (4 bytes): e.g. tournament, theory, etc.
+ * - numGames (3 bytes): total number of games contained into the index.
+ * - autoLoad (3 bytes): number of the game to load at start
+ *                       (0=none, 1=1st, >numGames=last).
+ * - description (108 bytes): a null-terminated string describing the database.
+ * - flag1 description (9 bytes): a null-terminated string describing flag1.
+ * - flag2 description (9 bytes): a null-terminated string describing flag2.
+ * - flag3 description (9 bytes): a null-terminated string describing flag3.
+ * - flag4 description (9 bytes): a null-terminated string describing flag4.
+ * - flag5 description (9 bytes): a null-terminated string describing flag5.
+ * - flag6 description (9 bytes): a null-terminated string describing flag6.
  */
+constexpr char INDEX_MAGIC[8] = "Scid.si";
+constexpr size_t SCID_DESC_LENGTH = 107;
+constexpr size_t CUSTOM_FLAG_MAX = 6;
+constexpr size_t CUSTOM_FLAG_DESC_LENGTH = 8;
+constexpr int INDEX_ENTRY_SIZE = 47;
+constexpr int OLD_INDEX_ENTRY_SIZE = 46;
+// Header on-disk size: magic=8, version=2, numGames=3, baseType=4, autoLoad=3
+// Description length = 111 bytes including trailing '\0'.
+// Custom flag desc length = 9 bytes including trailing '\0'.
+// So total is 128 bytes + 9*6 = 182 bytes for the whole header.
+constexpr size_t INDEX_HEADER_SIZE = 8 + 2 + 3 + 4 + 3 + SCID_DESC_LENGTH + 1 +
+                                     (CUSTOM_FLAG_DESC_LENGTH + 1) *
+                                         CUSTOM_FLAG_MAX;
+
+/// Read the header section of a SCIDv4 Index file into memory.
+/// @param indexFile: file handle positioned at the start of the Index file.
+/// @param fMode:     a valid file mode.
+/// @param header:    reference to the object where the data will be stored.
+/// @returns OK if successful or an error code.
+template <typename FileT, typename HeaderT>
+std::pair<errorT, gamenumT> readIndexHeader(FileT& indexFile, HeaderT& header) {
+	char magic[8];
+	indexFile.sgetn(magic, 8);
+	if (!std::equal(std::begin(magic), std::end(magic), std::begin(INDEX_MAGIC),
+	                std::end(INDEX_MAGIC))) {
+		return {ERROR_BadMagic, {}};
+	}
+
+	header.version = indexFile.ReadTwoBytes();
+	header.baseType = indexFile.ReadFourBytes();
+	auto numGames = indexFile.ReadThreeBytes();
+	header.autoLoad = indexFile.ReadThreeBytes();
+	char desc[SCID_DESC_LENGTH + 1];
+	indexFile.sgetn(desc, SCID_DESC_LENGTH + 1);
+	header.description.assign(desc,
+	                          std::find(desc, desc + SCID_DESC_LENGTH, '\0'));
+	if (header.version >= 400) {
+		for (size_t i = 0; i < CUSTOM_FLAG_MAX; i++) {
+			char buf[CUSTOM_FLAG_DESC_LENGTH + 1];
+			indexFile.sgetn(buf, CUSTOM_FLAG_DESC_LENGTH + 1);
+			header.flagDesc[i].assign(
+			    buf, std::find(buf, buf + CUSTOM_FLAG_DESC_LENGTH, '\0'));
+		}
+	}
+	return {OK, numGames};
+}
+
+/// Write the header section of a SCIDv4 Index file.
+/// @param indexFile: file handle of the Index file.
+/// @param header:    reference to the object containing the header data.
+/// @returns OK if successful or an error code.
+template <typename FileT, typename HeaderT>
+errorT writeIndexHeader(FileT& indexFile, HeaderT const& Header,
+                        gamenumT nGames) {
+	if (indexFile.pubseekpos(0) != std::streampos(0))
+		return ERROR_FileWrite;
+
+	std::streamsize n = 0;
+	n += indexFile.sputn(INDEX_MAGIC, 8);
+	n += indexFile.WriteTwoBytes(Header.version);
+	n += indexFile.WriteFourBytes(Header.baseType);
+	n += indexFile.WriteThreeBytes(nGames);
+	n += indexFile.WriteThreeBytes(Header.autoLoad);
+	char desc[SCID_DESC_LENGTH + 1] = {};
+	std::copy_n(Header.description.data(),
+	            std::min(Header.description.size(), SCID_DESC_LENGTH), desc);
+	n += indexFile.sputn(desc, SCID_DESC_LENGTH + 1);
+	for (auto const& flagDesc : Header.flagDesc) {
+		char buf[CUSTOM_FLAG_DESC_LENGTH + 1] = {};
+		std::copy_n(flagDesc.data(),
+		            std::min(flagDesc.size(), CUSTOM_FLAG_DESC_LENGTH), buf);
+
+		n += indexFile.sputn(buf, CUSTOM_FLAG_DESC_LENGTH + 1);
+	}
+	if (n != INDEX_HEADER_SIZE || indexFile.pubsync() == -1)
+		return ERROR_FileWrite;
+
+	return OK;
+}
+
+/// Decode SCID4 (or SCID3) data into an IndexEntry object.
+/// @param buf_it:  pointer to the buffer containing the data
+///                 (should contain INDEX_ENTRY_SIZE chars)
+/// @param version: 400 for SCID4 or 300 for SCID3.
+/// @param ie:      pointer to the IndexEntry object where the data will be
+///                 stored.
 void decodeIndexEntry(const char* buf_it, versionT version, IndexEntry* ie) {
 	auto ReadOneByte = [&buf_it]() {
 		uint8_t res = *buf_it++;
@@ -271,6 +335,8 @@ void decodeIndexEntry(const char* buf_it, versionT version, IndexEntry* ie) {
 		return res;
 	};
 
+	ie->setChessStd();
+
 	// Offset of the gamefile record (32 bits).
 	ie->SetOffset(ReadFourBytes());
 
@@ -353,20 +419,123 @@ void decodeIndexEntry(const char* buf_it, versionT version, IndexEntry* ie) {
 	uint16_t NumHalfMoves = ReadOneByte();
 	uint16_t pawnData0 = ReadOneByte();
 	ie->SetNumHalfMoves(((pawnData0 & 0xC0) << 2) | NumHalfMoves);
-	byte* pb = ie->GetHomePawnData();
-	*pb++ = pawnData0 & 0x3F;
-	std::copy_n(buf_it, HPSIG_SIZE - 1, pb);
+	ie->SetHomePawnData(pawnData0 & 0x3F,
+	                    reinterpret_cast<const unsigned char*>(buf_it));
 }
 
+/// Enccode an IndexEntry to SCID4 format.
+/// @param buf_it:  pointer to the buffer where the data would be stored
+///                 (should be able to contain at least INDEX_ENTRY_SIZE chars)
+void encodeIndexEntry(const IndexEntry* ie, char* buf_it) {
+	auto WriteOneByte = [&buf_it](uint8_t v) { *buf_it++ = v; };
+	auto WriteTwoBytes = [&WriteOneByte](uint16_t v) {
+		WriteOneByte(static_cast<uint8_t>(v >> 8));
+		WriteOneByte(static_cast<uint8_t>(v));
+	};
+	auto WriteFourBytes = [&WriteTwoBytes](uint32_t v) {
+		WriteTwoBytes(static_cast<uint16_t>(v >> 16));
+		WriteTwoBytes(static_cast<uint16_t>(v));
+	};
+
+	ASSERT(ie->GetOffset() < (1ULL << 32));
+	WriteFourBytes(static_cast<uint32_t>(ie->GetOffset()));
+
+	ASSERT(ie->GetLength() < (1ULL << 17));
+	WriteTwoBytes(static_cast<uint16_t>(ie->GetLength()));
+	uint8_t len_flags = static_cast<uint8_t>(ie->GetLength() >> 9) & 0x80;
+	len_flags |= static_cast<uint8_t>(ie->GetRawFlags() >> 16) & 0x3F;
+	WriteOneByte(len_flags);
+	WriteTwoBytes(static_cast<uint16_t>(ie->GetRawFlags()));
+
+	// WhiteID and BlackID are 20-bit values, EventID and SiteID are
+	// 19-bit values, and RoundID is an 18-bit value.
+	// WhiteID high 4 bits = bits 4-7 of WhiteBlack_High.
+	// BlackID high 4 bits = bits 0-3 of WhiteBlack_High.
+	// EventID high 3 bits = bits 5-7 of EventSiteRnd_high.
+	// SiteID  high 3 bits = bits 2-4 of EventSiteRnd_high.
+	// RoundID high 2 bits = bits 0-1 of EventSiteRnd_high.
+	ASSERT(std::max(ie->GetWhite(), ie->GetBlack()) < (1ULL << 20));
+	uint32_t WhiteID_Low = ie->GetWhite();
+	uint32_t BlackID_Low = ie->GetBlack();
+	uint32_t WhiteBlack_High = (WhiteID_Low & 0x0F0000) >> 12;
+	WhiteBlack_High |= (BlackID_Low & 0x0F0000) >> 16;
+	WriteOneByte(static_cast<uint8_t>(WhiteBlack_High));
+	WriteTwoBytes(static_cast<uint16_t>(WhiteID_Low));
+	WriteTwoBytes(static_cast<uint16_t>(BlackID_Low));
+
+	ASSERT(std::max(ie->GetEvent(), ie->GetSite()) < (1ULL << 19));
+	ASSERT(ie->GetRound() < (1ULL << 18));
+	uint32_t EventID_Low = ie->GetEvent();
+	uint32_t SiteID_Low = ie->GetSite();
+	uint32_t RoundID_Low = ie->GetRound();
+	uint32_t EventSiteRnd_High = (EventID_Low & 0x070000) >> 11;
+	EventSiteRnd_High |= (SiteID_Low & 0x070000) >> 14;
+	EventSiteRnd_High |= (RoundID_Low & 0x030000) >> 16;
+	WriteOneByte(static_cast<uint8_t>(EventSiteRnd_High));
+	WriteTwoBytes(static_cast<uint16_t>(EventID_Low));
+	WriteTwoBytes(static_cast<uint16_t>(SiteID_Low));
+	WriteTwoBytes(static_cast<uint16_t>(RoundID_Low));
+
+	uint16_t varCounts = ie->GetRaw4bitsCounts();
+	varCounts |= static_cast<uint16_t>(ie->GetResult() & 0x0F) << 12;
+	WriteTwoBytes(varCounts);
+
+	WriteTwoBytes(ie->GetEcoCode());
+
+	// Due to a compact encoding format, the EventDate
+	// must be within a few years of the Date.
+	uint32_t date = ie->GetDate() & 0xFFFFF;
+	uint32_t edate = ie->GetEventDate();
+	uint32_t eyear = date_GetYear(edate);
+	uint32_t dyear = date_GetYear(date);
+	if ((eyear + 3) < dyear || eyear > (dyear + 3)) {
+		edate = ZERO_DATE;
+	} else {
+		eyear = (eyear + 4 - dyear) & 7;
+		edate = (eyear << 9) | (date_GetMonth(edate) << 5) | date_GetDay(edate);
+	}
+	WriteFourBytes((edate << 20) | date);
+
+	// Elo ratings and rating types: 2 bytes each.
+	uint16_t wElo = std::min(MAX_ELO, ie->GetWhiteElo());
+	wElo |= static_cast<uint16_t>(ie->GetWhiteRatingType()) << 12;
+	uint16_t bElo = std::min(MAX_ELO, ie->GetBlackElo());
+	bElo |= static_cast<uint16_t>(ie->GetBlackRatingType()) << 12;
+	WriteTwoBytes(wElo);
+	WriteTwoBytes(bElo);
+
+	ASSERT(ie->GetFinalMatSig() < (1ULL << 24));
+	ASSERT(ie->GetStoredLineCode() < (1ULL << 8));
+	uint32_t FinalMatSig = ie->GetFinalMatSig();
+	FinalMatSig |= static_cast<uint32_t>(ie->GetStoredLineCode()) << 24;
+	WriteFourBytes(FinalMatSig);
+
+	// The first byte of HomePawnData has high bits of the NumHalfMoves
+	// counter in its top two bits:
+	uint16_t nMoves = ie->GetNumHalfMoves();
+	ASSERT(nMoves < (1ULL << 10));
+	WriteOneByte(static_cast<uint8_t>(nMoves));
+	uint8_t pawnData0 = static_cast<uint8_t>(nMoves >> 8) << 6;
+
+	// Write the 9-byte homePawnData array:
+	const byte* pb = ie->GetHomePawnData();
+	pawnData0 |= *pb & 0x3F;
+	WriteOneByte(pawnData0);
+	std::copy(pb + 1, pb + HPSIG_SIZE, buf_it);
+}
+
+} // namespace
+
 errorT CodecSCID4::dyn_open(fileModeT fMode, const char* filename,
                             const Progress& progress, Index* idx,
                             NameBase* nb) {
-	if (filename == nullptr || idx == nullptr || nb == nullptr)
+	if (fMode == FMODE_WriteOnly || !filename || !idx || !nb)
 		return ERROR;
 	if (*filename == '\0')
 		return ERROR_FileOpen;
 
 	idx_ = idx;
+	idx_->Init();
 	nb_ = nb;
 	filenames_.resize(3);
 	filenames_[0] = std::string(filename) + ".si4";
@@ -377,32 +546,65 @@ errorT CodecSCID4::dyn_open(fileModeT fMode, const char* filename,
 	if (err != OK)
 		return err;
 
+	const char* indexFilename = filenames_[0].c_str();
 	if (fMode == FMODE_Create) {
-		err = idx->Create(filename);
+		// Check that the file does not exists
+		if (idxfile_.Open(indexFilename, FMODE_ReadOnly) == OK)
+			err = ERROR_FileOpen;
+
+		if (err == OK)
+			err = idxfile_.Open(indexFilename, FMODE_Create);
+
+		if (err == OK)
+			err = writeIndexHeader(idxfile_, header_, idx_->GetNumGames());
+
 		if (err == OK) {
 			err = namefileWrite(filenames_[1].c_str(), nb_->getNames(),
-			                    idx_->calcNameFreq(*nb_));
+			                    nb->calcNameFreq(*idx_));
 		}
 	} else {
-		err = idx->Open(filename, fMode);
-		if (err == OK)
-			err = namefileRead(filenames_[1].c_str(), fMode, *nb_);
-		if (err == OK)
-			err = readIndex(progress);
+		if (auto err = namefileRead(filenames_[1].c_str(), fMode, *nb_))
+			return err;
+
+		if (auto err = idxfile_.Open(indexFilename, fMode))
+			return err;
+
+		auto [errHeader, nGames] = readIndexHeader(idxfile_, header_);
+		if (errHeader)
+			return errHeader;
+
+		constexpr versionT SCID_OLDEST_VERSION = 300; // Oldest readable version
+		if (header_.version < SCID_OLDEST_VERSION ||
+		    header_.version > SCID_VERSION)
+			return ERROR_FileVersion;
+
+		if (header_.version != SCID_VERSION && fMode != FMODE_ReadOnly)
+			return ERROR_FileMode; // Old versions must be opened readonly
+
+		err = readIndex(nGames, progress);
 	}
 
 	return err;
 }
 
 errorT CodecSCID4::flush() {
-	errorT err = idx_->flush();
+	seqWrite_ = 0;
+	errorT errHeader = OK;
+	if (header_.dirty) {
+		errHeader = writeIndexHeader(idxfile_, header_, idx_->GetNumGames());
+		if (errHeader == OK)
+			header_.dirty = false;
+	}
+	errorT errSync = (idxfile_.pubsync() != 0) ? ERROR_FileWrite : OK;
+	errorT err = (errHeader == OK) ? errSync : errHeader;
+
 	if (err == OK) {
 		// *** Compatibility ***
 		// Even if name's frequency is no longer used, it's necessary to
 		// keep the compatibility with older Scid versions, forcing a
 		// recalculation.
 		err = namefileWrite(filenames_[1].c_str(), nb_->getNames(),
-		                    idx_->calcNameFreq(*nb_));
+		                    nb_->calcNameFreq(*idx_));
 	}
 	errorT errGfile = (gfile_.pubsync() == 0) ? OK : ERROR_FileWrite;
 
@@ -415,7 +617,7 @@ errorT CodecSCID4::flush() {
  * @param progress: a Progress object used for GUI communications.
  * @returns OK if successful or an error code.
  */
-inline errorT CodecSCID4::readIndex(const Progress& progress) {
+errorT CodecSCID4::readIndex(gamenumT nGames, Progress const& progress) {
 	gamenumT nUnknowIDs = 0;
 	idNumberT maxID[NUM_NAME_TYPES];
 	for (nameT nt = NAME_PLAYER; nt < NUM_NAME_TYPES; nt++) {
@@ -460,13 +662,10 @@ inline errorT CodecSCID4::readIndex(const Progress& progress) {
 		return true;
 	};
 
-	auto idxFile = idx_->FilePtr;
-	auto version = idx_->Header.version;
-	auto nGames = idx_->GetNumGames();
 	idx_->entries_.resize(nGames);
-
-	auto nBytes = (version < 400) ? OLD_INDEX_ENTRY_SIZE : INDEX_ENTRY_SIZE;
-	for (gamenumT gNum = 0; idxFile->sgetc() != EOF; ++gNum) {
+	const auto nBytes = (header_.version < 400) ? OLD_INDEX_ENTRY_SIZE
+	                                            : INDEX_ENTRY_SIZE;
+	for (gamenumT gNum = 0; idxfile_.sgetc() != EOF; ++gNum) {
 		if (gNum == nGames)
 			return ERROR_CorruptData;
 
@@ -476,23 +675,68 @@ inline errorT CodecSCID4::readIndex(const Progress& progress) {
 		}
 
 		char buf[INDEX_ENTRY_SIZE];
-		if (idxFile->sgetn(buf, nBytes) != nBytes)
+		if (idxfile_.sgetn(buf, nBytes) != nBytes)
 			return ERROR_FileRead;
 
-		IndexEntry* ie = idx_->FetchEntry(gNum);
-		decodeIndexEntry(buf, version, ie);
+		IndexEntry& ie = idx_->entries_[gNum];
+		decodeIndexEntry(buf, header_.version, &ie);
 
-		if (!validateNameIDs(ie))
+		if (!validateNameIDs(&ie))
 			return ERROR_CorruptData;
-
-		nb_->AddElo(ie->GetWhite(), ie->GetWhiteElo());
-		nb_->AddElo(ie->GetBlack(), ie->GetBlackElo());
 	}
 	progress.report(1, 1);
 
-	if (nGames != idx_->GetNumGames())
-		return ERROR_FileRead;
-
 	idx_->nInvalidNameId_ = nUnknowIDs;
 	return (nUnknowIDs == 0) ? OK : ERROR_NameDataLoss;
 }
+
+errorT CodecSCID4::writeEntry(const IndexEntry& ie, gamenumT gnum) {
+	if (seqWrite_ == 0 || (gnum != seqWrite_ + 1)) {
+		std::streampos pos = gnum;
+		pos = pos * INDEX_ENTRY_SIZE + INDEX_HEADER_SIZE;
+		if (idxfile_.pubseekpos(pos) != pos) {
+			seqWrite_ = 0;
+			return ERROR_FileWrite;
+		}
+	}
+	char buf[INDEX_ENTRY_SIZE];
+	encodeIndexEntry(&ie, buf);
+	errorT res = idxfile_.sputn(buf, INDEX_ENTRY_SIZE) == INDEX_ENTRY_SIZE
+	                 ? OK
+	                 : ERROR_FileWrite;
+
+	seqWrite_ = (res == OK) ? gnum : 0;
+	return res;
+}
+
+errorT CodecSCID4::setExtraInfo(const char* tagname, const char* new_value) {
+	if (std::strcmp(tagname, "type") == 0) {
+		header_.baseType = strGetUnsigned(new_value);
+
+	} else if (std::strcmp(tagname, "description") == 0) {
+		header_.description = new_value;
+		if (header_.description.size() > SCID_DESC_LENGTH)
+			header_.description.resize(SCID_DESC_LENGTH);
+
+	} else if (std::strcmp(tagname, "autoload") == 0) {
+		header_.autoLoad = strGetUnsigned(new_value);
+
+	} else {
+		auto len = std::strlen(tagname);
+		if (len != 5 || !std::equal(tagname, tagname + 4, "flag"))
+			return ERROR_CodecUnsupFeat;
+
+		uint flag = IndexEntry::CharToFlag(tagname[4]);
+		if (flag < IndexEntry::IDX_FLAG_CUSTOM1 ||
+		    flag > IndexEntry::IDX_FLAG_CUSTOM6)
+			return ERROR_CodecUnsupFeat;
+
+		const auto idx = flag - IndexEntry::IDX_FLAG_CUSTOM1;
+		header_.flagDesc[idx] = new_value;
+		if (header_.flagDesc[idx].size() > CUSTOM_FLAG_DESC_LENGTH)
+			header_.flagDesc[idx].resize(CUSTOM_FLAG_DESC_LENGTH);
+	}
+
+	header_.dirty = true;
+	return OK;
+}
