@@ -16,11 +16,15 @@
 #include "engine.h"
 #include "recog.h"
 #include "sqmove.h"
-#include "sqlist.h"
+#include <algorithm>
 
 // The Engine class implements the Scid built-in chess engine.
 // See engine.h for details.
 
+// sqDir[][]: Array listing the direction between any two squares.
+//    For example, sqDir[A1][B2] == UP_RIGHT, and sqDir[A1][C2] == NULL_DIR.
+extern directionT sqDir[66][66];
+
 
 // Evaluation constants:
 
@@ -54,7 +58,7 @@ static const int KingTrapsRook     =  35;  // E.g. King on f1, Rook on h1
 static const int DoubledPawn       =   8;
 static const int IsolatedPawn      =  16;
 static const int BackwardPawn      =  10;  // Pawn at base of pawn chain.
-static const int DispersedPawn     =  10;  // Not in pawn chain/duo. (Unused)
+// static const int DispersedPawn     =  10;  // Not in pawn chain/duo. (Unused)
 static const int BlockedHomePawn   =  15;  // Blocked pawn on d2/e2/d7/e7.
 static const int BishopPair        =  25;  // Pair of bishops.
 static const int BishopEyesKing    =  12;  // Bishop targets enemy king.
@@ -229,7 +233,7 @@ inline int
 Engine::PieceValue (pieceT piece)
 {
     return pieceValues[piece_Type(piece)];
-};
+}
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // isOutpost
@@ -293,7 +297,7 @@ static uint nScoreFull  = 0;
 inline int
 Engine::ScoreWhiteMaterial (void)
 {
-    byte * pieceCount = Pos.GetMaterial();
+    const byte* pieceCount = Pos.GetMaterial();
     return  pieceCount[WQ] * QueenValue   +  pieceCount[WR] * RookValue
          +  pieceCount[WB] * BishopValue  +  pieceCount[WN] * KnightValue
          +  pieceCount[WP] * PawnValue;
@@ -302,7 +306,7 @@ Engine::ScoreWhiteMaterial (void)
 inline int
 Engine::ScoreBlackMaterial (void)
 {
-    byte * pieceCount = Pos.GetMaterial();
+    const byte* pieceCount = Pos.GetMaterial();
     return  pieceCount[BQ] * QueenValue   +  pieceCount[BR] * RookValue
          +  pieceCount[BB] * BishopValue  +  pieceCount[BN] * KnightValue
          +  pieceCount[BP] * PawnValue;
@@ -768,13 +772,10 @@ Engine::ScorePawnStructure (pawnTableEntryT * pawnEntry)
         pawnFiles[BLACK][f+1] = Pos.FyleCount (BP, f);
     }
 
-    for (colorT c = WHITE; c <= BLACK; c++) {
-        pieceT pawn = piece_Make (c, PAWN);
-        uint npawns = Pos.PieceCount(pawn);
-        SquareList sqlist;
-        Pos.GetSquares (pawn, &sqlist);
-        for (uint i = 0; i < npawns; i++) {
-            squareT sq = sqlist.Get(i);
+    for (squareT sq = A1; sq <= H8; ++sq) {
+        pieceT piece = Pos.GetPiece(sq);
+        if (piece_Type(piece) == PAWN) {
+            colorT c = piece_Color_NotEmpty(piece);
             squareT wsq = (c == WHITE) ? sq : square_FlipRank(sq);
             squareT bonusSq = square_FlipRank(wsq);
             pawnScore[c] += PawnSquare[bonusSq];
@@ -919,50 +920,11 @@ Engine::IsGettingMatedScore (int score)
     return (score < (-Infinity + (int)ENGINE_MAX_PLY));
 }
 
-//~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-// Engine::PlayMove
-//   Play the specified move, not in a search.
-void
-Engine::PlayMove (simpleMoveT * sm) {
-    PushRepeat(&RootPos);
-    RootPos.DoSimpleMove(sm);
-    Pos.DoSimpleMove(sm);
-#ifdef WINCE
-    simpleMoveT * newMove = (simpleMoveT *) my_Tcl_Alloc(sizeof(simpleMoveT));
-#else
-    simpleMoveT * newMove = new simpleMoveT;
-#endif
-    *newMove = *sm;
-    GameMoves[NumGameMoves] = newMove;
-    NumGameMoves++;
-    // Change the transposition table sequence number:
-    TranTableSequence++;
-}
-
-//~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-// Engine::RetractMove
-//    Take back a move played in the game.
-void
-Engine::RetractMove (void)
-{
-    if (NumGameMoves == 0) { return; }
-    PopRepeat();
-    NumGameMoves--;
-    RootPos.UndoSimpleMove(GameMoves[NumGameMoves]);
-    Pos.UndoSimpleMove(GameMoves[NumGameMoves]);
-#ifdef WINCE
-    my_Tcl_Free((char *)GameMoves);
-#else
-    delete GameMoves[NumGameMoves];
-#endif
-    TranTableSequence--;
-}
-
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // Engine::DoMove
 //   Make the specified move in a search.
 inline void
-Engine::DoMove (simpleMoveT * sm) {
+Engine::DoMove (ScoredMove * sm) {
     PushRepeat(&Pos);
     Pos.DoSimpleMove(sm);
     Ply++;
@@ -972,7 +934,7 @@ Engine::DoMove (simpleMoveT * sm) {
 // Engine::UndoMove
 //    Take back the specified move in a search.
 inline void
-Engine::UndoMove (simpleMoveT * sm) {
+Engine::UndoMove (ScoredMove * sm) {
     PopRepeat();
     Pos.UndoSimpleMove(sm);
     Ply--;
@@ -1014,7 +976,7 @@ Engine::NoMatingMaterial (void)
     // Check for K vs K, K+N vs K, and K+B vs K:
     if (npieces <= 2) { return true; }
     if (npieces == 3) {
-        byte * material = Pos.GetMaterial();
+        const byte* material = Pos.GetMaterial();
         if (material[WB] == 1  ||  material[WN] == 1) { return true; }
         if (material[BB] == 1  ||  material[BN] == 1) { return true; }
     }
@@ -1160,7 +1122,7 @@ inline byte tte_Castling (transTableEntryT * tte)
 inline bool tte_IsOnlyMove (transTableEntryT * tte)
 {  return (((tte->flags >> 2) & 1) == 1); }
 
-inline void tte_SetBestMove (transTableEntryT * tte, simpleMoveT * bestMove)
+inline void tte_SetBestMove (transTableEntryT * tte, ScoredMove * bestMove)
 {
     ASSERT (bestMove->from <= H8  &&  bestMove->to <= H8);
     ushort bm = bestMove->from;
@@ -1169,7 +1131,7 @@ inline void tte_SetBestMove (transTableEntryT * tte, simpleMoveT * bestMove)
     tte->bestMove = bm;
 }
 
-inline void tte_GetBestMove (transTableEntryT * tte, simpleMoveT * bestMove)
+inline void tte_GetBestMove (transTableEntryT * tte, ScoredMove * bestMove)
 {
     ushort bm = tte->bestMove;
     bestMove->promote = bm & 15; bm >>= 4;
@@ -1182,7 +1144,7 @@ inline void tte_GetBestMove (transTableEntryT * tte, simpleMoveT * bestMove)
 //   Store the score for the current position in the transposition table.
 void
 Engine::StoreHash (int depth, scoreFlagT ttFlag, int score,
-                   simpleMoveT * bestMove, bool isOnlyMove)
+                   ScoredMove * bestMove, bool isOnlyMove)
 {
     if (TranTableSize == 0) { return; }
     ASSERT (ttFlag <= SCORE_UPPER);
@@ -1275,7 +1237,7 @@ Engine::StoreHash (int depth, scoreFlagT ttFlag, int score,
 //    Probe the transposition table for the current position.
 //
 scoreFlagT
-Engine::ProbeHash (int depth, int * score, simpleMoveT * bestMove, bool * isOnlyMove)
+Engine::ProbeHash (int depth, int * score, ScoredMove * bestMove, bool * isOnlyMove)
 {
     // Clear the best move:
     if (bestMove != NULL) { bestMove->from = bestMove->to = NULL_SQUARE; }
@@ -1303,7 +1265,7 @@ Engine::ProbeHash (int depth, int * score, simpleMoveT * bestMove, bool * isOnly
     // sufficient, because it will be useful for move ordering anyway.
     if (bestMove != NULL  &&  ttEntry->bestMove != 0) {
         tte_GetBestMove (ttEntry, bestMove);
-        pieceT * board = Pos.GetBoard();
+        const pieceT* board = Pos.GetBoard();
         bestMove->movingPiece = board[bestMove->from];
     }
     if (isOnlyMove != NULL) {
@@ -1331,16 +1293,6 @@ static uint nFailHighFirstMove = 0;
 void
 Engine::SetPosition (Position * newpos)
 {
-    // Delete old game moves:
-    for (uint i=0; i < NumGameMoves; i++) {
-#ifdef WINCE
-        my_Tcl_Free((char *) GameMoves[i]);
-#else
-        delete GameMoves[i];
-#endif
-    }
-    NumGameMoves = 0;
-
     // Set the position:
     if (newpos == NULL) {
         RootPos.StdStart();
@@ -1402,12 +1354,12 @@ Engine::Think (MoveList * mlist)
     // Sort the root move list by quiescent evaluation to get a
     // reasonably good initial move order:
     for (uint i=0; i < mlist->Size(); i++) {
-        simpleMoveT * sm = mlist->Get(i);
+        auto sm = mlist->Get(i);
         DoMove(sm);
         sm->score = -Quiesce (-Infinity, Infinity);
         UndoMove(sm);
     }
-    mlist->Sort();
+    std::sort(mlist->begin(), mlist->end());
 
     // Check for an easy move, one that scores more than two pawns
     // better than any alternative:
@@ -1479,14 +1431,14 @@ Engine::Think (MoveList * mlist)
         PrintPV (depth, bestScore, ">>>");
 
         // Stop if Only a few moves OR checkmate has been found - but not too soon:
-        if (mlist->Size() <= depth || depth >= 5  &&  IsMatingScore (bestScore)) { break; }
+        if (mlist->Size() <= depth || (depth >= 5 && IsMatingScore(bestScore))) { break; }
 
         // Make sure the first move in the list remains there by
         // giving it a huge node count for its move ordering score:
         mlist->Get(0)->score = 1 << 30;
 
         // Sort the move list based on node counts from this iteration:
-        mlist->Sort();
+        std::sort(mlist->begin(), mlist->end());
     }
 
     return bestScore;
@@ -1514,11 +1466,11 @@ Engine::SearchRoot (int depth, int alpha, int beta, MoveList * mlist)
     int bestScore = -Infinity - 1;
 
     for (uint movenum=0; movenum < mlist->Size(); movenum++) {
-        simpleMoveT * sm = mlist->Get(movenum);
+        auto sm = mlist->Get(movenum);
         uint oldNodeCount = NodeCount;
         // Make this move and search it:
         DoMove (sm);
-        InCheck[Ply] = Pos.IsKingInCheck (sm);
+        InCheck[Ply] = Pos.IsKingInCheck (*sm);
 #define PVS_SEARCH
 #ifdef PVS_SEARCH
         int score = alpha;
@@ -1555,13 +1507,19 @@ Engine::SearchRoot (int depth, int alpha, int beta, MoveList * mlist)
             UpdatePV (sm);
             PrintPV (depth, bestScore);
             StoreHash (depth, SCORE_EXACT, score, sm, isOnlyMove);
-            mlist->MoveToFront (movenum);
+            std::rotate(mlist->begin(), mlist->begin() + movenum,
+                        mlist->begin() + movenum + 1);
             if (movenum > 0) { EasyMove = false; }
         }
     }
     return bestScore;
 }
 
+static bool isLegalMove(Position const& pos, simpleMoveT const& sm) {
+    return pos.IsLegalMove(sm.from, sm.to, sm.promote) &&
+           sm.movingPiece == pos.GetPiece(sm.from);
+}
+
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // Engine::Search
 //   Internal Search routine, used at every depth except
@@ -1608,7 +1566,7 @@ Engine::Search (int depth, int alpha, int beta, bool tryNullMove)
 
     // Probe the hash table:
     int hashscore = alpha;
-    simpleMoveT hashmove;
+    auto hashmove = ScoredMove();
     bool isOnlyMove = 0;
     scoreFlagT hashflag = ProbeHash (depth, &hashscore, &hashmove, &isOnlyMove);
 
@@ -1687,10 +1645,10 @@ Engine::Search (int depth, int alpha, int beta, bool tryNullMove)
 
     MoveList mlist;
     bool gotHashMove;
-    if (Pos.IsLegalMove (&hashmove)) {
+    if (isLegalMove(Pos, hashmove)) {
         gotHashMove = true;
         // For now, we only add the hash move to the move list.
-        mlist.Add (&hashmove);
+        mlist.push_back(hashmove);
         mlist.Get(0)->score = ENGINE_HASH_SCORE;
     } else {
         // No hash table move, so generate and score all the moves now.
@@ -1710,8 +1668,8 @@ Engine::Search (int depth, int alpha, int beta, bool tryNullMove)
     // Search each move:
     for (uint movenum = 0; movenum < mlist.Size(); movenum++) {
         // Find the highest-scoring remaining move:
-        mlist.FindBest (movenum);
-        simpleMoveT * sm = mlist.Get (movenum);
+        MoveList::iterator sm = std::min_element(mlist.begin() + movenum, mlist.end());
+        std::iter_swap(mlist.begin() + movenum, sm);
 
         // Move-specific extensions:
         int extensions = baseExtensions;
@@ -1730,7 +1688,7 @@ Engine::Search (int depth, int alpha, int beta, bool tryNullMove)
 
         // Make this move and remember if it gives check:
         DoMove (sm);
-        InCheck[Ply] = Pos.IsKingInCheck (sm);
+        InCheck[Ply] = Pos.IsKingInCheck (*sm);
 
         // Simple futility pruning. Note that pruning with depth of two
         // remaining is risky, but seems to work well enough in practise.
@@ -1814,9 +1772,14 @@ Engine::Search (int depth, int alpha, int beta, bool tryNullMove)
             mlist.Clear();
             Pos.GenerateMoves (&mlist, EMPTY, GEN_ALL_MOVES, InCheck[Ply]);
             ScoreMoves (&mlist);
-            int hashIndex = mlist.Find (&hashmove);
-            if (hashIndex >= 0) {
-                mlist.SwapWithFirst (hashIndex);
+            MoveList::iterator hm = std::find_if(
+                mlist.begin(), mlist.end(), [&](auto const& move) {
+                    return move.from == hashmove.from &&
+                           move.to == hashmove.to &&
+                           move.promote == hashmove.promote;
+                });
+            if (hm != mlist.end()) {
+                std::iter_swap(mlist.begin(), hm);
             } else {
                 // The hash table move was legal, but not found in the
                 // move list -- Bizarre!
@@ -1840,7 +1803,7 @@ Engine::Search (int depth, int alpha, int beta, bool tryNullMove)
     } else {
         // Update the transposition table with the best move:
         ASSERT (bestMoveIndex >= 0);
-        simpleMoveT * bestMove = mlist.Get(bestMoveIndex);
+        auto bestMove = mlist.Get(bestMoveIndex);
         IncHistoryValue (bestMove, depth * depth);
         // Should we also add this as a killer move? Possibly not,
         // since it was not good enough to cause a beta cutoff.
@@ -1900,7 +1863,7 @@ Engine::Quiesce (int alpha, int beta)
     MoveList mlist;
     Pos.GenerateMoves (&mlist, GEN_CAPTURES);
     for (uint m=0; m < mlist.Size(); m++) {
-        simpleMoveT * sm = mlist.Get(m);
+        auto sm = mlist.Get(m);
         sm->score = SEE (sm->from, sm->to);
     }
 
@@ -1909,8 +1872,8 @@ Engine::Quiesce (int alpha, int beta)
 
     for (uint i = 0; i < mlist.Size(); i++) {
         // Find the highest-scoring remaining move, make it and search:
-        mlist.FindBest(i);
-        simpleMoveT * sm = mlist.Get(i);
+        MoveList::iterator sm = std::min_element(mlist.begin() + i, mlist.end());
+        std::iter_swap(mlist.begin() + i, sm);
         pieceT promote = piece_Type(sm->promote);
 
         // Skip underpromotions:
@@ -2228,7 +2191,7 @@ void
 Engine::ScoreMoves (MoveList * mlist)
 {
     for (uint i = 0; i < mlist->Size(); i++) {
-        simpleMoveT * sm = mlist->Get(i);
+        auto sm = mlist->Get(i);
         if (sm->capturedPiece != EMPTY  ||  sm->promote != EMPTY) {
             int see = SEE (sm->from, sm->to);
             if (see >= 0) {
@@ -2286,11 +2249,11 @@ Engine::PrintPV (uint depth, int score, const char * note)
 
     // Make and print each PV move:
     for (i = 0; i < pv->length; i++) {
-        simpleMoveT * sm = &(pv->move[i]);
+        auto sm = &(pv->move[i]);
 
         // Check for legality, to protect against hash table
         // false hits and bugs in PV updating:
-        if (! Pos.IsLegalMove (sm)) {
+        if (! isLegalMove(Pos, *sm)) {
             Output (" <illegal>");
             break;
         }
@@ -2350,8 +2313,8 @@ Engine::PerfTest (uint depth)
     Pos.GenerateMoves (&mlist);
     uint nmoves = 0;
     for (uint i = 0; i < mlist.Size(); i++) {
-        simpleMoveT * sm = mlist.Get(i);
-        Pos.DoSimpleMove (sm);
+        auto sm = mlist.Get(i);
+        Pos.DoSimpleMove (*sm);
         nmoves += PerfTest (depth-1);
         Pos.UndoSimpleMove (sm);
     }
