@@ -12,8 +12,7 @@
 //
 //////////////////////////////////////////////////////////////////////
 
-#include "hfilter.h"
-#include "filter.h"
+#include "tree.h"
 #include <cstring>
 
 
@@ -76,10 +75,9 @@ CompressedFilter::Verify (Filter * filter)
 void
 CompressedFilter::CompressFrom (Filter * filter)
 {
-    Clear();
+    delete[] CompressedData;
 
     CFilterSize = filter->Size();
-    CFilterCount = filter->Count();
     if(filter->data() == NULL) {
         CompressedLength = 0;
         CompressedData = NULL;
