@@ -68,8 +68,7 @@ public:
 	};
 
 	Progress(Impl* f = NULL) : f_(f) {}
-	Progress(const Progress&);
-	Progress& operator=(const Progress&);
+	Progress(const Progress&) = delete;
 	~Progress() { delete f_; }
 
 	bool report(size_t done, size_t total) const {
@@ -143,8 +142,6 @@ inline uint32_t strStartHash(const char* str) {
 
 char * strDuplicate (const char * str);
 
-void   strCopyExclude (char * target, const char * original,
-                       const char * excludeChars);
 char * strAppend (char * target, const char * extra);
 uint   strPad (char * target, const char * orig, int length, char pad);
 const char * strFirstChar (const char * target, char matchChar);
