@@ -18,8 +18,6 @@
 #define SCID_MOVELIST_H
 
 #include "common.h"
-#include <cstring>
-#include <iterator>
 
 //////////////////////////////////////////////////////////////////////
 //  MoveList:  Constants
@@ -37,8 +35,9 @@ struct simpleMoveT
 {
     squareT  from;
     squareT  to;
-    pieceT   promote;
-    pieceT   movingPiece;
+    pieceT   promote; // EMPTY if not a promotion, type (no color) otherwise
+    pieceT   movingPiece : 7;
+    pieceT   castling : 1;
     byte     pieceNum;
     byte     capturedNum;
     pieceT   capturedPiece;
@@ -47,73 +46,81 @@ struct simpleMoveT
     byte     castleFlags;    // pre-move information
     squareT  epSquare;       // pre-move information
     ushort   oldHalfMoveClock;
-    int32_t  score;          // used for alpha/beta ordering.
 
 	bool isNullMove() const {
 		return from == to && from != NULL_SQUARE &&
 		       piece_Type(movingPiece) == KING;
 	}
 
+	/// Returns:
+	///  +2 for king side castle
+	///  -2 for queen side castle
+	///  0 (false) if it is not a castle moves.
 	int isCastle() const {
-		ASSERT(piece_Type(movingPiece) == KING);
-		if (square_Fyle(from) == E_FYLE) {
-			squareT toFyle = square_Fyle(to);
-			if (toFyle == G_FYLE)
-				return 1;
-			if (toFyle == C_FYLE)
-				return 2;
-		}
+		if (castling)
+			return to > from ? 2 : -2;
+
 		return 0;
 	}
 
-	bool operator<(const simpleMoveT& b) const {
+	/// Converts the move to long algebraic notation.
+	/// @return a pointer one past the last char written.
+	template <typename OutputIt> OutputIt toLongNotation(OutputIt dest) const {
+		if (from == to) {
+			// UCI standard for null move
+			*dest++ = '0';
+			*dest++ = '0';
+			*dest++ = '0';
+			*dest++ = '0';
+		} else {
+			*dest++ = square_FyleChar(from);
+			*dest++ = square_RankChar(from);
+			*dest++ = square_FyleChar(to);
+			*dest++ = square_RankChar(to);
+			if (promote != EMPTY) {
+				constexpr const char promoChars[] = "  qrbn ";
+				*dest++ = promoChars[piece_Type(promote)];
+			}
+		}
+		return dest;
+	}
+};
+
+struct ScoredMove : public simpleMoveT {
+	int32_t score; // used for alpha/beta ordering.
+
+	bool operator<(const ScoredMove& b) const {
 		// Highest score first
 		return score > b.score;
 	}
-
-	void clear() {
-		std::memset(this, 0, sizeof *this);
-	}
 };
 
-struct cmpMove {
-	const simpleMoveT& m;
-	explicit cmpMove(const simpleMoveT& sm) : m(sm) {}
-};
-inline bool operator==(const simpleMoveT& a, const cmpMove& b) {
-	return a.from == b.m.from && a.to == b.m.to && a.promote == b.m.promote;
-}
-
 // typedef std::vector<simpleMoveT> MoveList;
 class MoveList {
 	uint ListSize = 0;
-	simpleMoveT Moves[MAX_LEGAL_MOVES];
+	ScoredMove Moves[MAX_LEGAL_MOVES];
 
 public:
-	typedef simpleMoveT* iterator;
+	typedef ScoredMove* iterator;
 	iterator begin() { return Moves; };
 	iterator end() { return Moves + ListSize; }
 	uint Size() { return ListSize; }
 	void Clear() { ListSize = 0; }
-	void emplace_back(squareT from, squareT to, pieceT promote,
-	                  pieceT movingPiece, pieceT capturedPiece) {
+	ScoredMove& emplace_back() {
 		ASSERT(ListSize < MAX_LEGAL_MOVES);
-		simpleMoveT& sm = Moves[ListSize++];
-		sm.from = from;
-		sm.to = to;
-		sm.promote = promote;
-		sm.movingPiece = movingPiece;
-		sm.capturedPiece = capturedPiece;
+		ScoredMove& sm = Moves[ListSize++];
+		sm = ScoredMove();
+		return sm;
 	}
 	void resize(size_t count) {
 		ASSERT(count <= MAX_LEGAL_MOVES);
 		ListSize = static_cast<uint>(count);
 	}
-	void push_back(const simpleMoveT& sm) {
+	void push_back(const ScoredMove& sm) {
 		ASSERT(ListSize < MAX_LEGAL_MOVES);
 		Moves[ListSize++] = sm;
 	}
-	simpleMoveT* Get(size_t index) {
+	ScoredMove* Get(size_t index) {
 		ASSERT(index < ListSize);
 		return &(Moves[index]);
 	}
