@@ -19,20 +19,31 @@
 #ifndef SCID_NAMEBASE_H
 #define SCID_NAMEBASE_H
 
-#include "common.h"
+#include "index.h"
+#include "indexentry.h"
 #include "misc.h"
 #include <algorithm>
+#include <array>
 #include <map>
 #include <memory>
 #include <vector>
 
+using nameT = unsigned;
+enum {
+	NAME_PLAYER,
+	NAME_EVENT,
+	NAME_SITE,
+	NAME_ROUND,
+	NUM_NAME_TYPES,
+	NAME_INVALID = 99
+};
+
 /**
  * This class stores the database's names (players, events, sites and rounds).
  * Assigns a idNumberT (which will be used as reference) to each name.
  */
 class NameBase {
-	std::vector<std::unique_ptr<const char[]> > names_[NUM_NAME_TYPES];
-	std::vector<eloT> eloV_;
+	std::vector<std::unique_ptr<const char[]>> names_[NUM_NAME_TYPES];
 	struct idxCmp {
 		bool operator()(const char* str1, const char* str2) const {
 			// *** Compatibility ***
@@ -49,24 +60,12 @@ class NameBase {
 			if (*str1 == *str2)
 				return strCompare(str1, str2) < 0;
 
-			return static_cast<uint>(*str1) < static_cast<uint>(*str2);
+			return static_cast<uint32_t>(*str1) < static_cast<uint32_t>(*str2);
 		}
 	};
 	std::map<const char*, idNumberT, idxCmp> idx_[NUM_NAME_TYPES];
 
 public:
-	/**
-	 * A NameBase stores the max ELO for each player. This functions updates
-	 * the max ELO of a player if it's greater than the previous one.
-	 * @param id:  a valid idNumberT corresponding to a NAME_PLAYER name.
-	 * @param elo: the ELO.
-	 */
-	void AddElo(idNumberT id, eloT elo) {
-		ASSERT(id < GetNumNames(NAME_PLAYER));
-		if (elo > eloV_[id])
-			eloV_[id] = elo;
-	}
-
 	/**
 	 * Add a name (string) to the NameBase.
 	 * If the name already exists the corresponding ID is returned.
@@ -100,36 +99,35 @@ public:
 		names_[nt].emplace_back(buf);
 		idx_[nt].emplace_hint(exists, buf, newID);
 
-		if (nt == NAME_PLAYER)
-			eloV_.push_back(0);
-
 		return std::make_pair(OK, newID);
 	}
 
+	/// DEPRECATED
+	/// Add a name (string) and its associated id to the NameBase.
+	/// Return false if the name or the id already exists: the NameBase object
+	/// is then no longer valid and should be destroyed.
+	/// The caller should also ensure that before invoking any other object's
+	/// function none of names_[nt] == nullptr.
+	bool insert(const char* name, size_t nameLen, nameT nt, idNumberT id) {
+		if (id >= names_[nt].size())
+			names_[nt].resize(id + size_t{1});
+
+		if (names_[nt][id]) // A name with the same ID already exists
+			return false;
+
+		char* buf = new char[nameLen + 1];
+		std::copy_n(name, nameLen, buf);
+		buf[nameLen] = '\0';
+		names_[nt][id].reset(buf);
+		auto it = idx_[nt].emplace_hint(idx_[nt].end(), buf, id);
+		return it->second == id; // Check that the name doesn't already exists
+	}
+
 	/**
 	 * Frees memory, leaving the object empty.
 	 */
 	void Clear() { *this = NameBase(); }
 
-	/**
-	 * @returns references to the NameBase's containers.
-	 * (must be used only to read names from files)
-	 */
-	std::tuple<decltype(idx_) &, decltype(names_) &, decltype(eloV_) &>
-	getData() {
-		return std::tuple<decltype(idx_)&, decltype(names_)&, decltype(eloV_)&>(
-		    idx_, names_, eloV_);
-	}
-
-	/**
-	 * @param id: a valid idNumberT corresponding to a NAME_PLAYER name.
-	 * @returns the max ELO of a player.
-	 */
-	eloT GetElo(idNumberT id) const {
-		ASSERT(id < GetNumNames(NAME_PLAYER));
-		return eloV_[id];
-	}
-
 	/**
 	 * Get the first few matches of a name prefix.
 	 * @param nt:         @e nameT type of the name to be searched.
@@ -168,7 +166,7 @@ public:
 	 * @returns a reference to a container with all the names and IDs (given as
 	 * std::pair<const char*, idNumberT>).
 	 */
-	const decltype(idx_) & getNames() const { return idx_; }
+	const decltype(idx_)& getNames() const { return idx_; }
 
 	/**
 	 * @param nt: a valid @e nameT type.
@@ -205,13 +203,33 @@ public:
 	 */
 	std::vector<uint32_t> generateHashMap(nameT nt) const {
 		std::vector<uint32_t> res(names_[nt].size());
-		std::transform(names_[nt].begin(), names_[nt].end(), res.begin(),
-		               [](const std::unique_ptr<const char[]>& name) {
-			               return strStartHash(name.get());
-		               });
+		std::transform(
+		    names_[nt].begin(), names_[nt].end(), res.begin(),
+		    [](auto const& name) { return strStartHash(name.get()); });
 		return res;
 	}
 
+	/**
+	 * Counts how many times each name is used.
+	 * @returns an array of std::vectors containing the count of each name.
+	 */
+	std::array<std::vector<int>, NUM_NAME_TYPES>
+	calcNameFreq(Index const& idx) const {
+		std::array<std::vector<int>, NUM_NAME_TYPES> resVec;
+		for (nameT n = NAME_PLAYER; n < NUM_NAME_TYPES; n++) {
+			resVec[n].resize(GetNumNames(n), 0);
+		}
+		for (gamenumT i = 0, n = idx.GetNumGames(); i < n; i++) {
+			const IndexEntry* ie = idx.GetEntry(i);
+			resVec[NAME_PLAYER][ie->GetWhite()] += 1;
+			resVec[NAME_PLAYER][ie->GetBlack()] += 1;
+			resVec[NAME_EVENT][ie->GetEvent()] += 1;
+			resVec[NAME_SITE][ie->GetSite()] += 1;
+			resVec[NAME_ROUND][ie->GetRound()] += 1;
+		}
+		return resVec;
+	}
+
 	/**
 	 * Validate a @e nameT type.
 	 * @param nt: @e nameT type to be validated.
@@ -249,4 +267,61 @@ public:
 	}
 };
 
+/// The Seven Tag Roster defined in the PGN standard is stored in the
+/// IndexEntry, but 5 are indexes that refer to a NameBase object.
+/// This helper struct stores the referred values.
+struct TagRoster {
+	const char* event;
+	const char* site;
+	const char* round;
+	const char* white;
+	const char* black;
+
+	template <typename TEntry>
+	static TagRoster make(TEntry const& ie, NameBase const& nb) {
+		TagRoster res;
+		res.event = nb.GetName(NAME_EVENT, ie.GetEvent());
+		res.site = nb.GetName(NAME_SITE, ie.GetSite());
+		res.white = nb.GetName(NAME_PLAYER, ie.GetWhite());
+		res.black = nb.GetName(NAME_PLAYER, ie.GetBlack());
+		res.round = nb.GetName(NAME_ROUND, ie.GetRound());
+		return res;
+	}
+
+	template <typename TEntry, typename Fn>
+	auto map(TEntry& dest, Fn getID) const {
+		{
+			auto [err, id] = getID(NAME_EVENT, event);
+			if (err)
+				return err;
+			dest.SetEvent(id);
+		}
+		{
+			auto [err, id] = getID(NAME_SITE, site);
+			if (err)
+				return err;
+			dest.SetSite(id);
+		}
+		{
+			auto [err, id] = getID(NAME_ROUND, round);
+			if (err)
+				return err;
+			dest.SetRound(id);
+		}
+		{
+			auto [err, id] = getID(NAME_PLAYER, white);
+			if (err)
+				return err;
+			dest.SetWhite(id);
+		}
+		{
+			auto [err, id] = getID(NAME_PLAYER, black);
+			if (!err)
+				dest.SetBlack(id);
+
+			return err;
+		}
+	}
+};
+
 #endif // SCID_NAMEBASE_H
