@@ -16,6 +16,7 @@
 #include "crosstab.h"
 #include "dstring.h"
 #include "pbook.h"
+#include <algorithm>
 
 uint
 endgameTheme (matSigT msig)
@@ -174,7 +175,7 @@ OpLine::Init (Game * g, const IndexEntry * ie, gamenumT gameNum,
     // Now set positional themes:
     uint maxThemePly = maxThemeMoveNumber * 2;
     for (i=0; i < NUM_POSTHEMES; i++) { Theme[i] = 0; }
-    g->MoveToPly (0);
+    g->MoveToStart();
     for (i=0; i < maxThemePly; i++) {
         if (g->MoveForward() != OK) { break; }
         SetPositionalThemes (g->GetCurrentPos());
@@ -439,11 +440,15 @@ OpLine::PrintSummary (DString * dstr, uint format, bool fullDate, bool nmoves)
     if (BlackElo > 0) { dstr->Append (preElo, BlackElo, postElo); }
     dstr->Append (", ", Site, " ");
     if (fullDate) {
-        char dateStr [16];
+        char dateStr[16] = {};
         date_DecodeToString (Date, dateStr);
         // Remove any unknown date fields:
-        char * s = (char *) strFirstChar (dateStr+4, '?');
-        if (s != NULL) { s--; *s = 0; }
+        auto s_end = dateStr + 16;
+        auto s = std::find(dateStr + 4, s_end, '?');
+        if (s != s_end) {
+            s--;
+            *s = 0;
+        }
         dstr->Append (dateStr);
     } else {
         dstr->Append (date_GetYear (Date));
@@ -496,8 +501,8 @@ OpTable::Init (const char * type, Game * g, PBook * ebook)
         }
         if (ebook != NULL && ECOstr_.empty()) {
             auto eco = ebook->findECOstr(g->GetCurrentPos());
-            if (eco.first)
-                ECOstr_.append(eco.first, eco.second);
+            if (!eco.empty())
+                ECOstr_.append(eco);
         }
         g->MoveBackup();
         simpleMoveT * sm = g->GetCurrentMove();
@@ -2052,7 +2057,7 @@ OpTable::PopularMoveOrders (DString * dstr, uint count)
 
     for (uint i=0; i < count; i++) {
         if (i == NumMoveOrders) { break; }
-        char tempStr [10];
+        char tempStr [16];
         sprintf (tempStr, "%2u", i+1);
         dstr->Append (preNum, tempStr, postNum);
         if (Format == OPTABLE_CText) {
