@@ -24,7 +24,6 @@
 #ifndef SCID_PGNPARSE_H
 #define SCID_PGNPARSE_H
 
-#include "common.h"
 #include "game.h"
 #include "pgn_lexer.h"
 #include <string>
@@ -152,7 +151,7 @@ public:
 				return logFatalErr("Failed to parse the move: ", tok);
 			}
 		}
-		return (game.AddMove(&sm) == OK)
+		return (game.AddMove(sm) == OK)
 		           ? true
 		           : logFatalErr("Failed to add the move: ", tok);
 	}
