@@ -19,6 +19,8 @@
 #include "common.h"
 #include "movelist.h"
 #include <stdio.h>
+#include <string>
+#include <string_view>
 
 class DString;
 class SquareSet;
@@ -102,6 +104,8 @@ private:
                                     // or pawn move.
     ushort          PlyCounter;
     byte            Castling;       // castling flags
+    byte            variant_;       // 0 -> normal; 1 -> chess960
+    squareT         castleRookSq_[4];  // start rook squares
 
     uint            Hash;           // Hash value.
     uint            PawnHash;       // Pawn structure hash value.
@@ -125,7 +129,7 @@ private:
 
     void  AddLegalMove (MoveList * mlist, squareT from, squareT to, pieceT promo);
     void  GenCastling (MoveList * mlist);
-    void  GenKingMoves (MoveList * mlist, genMovesT genType, bool castling);
+    void  GenKingMoves (MoveList * mlist, genMovesT genType);
     void  AddPromotions (MoveList * mlist, squareT from, squareT dest);
     bool  IsValidEnPassant (squareT from, squareT to);
     void  GenPawnMoves (MoveList * mlist, squareT from, directionT dir,
@@ -133,14 +137,23 @@ private:
 
     void GenCheckEvasions(MoveList* mlist, pieceT mask, genMovesT genType,
                           SquareList* checkSquares);
-    errorT MatchPawnMove(MoveList* mlist, fyleT fromFyle, squareT to,
-                         pieceT promote);
 
-    errorT ReadMove(simpleMoveT* sm, const char* str, int slen, pieceT p);
-    errorT ReadMoveCastle(simpleMoveT* sm, const char* str, int slen);
-    errorT ReadMovePawn(simpleMoveT* sm, const char* str, int slen, fyleT from);
-    errorT ReadMoveKing(simpleMoveT* sm, const char* str, int slen);
+    errorT ReadMove(simpleMoveT* sm, const char* str, size_t slen, pieceT p) const;
+    errorT ReadMoveCastle(simpleMoveT* sm, std::string_view str) const;
+    errorT ReadMovePawn(simpleMoveT* sm, const char* str, size_t slen, fyleT from);
+    errorT ReadMoveKing(simpleMoveT* sm, const char* str, size_t slen) const;
 
+    template <typename TFunc>
+    bool under_attack(squareT target_sq, squareT captured_sq,
+                      TFunc not_empty) const;
+    bool under_attack(squareT target_sq) const;
+
+    static constexpr unsigned castlingIdx(colorT color, castleDirT side) {
+        return 2 * color + side;
+    }
+    squareT castleRookSq(colorT color, bool king_side) const {
+        return castleRookSq_[2 * color + (king_side ? 1 : 0)];
+    }
 
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     //  Position:  Public Functions
@@ -153,6 +166,8 @@ public:
     bool        IsStdStart() const;
     errorT      AddPiece (pieceT p, squareT sq);
 
+    bool isChess960() const { return variant_ == 1; }
+
     // Set and Get attributes -- one-liners
     byte        PieceCount (pieceT p)    { return Material[p]; }
     const byte* GetMaterial() const      { return Material; }
@@ -160,6 +175,7 @@ public:
     squareT     GetEPTarget () const     { return EPTarget; }
     void        SetToMove (colorT c)     { ToMove = c; }
     colorT      GetToMove () const       { return ToMove; }
+    bool        WhiteToMove () const     { return ToMove == WHITE; }
     void        SetPlyCounter (ushort x) { PlyCounter = x; }
     ushort      GetPlyCounter () const   { return PlyCounter; }
     ushort      GetFullMoveCount() const { return PlyCounter / 2 + 1; }
@@ -183,16 +199,15 @@ public:
     inline uint RankCount (pieceT p, rankT r) const {
         return NumOnRank[p][r];
     }
-    inline uint LeftDiagCount (pieceT p, leftDiagT diag) {
+    inline uint LeftDiagCount (pieceT p, leftDiagT diag) const {
         return NumOnLeftDiag[p][diag];
     }
-    inline uint RightDiagCount (pieceT p, rightDiagT diag) {
+    inline uint RightDiagCount (pieceT p, rightDiagT diag) const {
         return NumOnRightDiag[p][diag];
     }
-    inline uint SquareColorCount (pieceT p, colorT sqColor) {
+    inline uint SquareColorCount (pieceT p, colorT sqColor)  const {
         return NumOnSquareColor[p][sqColor];
     }
-    uint        GetSquares (pieceT p, SquareList * sqlist);
 
     const pieceT* GetBoard() const {
         const_cast<Position*>(this)->Board[COLOR_SQUARE] = COLOR_CHAR[ToMove];
@@ -205,22 +220,15 @@ public:
     }
 
     // Other one-line methods
-    squareT     GetKingSquare (colorT c)  { return List[c][0]; }
-    squareT     GetKingSquare ()          { return List[ToMove][0]; }
-    squareT     GetEnemyKingSquare ()     { return List[1-ToMove][0]; }
+    squareT     GetKingSquare (colorT c) const { return List[c][0]; }
+    squareT     GetKingSquare () const         { return List[ToMove][0]; }
+    squareT     GetEnemyKingSquare () const    { return List[1-ToMove][0]; }
 
     // Castling flags
-    inline void SetCastling (colorT c, castleDirT dir, bool flag);
     bool GetCastling(colorT c, castleDirT dir) const {
-        int b = (c == WHITE) ? 1 : 4;
-        if (dir == KSIDE)
-            b += b;
-        // Now b == 1 or 2 (white flags), or 4 or 8 (black flags)
-        return Castling & b;
+        return Castling & (1u << castlingIdx(c, dir));
     }
-    inline bool CastlingPossible () { return (Castling ? true : false); }
-    byte        GetCastlingFlags () { return Castling; }
-    void        SetCastlingFlags (byte b) { Castling = b; }
+    byte GetCastlingFlags() const { return Castling; }
 
     // Hashing
     inline uint HashValue (void) { return Hash; }
@@ -237,52 +245,57 @@ public:
     void  GenerateMoves (MoveList * mlist) { GenerateMoves (mlist, EMPTY, GEN_ALL_MOVES, true); }
     void  GenerateMoves (MoveList * mlist, genMovesT genType) { GenerateMoves (mlist, EMPTY, genType, true); }
     void  GenerateCaptures (MoveList * mlist) { GenerateMoves (mlist, EMPTY, GEN_CAPTURES, true); }
-    bool  IsLegalMove (simpleMoveT * sm);
+    int IsLegalMove(squareT from, squareT to, pieceT promo) const;
 
-    uint        CalcAttacks (colorT toMove, squareT kingSq, SquareList * squares);
+    /// Check that the minimum requirements for castling are satisfied:
+    /// - both the king and the rook exists in the position
+    /// - the final squares of the king and the rook are empty
+    /// @param check_legal: also test for checks or blocking pieces.
+    /// Ignore the castling flags and if the king is already in check.
+    template <bool check_legal = true> bool canCastle(bool king_side) const;
+
+    uint        CalcAttacks (colorT toMove, squareT kingSq, SquareList * squares) const;
     int         TreeCalcAttacks (colorT toMove, squareT target);
-    uint        CalcNumChecks () {
+    uint        CalcNumChecks () const {
                     return CalcAttacks (1-ToMove, GetKingSquare(), NULL);
                 }
-    uint        CalcNumChecks (squareT kingSq) {
+    uint        CalcNumChecks (squareT kingSq) const {
                     return CalcAttacks (1-ToMove, kingSq, NULL);
                 }
-    uint        CalcNumChecks (squareT kingSq, SquareList * checkSquares) {
+    uint        CalcNumChecks (squareT kingSq, SquareList * checkSquares) const {
                     return CalcAttacks (1-ToMove, kingSq, checkSquares);
                 }
 
     uint        Mobility (pieceT p, colorT color, squareT from);
     bool        IsKingInCheck () { return (CalcNumChecks() > 0); }
-    bool        IsKingInCheckDir (directionT dir);
-    bool        IsKingInCheck (simpleMoveT * sm);
+    bool        IsKingInCheck (simpleMoveT const& sm);
     bool        IsKingInMate ();
     bool        IsLegal ();
 
     bool        IsPromoMove (squareT from, squareT to);
 
+    void        makeMove(squareT from, squareT to, pieceT promo, simpleMoveT& res) const;
+    void        fillMove(simpleMoveT& sm) const;
+    void        DoSimpleMove(simpleMoveT const& sm);
     void        DoSimpleMove (simpleMoveT * sm);    // move execution ...
-    void        UndoSimpleMove (simpleMoveT * sm);  // ... and taking back
+    void        UndoSimpleMove (simpleMoveT const* sm);  // ... and taking back
 
     errorT      RelocatePiece (squareT fromSq, squareT toSq);
 
     void        MakeSANString (simpleMoveT * sm, char * s, sanFlagT flag);
-    void        MakeUCIString (simpleMoveT * sm, char * s);
 	void        CalcSANStrings (sanListT *sanList, sanFlagT flag);
 
-    errorT      ReadCoordMove(simpleMoveT* m, const char* s, int slen, bool reverse);
+    errorT      MakeCoordMoves(const char* moves, size_t movesLen, std::string* toSAN = nullptr);
+    errorT      ReadCoordMove(simpleMoveT* m, const char* s, size_t slen, bool reverse);
     errorT      ParseMove(simpleMoveT* sm, const char* str);
     errorT      ParseMove(simpleMoveT* sm, const char* begin, const char* end);
 
     // Board I/O
-    void        MakeLongStr (char * str);
+    void        MakeLongStr (char* str) const;
     errorT      ReadFromLongStr (const char * str);
-    errorT      ReadFromCompactStr (const byte * str);
     errorT      ReadFromFEN (const char * s);
+    errorT      ReadFromFENorUCI (std::string_view str);
     void        PrintCompactStr (char * cboard);
-    void        PrintCompactStrFlipped (char * cboard);
-    byte        CompactStrFirstByte () {
-        return (Board[0] << 4) | Board[1];
-    }
     void        PrintFEN(char* str, uint flags) const;
     void        DumpLatexBoard (DString * dstr, bool flip);
     void        DumpLatexBoard (DString * dstr) {
@@ -300,28 +313,17 @@ public:
 
     // Set up a random position:
     errorT      Random (const char * material);
+
+private:
+    void setCastling(colorT col, squareT rsq);
+    void ClearCastling(colorT col, castleDirT dir) {
+        Castling &= ~(1u << castlingIdx(col, dir));
+    }
+    void ClearCastlingFlags(colorT c) {
+        Castling &= (c == WHITE) ? 0b11111100 : 0b11110011;
+    }
 };
 
-
-
-//////////////////////////////////////////////////////////////////////
-//  Position:  Public Inline Functions
-
-
-//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-// Position::SetCastling():
-//      Set a castling flag.
-//
-inline void
-Position::SetCastling (colorT c, castleDirT dir, bool flag)
-{
-    byte b = (c==WHITE ? 1 : 4);
-    if (dir == KSIDE) b += b;
-    // Now b = 1 or 2 (white flags), or 4 or 8 (black flags)
-    if (flag) { Castling |= b; } else { Castling &= (255-b); }
-    return;
-}
-
 #endif  // SCID_POSITION_H
 
 //////////////////////////////////////////////////////////////////////
