@@ -1,5 +1,5 @@
 /*
-# Copyright (C) 2015 Fulvio Benini
+ * Copyright (C) 2015-2019 Fulvio Benini
 
 * This file is part of Scid (Shane's Chess Information Database).
 *
@@ -22,8 +22,11 @@
 #include "scidbase.h"
 #include "searchtournaments.h"
 #include "ui.h"
+#include <algorithm>
 #include <cstring>
+#include <map>
 #include <string>
+#include <vector>
 
 namespace {
 /*
@@ -53,23 +56,26 @@ namespace {
  * If @fMode == FMODE_Both, and the file cannot be opened for writing, this
  * function will try to open the database read-only.
  */
-static UI_res_t doOpenBase(UI_handle_t ti, const char* filename,
-                           fileModeT fMode, ICodecDatabase::Codec codec) {
-	if (DBasePool::find(filename) != 0) return UI_Result(ti, ERROR_FileInUse);
+static UI_res_t doOpenBase(UI_handle_t ti, const char* codec, fileModeT fMode,
+                           const char* filename) {
+	if (DBasePool::find(filename))
+		return UI_Result(ti, ERROR_FileInUse);
 
 	scidBaseT* dbase = DBasePool::getFreeSlot();
-	if (dbase == 0) return UI_Result(ti, ERROR_Full);
+	if (!dbase)
+		return UI_Result(ti, ERROR_Full);
 
 	Progress progress = UI_CreateProgress(ti);
-	errorT err = dbase->Open(codec, fMode, filename, progress);
+	errorT err = dbase->open(codec, fMode, filename, progress);
 
 	if ((err == ERROR_FileOpen || err == ERROR_FileMode) &&
 	    fMode == FMODE_Both) {
-		err = dbase->Open(codec, FMODE_ReadOnly, filename, progress);
+		err = dbase->open(codec, FMODE_ReadOnly, filename, progress);
 	}
-	progress.report(1,1);
+	progress.report(1, 1);
 
-	if (err != OK && err != ERROR_NameDataLoss) return UI_Result(ti, err);
+	if (err != OK && err != ERROR_NameDataLoss)
+		return UI_Result(ti, err);
 
 	int res = DBasePool::switchCurrent(dbase);
 	return UI_Result(ti, err, res);
@@ -83,7 +89,8 @@ UI_res_t sc_base_close(scidBaseT* dbase, UI_handle_t ti, int, const char**) {
 	if (dbase->getFileName() == "<clipbase>") {
 		return UI_Result(ti, ERROR_BadArg, "Cannot close clipbase.");
 	}
-	return UI_Result(ti, dbase->Close());
+	dbase->Close();
+	return UI_Result(ti, OK);
 }
 
 
@@ -131,18 +138,26 @@ UI_res_t sc_base_copygames(scidBaseT* dbase, UI_handle_t ti, int argc, const cha
 	scidBaseT* targetBase = DBasePool::getBase(strGetUnsigned(argv[4]));
 	if (targetBase == 0)
 		return UI_Result(ti, ERROR_BadArg, "sc_base copygames error: wrong targetBaseId");
-	if (targetBase->isReadOnly())
-		return UI_Result(ti, ERROR_FileReadOnly);
 
 	errorT err = OK;
 	const HFilter filter = dbase->getFilter(argv[3]);
 	if (filter != 0) {
 		err = targetBase->importGames(dbase, filter, UI_CreateProgress(ti));
 	} else {
-		uint gNum = strGetUnsigned (argv[3]);
-		if (gNum == 0)
-			return UI_Result(ti, ERROR_BadArg, "sc_base copygames error: wrong <gameNum|filterName>");
-		err = targetBase->importGame(dbase, gNum -1);
+		uint gNum = strGetUnsigned(argv[3]);
+		const IndexEntry* ie = (gNum > 0)
+		                           ? dbase->getIndexEntry_bounds(gNum - 1)
+		                           : nullptr;
+		if (ie == nullptr)
+			return UI_Result(
+			    ti, ERROR_BadArg,
+			    "sc_base copygames error: wrong <gameNum|filterName>");
+
+		Game game;
+		err = dbase->getGame(*ie, game);
+		if (err == OK) {
+			err = targetBase->saveGame(&game);
+		}
 	}
 	return UI_Result(ti, err);
 }
@@ -160,24 +175,14 @@ UI_res_t sc_base_copygames(scidBaseT* dbase, UI_handle_t ti, int argc, const cha
  */
 UI_res_t sc_base_create(UI_handle_t ti, int argc, const char** argv) {
 	const char* usage = "Usage: sc_base create <MEMORY|SCID4|PGN> filename";
-	if (argc != 4 && argc != 3) return UI_Result(ti, ERROR_BadArg, usage);
 
-	// Old interface defaults to SCID4
-	ICodecDatabase::Codec codec = ICodecDatabase::SCID4;
-	if (argc == 4) {
-		if (std::strcmp("MEMORY", argv[2]) == 0)
-			codec = ICodecDatabase::MEMORY;
-		else if (std::strcmp("SCID4", argv[2]) == 0)
-			codec = ICodecDatabase::SCID4;
-		else if (std::strcmp("PGN", argv[2]) == 0)
-			codec = ICodecDatabase::PGN;
-		else
-			return UI_Result(ti, ERROR_BadArg, usage);
-	}
+	if (argc == 3) // Old interface defaults to SCID4
+		return doOpenBase(ti, "SCID4", FMODE_Create, argv[2]);
 
-	return doOpenBase(
-	    ti, argc == 4 ? argv[3] : argv[2],
-	    codec == ICodecDatabase::MEMORY ? FMODE_Memory : FMODE_Create, codec);
+	if (argc == 4)
+		return doOpenBase(ti, argv[2], FMODE_Create, argv[3]);
+
+	return UI_Result(ti, ERROR_BadArg, usage);
 }
 
 
@@ -243,14 +248,15 @@ UI_res_t sc_base_gameflag(scidBaseT* dbase, UI_handle_t ti, int argc, const char
 		cmd = 4;
 	uint flagType = IndexEntry::CharToFlagMask(argv[5][0]);
 	if (flagType != 0 && cmd != 0) {
-		bool value = (cmd == 2);
-
-		const HFilter filter = dbase->getFilter(argv[3]);
-		if (filter != 0 || (std::strcmp("all", argv[3]) == 0)) {
+		Filter filter_all(dbase->numGames());
+		const HFilter filter = std::strcmp("all", argv[3]) == 0
+		                           ? HFilter(&filter_all)
+		                           : dbase->getFilter(argv[3]);
+		if (filter != 0) {
 			switch (cmd) {
-			case 2:
-			case 3: return UI_Result(ti, dbase->setFlag(value, flagType, filter));
-			case 4: return UI_Result(ti, dbase->invertFlag(flagType, filter));
+			case 2: return UI_Result(ti, dbase->setFlags(true, flagType, filter));
+			case 3: return UI_Result(ti, dbase->setFlags(false, flagType, filter));
+			case 4: return UI_Result(ti, dbase->invertFlags(flagType, filter));
 			}
 		} else {
 			gamenumT gNum = strGetUnsigned(argv[3]);
@@ -258,8 +264,8 @@ UI_res_t sc_base_gameflag(scidBaseT* dbase, UI_handle_t ti, int argc, const char
 				gNum--;
 				switch (cmd) {
 				case 1: return UI_Result(ti, OK, dbase->getFlag(flagType, gNum));
-				case 2:
-				case 3: return UI_Result(ti, dbase->setFlag(value, flagType, gNum));
+				case 2: return UI_Result(ti, dbase->setFlag(true, flagType, gNum));
+				case 3: return UI_Result(ti, dbase->setFlag(false, flagType, gNum));
 				case 4: return UI_Result(ti, dbase->invertFlag(flagType, gNum));
 				}
 			}
@@ -302,20 +308,21 @@ UI_res_t sc_base_gamelocation(scidBaseT* dbase, UI_handle_t ti, int argc, const
 		const NameBase* nb = dbase->getNameBase();
 		auto contains = [dbase, nb, text](gamenumT g) {
 			const IndexEntry* ie = dbase->getIndexEntry(g);
-			return strAlphaContains(ie->GetWhiteName(nb), text) ||
-			       strAlphaContains(ie->GetBlackName(nb), text) ||
-			       strAlphaContains(ie->GetEventName(nb), text) ||
-			       strAlphaContains(ie->GetSiteName(nb), text);
+			return strAlphaContains(nb->GetName(NAME_PLAYER, ie->GetWhite()), text) ||
+			       strAlphaContains(nb->GetName(NAME_PLAYER, ie->GetBlack()), text) ||
+			       strAlphaContains(nb->GetName(NAME_EVENT, ie->GetEvent()), text) ||
+			       strAlphaContains(nb->GetName(NAME_SITE, ie->GetSite()), text);
 		};
 		if (strGetBoolean(argv[8])) {
-			std::vector<gamenumT> buf(filter->size() - start);
+			std::vector<gamenumT> buf(
+			    start >= filter->size() ? 1 : filter->size() - start);
 			buf.resize(
 			    dbase->listGames(sort, start, buf.size(), filter, buf.data()));
 			auto it = std::find_if(buf.begin(), buf.end(), contains);
 			if (it != buf.end())
 				location = start + std::distance(buf.begin(), it);
 		} else {
-			std::vector<gamenumT> buf(start);
+			std::vector<gamenumT> buf(start ? start : 1);
 			buf.resize(dbase->listGames(sort, 0, start, filter, buf.data()));
 			auto it = std::find_if(buf.rbegin(), buf.rend(), contains);
 			if (it != buf.rend())
@@ -357,18 +364,19 @@ UI_res_t sc_base_gameslist(scidBaseT* dbase, UI_handle_t ti, int argc, const cha
 		uint ply = filter->get(idx) -1;
 
 		const IndexEntry* ie = dbase->getIndexEntry(idx);
+		const auto tags = TagRoster::make(*ie, *nb);
 
 		ginfo.clear();
 		ginfo.push_back(idx +1);
 		ginfo.push_back(RESULT_STR[ie->GetResult()]);
 		ginfo.push_back((ie->GetNumHalfMoves() + 1) / 2);
-		ginfo.push_back(ie->GetWhiteName(nb));
+		ginfo.push_back(tags.white);
 		std::string eloStr;
 		eloT welo = ie->GetWhiteElo();
 		if (welo != 0) {
 			eloStr = std::to_string(welo);
 		} else {
-			welo = ie->GetWhiteElo(nb);
+			welo = dbase->peakElo(ie->GetWhite());
 			eloStr = std::to_string(welo);
 			if (welo != 0) {
 				eloStr.insert(eloStr.begin(), '(');
@@ -376,12 +384,12 @@ UI_res_t sc_base_gameslist(scidBaseT* dbase, UI_handle_t ti, int argc, const cha
 			}
 		}
 		ginfo.push_back(eloStr);
-		ginfo.push_back(ie->GetBlackName(nb));
+		ginfo.push_back(tags.black);
 		eloT belo = ie->GetBlackElo();
 		if (belo != 0) {
 			eloStr = std::to_string(belo);
 		} else {
-			belo = ie->GetBlackElo(nb);
+			belo = dbase->peakElo(ie->GetBlack());
 			eloStr = std::to_string(belo);
 			if (belo != 0) {
 				eloStr.insert(eloStr.begin(), '(');
@@ -390,11 +398,11 @@ UI_res_t sc_base_gameslist(scidBaseT* dbase, UI_handle_t ti, int argc, const cha
 		}
 		ginfo.push_back(eloStr);
 		char buf_date[16];
-		date_DecodeToString (ie->GetDate(), buf_date);
+		date_DecodeToString(ie->GetDate(), buf_date);
 		ginfo.push_back(buf_date);
-		ginfo.push_back(ie->GetEventName(nb));
-		ginfo.push_back(ie->GetRoundName(nb));
-		ginfo.push_back(ie->GetSiteName(nb));
+		ginfo.push_back(tags.event);
+		ginfo.push_back(tags.round);
+		ginfo.push_back(tags.site);
 		ginfo.push_back(ie->GetNagCount());
 		ginfo.push_back(ie->GetCommentCount());
 		ginfo.push_back(ie->GetVariationCount());
@@ -417,9 +425,8 @@ UI_res_t sc_base_gameslist(scidBaseT* dbase, UI_handle_t ti, int argc, const cha
 		ginfo.push_back(buf_eventdate);
 		ginfo.push_back(ie->GetYear());
 		ginfo.push_back((welo + belo)/2);
-		ginfo.push_back(ie->GetRating(nb));
-		FastGame game = dbase->getGame(ie);
-		ginfo.push_back(game.getMoveSAN(ply, 10));
+		ginfo.push_back(ie->GetRating());
+		ginfo.push_back(dbase->getGame(ie).getMoveSAN(ply, 10));
 
 		res.push_back(std::to_string(idx+1) + "_" + std::to_string(ply));
 		res.push_back(ginfo);
@@ -569,20 +576,14 @@ UI_res_t sc_base_numGames(scidBaseT* dbase, UI_handle_t ti, int argc,
  */
 UI_res_t sc_base_open(UI_handle_t ti, int argc, const char** argv) {
 	const char* usage = "Usage: sc_base open <SCID4|PGN> filename";
-	if (argc != 4 && argc != 3) return UI_Result(ti, ERROR_BadArg, usage);
 
-	// Old interface defaults to SCID4
-	ICodecDatabase::Codec codec = ICodecDatabase::SCID4;
-	if (argc == 4) {
-		if (std::strcmp("SCID4", argv[2]) == 0)
-			codec = ICodecDatabase::SCID4;
-		else if (std::strcmp("PGN", argv[2]) == 0)
-			codec = ICodecDatabase::PGN;
-		else
-			return UI_Result(ti, ERROR_BadArg, usage);
-	}
+	if (argc == 3) // Old interface defaults to SCID4
+		return doOpenBase(ti, "SCID4", FMODE_Both, argv[2]);
 
-	return doOpenBase(ti, argc == 4 ? argv[3] : argv[2], FMODE_Both, codec);
+	if (argc == 4)
+		return doOpenBase(ti, argv[2], FMODE_Both, argv[3]);
+
+	return UI_Result(ti, ERROR_BadArg, usage);
 }
 
 
@@ -617,7 +618,7 @@ UI_res_t sc_base_sortcache(scidBaseT* dbase, UI_handle_t ti, int argc, const cha
 	if (argc != 5) return UI_Result(ti, ERROR_BadArg, usage);
 
 	if (std::strcmp("create", argv[3]) == 0) {
-		if (dbase->createSortCache(argv[4]) == NULL)
+		if (!dbase->createSortCache(argv[4]))
 			return UI_Result(ti, ERROR);
 	} else {
 		dbase->releaseSortCache(argv[4]);
@@ -722,6 +723,53 @@ UI_res_t sc_base_switch(scidBaseT* dbase, UI_handle_t ti)
 	return UI_Result(ti, OK, res);
 }
 
+/// Remove all occurrences of the specified tags from the database.
+/// @returns the number of changed games.
+UI_res_t sc_base_strip(scidBaseT& dbase, UI_handle_t ti, int argc,
+                       const char** argv) {
+	const char* usage = "Usage: sc_base strip baseId tagNames...";
+	if (argc < 4)
+		return UI_Result(ti, ERROR_BadArg, usage);
+
+	std::vector<std::string_view> tags(argv + 3, argv + argc);
+	Filter filter_all(dbase.numGames());
+	auto progress = UI_CreateProgress(ti);
+	const auto res = dbase.stripGames(HFilter(&filter_all), progress, tags);
+	return UI_Result(ti, res.first, res.second);
+}
+
+/// Produce a list of PGN tags used in the database
+/// @returns a even-sized list, where each pair of elements is a tag name and
+/// its frequency
+UI_res_t sc_base_taglist(scidBaseT& dbase, UI_handle_t ti) {
+	std::map<std::string, gamenumT, std::less<>> tag_freq;
+	auto progress = UI_CreateProgress(ti);
+	for (gamenumT gnum = 0, n = dbase.numGames(); gnum < n; ++gnum) {
+		if ((gnum % 1024 == 0) && !progress.report(gnum, n))
+			return UI_Result(ti, ERROR_UserCancel);
+
+		const auto ie = dbase.getIndexEntry(gnum);
+		const auto err = dbase.getGame(*ie).decodeTags(
+		    [&](auto const& tag, auto const&) {
+			    auto it = tag_freq.find(tag);
+			    if (it == tag_freq.end())
+				    tag_freq.emplace(tag, 1);
+			    else
+				    it->second++;
+		    });
+		if (err)
+			return UI_Result(ti, err);
+	}
+
+	UI_List res(tag_freq.size() * 2);
+	for (const auto& [tag, freq] : tag_freq) {
+		if (tag != "SetUp") {
+			res.push_back(tag.c_str());
+			res.push_back(freq);
+		}
+	}
+	return UI_Result(ti, OK, res);
+}
 
 /**
  * sc_base_tournaments() - return a list of tournaments
@@ -906,8 +954,8 @@ UI_res_t sc_base_player_elo(const scidBaseT& dbase, UI_handle_t ti, int argc,
 UI_res_t sc_base_inUse       (UI_extra_t, UI_handle_t, int argc, const char ** argv);
 UI_res_t sc_base_export      (UI_extra_t, UI_handle_t, int argc, const char ** argv);
 UI_res_t sc_base_piecetrack  (UI_extra_t, UI_handle_t, int argc, const char ** argv);
-UI_res_t sc_base_tag         (UI_extra_t, UI_handle_t, int argc, const char ** argv);
-uint sc_base_duplicates (scidBaseT* dbase, UI_handle_t, int argc, const char ** argv);
+UI_res_t sc_base_duplicates  (scidBaseT* dbase, UI_handle_t, int argc, const char ** argv);
+UI_res_t sc_base_gamesummary (const scidBaseT& dbase, UI_handle_t, int, const char**);
 
 
 UI_res_t sc_base (UI_extra_t cd, UI_handle_t ti, int argc, const char ** argv)
@@ -919,7 +967,8 @@ UI_res_t sc_base (UI_extra_t cd, UI_handle_t ti, int argc, const char ** argv)
 	    "gamelocation",    "gameslist",       "getGame",         "import",
 	    "inUse",           "isReadOnly",      "list",            "numGames",        "open",
 	    "piecetrack",      "player_elo",      "slot",            "sortcache",       "stats",
-	    "switch",          "tag",             "tournaments",     "type",
+	    "strip",           "switch",          "taglist",         "tournaments",     "type",
+	    "gamesummary",
 	    NULL
 	};
 	enum {
@@ -929,7 +978,8 @@ UI_res_t sc_base (UI_extra_t cd, UI_handle_t ti, int argc, const char ** argv)
 	    BASE_GAMELOCATION, BASE_GAMESLIST,    BASE_GETGAME,      BASE_IMPORT,
 	    BASE_INUSE,        BASE_ISREADONLY,   BASE_LIST,         BASE_NUMGAMES,     BASE_OPEN,
 	    BASE_PTRACK,       BASE_PLAYER_ELO,   BASE_SLOT,         BASE_SORTCACHE,    BASE_STATS,
-	    BASE_SWITCH,       BASE_TAG,          BASE_TOURNAMENTS,  BASE_TYPE
+	    BASE_STRIP,        BASE_SWITCH,       BASE_TAGLIST,      BASE_TOURNAMENTS,  BASE_TYPE,
+	    BASE_GAMESUMMARY
 	};
 
 	if (argc <= 1) return UI_Result(ti, ERROR_BadArg, "Usage: sc_base <cmd>");
@@ -959,9 +1009,6 @@ UI_res_t sc_base (UI_extra_t cd, UI_handle_t ti, int argc, const char ** argv)
 
 	case BASE_SLOT:
 		return sc_base_slot (ti, argc, argv);
-
-	case BASE_TAG:
-		return sc_base_tag (cd, ti, argc, argv);
 	}
 
 	//New multi-base functions
@@ -980,8 +1027,7 @@ UI_res_t sc_base (UI_extra_t cd, UI_handle_t ti, int argc, const char ** argv)
 		return sc_base_copygames(dbase, ti, argc, argv);
 
 	case BASE_DUPLICATES:
-		if (dbase->isReadOnly()) return UI_Result(ti, ERROR_FileReadOnly);
-		return UI_Result(ti, OK, sc_base_duplicates (dbase, ti, argc, argv));
+		return sc_base_duplicates(dbase, ti, argc, argv);
 
 	case BASE_EXTRA:
 		return sc_base_extra(dbase, ti, argc, argv);
@@ -1022,8 +1068,17 @@ UI_res_t sc_base (UI_extra_t cd, UI_handle_t ti, int argc, const char ** argv)
 	case BASE_SWITCH:
 		return sc_base_switch (dbase, ti);
 
+	case BASE_STRIP:
+		return sc_base_strip(*dbase, ti, argc, argv);
+
+	case BASE_TAGLIST:
+		return sc_base_taglist(*dbase, ti);
+
 	case BASE_TOURNAMENTS:
 		return sc_base_tournaments (dbase, ti, argc, argv);
+
+	case BASE_GAMESUMMARY:
+		return sc_base_gamesummary(*dbase, ti, argc, argv);
 	}
 
 	std::string res = "sc_base\nInvalid minor command: ";
