@@ -1,5 +1,5 @@
 /*
-# Copyright (C) 2014-2016 Fulvio Benini
+# Copyright (C) 2014-2019 Fulvio Benini
 
 * This file is part of Scid (Shane's Chess Information Database).
 *
@@ -22,14 +22,16 @@
 #include "bytebuf.h"
 #include "codec.h"
 #include "containers.h"
-#include "fastgame.h"
+#include "gameview.h"
 #include "game.h"
 #include "index.h"
 #include "namebase.h"
 #include "tree.h"
 #include <array>
-#include <vector>
+#include <cassert>
 #include <memory>
+#include <string_view>
+#include <vector>
 
 class SortCache;
 
@@ -68,31 +70,23 @@ struct scidBaseT {
 		Eco ecoGroup3_[(1 + (1<<16)/131)];
 	};
 
-	struct TreeStat {
-		colorT toMove;
-		std::string SAN;
-		int resultW, resultD, resultB;
-		double exp;
-		int ngames, nexp;
-
-	public:
-		TreeStat();
-		void add(int result, int eloW, int eloB);
-		bool operator<(const TreeStat& cmp) const { return ngames > cmp.ngames; }
-
-	private:
-		static double expVect_[1600];
-	};
-
 	scidBaseT();
 	~scidBaseT();
 
-	errorT Open(ICodecDatabase::Codec dbtype,
-	            fileModeT mode,
-	            const char* filename = 0,
-	            const Progress& progress = Progress());
+	errorT open(std::string_view dbType, fileModeT fMode, const char* filename,
+	            const Progress& progress = {}) {
+		auto codec = ICodecDatabase::SCID4;
+		if (dbType == "PGN") {
+			codec = ICodecDatabase::PGN;
+		} else if (dbType == "MEMORY") {
+			codec = ICodecDatabase::MEMORY;
+		} else if (dbType != "SCID4") {
+			return ERROR_BadArg;
+		}
+		return openHelper(codec, fMode, filename, progress);
+	}
 
-	errorT Close ();
+	void Close ();
 
 	const std::string& getFileName() const { return fileName_; }
 	bool isReadOnly() const { return fileMode_ == FMODE_ReadOnly; }
@@ -106,60 +100,78 @@ struct scidBaseT {
 
 	/// Store an extra information about the database (type, description, etc..)
 	errorT setExtraInfo(const char* tagname, const char* new_value) {
-		// TODO: move the code to CodecMemory and CodecSCID4
-		if (std::strcmp(tagname, "type") == 0)
-			return idx->SetType(strGetUnsigned(new_value));
+		if (isReadOnly())
+			return ERROR_FileReadOnly;
 
-		if (codec_->getType() == ICodecDatabase::SCID4) {
-			if (std::strcmp(tagname, "description") == 0)
-				return idx->SetDescription(new_value);
-
-			if (std::strcmp(tagname, "autoload") == 0)
-				return idx->SetAutoLoad(strGetUnsigned(new_value));
-
-			auto len = std::strlen(tagname);
-			if (len == 5 && std::equal(tagname, tagname + 4, "flag")) {
-				uint flagType = IndexEntry::CharToFlag(tagname[4]);
-				if (flagType != 0 &&
-				    idx->GetCustomFlagDesc(flagType) != nullptr)
-					return idx->SetCustomFlagDesc(flagType, new_value);
-			}
-		}
-		return ERROR_CodecUnsupFeat;
+		const auto res = codec_->setExtraInfo(tagname, new_value);
+		return (res != OK) ? res : codec_->flush();
 	}
 
 	const IndexEntry* getIndexEntry(gamenumT g) const {
+		assert(g < numGames());
 		return idx->GetEntry(g);
 	}
 	const IndexEntry* getIndexEntry_bounds(gamenumT g) const {
-		if (g < numGames()) return getIndexEntry(g);
-		return 0;
+		static_assert(std::is_unsigned_v<gamenumT>);
+		return g < numGames() ? getIndexEntry(g) : nullptr;
 	}
 	const NameBase* getNameBase() const {
 		return nb_;
 	}
-	FastGame getGame(const IndexEntry* ie) const {
-		uint length = ie->GetLength();
-		const byte* b = codec_->getGameData(ie->GetOffset(), length);
-		if (b == 0) length = 0; // Error
-		return FastGame::Create(b, b + length);
+
+	/// Return the highest elo of the player (in the database's games)
+	eloT peakElo(idNumberT playerID) const {
+		if (peakEloCache_.empty()) {
+			const auto maxPlayerID = nb_->GetNumNames(NAME_PLAYER);
+			peakEloCache_.resize(maxPlayerID, 0);
+			auto updateMax = [&](auto id, auto elo) {
+				if (elo > peakEloCache_[id])
+					peakEloCache_[id] = elo;
+			};
+			for (gamenumT gnum = 0, n = numGames(); gnum < n; gnum++) {
+				IndexEntry const& ie = *getIndexEntry(gnum);
+				updateMax(ie.GetWhite(), ie.GetWhiteElo());
+				updateMax(ie.GetBlack(), ie.GetBlackElo());
+			}
+		}
+
+		ASSERT(playerID < peakEloCache_.size());
+		return peakEloCache_[playerID];
 	}
-	errorT getGame(const IndexEntry* ie, ByteBuffer* destBuf) const {
-		uint length = ie->GetLength();
-		const byte* b = codec_->getGameData(ie->GetOffset(), length);
-		if (b == 0) return ERROR_FileRead;
-		// The data for the game is not actually copied into the bytebuffer, which would
-		// be slower and a waste of time if the bytebuffer is not going to be modified.
-		destBuf->ProvideExternal(const_cast<byte*>(b), length);
-		return OK;
+
+	eloT peakElo(const char* player) const {
+		idNumberT playerID;
+		if (getNameBase()->FindExactName(NAME_PLAYER, player, &playerID) == OK)
+			return peakElo(playerID);
+
+		return 0;
 	}
+
+	GameView getGame(const IndexEntry* ie) const {
+		auto data = codec_->getGameMoves(*ie);
+		if (data) {
+			auto [errPos, fen] = data.decodeStartBoard();
+			if (errPos == OK) {
+				if (fen) {
+					Position startPos;
+					if (startPos.ReadFromFEN(fen) == OK) {
+						return GameView(data, startPos);
+					}
+				} else {
+					return GameView(data);
+				}
+			}
+		}
+		return GameView({nullptr, 0});
+	}
+	ByteBuffer getGame(const IndexEntry& ie) const {
+		return codec_->getGameData(ie.GetOffset(), ie.GetLength());
+	}
 	errorT getGame(const IndexEntry& ie, Game& dest) const {
-		ByteBuffer buf(0);
-		auto res = getGame(&ie, &buf);
-		return (res != OK) ? res : dest.Decode(&buf, GAME_DECODE_ALL);
+		return dest.Decode(ie, TagRoster::make(ie, *getNameBase()),
+		                   getGame(ie));
 	}
 
-	errorT importGame(const scidBaseT* srcBase, uint gNum);
 	errorT importGames(const scidBaseT* srcBase, const HFilter& filter,
 	                   const Progress& progress);
 	errorT importGames(ICodecDatabase::Codec dbtype, const char* filename,
@@ -173,42 +185,45 @@ struct scidBaseT {
 	 * @returns OK if successful or an error code.
 	 */
 	errorT saveGame(Game* game, gamenumT replacedGameId = INVALID_GAMEID);
-	// TODO: private:
-	errorT saveGameHelper(Game* game, gamenumT gameId);
-
 
 	bool getFlag(uint flag, uint gNum) const {
 		return idx->GetEntry(gNum)->GetFlag (flag);
 	}
 	errorT setFlag(bool value, uint flag, uint gNum);
-	errorT setFlag(bool value, uint flag, const HFilter& filter);
+	errorT setFlags(bool value, uint flag, const HFilter& filter);
 	errorT invertFlag(uint flag, uint gNum);
-	errorT invertFlag(uint flag, const HFilter& filter);
+	errorT invertFlags(uint flag, const HFilter& filter);
 
 	/**
 	 * A Filter is a selection of games, usually obtained searching the
 	 * database. A new Filter is created calling the function newFilter()
 	 * and must be released calling the function deleteFilter().
-	 * A composed Filter is a special construct created combining two Filters
-	 * and includes only the games contained in both Filters.
-	 * A composed Filter should NOT be released.
 	 */
 	std::string newFilter();
-	std::string composeFilter(const std::string& mainFilter,
-	                          const std::string& maskFilter) const;
 	void deleteFilter(const char* filterId);
-	HFilter getFilter(const std::string& filterId) const {
-		return getFilterHelper(filterId, false);
-	}
-	HFilter getMainFilter(const std::string& filterId) const {
-		return getFilterHelper(filterId, true);
-	}
+	HFilter getFilter(std::string_view filterId) const;
+
+	/// A composed filter is a special construct created combining two filters
+	/// and includes only the games contained in both filters. It should NOT be
+	/// deleted and became invalid if any of its components is deleted.
+	/// @mainFilter: valid identifier of the main filter (the filter which is
+	///              modified by non-const operations).
+	/// @maskFilter: valid identifier of the mask filter (const).
+	/// @return the id of the composed filter.
+	std::string composeFilter(std::string_view mainFilter,
+	                          std::string_view maskFilter) const;
+
+	/// Get the components of a composed filter.
+	/// @filterId: valid identifier of a filter.
+	/// @return the components (second is empty if its not a a composed filter).
+	std::pair<std::string, std::string>
+	getFilterComponents(std::string_view filterId) const;
 
 	const Stats& getStats() const;
-	std::vector<scidBaseT::TreeStat> getTreeStat(const HFilter& filter);
+	std::vector<TreeNode> getTreeStat(const HFilter& filter) const;
 	uint getNameFreq (nameT nt, idNumberT id) {
 		if (nameFreq_[nt].size() == 0)
-			nameFreq_ = idx->calcNameFreq(*getNameBase());
+			nameFreq_ = getNameBase()->calcNameFreq(*idx);
 		return nameFreq_[nt][id];
 	}
 
@@ -224,10 +239,9 @@ struct scidBaseT {
 	 * @param criteria: the list of fields by which games will be ordered.
 	 *                  Each field should be followed by '+' to indicate an
 	 *                  ascending order or by '-' for a descending order.
-	 * @returns a pointer to a SortCache object in case of success, NULL
-	 * otherwise.
+	 * @returns true on success
 	 */
-	SortCache* createSortCache(const char* criteria);
+	bool createSortCache(const char* criteria);
 
 	/**
 	 * Decrement the reference count of the SortCache object matching @e
@@ -274,14 +288,6 @@ struct scidBaseT {
 	size_t sortedPosition(const char* criteria, const HFilter& filter,
 	                      gamenumT gameId);
 
-	void setDuplicates(uint* duplicates) {
-		if (duplicates_ != NULL) { delete[] duplicates_; duplicates_ = NULL; }
-		duplicates_ = duplicates;
-	}
-	uint getDuplicates(gamenumT gNum) {
-		return (duplicates_ == NULL) ? 0 : duplicates_[gNum];
-	}
-
 	/**
 	 * Transform the IndexEntries of the games included in @e hfilter.
 	 * The @e entry_op must accept a IndexEntry& parameter and return true when
@@ -295,7 +301,9 @@ struct scidBaseT {
 	template <typename TOper>
 	std::pair<errorT, size_t>
 	transformIndex(HFilter hfilter, const Progress& progress, TOper entry_op) {
-		beginTransaction();
+		if (auto errModify = beginTransaction())
+			return {errModify, 0};
+
 		auto res = transformIndex_(hfilter, progress, entry_op);
 		auto err = endTransaction();
 		res.first = (res.first == OK) ? err : res.first;
@@ -324,34 +332,83 @@ struct scidBaseT {
 	               const std::vector<std::string>& newNames, TInitFunc fnInit,
 	               TMapFunc getID);
 
-	// TODO: private:
 	/**
-	 * This function must be called before modifying the games of the database.
-	 * Currently this function do not guarantees that the database is not altered
-	 * in case of errors.
+	 * Strip the games included in @e hfilter.
+	 * @param hfilter:  HFilter containing the games to be transformed.
+	 * @param progress: a Progress object used for GUI communications.
+	 * @param entry_op: operator that will be applied to games.
+	 * @returns a std::pair containing OK (or an error code) and the number of
+	 * games modified.
 	 */
-	void beginTransaction();
+	std::pair<errorT, size_t>
+	stripGames(HFilter hfilter, const Progress& progress,
+	           std::vector<std::string_view> const& removeTags) {
+		if (auto errModify = beginTransaction())
+			return {errModify, 0};
 
-	// TODO: private:
-	/**
-	 * Update caches and flush the database's files.
-	 * This function must be called after changing one or more games.
-	 * @param gameId: id of the modified game
-	 *                INVALID_GAMEID to update all games.
-	 * @returns OK if successful or an error code.
-	 */
-	errorT endTransaction(gamenumT gameId = INVALID_GAMEID);
+		std::vector<std::pair<std::string_view, std::string_view>> tagsBuf;
+		std::vector<byte> encodeBuf;
+		size_t nCorrections = 0;
+		size_t iProg = 0;
+		const size_t totProg = hfilter->size();
+		errorT err = OK;
+		for (const auto gnum : hfilter) {
+			if ((++iProg % 1024 == 0) && !progress.report(iProg, totProg)) {
+				err = ERROR_UserCancel;
+				break;
+			}
+
+			bool changed = false;
+			tagsBuf.clear();
+			IndexEntry const& ie = *getIndexEntry(gnum);
+			auto gamedata = getGame(ie);
+			auto err = gamedata.decodeTags(
+			    [&](auto const& tag, auto const& value) {
+				    if (std::find(removeTags.begin(), removeTags.end(), tag) !=
+				        removeTags.end())
+					    changed = true;
+				    else
+					    tagsBuf.emplace_back(tag, value);
+			    });
+			if (err != OK)
+				break;
+
+			if (!changed)
+				continue;
+
+			encodeBuf.clear();
+			encodeTags(tagsBuf, encodeBuf);
+			encodeBuf.insert(encodeBuf.end(), gamedata.data(),
+			                 gamedata.data() + gamedata.size());
+			err = codec_->saveGame(ie, TagRoster::make(ie, *nb_),
+			                       {encodeBuf.data(), encodeBuf.size()}, gnum);
+			if (err != OK)
+				break;
+
+			++nCorrections;
+		}
+		const auto err_trans = endTransaction();
+		if (err == OK)
+			err = err_trans;
+		return {err, nCorrections};
+	}
+
+	std::unique_ptr<gamenumT[]> extractDuplicates() {
+		return std::move(duplicates_);
+	}
+	void setDuplicates(std::unique_ptr<gamenumT[]> duplicates) {
+		duplicates_ = std::move(duplicates);
+	}
+	gamenumT getDuplicates(gamenumT gNum) const {
+		return duplicates_ ? duplicates_[gNum] : 0;
+	}
 
 public:
-	Index* idx;       // the Index file in memory for this base.
 	bool inUse;       // true if the database is open (in use).
-	treeT tree;
 	TreeCache treeCache;
-	ByteBuffer* bbuf;
 	Filter* dbFilter;
 	Filter* treeFilter;
 
-
 	//TODO: this vars do not belong to scidBaseT class
 	Game* game;       // the active game for this base.
 	int gameNumber;   // game number of active game.
@@ -361,22 +418,37 @@ public:
 
 private:
 	std::unique_ptr<ICodecDatabase> codec_;
+	Index* idx;
 	NameBase* nb_;
 	std::string fileName_; // File name without ".si" suffix
 	fileModeT fileMode_; // Read-only, write-only, or both.
 	std::vector< std::pair<std::string, Filter*> > filters_;
 	mutable Stats* stats_;
 	std::array<std::vector<int>, NUM_NAME_TYPES> nameFreq_;
-	uint* duplicates_; // For each game: idx of duplicate game + 1 (0 if there is no duplicate).
+	std::unique_ptr<gamenumT[]> duplicates_; // For each game: idx of duplicate game + 1 (0 if there is no duplicate).
 	std::vector< std::pair<std::string, SortCache*> > sortCaches_;
+	mutable std::vector<eloT> peakEloCache_;
 
 private:
+	errorT openHelper(ICodecDatabase::Codec dbtype, fileModeT mode,
+	                  const char* filename, const Progress& progress = {});
+
 	void clear();
+
+	/// This function must be called before modifying the games of the database.
+	/// Currently this function do not guarantees that the database is not
+	/// altered in case of errors.
+	errorT beginTransaction();
+
+	/// Update caches and flush the database's files.
+	/// This function must be called after changing one or more games.
+	/// @param gameId: id of the modified game
+	///                INVALID_GAMEID to update all games.
+	/// @returns OK if successful or an error code.
+	errorT endTransaction(gamenumT gameId = INVALID_GAMEID);
+
 	errorT importGameHelper(const scidBaseT* sourceBase, uint gNum);
 
-	Filter* fetchFilter(const std::string& filterId) const;
-	HFilter getFilterHelper(const std::string& filterId,
-	                        bool unmasked = false) const;
 	SortCache* getSortCache(const char* criteria);
 
 	/**
@@ -413,65 +485,13 @@ private:
 	}
 };
 
-inline void scidBaseT::TreeStat::add(int result, int eloW, int eloB) {
-	ngames++;
-	double r = 0;
-	switch (result) {
-		case RESULT_White: resultW++; r = 1; break;
-		case RESULT_Draw: resultD++; r = 0.5; break;
-		case RESULT_Black: resultB++; break;
-		default: return;
-	}
-	if (eloW == 0 || eloB == 0) return;
-	int eloDiff = eloB - eloW;
-	if (eloDiff < 800 && eloDiff >= -800) {
-		exp += r - expVect_[eloDiff+800];
-		nexp++;
-	}
-}
-
-inline errorT scidBaseT::invertFlag(uint flag, uint gNum) {
-	return setFlag(! getFlag(flag, gNum), flag, gNum);
-}
-
-inline errorT scidBaseT::invertFlag(uint flag, const HFilter& filter) {
-	errorT res = OK;
-	for (gamenumT i = 0, n = numGames(); i < n; i++) {
-		if (filter != 0 && filter->get(i) == 0) continue;
-		res = invertFlag(flag, i);
-		if (res != OK) return res;
-	}
-	return res;
-}
-
-inline errorT scidBaseT::setFlag(bool value, uint flag, uint gNum){
-	ASSERT(gNum < idx->GetNumGames());
-	IndexEntry* ie = idx->FetchEntry (gNum);
-	ie->SetFlag (flag, value);
-	errorT res = idx->WriteEntry(ie, gNum);
-	if (stats_ != NULL) { delete stats_; stats_ = NULL;}
-	// TODO: necessary only for sortcaches with SORTING_deleted (and SORTING_flags when implemented)
-	// idx->IndexUpdated(gNum);
-	return res;
-}
-
-inline errorT scidBaseT::setFlag(bool value, uint flag, const HFilter& filter) {
-	errorT res = OK;
-	for (gamenumT gNum = 0, n = numGames(); gNum < n; gNum++) {
-		if (filter != 0 && filter->get(gNum) == 0) continue;
-		res = setFlag(value, flag, gNum);
-		if (res != OK) return res;
-	}
-	return res;
-}
-
-
 template <typename TInitFunc, typename TMapFunc>
 std::pair<errorT, size_t>
 scidBaseT::transformNames(nameT nt, HFilter hfilter, const Progress& progress,
                           const std::vector<std::string>& newNames,
-                          TInitFunc initFunc, TMapFunc getID) {
-	beginTransaction();
+                          TInitFunc initFunc, TMapFunc getNewID) {
+	if (auto errModify = beginTransaction())
+		return {errModify, 0};
 
 	std::vector<idNumberT> nameIDs(newNames.size());
 	auto it = nameIDs.begin();
@@ -486,43 +506,46 @@ scidBaseT::transformNames(nameT nt, HFilter hfilter, const Progress& progress,
 
 	initFunc(nameIDs);
 
-	auto fnGet = [](nameT nt, const IndexEntry& ie) {
-		switch (nt) { // clang-format off
-		case NAME_PLAYER: return ie.GetWhite();
-		case NAME_EVENT:  return ie.GetEvent();
-		case NAME_SITE:   return ie.GetSite();
-		} // clang-format on
-		ASSERT(nt == NAME_ROUND);
-		return ie.GetRound();
-	};
-	auto fnSet = [](nameT nt, IndexEntry& ie, idNumberT newID) {
-		switch (nt) { // clang-format off
-		case NAME_PLAYER: return ie.SetWhite(newID);
-		case NAME_EVENT:  return ie.SetEvent(newID);
-		case NAME_SITE:   return ie.SetSite(newID);
-		} // clang-format on
-		ASSERT(nt == NAME_ROUND);
-		return ie.SetRound(newID);
-	};
 	auto res = transformIndex_(hfilter, progress, [&](IndexEntry& ie) {
 		const IndexEntry& ie_const = ie;
-		auto oldID = fnGet(nt, ie);
-		auto newID = getID(oldID, ie_const);
-		bool b1 = (oldID != newID);
-		idNumberT newBlack = 0;
-		bool b2 = (nt == NAME_PLAYER);
-		if (b2) {
-			auto oldBlack = ie.GetBlack();
-			newBlack = getID(oldBlack, ie_const);
-			b2 = (oldBlack != newBlack);
+		idNumberT oldID;
+		idNumberT oldBlackID = 0;
+		idNumberT newBlackID = 0;
+		switch (nt) {
+		case NAME_PLAYER:
+			oldID = ie_const.GetWhite();
+			oldBlackID = ie_const.GetBlack();
+			newBlackID = getNewID(oldBlackID, ie_const);
+			break;
+		case NAME_EVENT:
+			oldID = ie_const.GetEvent();
+			break;
+		case NAME_SITE:
+			oldID = ie_const.GetSite();
+			break;
+		default:
+			ASSERT(nt == NAME_ROUND);
+			oldID = ie_const.GetRound();
 		}
-		if (!b1 && !b2)
+		const auto newID = getNewID(oldID, ie_const);
+		if (oldID == newID && oldBlackID == newBlackID)
 			return false;
 
-		if (b1)
-			fnSet(nt, ie, newID);
-		if (b2)
-			ie.SetBlack(newBlack);
+		switch (nt) {
+		case NAME_PLAYER:
+			ie.SetWhite(newID);
+			ie.SetBlack(newBlackID);
+			break;
+		case NAME_EVENT:
+			ie.SetEvent(newID);
+			break;
+		case NAME_SITE:
+			ie.SetSite(newID);
+			break;
+		default:
+			ASSERT(nt == NAME_ROUND);
+			ie.SetRound(newID);
+		}
 		return true;
 	});
 
