@@ -21,6 +21,7 @@
 #include "scidbase.h"
 #include <algorithm>
 #include <string>
+#include <string_view>
 #include <vector>
 
 namespace {
@@ -50,7 +51,7 @@ public:
 		}
 	}
 
-	void Init_exact (idNumberT n, nameT name_type, std::string pattern) {
+	void Init_exact (idNumberT n, nameT name_type, std::string const& pattern) {
 		const NameBase* nb = base_->getNameBase();
 		for (idNumberT i=0; i < n; i++) {
 			const char* name = nb->GetName (name_type, i);
@@ -144,6 +145,19 @@ public:
 	}
 };
 
+class SearchVariant {
+	const scidBaseT* base_;
+	bool std_;
+
+public:
+	SearchVariant(const scidBaseT* base, std::string_view variant)
+	    : base_(base), std_(variant == "std") {}
+
+	bool operator()(gamenumT gnum) const {
+		return base_->getIndexEntry(gnum)->isChessStd() == std_;
+	}
+};
+
 template <typename T>
 class SearchRange : public StrRange {
 protected:
@@ -224,41 +238,39 @@ public:
 
 class SearchRangeElo : public SearchRange<eloT> {
 protected:
-	eloT (IndexEntry::* fElo1_) (const NameBase*) const;
-	eloT (IndexEntry::* fElo2_) (const NameBase*) const;
-	const NameBase* nb_;
+	eloT (IndexEntry::*fElo1_)() const;
+	eloT (IndexEntry::*fElo2_)() const;
 
 public:
-	SearchRangeElo(const scidBaseT* base,
-	               const char* range,
-	               eloT (IndexEntry::* f1) (const NameBase*) const,
-	               eloT (IndexEntry::* f2) (const NameBase*) const = 0)
-	: SearchRange<eloT>(base, range, 0), fElo1_(f1), fElo2_(f2) {
-		nb_ = base_->getNameBase();
-	}
+	SearchRangeElo(const scidBaseT* base, const char* range,
+	               eloT (IndexEntry::*f1)() const,
+	               eloT (IndexEntry::*f2)() const = 0)
+	    : SearchRange<eloT>(base, range, 0), fElo1_(f1), fElo2_(f2) {}
 
-	bool operator() (gamenumT gnum) const {
-		long v1 = (base_->getIndexEntry(gnum)->*fElo1_)(nb_);
+	bool operator()(gamenumT gnum) const {
+		long v1 = (base_->getIndexEntry(gnum)->*fElo1_)();
 		long v2 = min_;
-		if (fElo2_ != 0) v2 = (base_->getIndexEntry(gnum)->*fElo2_)(nb_);
-		if (v1 < min_ || v1 > max_ || v2 < min_ || v2 > max_) return false;
+		if (fElo2_ != 0)
+			v2 = (base_->getIndexEntry(gnum)->*fElo2_)();
+		if (v1 < min_ || v1 > max_ || v2 < min_ || v2 > max_)
+			return false;
 		return true;
 	}
 };
 
 class SearchRangeEloDiff : public SearchRangeElo {
 public:
-	SearchRangeEloDiff(const scidBaseT* base,
-	                   const char* range,
-	                   eloT (IndexEntry::* f1) (const NameBase*) const,
-	                   eloT (IndexEntry::* f2) (const NameBase*) const)
-	: SearchRangeElo(base, range, f1, f2) {}
+	SearchRangeEloDiff(const scidBaseT* base, const char* range,
+	                   eloT (IndexEntry::*f1)() const,
+	                   eloT (IndexEntry::*f2)() const)
+	    : SearchRangeElo(base, range, f1, f2) {}
 
-	bool operator() (gamenumT gnum) const {
-		long v1 = (base_->getIndexEntry(gnum)->*fElo1_)(nb_);
-		long v2 = (base_->getIndexEntry(gnum)->*fElo2_)(nb_);
+	bool operator()(gamenumT gnum) const {
+		long v1 = (base_->getIndexEntry(gnum)->*fElo1_)();
+		long v2 = (base_->getIndexEntry(gnum)->*fElo2_)();
 		long v = v1 - v2;
-		if (v < min_ || v > max_) return false;
+		if (v < min_ || v > max_)
+			return false;
 		return true;
 	}
 };
@@ -451,6 +463,9 @@ I doSearch(I itB, I itR, I itE, const scidBaseT* base, SearchParam& param) {
 	if (param == "result") return std::stable_partition(itB, itE,
 		SearchResult(base, param.getValue())
 	);
+	if (param == "variant")
+		return std::stable_partition(itB, itE,
+		                             SearchVariant(base, param.getValue()));
 
 	param.invalidate();
 	return itR;
