@@ -292,19 +292,20 @@ errorT SpellChecker::read(const char* filename, const Progress& progress)
 	}
 
 	// Free unused memory
-	char* shrink = (char*) realloc(staticStrings_, 1 + std::distance(staticStrings_,line));
-	if (shrink != NULL && shrink != staticStrings_) {
-		// Unlikely, but realloc() moved the memory: update the pointers.
-		const char* oldAddr = staticStrings_;
+	const auto new_size = std::distance(staticStrings_, line);
+	char* shrink = (char*)realloc(staticStrings_, new_size ? new_size : 1);
+	if (shrink) {
+		const auto offset = shrink - staticStrings_;
 		staticStrings_ = shrink;
-		for (nameT i=0; i < NUM_NAME_TYPES; i++) {
-			for (auto& e : (names_[i]))
-				e = staticStrings_ + std::distance(oldAddr, e);
-		}
-		for (auto& e : pInfo_) {
-			e.comment_ = staticStrings_ + std::distance(oldAddr, e.comment_);
-			for (auto& bio : e.bio_) {
-				bio = staticStrings_ + std::distance(oldAddr, bio);
+		if (offset) { // realloc() moved the memory: update the pointers.
+			for (nameT i = 0; i < NUM_NAME_TYPES; i++) {
+				for (auto& e : names_[i])
+					e += offset;
+			}
+			for (auto& e : pInfo_) {
+				e.comment_ += offset;
+				for (auto& bio : e.bio_)
+					bio += offset;
 			}
 		}
 	}
@@ -388,9 +389,9 @@ const char *
 PlayerInfo::getTitle() const
 {
     static const char * titles[] = {
-        "gm", "im", "fm",
-        "wgm", "wim", "wfm", "w",
-        "cgm", "cim", "hgm",
+        "GM", "IM", "FM",
+        "WGM", "WIM", "WFM", "W",
+        "CGM", "CIM", "HGM",
         NULL
     };
     const char ** titlePtr = titles;
@@ -399,7 +400,7 @@ PlayerInfo::getTitle() const
     if (*comment == 0) { return ""; }
 
     while (*titlePtr != NULL) {
-        if (strIsPrefix (*titlePtr, comment)) { return *titlePtr; }
+        if (strIsCasePrefix (*titlePtr, comment)) { return *titlePtr; }
         titlePtr++;
     }
     return "";
