@@ -58,60 +58,17 @@ public:
 };
 
 class SquareSet {
-	uint Bits_a1h4;
-	uint Bits_a5h8;
+	unsigned long long bits_ = 0;
 
 public:
-	SquareSet() { Bits_a1h4 = Bits_a5h8 = 0; }
-	SquareSet(squareT* squares) {
-		Bits_a1h4 = Bits_a5h8 = 0;
-		AddAll(squares);
-	}
-
-	void Clear(void) { Bits_a1h4 = Bits_a5h8 = 0; }
-	void AddAll(void) { Bits_a1h4 = Bits_a5h8 = 0xFFFFFFFFu; }
-
 	void Add(squareT sq) {
-		ASSERT(sq <= H8);
-		if (sq <= H4) {
-			Bits_a1h4 |= (1 << sq);
-		} else {
-			Bits_a5h8 |= (1 << (sq & 31));
-		}
-	}
-
-	void AddAll(squareT* squares) {
-		while (true) {
-			squareT sq = *squares;
-			if (sq == NULL_SQUARE) {
-				break;
-			}
-			ASSERT(sq <= H8);
-			squares++;
-			if (sq <= H4) {
-				Bits_a1h4 |= (1 << sq);
-			} else {
-				Bits_a5h8 |= (1 << (sq & 31));
-			}
-		}
+		ASSERT(sq < 64);
+		bits_ |= 1ull << sq;
 	}
 
 	bool Contains(squareT sq) {
-		ASSERT(sq <= H8);
-		if (sq <= H4) {
-			return (Bits_a1h4 & (1 << sq)) != 0;
-		} else {
-			return (Bits_a5h8 & (1 << (sq & 31))) != 0;
-		}
-	}
-
-	void Remove(squareT sq) {
-		ASSERT(sq <= H8);
-		if (sq <= H4) {
-			Bits_a1h4 &= ~(1 << sq);
-		} else {
-			Bits_a5h8 &= ~(1 << (sq & 31));
-		}
+		ASSERT(sq < 64);
+		return (bits_ & (1ull << sq)) != 0;
 	}
 };
 
@@ -119,8 +76,8 @@ public:
 // sqMove
 //   Array indexed by square value and direction, giving the square
 //   obtained by moving from the square in that direction.
-constexpr squareT
-sqMove[66][11] = {
+inline constexpr squareT
+precomputed_sqMove[66][11] = {
                 /* UP DOWN    LEFT UL  DL    RIGHT UR  DR */
    { /* A1 */  NS, A2, NS, NS, NS, NS, NS, NS, B1, B2, NS   },
    { /* B1 */  NS, B2, NS, NS, A1, A2, NS, NS, C1, C2, NS   },
@@ -196,8 +153,8 @@ sqMove[66][11] = {
 //   square reached by moving from the square in that direction.
 //   The last square is the same as the original square if moving
 //   in the specified direction would move off the board.
-constexpr squareT
-sqLast[66][11] = {
+inline constexpr squareT
+precomputed_sqLast[66][11] = {
                 /* UP DOWN    LEFT UL  DL    RIGHT UR  DR */
    { /* A1 */  NS, A8, A1, NS, A1, A1, A1, NS, H1, H8, A1   },
    { /* B1 */  NS, B8, B1, NS, A1, A2, B1, NS, H1, H7, B1   },
@@ -272,7 +229,7 @@ sqLast[66][11] = {
 constexpr squareT
 square_Move(squareT sq, directionT dir)
 {
-    return sqMove[sq][dir];
+    return precomputed_sqMove[sq][dir];
 }
 
 // square_Last():
@@ -285,7 +242,7 @@ square_Move(squareT sq, directionT dir)
 constexpr squareT
 square_Last (squareT sq, directionT dir)
 {
-    return sqLast[sq][dir];
+    return precomputed_sqLast[sq][dir];
 }
 
 #endif
