@@ -1,6 +1,7 @@
 # board.tcl: part of Scid
 # Copyright (C) 2001-2003 Shane Hudson. All rights reserved.
-# Copyright (C) 2014 Fulvio Benini
+# Copyright (C) 2014-2021 Fulvio Benini
+# Copyright (C) 2021 Uwe Klimmek
 
 # letterToPiece
 #    Array that maps piece letters to their two-character value.
@@ -23,6 +24,22 @@ set colorSchemes {
 }
 array set newColors {}
 
+# calculate an average of the colors from a graphic file
+proc avgImgColor { file } {
+    set i 0; set r 0; set g 0; set b 0
+    set textureSize [image height $file]
+    for { set p 2 } { $p < $textureSize } {incr p 4; incr i } {
+        lassign [$file get $p $p] r1 g1 b1
+        incr r $r1
+        incr g $g1
+        incr b $b1
+    }
+    set r [expr int(($r) / $i)]
+    set g [expr int(($g) / $i)]
+    set b [expr int(($b) / $i)]
+    return [ format "#%02x%02x%02x" $r $g $b ]
+}
+
 proc SetBoardTextures {} {
   global boardfile_dark boardfile_lite
   # handle cases of old configuration files
@@ -81,7 +98,6 @@ proc setPieceFont {font} {
 		if {$size >= $::boardSize} { break }
 	}
 	set ::boardSize $size
-	menuUpdateBoardSizes
 	SetBoardTextures
 }
 
@@ -95,69 +111,87 @@ proc chooseBoardTextures {i} {
   set boardfile_dark ${prefix}-d
   set boardfile_lite ${prefix}-l
   SetBoardTextures
-  
+  # create colors for coords on the board
+  # use variable lite and dark from colorschemes
+  set ::squareColor_lite [::avgImgColor $boardfile_lite]
+  set ::squareColor_dark [::avgImgColor $boardfile_dark]
+  ::board::innercoords .main.board
+  updateBoard
+}
+
+proc updateBoardColors { w {choice -1}} {
+  global squareColor_lite squareColor_dark highcolor bestcolor
+  global colorSchemes newColors
+  set colors {squareColor_lite squareColor_dark highcolor bestcolor}
+  # Just update the dialog box colors and return:
+  if {$choice >= 0} {
+    set list [lindex $colorSchemes $choice]
+    set newColors(squareColor_lite) [lindex $list 1]
+    set newColors(squareColor_dark) [lindex $list 2]
+    set newColors(highcolor) [lindex $list 3]
+    set newColors(bestcolor) [lindex $list 4]
+
+    # Remove board textures
+    set ::boardfile_dark emptySquare
+    set ::boardfile_lite emptySquare
+    ::SetBoardTextures
+  }
+  set nlite $newColors(squareColor_lite)
+  set ndark $newColors(squareColor_dark)
+
+  foreach i {wr bn wb bq wk bp} {
+    $w.bd.$i configure -background $ndark
+  }
+  foreach i {br wn bb wq bk wp} {
+    $w.bd.$i configure -background $nlite
+  }
+  $w.bd.bb configure -background $newColors(highcolor)
+  $w.bd.wk configure -background $newColors(bestcolor)
+  foreach i $colors {
+    $w.select.b$i configure -background $newColors($i)
+  }
+
+  foreach i {squareColor_lite squareColor_dark highcolor bestcolor} {
+    set $i $newColors($i)
+  }
+  foreach i {0 1 2 3} {
+    set c $w.border.c$i
+    $c itemconfigure dark -fill $squareColor_dark -outline $squareColor_dark
+    $c itemconfigure lite -fill $squareColor_lite -outline $squareColor_lite
+  }
+  foreach i {0 1 2 3 4} {
+    set c $w.coords.c$i
+    $c itemconfigure dark -fill $squareColor_dark -outline $squareColor_dark
+    $c itemconfigure lite -fill $squareColor_lite -outline $squareColor_lite
+  }
+  ::board::innercoords .main.board
+  updateBoard
+  return
 }
 
 # chooseBoardColors:
 #   Dialog for selecting board colors.
+#   Frame for this dialog is generated by preferences dialog
 #
-proc chooseBoardColors {{choice -1}} {
-  global lite dark highcolor bestcolor
+proc chooseBoardColors { w {choice -1}} {
+  global squareColor_lite squareColor_dark highcolor bestcolor
   global colorSchemes newColors
-  
-  set colors {lite dark highcolor bestcolor}
-  
-  set w .boardColorDialog
-  
-  if {[winfo exists $w]} {
-    # Just update the dialog box colors and return:
-    if {$choice >= 0} {
-      set list [lindex $colorSchemes $choice]
-      set newColors(lite) [lindex $list 1]
-      set newColors(dark) [lindex $list 2]
-      set newColors(highcolor) [lindex $list 3]
-      set newColors(bestcolor) [lindex $list 4]
-    }
-    set nlite $newColors(lite)
-    set ndark $newColors(dark)
-    
-    foreach i {wr bn wb bq wk bp} {
-      $w.bd.$i configure -background $ndark
-    }
-    foreach i {br wn bb wq bk wp} {
-      $w.bd.$i configure -background $nlite
-    }
-    $w.bd.bb configure -background $newColors(highcolor)
-    $w.bd.wk configure -background $newColors(bestcolor)
-    foreach i $colors {
-      $w.select.b$i configure -background $newColors($i)
-    }
-    
-    foreach i {0 1 2 3} {
-      set c $w.border.c$i
-      $c itemconfigure dark -fill $dark -outline $dark
-      $c itemconfigure lite -fill $lite -outline $lite
-    }
-    
-    return
-  }
-  
-  toplevel $w
-  wm title $w "Scid: [tr OptionsBoardColors]"
-  
+
+  set colors {squareColor_lite squareColor_dark highcolor bestcolor}
+
   foreach i $colors { set newColors($i) [set $i] }
   set bd $w.bd
-  pack [ttk::frame $bd] -side top -expand 1
+  pack [ttk::frame $bd] -side top -expand 1 -anchor w
   addHorizontalRule $w
-  pack [ttk::frame $w.select] -side top -fill x
+  pack [ttk::frame $w.select] -side top -fill x -padx 5
   addHorizontalRule $w
   pack [ttk::frame $w.preset] -side top -fill x
-  pack [ttk::frame $w.texture] -side top -fill x
+  pack [ttk::frame $w.texture] -side top -fill x -pady 2
   addHorizontalRule $w
-  pack [ttk::frame $w.border] -side top
+  pack [ttk::frame $w.coords] -side top -fill x -pady 4
   addHorizontalRule $w
-  pack [ttk::frame $w.buttons] -side top -fill x
-  
+  pack [ttk::frame $w.border] -side top -anchor w -pady { 4 0 }
+
   foreach psize $::boardSizes {
     if {$psize >= 40} { break }
   }
@@ -169,28 +203,43 @@ proc chooseBoardColors {{choice -1}} {
     grid $bd.w$j -row 1 -column $column
     incr column
   }
-  
+  ttk::frame $bd.p
+  ttk::label $bd.p.lb -text [tr OptionsBoardPieces]
+  ttk::combobox $bd.p.pieces -width 12 -textvar ::boardStyle -values $::boardStyles
+  bind $bd.p.pieces <<ComboboxSelected>> { setPieceFont $::boardStyle; updateBoard }
+  ttk::frame $bd.s
+  ttk::label $bd.s.lb -text [tr OptionsBoardSize]
+  ttk::checkbutton $bd.s.auto -text "Auto" -variable ::autoResizeBoard -command "::resizeMainBoard"
+  ttk::combobox $bd.s.size -width 4 -textvar ::boardSize  -values $::boardSizes
+  bind $bd.s.size <<ComboboxSelected>> { ::board::resize .main.board $::boardSize }
+  pack $bd.p.lb $bd.p.pieces -side left -anchor w -padx 5
+  pack $bd.s.lb $bd.s.auto $bd.s.size -side left -anchor w -padx 5
+  ttk::label $bd.empty -text "  "
+  grid $bd.empty -row 0 -column 7
+  grid $bd.p -row 0 -column 8
+  grid $bd.s -row 1 -column 8
+
   set f $w.select
   foreach row {0 1 0 1} column {0 0 2 2} c {
-    lite dark highcolor bestcolor
+    squareColor_lite squareColor_dark highcolor bestcolor
   } n {
     LightSquares DarkSquares SelectedSquares SuggestedSquares
   } {
     button $f.b$c -image e20 -background [set $c] -command "
     set x \[ tk_chooseColor -initialcolor \$newColors($c) -title Scid \]
-    if {\$x != \"\"} { set newColors($c) \$x; chooseBoardColors }
+    if {\$x != \"\"} { set newColors($c) \$x; updateBoardColors $w}
     "
     ttk::label $f.l$c -text "$::tr($n)  "
     grid $f.b$c -row $row -column $column
     grid $f.l$c -row $row -column [expr {$column + 1} ] -sticky w
   }
-  
+
   # Border width option:
   set f $w.border
   foreach i {0 1 2 3} {
     if {$i != 0} { pack [ttk::frame $f.gap$i -width 20] -side left -padx 1 }
     set b $f.b$i
-    ttk::radiobutton $b -text "$i:" -variable newborderwidth -value $i
+    ttk::radiobutton $b -text "$i:" -variable ::borderwidth -value $i -command "set ::borderwidth $i; ::board::border .main.board $i; updateBoard"
     set c $f.c$i
     canvas $c -height $psize -width $psize -background black
     $c create rectangle 0 0 [expr {20 - $i}] [expr {20 - $i}] -tag dark
@@ -198,10 +247,51 @@ proc chooseBoardColors {{choice -1}} {
     $c create rectangle 0 [expr {20 + $i}] [expr 20 - $i] $psize -tag lite
     $c create rectangle [expr {20 + $i}] 0 $psize [expr {20 - $i}] -tag lite
     pack $b $c -side left -padx 1
-    bind $c <Button-1> "set newborderwidth $i"
+    bind $c <Button-1> "set ::borderwidth $i; ::board::border .main.board $i; updateBoard"
   }
-  set ::newborderwidth $::borderwidth
-  
+
+  # Coords option:
+  set f $w.coords
+  # bl: border left, bt: border top, ssi: squaresize
+  set slist [list 0 0 20 8 0 16 8 8 12 8 0 20 8 0 20]
+  foreach i {0 1 2 3 4} {bl bt ssi} $slist {
+    if {$i != 0} { pack [ttk::frame $f.gap$i -width 20] -side left -padx 1 }
+    set b $f.b$i
+    set fcom "set ::boardCoords $i
+              ::board::coords .main.board $i
+              ::board::resize .main.board redraw"
+    ttk::radiobutton $b -text "$i:" -variable ::boardCoords -value $i -command $fcom
+    set c $f.c$i
+    canvas $c -height $psize -width $psize -background white
+    if { $i >= 3 } {
+        set x0 0
+        set y0 0
+    } else {
+        set x0 [expr $bl]
+        set y0 [expr $bt]
+    }
+    set x1 [expr $x0 + $ssi]
+    set y1 [expr $y0 + $ssi]
+    set x2 [expr $x1 + $ssi]
+    set y2 [expr $y1 + $ssi]
+    $c create rectangle $x0 $y0 $x1 $y1 -tag dark
+    $c create rectangle $x1 $y1 $x2 $y2 -tag dark
+    $c create rectangle $x0 $y1 $x1 $y2 -tag lite
+    $c create rectangle $x1 $y0 $x2 $y1 -tag lite
+    if { $i > 0 } {
+        foreach { x y co } { 4 30 1 4 10 2 14 36 a 28 36 b } {
+            $c create text $x $y -text $co -fill black -font font_Small
+        }
+        if { $i == 2 || $i == 4 } {
+            foreach { x y co } { 38 30 1 38 10 2 14 4 a 28 4 b } {
+                $c create text $x $y -text $co -fill black -font font_Small
+            }
+        }
+    }
+    pack $b $c -side left -padx 1
+    bind $c <Button-1> $fcom
+  }
+
   set count 0
   foreach list $colorSchemes {
     set f $w.preset.p$count
@@ -210,16 +300,12 @@ proc chooseBoardColors {{choice -1}} {
     ttk::label $f.bdark -image bp$psize -background [lindex $list 2]
     ttk::label $f.wlite -image wp$psize -background [lindex $list 1]
     ttk::label $f.wdark -image wp$psize -background [lindex $list 2]
-    ttk::button $f.select -text [expr {$count + 1}] -command "chooseBoardColors $count ; \
-        set ::boardfile_dark emptySquare ; \
-        set ::boardfile_lite emptySquare ; \
-        ::SetBoardTextures "
-    foreach i {blite bdark wlite wdark} {
-      bind $f.$i <1> "chooseBoardColors $count ; \
-          set ::boardfile_dark emptySquare ; \
-          set ::boardfile_lite emptySquare ; \
-          ::SetBoardTextures "
-    }
+    ttk::button $f.select -text [expr {$count + 1}] \
+        -command "updateBoardColors $w $count"
+    bind $f.blite <1> "$f.select invoke"
+    bind $f.bdark <1> "$f.select invoke"
+    bind $f.wlite <1> "$f.select invoke"
+    bind $f.wdark <1> "$f.select invoke"
     grid $f.blite -row 0 -column 0 -sticky e
     grid $f.bdark -row 0 -column 1 -sticky w
     grid $f.wlite -row 1 -column 1 -sticky w
@@ -227,7 +313,7 @@ proc chooseBoardColors {{choice -1}} {
     grid $f.select -row 2 -column 0 -columnspan 2 ; # -sticky we
     incr count
   }
-  
+
   #########################################################
   set f $w.texture
   set count 0
@@ -241,7 +327,7 @@ proc chooseBoardColors {{choice -1}} {
     $f.c create image $psize 0 -image ${tex}-d -anchor nw
     $f.c create image 0 $psize -image ${tex}-d -anchor nw
     $f.c create image $psize $psize -image ${tex}-l -anchor nw
-    
+
     $f.c create image 0 0 -image bp$psize -anchor nw
     $f.c create image $psize 0 -image wp$psize -anchor nw
     $f.c create image 0 $psize -image wp$psize -anchor nw
@@ -249,28 +335,12 @@ proc chooseBoardColors {{choice -1}} {
     ttk::button $f.select -text [expr {$count + 1}] -command "chooseBoardTextures $count"
     bind $f.c <1> "chooseBoardTextures $count"
     pack $f.c $f.select -side top
-    
+
     incr count
     incr col
-    if {$col > 4} { set col 0 ; incr row }
+    if {$col > 5} { set col 0 ; incr row }
   }
-  
-  dialogbutton $w.buttons.ok -text "OK" -command "
-  foreach i {lite dark highcolor bestcolor} {
-    set \$i \$newColors(\$i)
-  }
-  set borderwidth \$newborderwidth
-  ::board::border .main.board \$borderwidth
-  grab release $w
-  destroy $w
-  "
-  dialogbutton $w.buttons.cancel -text $::tr(Cancel) \
-      -command "catch {grab release $w}; destroy $w"
-  bind $w <Escape> "catch {grab release $w}; destroy $w"
-  packbuttons right $w.buttons.cancel $w.buttons.ok
-  chooseBoardColors
-  wm resizable $w 0 0
-  catch {grab $w}
+  updateBoardColors $w
 }
 
 namespace eval ::board {
@@ -312,6 +382,51 @@ proc ::board::san {sqno} {
   
 }
 
+# Show a pop-up board.
+# xc and yc are the coordinates of the top-left corner, or the bottom-left
+# corner if above is not "".
+proc ::board::popup {w positionLongStr xc yc {above ""}} {
+    set psize 30
+    if {$psize > $::boardSize} { set psize $::boardSize }
+
+    if {! [winfo exists $w]} {
+        toplevel $w
+        wm overrideredirect $w 1
+        ::board::new $w.bd $psize
+        grid $w.bd
+        ::update idletasks
+    }
+
+    lassign $positionLongStr pos lastmove
+    ::board::update $w.bd $pos
+
+    if {$lastmove ne ""} {
+      ::board::lastMoveHighlight $w.bd $lastmove
+    }
+
+    # Make sure the popup window can fit on the screen:
+    set screenwidth [winfo screenwidth $w]
+    set screenheight [winfo screenheight $w]
+    set dx [winfo width $w]
+    set dy [winfo height $w]
+    incr xc 8
+    if {($xc+$dx) > $screenwidth} {
+        set xc [expr {$screenwidth - $dx}]
+    }
+    if {($yc+$dy) > ($screenheight -8)} {
+            set above 1
+    }
+    if {$above ne ""} {
+        set yc [expr { $yc -$dy -8 }]
+        if {$yc < 0} { set yc 0 }
+    } else {
+        incr yc 8
+    }
+    wm geometry $w "+$xc+$yc"
+    wm deiconify $w
+    raiseWin $w
+}
+
 # ::board::new
 #   Creates a new board in the specified frame.
 #
@@ -325,20 +440,26 @@ proc ::board::new {w {psize 40} } {
 
   set ::board::_size($w) $psize
   set ::board::_border($w) $::borderwidth
-  set ::board::_coords($w) 2
+  set ::board::_coords($w) 4
   set ::board::_flip($w) 0
   set ::board::_data($w) [sc_pos board]
   set ::board::_showMarks($w) 0
   set ::board::_mark($w) {}
   set ::board::_drag($w) -1
   set ::board::_showmat($w) 0
+  set ::board::_evalbarShow($w) 0
+  set ::board::_evalbarMaxScore($w) 4
+  set ::board::_evalbarScore($w) 0
+  set ::board::_evalbarHeight($w) 0
+  set ::board::_evalbarWidth($w) 0
+  set ::board::_evalbarScale($w) 1
   
   set border $::board::_border($w)
   set bsize [expr {$psize * 8 + $border * 9} ]
-  set bgcolor [ttk::style lookup Button.label -background]
   
   ttk::frame $w -class Board
-  canvas $w.bd -width $bsize -height $bsize -cursor crosshair -background $bgcolor -borderwidth 0 -highlightthickness 0
+  canvas $w.bd -width $bsize -height $bsize -cursor crosshair -borderwidth 0 -highlightthickness 0
+  ::applyThemeColor_background $w.bd
   catch { grid anchor $w center }
   
   set startrow 5
@@ -371,8 +492,12 @@ proc ::board::new {w {psize 40} } {
     grid $w.bfile$file -row [expr $startrow + 9] -column [expr $i + 2] -sticky n
   }
   
-  canvas $w.mat -width 20 -height $bsize -highlightthickness 0 -background $bgcolor
-  grid $w.mat -row 6 -column 12 -rowspan 8 -pady 5 -padx 5
+  canvas $w.score -width 8
+  grid $w.score -row 6 -column 12 -rowspan 8 -sticky ew
+  grid remove $w.score
+  canvas $w.mat -width 20 -height $bsize -highlightthickness 0
+  ::applyThemeColor_background $w.mat
+  grid $w.mat -row 6 -column 13 -rowspan 8 -pady 0
   grid remove $w.mat
 
   ::board::coords $w
@@ -413,37 +538,49 @@ proc ::board::addNamesBar {w {varname}} {
 
 proc ::board::addInfoBar {w varname} {
   ttk::frame $w.bar
-  set $w.bar.info [ttk::frame $w.bar.info]
-  autoscrollframe $w.bar.info text $w.bar.info.t -relief flat -bg [ttk::style lookup Button.label -background] \
-                                                 -font font_Regular -cursor arrow -state disabled
-  $w.bar.info.t tag configure header -font font_Bold
+  autoscrollText y $w.bar.info $w.bar.info.t Toolbutton
   $w.bar.info.t tag bind click <Any-Enter> "$w.bar.info.t configure -cursor hand2"
   $w.bar.info.t tag bind click <Any-Leave> "$w.bar.info.t configure -cursor {}"
   grid propagate $w.bar.info 0
-  grid $w.bar.info.t -sticky news
+  ttk::button $w.bar.leavevar -image tb_BD_BackStart -style Toolbutton
   ttk::button $w.bar.back -image tb_BD_Back -style Toolbutton
-  ttk::button $w.bar.cmd -image tb_BD_ShowToolbar -style Toolbutton -command "::board::toggleInfoBar_ $w"
   ttk::button $w.bar.forward -image tb_BD_Forward -style Toolbutton
-  set bar_tb [::board::newToolBar_ $w $varname]
-  grid $w.bar.back -row 0 -column 0 -sticky news
-  grid $w.bar.cmd -in $w.bar -row 0 -column 1 -sticky news -padx 8
-  grid $bar_tb -in $w.bar -row 0 -column 2 -sticky ew
-  grid remove $bar_tb
-  grid $w.bar.info -in $w.bar -row 0 -column 2 -sticky news
+  ttk::button $w.bar.endvar -image tb_BD_ForwardEnd -style Toolbutton
+  set menu [::board::newToolBar_ $w $varname]
+  ttk::button $w.bar.cmd -image tb_BD_ShowToolbar -style Toolbutton \
+    -command "::board::updateToolBar_ $menu $varname $w.bar.cmd"
+  grid $w.bar.cmd -in $w.bar -row 0 -column 0 -sticky news
+  grid $w.bar.info -in $w.bar -row 0 -column 1 -sticky news -padx 4
+  grid $w.bar.leavevar -row 0 -column 2 -sticky news
+  grid $w.bar.back -row 0 -column 3 -sticky news
   grid $w.bar.forward -row 0 -column 4 -sticky news
-  grid columnconfigure $w.bar 2 -weight 1
+  grid $w.bar.endvar -row 0 -column 5 -sticky news
+  grid columnconfigure $w.bar 1 -weight 1
   grid $w.bar -row 20 -column 3 -columnspan 8 -sticky news -pady 4
+  ::bind $w.bar <Configure> {+
+	grid remove %W.leavevar
+	grid remove %W.endvar
+	if {%w > 450} {
+	  grid %W.leavevar
+	  grid %W.endvar
+	}
+  }
+}
+
+proc ::board::addInfo {{w} {msg}} {
+  if {$msg eq ""} { return }
+  $w.bar.info.t configure -state normal
+  $w.bar.info.t insert end "\n$msg"
+  $w.bar.info.t configure -state disabled
 }
 
 proc ::board::setInfo {{w} {msg}} {
-  toggleInfoBar_ $w "tmpRestore"
   $w.bar.info.t configure -state normal
   $w.bar.info.t delete 1.0 end
   $w.bar.info.t insert end "$msg"
   $w.bar.info.t configure -state disabled
 }
 
-
 proc ::board::setInfoAlert {{w} {header} {msg} {msgcolor} {cmd}} {
   $w.bar.info.t configure -state normal
   $w.bar.info.t delete 1.0 end
@@ -455,10 +592,9 @@ proc ::board::setInfoAlert {{w} {header} {msg} {msgcolor} {cmd}} {
     if {[winfo exists $cmd]} {
       after idle \"tk_popup $cmd %X \[expr -10 + %Y - \[winfo reqheight $cmd\] \]\"
     } else {
-      $cmd
+      after idle $cmd
     }
   "
-  toggleInfoBar_ $w "tmpInfo"
 }
 
 set ::board::repeatCmd 400
@@ -483,21 +619,87 @@ proc ::board::setButtonCmd {{w} {button} {cmd}} {
   }
 }
 
-proc ::board::toggleInfoBar_ {{w} {action "click"}} {
-  set bstate [$w.bar.cmd state]
-  if {$action == "tmpInfo" && $bstate == "pressed"} {
-      grid remove $w.buttons;
-      grid $w.bar.info
-  } elseif {($action == "tmpRestore" && $bstate == "pressed") || \
-            ($action == "click" && "$w.bar.info" == [grid slaves $w.bar -column 2])} {
-      grid remove $w.bar.info;
-      grid $w.buttons
-      $w.bar.cmd state pressed
+proc ::board::setButtonImg {{w} {button} {img}} {
+  $w.bar.$button configure -image $img
+}
+
+# Associates fn with the specified evaluation bar's event.
+proc ::board::bindEvalBar {w event fn} {
+  ::bind $w.score $event $fn
+}
+
+proc ::board::toggleEvalBar {w} {
+  set ::board::_evalbarShow($w) [expr {1 - $::board::_evalbarShow($w)}]
+  if {$::board::_evalbarShow($w)} {
+      grid $w.score
+      ::board::drawEvalBar_ $w
   } else {
-      grid remove $w.buttons;
-      grid $w.bar.info
-      $w.bar.cmd state !pressed
+      grid remove $w.score
   }
+  return $::board::_evalbarShow($w)
+}
+
+proc ::board::drawEvalBar_ { w } {
+    if { ! $::board::_evalbarShow($w) } { return }
+    set maxscore $::board::_evalbarMaxScore($w)
+    set h [expr $::board::_size($w) * 8 + $::board::_border($w) * 6 - 2 ]
+    set width 14
+
+    $w.score delete nl barUp barDown
+    $w.score configure -background grey50 -width [expr $width -2] -height $h \
+        -borderwidth 1 -highlightthickness 0
+
+    set colorUp grey7
+    set colorDown grey94
+    set ::board::_evalbarScale($w) [expr ($h + 2) / ($maxscore * -2.0)]
+    if { $::board::_flip($w) } {
+        set colorUp grey94
+        set colorDown grey7
+        set ::board::_evalbarScale($w) [expr $::board::_evalbarScale($w) * -1]
+    }
+    $w.score create rectangle 0 0 0 0 -tag barUp -width 0 -fill $colorUp
+    $w.score create rectangle 0 0 0 0 -tag barDown -width 0 -fill $colorDown
+
+    for { set i [expr 1 - $maxscore] } { $i < $maxscore } { incr i } {
+        set h1 [expr $h / 2 + $i * $::board::_evalbarScale($w)]
+        if { $i == 0 } {
+            $w.score create rectangle 0 $h1 $width [expr $h1 + 2] -fill red -width 0 -tag nl
+        } else {
+            $w.score create line 0 $h1 $width $h1 -fill gray40 -tag nl
+        }
+    }
+    set ::board::_evalbarHeight($w) $h
+    set ::board::_evalbarWidth($w) $width
+    ::board::updateEvalBar $w $::board::_evalbarScore($w)
+}
+
+# Update the score bar (if it is visibile) to reflect the provided score.
+# The score value is from white prospective. An empty "" value means no score.
+proc ::board::updateEvalBar { w score } {
+    set ::board::_evalbarScore($w) $score
+    if { ! $::board::_evalbarShow($w) } { return }
+
+    if { $score eq "" } {
+        $w.score coords barUp 0 0 0 0
+        $w.score coords barDown 0 0 0 0
+    } else {
+        set width $::board::_evalbarWidth($w)
+        set h $::board::_evalbarHeight($w)
+        # Handle mate notation like +M12 or -M5
+        if {[string index $score 1] eq "M" \
+            && [string is integer [string range $score 2 end]] \
+            && [set sign [string index $score 0]] in {- +}} {
+            if {$sign eq "+"} {
+                set midY 0
+            } else {
+                set midY [expr $h + 1]
+            }
+        } else {
+            set midY [expr $h / 2 + $score * $::board::_evalbarScale($w)]
+        }
+        $w.score coords barUp 0 0 $width $midY
+        $w.score coords barDown 0 $midY $width [expr $h + 1]
+    }
 }
 
 proc ::board::updateToolBar_ {{menu} {varname} {mb ""} } {
@@ -525,60 +727,33 @@ proc ::board::updateToolBar_ {{menu} {varname} {mb ""} } {
 
 proc ::board::newToolBar_ {{w} {varname}} {
   global "$varname"
-  ttk::frame $w.buttons
 
-  set m [menu $w.buttons.menu_back -bg white -font font_Regular]
-  $m add command -label "  Go back to mainline" -image tb_BD_BackToMainline -compound left
-  $m add command -label "  Leave variant" -image tb_BD_VarLeave -compound left
-  $m add command -label "  Go to start" -image tb_BD_Start -compound left -accelerator "<home>"
+  set m [menu $w.menu_back -bg white -font font_Regular]
+  $m add command -label "  [tr BackToMainline]" -image tb_BD_BackToMainline -compound left
+  $m add command -label "  [tr EditDelete]" -image tb_BD_VarDelete -compound left
+  $m add command -label "  [tr LeaveVariant]" -image tb_BD_VarLeave -compound left
+  $m add command -label "  [tr GameStart]" -image tb_BD_Start -compound left -accelerator "<home>"
   ::bind $w.bar.back <ButtonRelease-$::MB3> "::board::updateToolBar_ $m $varname %W"
 
-  set m [menu $w.buttons.menu_forw -bg white -font font_Regular]
-  $m add command -label "  Autoplay" -image tb_BD_Autoplay -compound left
-  $m add command -label "  Go to end" -image tb_BD_End -compound left -accelerator "<end>"
+  set m [menu $w.menu_forw -bg white -font font_Regular]
+  $m add command -label "  [tr Autoplay]" -image tb_BD_Autoplay -compound left
+  $m add command -label "  [tr GameEnd]" -image tb_BD_End -compound left -accelerator "<end>"
   ::bind $w.bar.forward <ButtonRelease-$::MB3> "::board::updateToolBar_ $m $varname %W"
 
-  set menus { tb_BD_Changes tb_BD_Comment tb_BD_Variations tb_BD_Layout }
-  set i 0
-  foreach b $menus {
-    menu $w.buttons.menu_$b -bg white -font font_Regular -postcommand "::board::updateToolBar_ $w.buttons.menu_$b $varname"
-    ttk::menubutton $w.buttons.$b -style Toolbutton -image $b -menu "$w.buttons.menu_$b" -direction above
-    grid $w.buttons.$b -row 0 -column $i -padx 4
-    incr i
-  }
-
-  set m "$w.buttons.menu_[lindex $menus 0]"
-  $m add command -label "  [tr GameAdd]" -image tb_BD_SaveAs -compound left
-  $m add command -label "  [tr GameReplace]" -image tb_BD_Save -compound left
-  $m add separator
-  $m add command -label "  Undo all" -image tb_BD_Revert -compound left
-  $m add command -label "  Redo" -image tb_BD_Redo -compound left
-  $m add command -label "  Undo" -image tb_BD_Undo -compound left
-
-  set m "$w.buttons.menu_[lindex $menus 1]"
+  set m [menu $w.menu -bg white -font font_Regular]
   $m add command -label "  [tr EditSetup]" -image tb_BD_SetupBoard -compound left
+  $m add command -label "  [tr IERotate]" -image tb_BD_Flip -compound left
+  $m add command -label "  [tr ShowHideMaterial]" -image tb_BD_Material -compound left
+  #TODO translate
+  $m add command -label "  Show/Hide Evaluation Bar" -image tb_BD_Scorebar -compound left
+  $m add command -label "  [tr ConfigureScid]" -image tb_BD_Layout -compound left
 
-  set m "$w.buttons.menu_[lindex $menus 2]"
-  $m add command -label "  Delete variant" -image tb_BD_VarDelete -compound left
-  $m add command -label "  Promote variant" -image tb_BD_VarPromote -compound left
-  $m add command -label "  Leave variant" -image tb_BD_VarLeave -compound left
-  $m add command -label "  Go back to mainline" -image tb_BD_BackToMainline -compound left
-  $m add separator
-  $m add command -label "  Go to start" -image tb_BD_Start -compound left
-  $m add command -label "  Go to end" -image tb_BD_End -compound left
-  $m add command -label "  Autoplay" -image tb_BD_Autoplay -compound left
-
-  set m "$w.buttons.menu_[lindex $menus 3]"
-  $m add command -label "  Rotate" -image tb_BD_Flip -compound left
-  $m add command -label "  Show/hide coord" -image tb_BD_Coords -compound left
-  $m add command -label "  Show/hide material" -image tb_BD_Material -compound left
-  $m add command -label "  Full Screen" -image tb_BD_Fullscreen -compound left
   set ${varname}(tb_BD_Flip) "::board::flip $w"
-  set ${varname}(tb_BD_Coords) "::board::coords $w"
   set ${varname}(tb_BD_Material) "::board::toggleMaterial $w"
-  set ${varname}(tb_BD_Fullscreen) { wm attributes . -fullscreen [expr ![wm attributes . -fullscreen] ] }
+  set ${varname}(tb_BD_Scorebar) "::board::toggleEvalBar $w"
+  set ${varname}(tb_BD_Layout) {::preferences::Open toggle}
 
-  return $w.buttons
+  return $m
 }
 
 proc ::board::flipNames_ { {w} {white_on_top} } {
@@ -610,7 +785,7 @@ proc ::board::sideToMove_ { {w} {side} } {
 #   a light or dark square.
 #
 proc ::board::defaultColor {sq} {
-  return [expr {($sq + ($sq / 8)) % 2 ? "$::lite" : "$::dark"}]
+  return [expr {($sq + ($sq / 8)) % 2 ? "$::squareColor_lite" : "$::squareColor_dark"}]
 }
 
 # ::board::size
@@ -687,7 +862,9 @@ proc ::board::resize {w psize} {
   # resize the material canvas
   $w.mat configure -height $bsize
   
+  ::board::coords $w $::board::_coords($w)
   ::board::update $w
+  ::board::drawEvalBar_ $w
   
   return $psize
 }
@@ -1126,6 +1303,21 @@ proc ::board::mark::DrawArrow {pathName from to color} {
       {-tag [list mark arrows "mark${from}:${to}"]}
 }
 
+# Draw an arrow to indicate the best move.
+# It also eliminate any existing best move arrow.
+# So, if moveUCI == "", it just deletes any existing best move arrow.
+# TODO: draw a better arrow that has the alpha channel.
+proc ::board::mark::DrawBestMove {pathName moveUCI} {
+  {*}$pathName.bd delete bestmove
+  if {$moveUCI eq ""} { return }
+
+  set from [ ::board::sq [ string range $moveUCI 0 1 ] ]
+  set to [ ::board::sq [ string range $moveUCI 2 3 ] ]
+  set coord [GetArrowCoords $pathName.bd $from $to 0.2]
+  {*}$pathName.bd create line $coord -fill #FF5E0E -arrow last -width 5 \
+    -arrowshape {18 24 10} -tag [list mark arrows bestmove]
+}
+
 # ::board::mark::DrawRectangle --
 # Draws a rectangle surrounding the square
 proc ::board::mark::DrawRectangle { pathName square color pattern } {
@@ -1379,10 +1571,9 @@ proc ::board::drawText {w sq text color args {shadow ""} } {
 }
 
 # Highlight last move played by drawing a red rectangle around the two squares
-proc  ::board::lastMoveHighlight {w} {
+proc  ::board::lastMoveHighlight {w moveuci} {
   $w.bd delete highlightLastMove
   if { ! $::highlightLastMove } {return}
-  set moveuci [ sc_game info previousMoveUCI ]
   if {[string length $moveuci] >= 4} {
     set moveuci [ string range $moveuci 0 3 ]
     set square1 [ ::board::sq [string range $moveuci 0 1 ] ]
@@ -1437,7 +1628,10 @@ proc ::board::update {w {board ""} {animate 0}} {
     $w.bd delete p$sq
     $w.bd create image $xc $yc -image $::board::letterToPiece($piece)$psize -tag p$sq
   }
-  
+  if {$::board::_coords($w) >= 3 } {
+      $w.bd raise innercoords
+  }
+
   # Update side-to-move icon:
   ::board::sideToMove_ $w [string index $::board::_data($w) 65]
   
@@ -1466,7 +1660,7 @@ proc ::board::update {w {board ""} {animate 0}} {
   
   # Redraw last move highlight if mainboard
   if { $w == ".main.board"} {
-    ::board::lastMoveHighlight $w
+    ::board::lastMoveHighlight $w [sc_game info previousMoveUCI]
   }
   
   # Redraw material values
@@ -1541,7 +1735,9 @@ proc ::board::flip {w {newstate -1}} {
     }
   }
   ::board::flipNames_ $w $flip
+  ::board::coords $w $::board::_coords($w)
   ::board::update $w
+  ::board::drawEvalBar_ $w
   return $w
 }
 ################################################################################
@@ -1622,27 +1818,93 @@ proc ::board::toggleMaterial {w} {
 }
 
 ################################################################################
-#
+# draw coordinates on the board
+# sq: square c: character pos: 0=left,bottom  1=right,top
+# use dark and lite from colorscheme as fontcolor:
+#     lite on dark squares and dark on lite squares
 ################################################################################
+proc ::board::drawInnerCoords { w sq c pos fontsize color} {
+    set box [::board::mark::GetBox $w.bd $sq 1.0]
+    set len [expr int([lindex $box 4])]
+    if { [string is digit $c] } {
+        set x   [expr [lindex $box 0] + $pos * ($len - $fontsize)]
+        set y   [expr [lindex $box 1] + $fontsize ]
+    } else {
+        set x   [expr [lindex $box 0] ]
+        set y   [expr [lindex $box 3] - $fontsize - $pos * ($len - 2 * $fontsize)]
+        # avoid collision a1 and h8 in the upper right square
+        if { $pos && (($::board::_flip($w) && $c eq "h") || (!$::board::_flip($w) && $c eq "a")) } {
+            set x [expr $x + $fontsize]
+        }
+    }
+    $w.bd create text $x $y -fill $color \
+        -font [list font_Regular $fontsize ] \
+        -text $c \
+        -anchor w \
+        -tag innercoords
+}
+
+# ::board::innercoords
+#   Add or remove coordinates on the square on the board.
+#   0 (no coords), 1 (left and bottom beside board ), 2 (all sides beside board),
+#   3 (left and bottom, on board ), 4 (all sides on board)
+proc ::board::innercoords {w} {
+    $w.bd delete innercoords
+    if {$::board::_coords($w) < 3 } {
+        return
+    }
+    # Use 20% of square for fontsize, but not larger than font_small 
+    set fontSize [expr int($::board::_size($w) / 5) ]
+    set size [font configure font_Small -size]
+    if { $fontSize > $size } { set fontSize $size }
+    if { ! $::board::_flip($w) } {
+        set ch_l [list a c e g 1 3 5 7]
+        set ch_d [list b d f h 2 4 6 8]
+        set sq_bl_l [list 0 2 4 6 0 16 32 48]
+        set sq_tr_d [list 56 58 60 62 7 23 39 55]
+        set sq_bl_d [list 1 3 5 7 8 24 40 56]
+        set sq_tr_l [list 57 59 61 63 15 31 47 63]
+    } else {
+        set ch_d [list 1 3 5 7 a c e g]
+        set ch_l [list h f d b 8 6 4 2]
+        set sq_bl_d [list 7 23 39 55 56 58 60 62]
+        set sq_tr_l [list 0 16 32 48 0 2 4 6]
+        set sq_bl_l [list 63 61 59 57 63 47 31 15]
+        set sq_tr_d [list 7 5 3 1 56 40 24 8]
+    }
+    if {$::board::_coords($w) >= 3 } {
+        foreach sq $sq_bl_l ch $ch_l {
+            drawInnerCoords $w $sq $ch 0 $fontSize $::squareColor_lite
+        }
+        foreach sq $sq_bl_d ch  $ch_d {
+            drawInnerCoords $w $sq $ch 0 $fontSize $::squareColor_dark
+        }
+    }
+    if {$::board::_coords($w) == 4 } {
+        foreach sq $sq_tr_l ch $ch_d {
+            drawInnerCoords $w $sq $ch 1 $fontSize $::squareColor_lite
+        }
+        foreach sq $sq_tr_d ch  $ch_l {
+            drawInnerCoords $w $sq $ch 1 $fontSize $::squareColor_dark
+        }
+    }
+}
 
 # ::board::coords
-#   Add or remove coordinates around the edge of the board.
-# Toggle between 0,1,2.
-proc ::board::coords {w} {
-  set coords [expr {1 + $::board::_coords($w)} ]
-  if { $coords > 2 } { set coords 0 }
-  set ::board::_coords($w) $coords
-  
-  if {$coords == 0 } {
-    for {set i 1} {$i <= 8} {incr i} {
-      grid remove $w.lrank$i
-      grid remove $w.rrank$i
-    }
-    foreach i {a b c d e f g h} {
-      grid remove $w.tfile$i
-      grid remove $w.bfile$i
-    }
-  } elseif {$coords == 1 } {
+#   Configure coordinates around the edge of the board or on the board
+#   Toggle ::board::_coords between 0 (no coords), 1 (left and bottom beside board ),
+#   2 (all sides beside board), 3 (left and bottom, on board ), 4 (all sides on board)
+proc ::board::coords {w {coordstype ""}} {
+  # if coordstype is set then use it, else toggle between options
+  if { $coordstype eq "" } {
+    set coordstype [expr {1 + $::board::_coords($w)} ]
+    if { $coordstype > 4 } { set coordstype 0 }
+  }
+  if { $coordstype >= 0 && $coordstype <= 4 } {
+    set ::board::_coords($w) $coordstype
+  }
+
+  if {$coordstype == 1 } {
     for {set i 1} {$i <= 8} {incr i} {
       grid configure $w.lrank$i
       grid remove $w.rrank$i
@@ -1651,7 +1913,7 @@ proc ::board::coords {w} {
       grid remove $w.tfile$i
       grid configure $w.bfile$i
     }
-  } else { #Klimmek: coords == 2 then show left and bottom
+  } elseif {$coordstype == 2 } {
     for {set i 1} {$i <= 8} {incr i} {
       grid configure $w.lrank$i
       grid configure $w.rrank$i
@@ -1660,9 +1922,19 @@ proc ::board::coords {w} {
       grid configure $w.tfile$i
       grid configure $w.bfile$i
     }
+  } else {
+    for {set i 1} {$i <= 8} {incr i} {
+        grid remove $w.lrank$i
+        grid remove $w.rrank$i
+    }
+    foreach i {a b c d e f g h} {
+        grid remove $w.tfile$i
+        grid remove $w.bfile$i
+    }
   }
+  ::board::innercoords $w
 
-  return $coords
+  return $coordstype
 }
 
 # ::board::animate
@@ -1694,15 +1966,14 @@ proc ::board::animate {w oldboard newboard} {
   
   set from -1
   set to -1
+  set from2 -1
+  set to2 -1
   set captured -1
   set capturedPiece "."
   
   if {$diffcount == 4} {
     # Check for making/unmaking a castling move:
-    set castlingList [list [sq e1] [sq g1] [sq h1] [sq f1] \
-        [sq e8] [sq g8] [sq h8] [sq f8] \
-        [sq e1] [sq c1] [sq a1] [sq d1] \
-        [sq e8] [sq c8] [sq a8] [sq d8]]
+    set castlingList [list 4 6 7 5 60 62 63 61 4 2 0 3 60 58 56 59]
     
     foreach {kfrom kto rfrom rto} $castlingList {
       if {[lsort $difflist] == [lsort [list $kfrom $kto $rfrom $rto]]} {
@@ -1712,17 +1983,20 @@ proc ::board::animate {w oldboard newboard} {
           [string tolower [string index $newboard $rto]] == "r"} {
           # A castling move animation.
           # Move the rook back to initial square until animation is complete:
-          # TODO: It may look nicer if the rook was animated as well...
           eval $w.bd coords p$rto [::board::midSquare $w $rfrom]
           set from $kfrom
           set to $kto
+          set from2 $rfrom
+          set to2 $rto
         } elseif {[string tolower [string index $newboard $kfrom]] == "k"  &&
           [string tolower [string index $newboard $rfrom]] == "r"  &&
           [string tolower [string index $oldboard $kto]] == "k"  &&
           [string tolower [string index $oldboard $rto]] == "r"} {
-          # An undo-castling animation. No need to move the rook.
+          eval $w.bd coords p$rfrom [::board::midSquare $w $rto]
           set from $kto
           set to $kfrom
+          set from2 $rto
+          set to2 $rfrom
         }
       }
     }
@@ -1818,6 +2092,8 @@ proc ::board::animate {w oldboard newboard} {
   set ::board::_animate($w,end) [expr {$start + $::animateDelay} ]
   set ::board::_animate($w,from) $from
   set ::board::_animate($w,to) $to
+  set ::board::_animate($w,from2) $from2
+  set ::board::_animate($w,to2) $to2
   ::board::_animate $w
 }
 
@@ -1848,7 +2124,22 @@ proc ::board::_animate {w} {
   set y [expr {$fromY + round(($toY - $fromY) * $ratio)} ]
   $w.bd coords p$to $x $y
   $w.bd raise p$to
-  
+  if { $::board::_animate($w,from2) >= 0 } {
+      # move second piece
+      set from $::board::_animate($w,from2)
+      set to $::board::_animate($w,to2)
+      set fromMid [::board::midSquare $w $from]
+      set toMid [::board::midSquare $w $to]
+      set fromX [lindex $fromMid 0]
+      set fromY [lindex $fromMid 1]
+      set toX [lindex $toMid 0]
+      set toY [lindex $toMid 1]
+      set x [expr {$fromX + round(($toX - $fromX) * $ratio)} ]
+      set y [expr {$fromY + round(($toY - $fromY) * $ratio)} ]
+      $w.bd coords p$to $x $y
+      $w.bd raise p$to
+  }
+
   # Schedule another animation update in a few milliseconds:
   after 5 "::board::_animate $w"
 }
@@ -1860,7 +2151,6 @@ proc InitBoard {} {
   }
 
   setPieceFont "$::boardStyle"
-  menuUpdatePieces
 }
 InitBoard
 
