@@ -80,8 +80,9 @@ proc ::file::New {} {
   set ::curr_db $baseId
   set ::initialDir(base) [file dirname $fName]
   ::recentFiles::add $fName
-  ::notify::GameChanged
+  ::windows::gamelist::Open $::curr_db
   ::notify::DatabaseChanged
+  ::notify::GameChanged
   return $baseId
 }
 
@@ -95,13 +96,18 @@ proc ::file::Open {{fName ""}} {
     set ::curr_db $::file::lastOpened
     ::windows::gamelist::Open $::curr_db
     ::notify::DatabaseChanged
+    set gamenum 1
     foreach {tagname tagvalue} [sc_base extra $::curr_db] {
       if {$tagname eq "autoload" && $tagvalue != 0} {
-        ::game::Load $tagvalue 0
+        set gamenum $tagvalue
         break
       }
     }
-    ::notify::GameChanged
+    if {$gamenum <= [sc_base numGames $::curr_db]} {
+      ::game::Load $gamenum 0
+    } else {
+      ::notify::GameChanged
+    }
   }
   return $err
 }
@@ -147,7 +153,7 @@ proc ::file::Open_ {{fName ""} } {
     if {$err} {
       ERROR::MessageBox "$fName\n"
     } else {
-      sc_base extra $::file::lastOpened type 3
+      catch { sc_base extra $::file::lastOpened type 3 }
       set ::initialDir(base) [file dirname "$fName"]
       ::recentFiles::add "$fName"
     }
@@ -302,4 +308,5 @@ proc ::file::autoLoadBases.remove { {baseIdx} } {
   if {$idx != -1} {
     set ::autoLoadBases [lreplace $::autoLoadBases $idx $idx]
   }
+  return $idx
 }
