@@ -93,6 +93,8 @@ menuText K EditCopyBoard "Copiar posici" 8 \
   {Copia l'escaquer actual en notaci FEN a la selecci de text (clipboard)}
 menuText K EditPasteBoard "Pegar escaquer inicial" 6 \
   {Posa l'escaquer inicial des de la selecci de text actual (clipboard)}
+# ====== TODO To be translated ======
+menuText K ConfigureScid "Preferences..." 0 {Configure all options for SCID}
 
 # Game menu:
 menuText K Game "Partida" 0
@@ -245,11 +247,6 @@ menuText K CCEditCopy "Copy Gamelist to Clipbase" 0 {Copy the games as CSV list
 
 # Options menu:
 menuText K Options "Opcions" 0
-menuText K OptionsBoard "Escaquer" 0 {Opcions sobre l'aspecte de l'escaquer}
-menuText K OptionsBoardSize "Tamany de l'escaquer" 0 {Canvia el tamany de l'escaquer}
-menuText K OptionsBoardPieces "Estil de peces" 10 \
-  {Canvia l'estil de les peces de l'escaquer}
-menuText K OptionsBoardColors "Colors..." 0 {Canvia els colors de l'escaquer}
 menuText K OptionsBoardGraphics "Casselles..." 0 {Escollir textures per les casselles}
 translate K OptionsBGW {Escollir textura per les casselles}
 translate K OptionsBoardGraphicsText {Escollir arxiu grfic per casselles blanques i negres}
@@ -276,8 +273,6 @@ menuText K OptionsMovesHighlightLastMoveColor "Color" 0 {Color of line}
 # ====== TODO To be translated ======
 menuText K OptionsMovesHighlightLastMoveArrow "include Arrow" 0 {Include Arrow with Highlight}
 menuText K OptionsMoves "Jugades" 0 {Opcions d'entrada de jugades}
-menuText K OptionsMovesAsk "Preguntar abans de substituir jugades" 0 \
-  {Pregunta abans de sobreescriure qualsevol jugada existent}
 menuText K OptionsMovesAnimate "Velocitat d'animaci" 1 \
   {Posa el temps d'animaci entre jugades}
 menuText K OptionsMovesDelay "Retard de la jugada automtica..." 0 \
@@ -295,21 +290,16 @@ menuText K OptionsMovesShowVarArrows "Show Arrows for Variations" 0 {Turn on/off
 # ====== TODO To be translated ======
 menuText K OptionsMovesGlossOfDanger "Color Coded Gloss of Danger" 0 {Turn on/off color coded gloss of danger}
 menuText K OptionsNumbers "Format de nmeros" 11 {Selecciona el format de nmeros}
-menuText K OptionsStartup "Inici" 3 {Seleccionar les finestres que s'obren al comenar}
 menuText K OptionsTheme "Tema" 0 {Canviar l'aspecte del programari}
 menuText K OptionsWindows "Finestres" 0 {Opcions de finestra}
-menuText K OptionsWindowsIconify "Autominimitzar" 4 \
-  {Minimitza totes les finestres quan la finestra principal es minimitzada}
-menuText K OptionsWindowsRaise "Posar automticamente en primer pla" 0 \
-  {Fa visibles algunes finestres (ex. barres de progrs) quan estiguin cobertes}
-menuText K OptionsSounds "Sons..." 2 {Configura el so d'anunci de les jugades}
+menuText K OptionsSounds "Sons" 2 {Configura el so d'anunci de les jugades}
+# ====== TODO To be translated ======
+menuText K OptionsResources "Resources..." 0 {Choose resource files and folders}
 menuText K OptionsWindowsDock "Bloqueja finestres" 0 {Bloqueja i agrupa finestres}
 menuText K OptionsWindowsSaveLayout "Salvar disposici" 0 {Salvar disposici}
 menuText K OptionsWindowsRestoreLayout "Restaurar disposici" 0 {Restaurar disposici}
 menuText K OptionsWindowsShowGameInfo "Mostrar informaci de la partida" 0 {Mostrar informaci de la partida}
 menuText K OptionsWindowsAutoLoadLayout "Auto cargar primera disposici" 0 {Autocargar primera disposici en comenar}
-menuText K OptionsToolbar "Barra d'eines de la finestra principal" 9 \
-  {Mostra/amaga la barra d'eines de la finestra principal}
 menuText K OptionsECO "Cargar arxiu ECO..." 7 \
   {Cargar l'arxiu de clasificaci ECO}
 menuText K OptionsSpell "Cargar arxiu de comprovaci ortogrfica..." 2 \
@@ -323,19 +313,11 @@ menuText K OptionsTacticsBasesDir "Carpeta de bases de dades..." 0 {Fixa la carp
 # ====== TODO To be translated ======
 menuText K OptionsPhotosDir "Photos directory..." 0 {Sets the photos bases directory}
 # ====== TODO To be translated ======
-menuText K OptionsThemeDir "Load Theme(s)..."  0 { Load a GUI theme package file }
+menuText K OptionsThemeDir "Theme(s) File:"  0 { Load a GUI theme package file }
 menuText K OptionsSave "Salvar opcions" 0 \
   {Salva totes les opcions a l'arxiu $::optionsFile}
 menuText K OptionsAutoSave "Autoguardar opcions en sortir" 0 \
   {Guarda automticament totes les opcions quan es surt de Scid}
-# ====== TODO To be translated ======
-menuText K OptionsMenuColor "Setup Menu Colors..." 0 { }
-# ====== TODO To be translated ======
-translate K MenuColorForeground "Textcolor"
-# ====== TODO To be translated ======
-translate K MenuColorBackground "Background"
-# ====== TODO To be translated ======
-translate K MenuColorSelect "Select"
 
 # Help menu:
 menuText K Help "Ajut" 1
@@ -376,6 +358,8 @@ translate K Defaults {Per defecte}
 translate K Delete {Esborrar}
 translate K Graph {Grfic}
 translate K Help {Ajut}
+# ====== TODO To be translated ======
+translate K Hide {Hide}
 translate K Import {Importar}
 translate K Index {ndex}
 translate K LoadGame {Cargar partida}
@@ -476,6 +460,8 @@ translate K PInfoMostBlack {Obertures ms comuns amb Negres}
 translate K PInfoRating {Historial de classificaci}
 translate K PInfoBio {Biografia}
 translate K PInfoEditRatings {Editar elos}
+# ====== TODO To be translated ======
+translate K PInfoEloFile {File}
 
 # Tablebase information:
 translate K Draw {Taules}
@@ -674,6 +660,10 @@ menuText K GraphOptionsWhite "Blanques" 0
 menuText K GraphOptionsBlack "Negres" 0
 menuText K GraphOptionsBoth "Ambdos" 0
 menuText K GraphOptionsPInfo "Opcions informaci jugador" 0
+# ====== TODO To be translated ======
+menuText K GraphOptionsEloFile "Elo from rating file" 0
+# ====== TODO To be translated ======
+menuText K GraphOptionsEloDB "Elo from database" 0
 translate K GraphFilterTitle "Filtre grfic: freqencia per 1000 partides"
 translate K GraphAbsFilterTitle "Filtre grfic: freqencia de les partides"
 translate K ConfigureFilter {Configurar Eix-X per Any, Rating i Jugades}
@@ -706,7 +696,7 @@ translate K BlundersThreshold {Marge d'error }
 translate K ScoreAllMoves {Score all moves}
 translate K LowPriority {Baixa prioritat del processador}
 translate K ClickHereToSeeMoves {Clic aqu per veure les jugades}
-translate K ConfigureInformant {Configurar informacions}
+translate K ConfigureInformant {Informacions}
 translate K Informant!? {Jugada interesant}
 translate K Informant? {Jugada dolenta}
 translate K Informant?? {Desastrosa}
@@ -731,12 +721,6 @@ translate K EngineNew {Nova}
 translate K EngineEdit {Editar}
 translate K EngineRequired {Els camps en negreta son obligatoris; la resta opcionals}
 
-# Stats window mens:
-menuText K StatsFile "Arxiu" 0
-menuText K StatsFilePrint "Imprimir a arxiu..." 0
-menuText K StatsFileClose "Tancar finestra" 0
-menuText K StatsOpt "Opcions" 0
-
 # PGN window mens:
 menuText K PgnFile "Arxiu" 0
 menuText K PgnFileCopy "Copiar partida al portapapers" 0
@@ -1405,6 +1389,8 @@ translate K SoundsAnnounceOptions {Opcions d'anunci de jugades}
 translate K SoundsAnnounceNew {Anunciar noves jugades quan estiguin fetes}
 translate K SoundsAnnounceForward {Anunciar jugades quan avancem una jugada}
 translate K SoundsAnnounceBack {Anunciar jugada quan rectifiquem o retrocedim una jugada}
+# ====== TODO To be translated ======
+translate K SoundsSoundDisabled {Scid could not find the Snack audio package at startup;\nSound is disabled.}
 
 # Upgrading databases:
 translate K Upgrading {Actualitzaci}
@@ -1648,6 +1634,22 @@ translate K FICSObserveconfirm {Vols observar la partida}
 # ====== TODO To be translated ======
 translate K FICSpremove {Enable premove}
 # ====== TODO To be translated ======
+translate K FICSObserve {Observe}
+# ====== TODO To be translated ======
+translate K FICSRatedGames {Rated Games}
+# ====== TODO To be translated ======
+translate K FICSUnratedGames {Unrated Games}
+# ====== TODO To be translated ======
+translate K FICSRated {Rated}
+# ====== TODO To be translated ======
+translate K FICSUnrated {Unrated}
+# ====== TODO To be translated ======
+translate K FICSRegisteredPlayer {Registered player only}
+# ====== TODO To be translated ======
+translate K FICSFreePlayer {Free player only}
+# ====== TODO To be translated ======
+translate K FICSNetError {Network error\nCan't connect to }
+# ====== TODO To be translated ======
 translate K GameReview {Game review}
 # ====== TODO To be translated ======
 translate K GameReviewTimeExtended {Time extended}
@@ -1863,6 +1865,25 @@ translate K MakeCorrections {Make Corrections}
 translate K Surnames {Surnames}
 # ====== TODO To be translated ======
 translate K Ambiguous {Ambiguous}
-
+translate K OptionsToolbar "Barra d'eines de la finestra principal"
+translate K OptionsBoard "Escaquer"
+# ====== TODO To be translated ======
+translate K OptionsMenuColor "Menu colors"
+translate K OptionsBoardSize "Tamany de l'escaquer"
+translate K OptionsBoardPieces "Estil de peces"
+# ====== TODO To be translated ======
+translate K OptionsInternationalization "Internationalization"
+# ====== TODO To be translated ======
+translate K MenuColorForeground "Textcolor"
+# ====== TODO To be translated ======
+translate K MenuColorBackground "Background"
+# ====== TODO To be translated ======
+translate K MenuColorSelect "Select"
+# ====== TODO To be translated ======
+translate K OptionsTablebaseDir "Select up to 4 table base folders:"
+# ====== TODO To be translated ======
+translate K BestMoveArrow "Best move arrow"
+# ====== TODO To be translated ======
+translate K NewLocalEngine "+ New engine ..."
 }
 # end of catalan.tcl
