@@ -124,6 +124,7 @@ menuText E EditCopyBoard "Copy Position" 6 \
   {Copy the current board in FEN notation to the text selection (clipboard)}
 menuText E EditPasteBoard "Paste Start Board" 12 \
   {Set the start board from the current text selection (clipboard)}
+menuText E ConfigureScid "Preferences..." 0 {Configure all options for SCID}
 
 # Game menu:
 menuText E Game "Game" 0
@@ -267,11 +268,6 @@ menuText E CCEditCopy "Copy Gamelist to Clipbase" 0 {Copy the games as CSV list
 
 # Options menu:
 menuText E Options "Options" 0
-menuText E OptionsBoard "Chessboard" 0 {Chess board appearance options}
-menuText E OptionsBoardSize "Size" 0 {Change the board size}
-menuText E OptionsBoardPieces "Piece Style" 6 {Change the board piece style}
-menuText E OptionsBoardColors "Colors..." 0 {Change board colors}
-#Klimmek
 menuText E OptionsBoardGraphics "Squares..." 0 {Select textures for squares}
 translate E OptionsBGW {Select texture for squares}
 translate E OptionsBoardGraphicsText {Select graphic files for white and black squares:}
@@ -292,8 +288,6 @@ menuText E OptionsMovesHighlightLastMoveWidth "Width" 0 {Thickness of line}
 menuText E OptionsMovesHighlightLastMoveColor "Color" 0 {Color of line}
 menuText E OptionsMovesHighlightLastMoveArrow "include Arrow" 0 {Include Arrow with Highlight}
 menuText E OptionsMoves "Moves" 0 {Move entry options}
-menuText E OptionsMovesAsk "Ask Before Replacing Moves" 0 \
-  {Ask before overwriting any existing moves}
 menuText E OptionsMovesAnimate "Animation Time" 1 \
   {Set the amount of time used to animate moves}
 menuText E OptionsMovesDelay "Autoplay Time Delay..." 1 \
@@ -309,37 +303,28 @@ menuText E OptionsMovesKey "Keyboard Completion" 0 \
 menuText E OptionsMovesShowVarArrows "Show Arrows for Variations" 0 {Turn on/off arrows showing moves in variations}
 menuText E OptionsMovesGlossOfDanger "Color Coded Gloss of Danger" 0 {Turn on/off color coded gloss of danger}
 menuText E OptionsNumbers "Number Format" 0 {Select the number format}
-menuText E OptionsStartup "Startup" 3 {Select windows to open at startup}
 menuText E OptionsTheme "Theme" 0 {Change look of interface}
 menuText E OptionsWindows "Windows" 0 {Window options}
-menuText E OptionsWindowsIconify "Auto-Iconify" 5 \
-  {Iconify all windows when the main window is iconified}
-menuText E OptionsWindowsRaise "Auto-Raise" 5 \
-  {Raise certain windows (e.g. progress bars) whenever they are obscured}
-menuText E OptionsSounds "Sounds..." 2 {Configure move announcement sounds}
+menuText E OptionsSounds "Sounds" 2 {Configure move announcement sounds}
+menuText E OptionsResources "Resources..." 0 {Choose resource files and folders}
 menuText E OptionsWindowsDock "Dock windows" 0 {Dock windows (needs restart)}
 menuText E OptionsWindowsSaveLayout "Save layout" 0 {Save layout}
 menuText E OptionsWindowsRestoreLayout "Restore layout" 0 {Restore layout}
 menuText E OptionsWindowsShowGameInfo "Show game info" 0 {Show game info}
 menuText E OptionsWindowsAutoLoadLayout "Auto load first layout" 0 {Auto load first layout at startup}
-menuText E OptionsToolbar "Toolbar..." 0 {Configure the main window toolbar}
-menuText E OptionsECO "Load ECO File..." 7 {Load the ECO classification file}
-menuText E OptionsSpell "Load Spellcheck File..." 11 \
+menuText E OptionsECO "ECO File" 7 {Load the ECO classification file}
+menuText E OptionsSpell "Spellcheck File" 11 \
   {Load the Scid spellcheck file}
-menuText E OptionsTable "Tablebase Directory..." 10 \
+menuText E OptionsTable "Tablebase Directory" 10 \
   {Select a tablebase file; all tablebases in its directory will be used}
-menuText E OptionsRecent "Recent Files..." 0 {Change the number of recent files displayed in the File menu}
-menuText E OptionsBooksDir "Books directory..." 0 {Sets the opening books directory}
-menuText E OptionsTacticsBasesDir "Bases directory..." 0 {Sets the tactics (training) bases directory}
-menuText E OptionsPhotosDir "Photos directory..." 0 {Sets the photos bases directory}
-menuText E OptionsThemeDir "Load Theme(s)..."  0 { Load a GUI theme package file }
+menuText E OptionsRecent "Recent Files" 0 {Change the number of recent files displayed in the File menu}
+menuText E OptionsBooksDir "Books directory" 0 {Sets the opening books directory}
+menuText E OptionsTacticsBasesDir "Bases directory" 0 {Sets the tactics (training) bases directory}
+menuText E OptionsPhotosDir "Photos directory" 0 {Sets the photos bases directory}
+menuText E OptionsThemeDir "Theme(s) File"  0 { Load a GUI theme package file }
 menuText E OptionsSave "Save Options" 0 "Save all settable options to the file $::optionsFile"
 menuText E OptionsAutoSave "Auto-Save Options on Exit" 0 \
   {Auto-save all options when exiting Scid}
-menuText E OptionsMenuColor "Setup Menu Colors..." 0 { }
-translate E MenuColorForeground "Textcolor"
-translate E MenuColorBackground "Background"
-translate E MenuColorSelect "Select"
 
 # Help menu:
 menuText E Help "Help" 0
@@ -379,6 +364,7 @@ translate E Defaults {Defaults}
 translate E Delete {Delete}
 translate E Graph {Graph}
 translate E Help {Help}
+translate E Hide {Hide}
 translate E Import {Import}
 translate E Index {Index}
 translate E LoadGame {Load Game}
@@ -694,7 +680,7 @@ translate E BlundersThreshold {Threshold}
 translate E ScoreAllMoves {Score all moves}
 translate E LowPriority {Low CPU Priority}
 translate E ClickHereToSeeMoves {Click here to see moves}
-translate E ConfigureInformant {Configure Informant}
+translate E ConfigureInformant {Informant values}
 translate E Informant!? {Interesting move}
 translate E Informant? {Poor move}
 translate E Informant?? {Blunder}
@@ -1356,6 +1342,7 @@ translate E SoundsAnnounceOptions {Move Announcement Options}
 translate E SoundsAnnounceNew {Announce new moves as they are made}
 translate E SoundsAnnounceForward {Announce moves when moving forward one move}
 translate E SoundsAnnounceBack {Announce when retracting or moving back one move}
+translate E SoundsSoundDisabled {Scid could not find the Snack audio package at startup;\nSound is disabled.}
 
 # Upgrading databases:
 translate E Upgrading {Upgrading}
@@ -1550,9 +1537,9 @@ translate E QGDExchange {QGD Exchange}
 translate E SemiSlav {Semi-Slav}
 translate E QGDwithBg5 {QGD with Bg5}
 translate E QGDOrthodox {QGD Orthodox}
-translate E Grunfeld {Grnfeld}
-translate E GrunfeldExchange {Grnfeld Exchange}
-translate E GrunfeldRussian {Grnfeld Russian}
+translate E Grunfeld {Grünfeld}
+translate E GrunfeldExchange {Grünfeld Exchange}
+translate E GrunfeldRussian {Grünfeld Russian}
 translate E Catalan {Catalan}
 translate E CatalanOpen {Catalan Open}
 translate E CatalanClosed {Catalan Closed}
@@ -1561,7 +1548,7 @@ translate E NimzoIndian {Nimzo-Indian}
 translate E NimzoIndianClassical {Nimzo-Indian Classical}
 translate E NimzoIndianRubinstein {Nimzo-Indian Rubinstein}
 translate E KingsIndian {King's Indian}
-translate E KingsIndianSamisch {King's Indian Smisch}
+translate E KingsIndianSamisch {King's Indian Sämisch}
 translate E KingsIndianMainLine {King's Indian Main Line}
 
 # FICS
@@ -1589,7 +1576,7 @@ translate E FICSManualConfirm {confirm manually}
 translate E FICSFilterFormula {Filter with formula}
 translate E FICSIssueSeek {Issue seek}
 translate E FICSChallenge {Challenge}
-translate E FICSAccept {accept}
+translate E FICSAccept {Do you accept ?}
 translate E FICSDecline {decline}
 translate E FICSColour {Colour}
 translate E FICSSend {send}
@@ -1597,6 +1584,14 @@ translate E FICSConnect {Connect}
 translate E FICSdefaultuservars {Use default variables}
 translate E FICSObserveconfirm {Do you want to observe game}
 translate E FICSpremove {Enable premove}
+translate E FICSObserve {Observe}
+translate E FICSRatedGames {Rated Games}
+translate E FICSUnratedGames {Unrated Games}
+translate E FICSRated {Rated}
+translate E FICSUnrated {Unrated}
+translate E FICSRegisteredPlayer {Registered player only}
+translate E FICSFreePlayer {Free player only}
+translate E FICSNetError {Network error\nCan't connect to }
 
 # Game review
 translate E GameReview {Game review}
@@ -1769,5 +1764,21 @@ translate E FilterStatistic {Filter Statistics}
 translate E MakeCorrections {Make Corrections}
 translate E Surnames {Surnames}
 translate E Ambiguous {Ambiguous}
+
+#Preferences Dialog
+translate E OptionsToolbar "Toolbar"
+translate E OptionsBoard "Chessboard"
+translate E OptionsMenuColor "Menu colors"
+translate E OptionsBoardSize "Board size"
+translate E OptionsBoardPieces "Piece Style"
+translate E OptionsInternationalization "Internationalization"
+translate E MenuColorForeground "Textcolor"
+translate E MenuColorBackground "Background"
+translate E MenuColorSelect "Select"
+translate E OptionsTablebaseDir "Select up to 4 table base folders:"
+
+# Evaluation bar
+translate E BestMoveArrow "Best move arrow"
+translate E NewLocalEngine "+ New engine ..."
 }
 # end of english.tcl
