@@ -90,6 +90,8 @@ menuText I EditCopyBoard "Copia posizione" 6 \
   {Copia la posizione della scacchiera corrente in notazione FEN come testo (clipboard)}
 menuText I EditPasteBoard "Incolla come posizione di partenza" 17 \
   {Imposta la posizione di partenza dalla selezione del testo corrente (clipboard)}
+# ====== TODO To be translated ======
+menuText I ConfigureScid "Preferences..." 0 {Configure all options for SCID}
 
 # Game menu:
 menuText I Game "Partita" 0
@@ -228,11 +230,6 @@ menuText I CCEditCopy "Copia la lista di partite nella clipboard" 0 {Copia le pa
 
 # Options menu:
 menuText I Options "Opzioni" 0
-menuText I OptionsBoard "Scacchiera" 0 {Opzioni di visualizzazione della scacchiera}
-menuText I OptionsBoardSize "Dimensione della scacchiera" 0 {Cambia la dimensione della scacchiera}
-menuText I OptionsBoardPieces "Stile dei pezzi" 0 \
-  {Modifica lo stile dei pezzi della scacchiera}
-menuText I OptionsBoardColors "Colori..." 0 {Cambia i colori della scacchiera}
 menuText I OptionsBoardGraphics "Caselle..." 0 {Seleziona l'aspetto delle caselle}
 translate I OptionsBGW {Seleziona l'aspetto delle caselle}
 translate I OptionsBoardGraphicsText {Seleziona i file grafici per le caselle bianche e nere:}
@@ -253,8 +250,6 @@ menuText I OptionsMovesHighlightLastMoveWidth "Larghezza" 0 {Spessore della line
 menuText I OptionsMovesHighlightLastMoveColor "Colore" 0 {Colore della linea}
 menuText I OptionsMovesHighlightLastMoveArrow "Includi freccia" 0 {Include una freccia}
 menuText I OptionsMoves "Mosse" 0 {Opzioni di immissione delle mosse}
-menuText I OptionsMovesAsk "Chiedi conferma prima di sostituire le mosse" 0 \
-  {Chiede prima di sovrascrivere ogni mossa esistente}
 menuText I OptionsMovesAnimate "Intervallo di tempo per l'animazione delle mosse" 4 \
   {Definisce l'intervallo di tempo per l'animazione delle mosse}
 menuText I OptionsMovesDelay "Intervallo di tempo per il gioco automatico..." 1 \
@@ -270,46 +265,33 @@ menuText I OptionsMovesKey "Completamento da tastiera" 1 \
 menuText I OptionsMovesShowVarArrows "Mostra frecce per le varianti" 4 {Attiva/disattiva le freccie indicanti le mosse delle varianti}
 menuText I OptionsMovesGlossOfDanger "Codici di pericolo a colori" 1 {Attiva/disattiva i codici di pericolo a colori}
 menuText I OptionsNumbers "Formato dei numeri" 13 {Seglie il formato dei numeri}
-menuText I OptionsStartup "Apertura all'avvio" 3 {Sceglie le finestre da aprire all'avvio}
 menuText I OptionsTheme "Tema" 0 {Cambia l'aspetto dell'interfaccia}
 menuText I OptionsWindows "Finestre" 2 {Opzioni di finestra}
-menuText I OptionsWindowsIconify "Minimizza automaticamente" 2 \
-  {Minimizza tutte le finestre quando la finestra principale viene minimizzata}
-menuText I OptionsWindowsRaise "Ingrandisci automaticamente" 0 \
-  {Aumenta alcune finestre (p. es. le barre di progresso) ogni volta che sono oscurate}
-menuText I OptionsSounds "Suoni..." 2 {Configura i suoni per l'annuncio delle mosse} ;# ***
+menuText I OptionsSounds "Suoni" 2 {Configura i suoni per l'annuncio delle mosse} ;# ***
+# ====== TODO To be translated ======
+menuText I OptionsResources "Resources..." 0 {Choose resource files and folders}
 menuText I OptionsWindowsDock "Aggancia le finestre" 0 {Aggancia le finestre}
 menuText I OptionsWindowsSaveLayout "Salva layout" 0 {Salva il layout}
 menuText I OptionsWindowsRestoreLayout "Ripristina layout" 0 {Ripristina il layout}
 menuText I OptionsWindowsShowGameInfo "Mostra informazioni partita" 0 {Mostra le informazioni sulla partita}
 menuText I OptionsWindowsAutoLoadLayout "Carica automaticamente il primo layout" 0 {Carica automaticamente il primo layout all'avvio}
-menuText I OptionsToolbar "Barra degli strumenti" 0 \
-  {Mostra/nasconde la barra degli strumenti nella finestra principale}
 menuText I OptionsECO "Carica il file ECO..." 15 {Carica il file di classificazione ECO}
-menuText I OptionsSpell "Carica il file di controllo ortografico..." 0 \
+menuText I OptionsSpell "Carica il file di controllo ortografico" 0 \
   {Carica il file di controllo ortografico}
-menuText I OptionsTable "Directory di tablebase..." 8 \
+menuText I OptionsTable "Directory di tablebase" 8 \
   {Seglie un file tablebase; tutte le tablebase nella directory saranno utilizzate}
 menuText I OptionsRecent "File utilizzati di recente..." 10 \
   {Cambia il numero di file recentemente utilizzati visualizzato nel menu File}
-menuText I OptionsBooksDir "Directory del libro di aperture..." 0 {Configura la directory per il libro delle aperture}
-menuText I OptionsTacticsBasesDir "Directory dei database..." 15 {Configura la directory per i database di allenamento}
+menuText I OptionsBooksDir "Directory del libro di aperture" 0 {Configura la directory per il libro delle aperture}
+menuText I OptionsTacticsBasesDir "Directory dei database" 15 {Configura la directory per i database di allenamento}
 # ====== TODO To be translated ======
-menuText I OptionsPhotosDir "Photos directory..." 0 {Sets the photos bases directory}
+menuText I OptionsPhotosDir "Photos directory" 0 {Sets the photos bases directory}
 # ====== TODO To be translated ======
-menuText I OptionsThemeDir "Load Theme(s)..."  0 { Load a GUI theme package file }
+menuText I OptionsThemeDir "Theme(s) File:"  0 { Load a GUI theme package file }
 menuText I OptionsSave "Salva opzioni" 3 \
   "Salva tutte le opzioni definibili nel file $::optionsFile"
 menuText I OptionsAutoSave "Salva opzioni all'uscita" 17 \
   {Salva automaticamente tutte le opzioni quando si esce da Scid}
-# ====== TODO To be translated ======
-menuText I OptionsMenuColor "Setup Menu Colors..." 0 { }
-# ====== TODO To be translated ======
-translate I MenuColorForeground "Textcolor"
-# ====== TODO To be translated ======
-translate I MenuColorBackground "Background"
-# ====== TODO To be translated ======
-translate I MenuColorSelect "Select"
 
 # Help menu:
 menuText I Help "Aiuto" 0
@@ -349,6 +331,7 @@ translate I Defaults {Default}
 translate I Delete {Cancella}
 translate I Graph {Grafico}
 translate I Help {Aiuto}
+translate I Hide {Nascondi}
 translate I Import {Importa}
 translate I Index {Indice}
 translate I LoadGame {Carica partita}
@@ -449,6 +432,8 @@ translate I PInfoMostBlack {Le pi frequenti aperture con il Nero}
 translate I PInfoRating {Variazioni Elo}
 translate I PInfoBio {Biografia}
 translate I PInfoEditRatings {Edita i rating}
+# ====== TODO To be translated ======
+translate I PInfoEloFile {File}
 
 # Tablebase information:
 translate I Draw {Patta}
@@ -642,6 +627,10 @@ menuText I GraphOptionsWhite "Bianco" 0
 menuText I GraphOptionsBlack "Nero" 0
 menuText I GraphOptionsBoth "Entrambi" 1
 menuText I GraphOptionsPInfo "Informazioni sul giocatore" 0
+# ====== TODO To be translated ======
+menuText I GraphOptionsEloFile "Elo from rating file" 0
+# ====== TODO To be translated ======
+menuText I GraphOptionsEloDB "Elo from database" 0
 translate I GraphFilterTitle "Grafico del filtro: frequenza ogni 1000 partite"
 translate I GraphAbsFilterTitle "Grafico del filtro: frequenza delle partite"
 translate I ConfigureFilter {Configura l'asse delle X per Anno, Rating e Mosse}
@@ -673,7 +662,7 @@ translate I BlundersThreshold {Limite}
 translate I ScoreAllMoves {Punteggio ad ogni mossa}
 translate I LowPriority {Imposta la priorit della CPU a bassa}
 translate I ClickHereToSeeMoves {Clicca qui per vedere le mosse}
-translate I ConfigureInformant {Configura il valore dei simboli per i commenti}
+translate I ConfigureInformant {Valore dei simboli per i commenti}
 translate I Informant!? {Mossa interessante}
 translate I Informant? {Mossa debole}
 translate I Informant?? {Errore grave}
@@ -698,12 +687,6 @@ translate I EngineNew {Nuovo}
 translate I EngineEdit {Modifica}
 translate I EngineRequired {I campi in grassetto sono obbligatori; gli altri sono opzionali}
 
-# Stats window menus:
-menuText I StatsFile "File" 0
-menuText I StatsFilePrint "Stampa su file..." 0
-menuText I StatsFileClose "Chiudi la finestra" 0
-menuText I StatsOpt "Opzioni" 0
-
 # PGN window menus:
 menuText I PgnFile "File" 0
 menuText I PgnFileCopy "Copia la partita verso la clipboard" 1
@@ -1334,6 +1317,7 @@ translate I SoundsAnnounceOptions {Opzioni per l'annuncio delle mosse}
 translate I SoundsAnnounceNew {Annuncia l'esecuzione di una nuova mossa}
 translate I SoundsAnnounceForward {Annuncia quando si va avanti di una mossa}
 translate I SoundsAnnounceBack {Annuncia quando si va indietro di una mossa}
+translate I SoundsSoundDisabled {Scid non  riuscito a trovare il pacchetto audio Snack all'avvio;\nSound  disabilitato.}
 
 # Upgrading databases:
 translate I Upgrading {Aggiornamento}
@@ -1571,6 +1555,22 @@ translate I FICSConnect {Connetti}
 translate I FICSdefaultuservars {Usa le variabili predefinite}
 translate I FICSObserveconfirm {Vuoi osservare la partita}
 translate I FICSpremove {Abilita premove}
+# ====== TODO To be translated ======
+translate I FICSObserve {Observe}
+# ====== TODO To be translated ======
+translate I FICSRatedGames {Rated Games}
+# ====== TODO To be translated ======
+translate I FICSUnratedGames {Unrated Games}
+# ====== TODO To be translated ======
+translate I FICSRated {Rated}
+# ====== TODO To be translated ======
+translate I FICSUnrated {Unrated}
+# ====== TODO To be translated ======
+translate I FICSRegisteredPlayer {Registered player only}
+# ====== TODO To be translated ======
+translate I FICSFreePlayer {Free player only}
+# ====== TODO To be translated ======
+translate I FICSNetError {Network error\nCan't connect to }
 translate I GameReview {Rivedi partita}
 translate I GameReviewTimeExtended {Tempo esteso}
 translate I GameReviewMargin {Margine di errore}
@@ -1748,6 +1748,26 @@ translate I MakeCorrections {Make Corrections}
 translate I Surnames {Surnames}
 # ====== TODO To be translated ======
 translate I Ambiguous {Ambiguous}
+translate I OptionsToolbar "Barra degli strumenti"
+translate I OptionsBoard "Scacchiera"
+# ====== TODO To be translated ======
+translate I OptionsMenuColor "Menu colors"
+# ====== TODO To be translated ======
+translate I OptionsBoardSize "Dimensione della scacchiera"
+# ====== TODO To be translated ======
+translate I OptionsBoardPieces "Stile dei pezzi"
+# ====== TODO To be translated ======
+translate I OptionsInternationalization "Internationalization"
+# ====== TODO To be translated ======
+translate I MenuColorForeground "Textcolor"
+# ====== TODO To be translated ======
+translate I MenuColorBackground "Background"
+# ====== TODO To be translated ======
+translate I MenuColorSelect "Select"
+# ====== TODO To be translated ======
+translate I OptionsTablebaseDir "Select up to 4 table base folders:"
+translate I BestMoveArrow "Indica mossa migliore"
+translate I NewLocalEngine "+ Nuovo motore ..."
 }
 
 ############################################################
