@@ -88,6 +88,7 @@ menuText B EditCopyBoard "Copia posio" 6 \
   {Copia o tabuleiro corrente em notao FEN para a rea de transferncia} 
 menuText B EditPasteBoard "Colar Posicao" 12 \
   {Configura a posicao inicial a partir da area de transferencia}
+menuText B ConfigureScid "Preferencias..." 0 {Configurar todas as opcoes para o SCID}
 
 # Game menu:
 menuText B Game "Jogo" 0
@@ -169,7 +170,7 @@ menuText B ToolsTrainTactics "Tticas"  0 {Exerccios de ttica}
 menuText B ToolsTrainCalvar "Clculo de Variantes"  0 {Treinamento de clculo de variantes}
 menuText B ToolsTrainFindBestMove "Procurar melhor movimento"  0 {Procura o melhor movimento}
 menuText B ToolsTrainFics "Jogar na internet"  0 {Jogar em  freechess.org}
-menuText B ToolsEngineTournament "Torneio de motores de Xadrez"  0 {Inicia um torneio entre motores de Xadrez}
+menuText B ToolsEngineTournament "Torneio de Engines de Xadrez"  0 {Inicia um torneio entre engines de Xadrez}
 menuText B ToolsBookTuning "Sintonizar Livro" 0 {Sintonizar livro de aberturas}
 menuText B ToolsConnectHardware "Conectar Hardware" 0 {Conectar hardware externo}
 menuText B ToolsConnectHardwareConfigure "Configurar..." 0 {Configurar hardware e conexo externa}
@@ -226,11 +227,6 @@ menuText B CCEditCopy "Copiar Lista de Jogos para a base de cpia" 0 {Copia os jo
 
 # Options menu:
 menuText B Options "Opcoes" 0
-menuText B OptionsBoard "Tabuleiro" 0 {Opes de aparncia do tabuleiro} 
-menuText B OptionsBoardSize "Tamanho do Tabuleiro" 0 {Muda o tamanho do tabuleiro}
-menuText B OptionsBoardPieces "Estilo de Pecas no Tabuleiro" 10 \
-  {Muda o estilo das pecas mostradas no tabuleiro}
-menuText B OptionsBoardColors "Cores..." 0 {Muda as cores do tabuleiro}
 menuText B OptionsBoardGraphics "Casas..." 0 {Seleciona texturas para as casas}
 translate B OptionsBGW {Seleciona texturas para as casas}
 translate B OptionsBoardGraphicsText {Seleciona arquivos grficos para as casas brancas e pretas:}
@@ -251,8 +247,6 @@ menuText B OptionsMovesHighlightLastMoveWidth "Espessura" 0 {Espessura da linha}
 menuText B OptionsMovesHighlightLastMoveColor "Cor" 0 {Cor da linha}
 menuText B OptionsMovesHighlightLastMoveArrow "seta de inclusao" 0 {Seta de Inclusao Destacada}
 menuText B OptionsMoves "Movimentos" 0 {Opcoes para entrada dos movimentos}
-menuText B OptionsMovesAsk "Perguntar antes de substituir movimentos" 0 \
-  {Pergunta antes de substituir movimentos existentes}
 menuText B OptionsMovesAnimate "Tempo de animao" 1 \
   {Define a quantidade de tempo usada para animar os movimentos} 
 menuText B OptionsMovesDelay "Tempo de atraso p/ Jogo automatico..." 1 \
@@ -268,31 +262,26 @@ menuText B OptionsMovesKey "Auto completar" 0 \
 menuText B OptionsMovesShowVarArrows "Mostrar Setas para variantes" 0 {Liga/Desliga as setas que mostram movimentos em variantes}
 menuText B OptionsMovesGlossOfDanger "Codigos de Cor para Perigo" 0 {Liga/Desliga os codigos de cor para perigo}
 menuText B OptionsNumbers "Formato de Numeros" 0 {Selecione o formato usado para numeros}
-menuText B OptionsStartup "Iniciar" 1 \
-  {Seleciona janelas que serao abertas ao iniciar o programa}
 menuText B OptionsTheme "Tema" 0 {Muda a aparncia da interface}
 menuText B OptionsWindows "Janelas" 0 {Opcoes para Janelas}
-menuText B OptionsWindowsIconify "Auto-iconizar" 5 \
-  {Iconizar todas as janelas quando a janela principal eh iconizada}
-menuText B OptionsWindowsRaise "Manter no topo" 0 \
-  {Mantem no topo certas janelas (ex. barras de progresso) sempre que sao obscurecidas por outras}
-menuText B OptionsSounds "Sons..." 2 {Configura sons para anunciar os movimentos} 
+menuText B OptionsSounds "Sons" 2 {Configura sons para anunciar os movimentos} 
+menuText B OptionsResources "Recursos..." 0 {Escolher pastas e arquivos de recursos}
 menuText B OptionsWindowsDock "Estacionar janelas" 0 {Estaciona as janelas}
 menuText B OptionsWindowsSaveLayout "Salvar layout" 0 {Salva o layout das janelas}
 menuText B OptionsWindowsRestoreLayout "Restaurar layout" 0 {Restaura layout}
 menuText B OptionsWindowsShowGameInfo "Mostrar Informaes do Jogo" 0 {Mostra informaes do jogo}
 menuText B OptionsWindowsAutoLoadLayout "Carregar primeiro layout na entrada" 0 {Carrega automaticamente o primeiro layout ao entrar na aplicao}
-menuText B OptionsToolbar "Barra de Ferramentas da Janela Principal" 12 \
-  {Exibe/Oculta a barra de ferramentas da janela principal}
-menuText B OptionsECO "Carregar arquivo ECO..." 7 {Carrega o arquivo com a classificacao ECO}
-menuText B OptionsSpell "Carregar arquivo de verificacao ortografica..." 6 \
+menuText B OptionsECO "Carregar arquivo ECO" 7 {Carrega o arquivo com a classificacao ECO}
+menuText B OptionsSpell "Carregar arquivo de verificacao ortografica" 6 \
   {Carrega o arquivo de verificacao ortografica do Scid}
-menuText B OptionsTable "Diretorio de tabelas de base..." 0 \
+menuText B OptionsTable "Diretorio de tabelas de base" 0 \
   {Selecione um arquivo de tabela de base; todas as tabelas nesse diretorio serao usadas}
 menuText B OptionsRecent "Arquivos recentes..." 0 \
   {Muda o nmero de arquivos recentes no menu Arquivo} 
-menuText B OptionsBooksDir "Diretrio de Livros..." 0 {Define o diretrio para os livros de aberturas}
-menuText B OptionsTacticsBasesDir "Diretrio de bases..." 0 {Define o diretrio para as bases de treinamento de tticas}
+menuText B OptionsBooksDir "Diretrio de Livros" 0 {Define o diretrio para os livros de aberturas}
+menuText B OptionsTacticsBasesDir "Diretrio de bases" 0 {Define o diretrio para as bases de treinamento de tticas}
+menuText B OptionsPhotosDir "Diretorio de Fotos" 0 {Define o diretorio base de fotos}
+menuText B OptionsThemeDir "Carregar Tema(s)"  0 {Carrega arquivo de tema para a tela}
 menuText B OptionsSave "Salvar Configuracao" 0 \
   "Salva a configuracao no arquivo $::optionsFile"
 menuText B OptionsAutoSave "Salva Opcoes ao sair" 0 \
@@ -300,7 +289,7 @@ menuText B OptionsAutoSave "Salva Opcoes ao sair" 0 \
 
 # Help menu:
 menuText B Help "Ajuda" 0
-menuText B HelpContents "Contents" 0 {Show the help contents page} 
+menuText B HelpContents "Conteudo" 0 {Mostra a pagina de conteudo da ajuda}
 menuText B HelpIndex "Indice" 0 {Indice da Ajuda}
 menuText B HelpGuide "Consulta Rapida" 0 {Mostra a pagina de consulta rapida}
 menuText B HelpHints "Dicas" 0 {Mostra a pagina de dicas}
@@ -331,11 +320,13 @@ translate B Cancel {Cancelar}
 translate B Continue {Continuar}
 translate B Clear {Limpar}
 translate B Close {Fechar}
-translate B Contents {Contedo} 
+translate B Contents {Conteudo} 
 translate B Defaults {Defaults}
 translate B Delete {Deletar}
 translate B Graph {Grafico}
 translate B Help {Ajuda}
+# ====== TODO To be translated ======
+translate B Hide {Hide}
 translate B Import {Importar}
 translate B Index {Indice}
 translate B LoadGame {Carrega jogo}
@@ -350,7 +341,7 @@ translate B Stop {Parar}
 translate B Store {Guardar}
 translate B Update {Atualizar}
 translate B ChangeOrient {Muda orientacao da janela}
-translate B ShowIcons {Mostrar cones} 
+translate B ShowIcons {Mostrar Icones} 
 translate B None {Nenhum}
 translate B First {Primeiro}
 translate B Current {Atual}
@@ -389,6 +380,7 @@ translate B Month {Mes}
 translate B Months {Janeiro Fevereiro Marco Abril Maio Junho Julho Agosto Setembro Outubro Novembro Dezembro}
 translate B Days {Dom Seg Ter Qua Qui Sex Sab}
 translate B YearToToday {Anos ate hoje}
+translate B YearToTodayTooltip {Define a data para 1 ano atrs}
 translate B Result {Resultado}
 translate B Round {Rodada}
 translate B Length {Tamanho}
@@ -434,6 +426,7 @@ translate B PInfoMostBlack {Aberturas mais comuns com as Pretas}
 translate B PInfoRating {Historico de Rating}
 translate B PInfoBio {Biografia}
 translate B PInfoEditRatings {Editar Ratings} 
+translate B PInfoEloFile {Arquivo}
 
 # Tablebase information:
 translate B Draw {Empate}
@@ -452,6 +445,14 @@ translate B WinningMoves {Movimentos vencedores}
 translate B DrawingMoves {Movimentos para empate} 
 translate B LosingMoves {Movimentos perdedores} 
 translate B UnknownMoves {Movimentos com resultado desconhecido} 
+translate B SideLongest {Lado    Mov. p/    %     %     %\n}
+translate B toNoveMate {a mover   mate      V     E     D\n}
+translate B NoSummary {\nSem resumo para esta tablebase.}
+translate B MutualZugzwang {Zugzwangs Nutuos: }
+translate B SelectetZugzwang {\nPosicoes de zugzwang selecionadas:}
+translate B WdrawBloss {Branca empata, Preta perde:}
+translate B BdrawWloss {Preta empata, Branca perde:}
+translate B AllLoss {" Quem mover perde   :     " }
 
 # Tip of the day:
 translate B Tip {Dica}
@@ -612,6 +613,8 @@ menuText B GraphOptionsWhite "Branco" 0
 menuText B GraphOptionsBlack "Preto" 0
 menuText B GraphOptionsBoth "Ambos" 0
 menuText B GraphOptionsPInfo "Informacao do Jogador" 0
+menuText B GraphOptionsEloFile "Elo do arquivo de rating" 0
+menuText B GraphOptionsEloDB "Elo da base de dados" 0
 translate B GraphFilterTitle "Grfico de filtro: frequencia por 1000 jogos" 
 translate B GraphAbsFilterTitle "Grfico de filtro: frequencia dos jogos"
 translate B ConfigureFilter {Configurar Eixos X para Ano, Rating e Movimentos}
@@ -643,7 +646,7 @@ translate B BlundersThreshold {Limite}
 translate B ScoreAllMoves {Analise todos os movimentos}
 translate B LowPriority {Baixa prioridade da CPU} 
 translate B ClickHereToSeeMoves {Clique aqui para ver os movimentos}
-translate B ConfigureInformant {Configurar Informante}
+translate B ConfigureInformant {Informante}
 translate B Informant!? {Movimento interessante}
 translate B Informant? {Movimento pobre}
 translate B Informant?? {Erro crasso}
@@ -668,12 +671,6 @@ translate B EngineNew {Novo}
 translate B EngineEdit {Editar}
 translate B EngineRequired {Campos em negrito so obrigatrios; os demais so opcionais}
 
-# Stats window menus:
-menuText B StatsFile "Arquivo" 0
-menuText B StatsFilePrint "Imprimir para arquivo..." 0
-menuText B StatsFileClose "Fecha janela" 0
-menuText B StatsOpt "Opcoes" 0
-
 # PGN window menus:
 menuText B PgnFile "Arquivo" 0
 menuText B PgnFileCopy "Copiar o jogo para a rea de transferncia" 0 
@@ -1301,6 +1298,7 @@ translate B SoundsAnnounceOptions {Opes de anuncio de movimentos}
 translate B SoundsAnnounceNew {Anuncia novos movimentos quando eles so feitos} 
 translate B SoundsAnnounceForward {Anuncia movimentos quando avanar um movimento} 
 translate B SoundsAnnounceBack {Anuncia movimentos quando retroceder um movimento} 
+translate B SoundsSoundDisabled {O Scid no conseguiu encontrar o pacote de udio Snack na inicializao;\nSound est desativado.}
 
 # Upgrading databases:
 translate B Upgrading {Atualizando}
@@ -1537,6 +1535,22 @@ translate B FICSConnect {Conectar}
 translate B FICSdefaultuservars {Usar variaveis default}
 translate B FICSObserveconfirm {Voce quer observar o jogo}
 translate B FICSpremove {Habilita Pre-movimento}
+# ====== TODO To be translated ======
+translate B FICSObserve {Observe}
+# ====== TODO To be translated ======
+translate B FICSRatedGames {Rated Games}
+# ====== TODO To be translated ======
+translate B FICSUnratedGames {Unrated Games}
+# ====== TODO To be translated ======
+translate B FICSRated {Rated}
+# ====== TODO To be translated ======
+translate B FICSUnrated {Unrated}
+# ====== TODO To be translated ======
+translate B FICSRegisteredPlayer {Registered player only}
+# ====== TODO To be translated ======
+translate B FICSFreePlayer {Free player only}
+# ====== TODO To be translated ======
+translate B FICSNetError {Network error\nCan't connect to }
 translate B GameReview {Rever jogo}
 translate B GameReviewTimeExtended {Tempo estendido}
 translate B GameReviewMargin {Mergem de erro}
@@ -1648,6 +1662,54 @@ translate B DockLeft {Mover para a esquerda}
 translate B DockRight {Mover para a direita}
 translate B Undock {Desacoplar}
 translate B ChangeIcon {Alterar icone...}
+translate B NewGameListWindow {Lista de Novos Jogos}
+translate B LoadatStartup {Carregar ao inicializar}
+translate B ShowHideDB {Exibe/Oculta base de dados}
+translate B ChangeFilter {Altera filtro}
+translate B ChangeLayout {Carrega/Salva/Altera criterio de ordenacao e layout das colunas}
+translate B ShowHideStatistic {Exibe/Oculta Estatisticas}
+translate B BoardFilter {Mostra apenas jogos que atendam a posicao atual no tabuleiro}
+translate B CopyGameTo {Copiar jogo para}
+translate B FindBar {Barra de Pesquisa}
+translate B FindCurrentGame {Pesquisar jogo atual}
+translate B DeleteGame {Excluir jogo}
+translate B UndeleteGame {Recuperar jogo deletado}
+translate B ResetSort {Reiniciar ordenacao}
+translate B ConvertNullMove {Converter movimentos nullos para comentarios}
+translate B SetupBoard {Definir tabuleiro}
+translate B Rotate {Rotacionar}
+translate B SwitchColors {Trocar cores}
+translate B FlipBoard {Virar o tabuleiro}
+translate B ImportPGN {Importar jogo em PGN}
+translate B ImportingFiles {Importar arquivos PGN para}
+translate B ImportingFrom {Importando de}
+translate B ImportingIn {Importar jogos para}
+translate B UseLastTag {Usar ultimas\ntags do jogo}
+translate B Random {Aleatorio}
+translate B BackToMainline {Voltar para linha principal}
+translate B LeaveVariant {Deixar variante}
+translate B Autoplay {Jogo automatico}
+translate B ShowHideCoords {Exibir/Ocultar Coord.}
+translate B ShowHideMaterial {Exibir/Ocultar Material}
+translate B FullScreen {Tela Cheia}
+translate B FilterStatistic {Estatisticas de Filtro}
+translate B MakeCorrections {Fazer Correcoes}
+translate B Surnames {Sobrenomes}
+translate B Ambiguous {Ambiguo}
+translate B OptionsToolbar "Barra de Ferramentas da Janela Principal"
+translate B OptionsBoard "Tabuleiro"
+translate B OptionsMenuColor "Define Cores dos Menus"
+translate B OptionsBoardSize "Tamanho do Tabuleiro"
+translate B OptionsBoardPieces "Estilo de Pecas no Tabuleiro"
+translate B OptionsInternationalization "Internacionalizacao"
+translate B MenuColorForeground "Cor do Texto"
+translate B MenuColorBackground "Cor de Fundo"
+translate B MenuColorSelect "Selecionar"
+translate B OptionsTablebaseDir "Selecione at 4 pastas tabela base de finais:"
+# ====== TODO To be translated ======
+translate B BestMoveArrow "Best move arrow"
+# ====== TODO To be translated ======
+translate B NewLocalEngine "+ New engine ..."
 }
 
 # end of portbr.tcl
