@@ -122,6 +122,8 @@ menuText U EditCopyBoard "Kopioi asema" 0 \
   {Kopioi nykyinen asema leikepydlle FEN-muodossa}
 menuText U EditPasteBoard "Liit asema" 0 \
   {Liit leikepydll oleva FEN-teksti alkuasemaksi}
+# ====== TODO To be translated ======
+menuText U ConfigureScid "Preferences..." 0 {Configure all options for SCID}
 
 # Game menu:
 menuText U Game "Peli" 0
@@ -266,11 +268,6 @@ menuText U CCEditCopy "Kopioi pelilista leikekantaan" 0 {Kopioi pelit leikekanta
 
 # Options menu:
 menuText U Options "Asetukset" 0
-menuText U OptionsBoard "Shakkilauta" 0 {Shakkilaudan ulkonkn liittyvt asetukset}
-menuText U OptionsBoardSize "Koko" 0 {Muuta laudan kokoa}
-menuText U OptionsBoardPieces "Nappulat" 0 {Muuta nappuloiden ulkomuotoa}
-menuText U OptionsBoardColors "Vrit" 0 {Vaihda laudan vrej}
-#Klimmek
 menuText U OptionsBoardGraphics "Ruudut" 0 {Valitse ruuduissa kytettv tekstuuri}
 translate U OptionsBGW {Valitse ruuduissa kytettv tekstuuri}
 translate U OptionsBoardGraphicsText {Valitse ruuduissa kytettv grafiikkatiedosto:}
@@ -291,8 +288,6 @@ menuText U OptionsMovesHighlightLastMoveWidth "Viiva" 0 {Laudalla nytettvn viiva
 menuText U OptionsMovesHighlightLastMoveColor "Vri" 0 {Laudalla nytettvn viivan vri}
 menuText U OptionsMovesHighlightLastMoveArrow "Sis. nuoli" 0 {Korostettuun siirtoon sisllytetn nuoli}
 menuText U OptionsMoves "Siirrot" 0 {Siirtojen syttmiseen liittyvt asetukset}
-menuText U OptionsMovesAsk "Kysy ennen korvaamista" 0 \
-  {Ohjelma kysyy luvan ennen kuin kirjoittaa vanhojen tietojen plle}
 menuText U OptionsMovesAnimate "Animaation nopeus" 1 \
   {Siirtojen animoinnin nopeus}
 menuText U OptionsMovesDelay "Toiston siirtonopeus" 1 \
@@ -309,20 +304,16 @@ menuText U OptionsMovesShowVarArrows "Muunnelmat nuolin" 0 {Nyt/l nyt muunnelmia
 # ====== TODO To be translated ======
 menuText U OptionsMovesGlossOfDanger "Color Coded Gloss of Danger" 0 {Turn on/off color coded gloss of danger}
 menuText U OptionsNumbers "Numerointi" 0 {Numeroformaatit, 1-3 desimaalipisteell, 4-6 -pilkulla}
-menuText U OptionsStartup "Kynnistys" 0 {Valitse lisikkunat, jotka avataan ohjelmaa kynnistettess}
 menuText U OptionsTheme "Teema" 0 {Valitse kyttliittymn teema}
 menuText U OptionsWindows "Ikkunat" 0 {Ikkunoiden asetukset}
-menuText U OptionsWindowsIconify "Pienenn automaattisesti" 0 \
-  {Pienenn mys muut ikkunat, kun pikkuna pienennetn}
-menuText U OptionsWindowsRaise "Nosta automaattisesti" 0 \
-  {Nosta ert ikkunat automaattisesti ylimmksi}
 menuText U OptionsSounds "net" 0 {Muokaa siirtoilmoitusni}
+# ====== TODO To be translated ======
+menuText U OptionsResources "Resources..." 0 {Choose resource files and folders}
 menuText U OptionsWindowsDock "Telakoi ikkunat" 0 {Telakoi irti olevat ikkunat (vaatii uudelleenkynnistyksen)}
 menuText U OptionsWindowsSaveLayout "Tallenna layout" 0 {Tallenna nimelle ikkunoiden ja tykalupalkkien sijainti}
 menuText U OptionsWindowsRestoreLayout "Palauta layout" 0 {Palauta tallennettu layout}
 menuText U OptionsWindowsShowGameInfo "Pelin tiedot" 0 {Nyt/piilota pelin tiedot (pelaajanimet, turnaus...)}
 menuText U OptionsWindowsAutoLoadLayout "Ensimminen layout automaattisesti" 0 {Lataa ensimminen tallennettu layout automaattisesti}
-menuText U OptionsToolbar "Tykalupalkki" 0 {Muokkaa pikkunan tykalupalkkia}
 menuText U OptionsECO "Lataa ECO-tiedosto" 7 {Lataa ECO avausluokittelu tiedostosta}
 menuText U OptionsSpell "Lataa oikeinkirjoitustiedosto" 0 \
   {Lataa Scidin oikeinkirjoitustiedosto}
@@ -331,6 +322,10 @@ menuText U OptionsTable "Loppupelitietokannat" 0 \
 menuText U OptionsRecent "Viimeaikaiset tiedostot" 0 {Kuinka monta tiedostoa nytetn Tiedosto-valikon viimeaikaisten listassa}
 menuText U OptionsBooksDir "Avauskirjat" 0 {Hakemisto, jossa avauskirjat sijaitsevat}
 menuText U OptionsTacticsBasesDir "Taktiikkakannat" 0 {Hakemisto, jossa taktiikka (harjoitus) tietokannat sijaitsevat}
+# ====== TODO To be translated ======
+menuText U OptionsPhotosDir "Photos directory" 0 {Sets the photos bases directory}
+# ====== TODO To be translated ======
+menuText U OptionsThemeDir "Theme(s) File:"  0 { Load a GUI theme package file }
 menuText U OptionsSave "Tallenna asetukset" 0 "Tallenna kaikki asetukset tiedostoon $::optionsFile"
 menuText U OptionsAutoSave "Automaattinen asetusten tallennus" 0 \
   {Tallenna asetukset automaattisesti ohjelmasta poistuttaessa}
@@ -373,6 +368,8 @@ translate U Defaults {Oletukset}
 translate U Delete {Poista}
 translate U Graph {Graafi}
 translate U Help {Ohje}
+# ====== TODO To be translated ======
+translate U Hide {Hide}
 translate U Import {Tuo}
 translate U Index {Hakemisto}
 translate U LoadGame {Lataa peli}
@@ -426,6 +423,8 @@ translate U Month {Kuukausi}
 translate U Months {Tammikuu Helmikuu Maaliskuu Huhtikuu Toukokuu Keskuu Heinkuu Elokuu Syyskuu Lokakuu Marraskuu Joulukuu}
 translate U Days {Su Ma Ti Ke To Pe La}
 translate U YearToToday {Vuoden alusta}
+# ====== TODO To be translated ======
+translate U YearToTodayTooltip {Set date from 1 year back to today}
 translate U Result {Tulos}
 translate U Round {Kierros}
 translate U Length {Pituus}
@@ -471,6 +470,8 @@ translate U PInfoMostBlack {Yleisimmt avaukset: Musta}
 translate U PInfoRating {Vahvuuslukuhistoria}
 translate U PInfoBio {Biografia}
 translate U PInfoEditRatings {Muokkaa vahvuuslukuja}
+# ====== TODO To be translated ======
+translate U PInfoEloFile {File}
 
 # Tablebase information:
 translate U Draw {Tasapeli}
@@ -489,6 +490,22 @@ translate U WinningMoves {Voittavat siirrot}
 translate U DrawingMoves {Tasapeliin vievt siirrot}
 translate U LosingMoves {Hvivt siirrot}
 translate U UnknownMoves {Epvarma tulos}
+# ====== TODO To be translated ======
+translate U SideLongest {Side    Longest    %     %     %\n}
+# ====== TODO To be translated ======
+translate U toNoveMate {to move   mate    Win  Draw  Loss\n}
+# ====== TODO To be translated ======
+translate U NoSummary {\nNo summary for this tablebase.}
+# ====== TODO To be translated ======
+translate U MutualZugzwang {Mutual zugzwangs: }
+# ====== TODO To be translated ======
+translate U SelectetZugzwang {\nSelected zugzwang positions:}
+# ====== TODO To be translated ======
+translate U WdrawBloss {White draws, Black loses:}
+# ====== TODO To be translated ======
+translate U BdrawWloss {Black draws, White loses:}
+# ====== TODO To be translated ======
+translate U AllLoss {" Whoever moves loses:     " }
 
 # Tip of the day:
 translate U Tip {Vihje}
@@ -645,6 +662,10 @@ menuText U GraphOptionsWhite "Valkea" 0
 menuText U GraphOptionsBlack "Musta" 0
 menuText U GraphOptionsBoth "Molemmat" 1
 menuText U GraphOptionsPInfo "Pelaaja Info pelaaja" 0
+# ====== TODO To be translated ======
+menuText U GraphOptionsEloFile "Elo from rating file" 0
+# ====== TODO To be translated ======
+menuText U GraphOptionsEloDB "Elo from database" 0
 translate U GraphFilterTitle "Graafi: yleisyys per 1000 peli"
 translate U GraphAbsFilterTitle "graafi: pelien yleisyys"
 translate U ConfigureFilter "Muokkaa X-akseli; vuosi, vahvuus, siirrot"
@@ -676,7 +697,7 @@ translate U BlundersThreshold {Virhekynnys}
 translate U ScoreAllMoves {Pisteyt kaikki siirrot}
 translate U LowPriority {Matala CPUn kyttaste}
 translate U ClickHereToSeeMoves {Klikkaa nhdksesi siirrot}
-translate U ConfigureInformant {Tee Informant-asetukset}
+translate U ConfigureInformant {Informant-asetukset}
 translate U Informant!? {Mielenkiintoinen siirto}
 translate U Informant? {Heikko siirto}
 translate U Informant?? {Virhe}
@@ -703,12 +724,6 @@ translate U EngineNew {Uusi}
 translate U EngineEdit {Muokkaa}
 translate U EngineRequired {Lihavoidut kentt ovat pakollisia}
 
-# Stats window menus:
-menuText U StatsFile "Tiedosto" 0
-menuText U StatsFilePrint "Tulosta tiedostoon..." 1
-menuText U StatsFileClose "Sulje ikkuna" 0
-menuText U StatsOpt "Asetukset" 0
-
 # PGN window menus:
 menuText U PgnFile "Tiedosto" 0
 menuText U PgnFileCopy "Kopioi peli leikepydlle" 0
@@ -1341,6 +1356,8 @@ translate U SoundsAnnounceOptions {Siirtoilmoitusasetukset}
 translate U SoundsAnnounceNew {Ilmoita uudet siirrot}
 translate U SoundsAnnounceForward {Ilmoita, kun siirrytn eteenpin yksi siirto}
 translate U SoundsAnnounceBack {Ilmoita, kun siirrytn taaksepin yksi siirto}
+# ====== TODO To be translated ======
+translate U SoundsSoundDisabled {Scid could not find the Snack audio package at startup;\nSound is disabled.}
 
 # Upgrading databases:
 translate U Upgrading {Pivitys}
@@ -1580,6 +1597,22 @@ translate U FICSConnect {yhdist}
 translate U FICSdefaultuservars {Kyt oletusmuuttujia}
 translate U FICSObserveconfirm {Haluatko seurata peli}
 translate U FICSpremove {Ennakkosiirto plle}
+# ====== TODO To be translated ======
+translate U FICSObserve {Observe}
+# ====== TODO To be translated ======
+translate U FICSRatedGames {Rated Games}
+# ====== TODO To be translated ======
+translate U FICSUnratedGames {Unrated Games}
+# ====== TODO To be translated ======
+translate U FICSRated {Rated}
+# ====== TODO To be translated ======
+translate U FICSUnrated {Unrated}
+# ====== TODO To be translated ======
+translate U FICSRegisteredPlayer {Registered player only}
+# ====== TODO To be translated ======
+translate U FICSFreePlayer {Free player only}
+# ====== TODO To be translated ======
+translate U FICSNetError {Network error\nCan't connect to }
 
 # Game review
 translate U GameReview {Pelin arvioiminen}
@@ -1712,6 +1745,93 @@ translate U Undock {Vapauta lukitus}
 
 # Switcher window
 translate U ChangeIcon {Vaihda kuvake...}
-
+# ====== TODO To be translated ======
+translate U NewGameListWindow {New Game List Window}
+# ====== TODO To be translated ======
+translate U LoadatStartup {Load at startup}
+# ====== TODO To be translated ======
+translate U ShowHideDB {Show/Hide databases}
+# ====== TODO To be translated ======
+translate U ChangeFilter {Change filter}
+# ====== TODO To be translated ======
+translate U ChangeLayout {Load/Save/Change sorting criteria and column layout}
+# ====== TODO To be translated ======
+translate U ShowHideStatistic {Show/Hide statistics}
+# ====== TODO To be translated ======
+translate U BoardFilter {Show only games that matches the current board position}
+# ====== TODO To be translated ======
+translate U CopyGameTo {Copy Game to}
+# ====== TODO To be translated ======
+translate U FindBar {Find Bar}
+# ====== TODO To be translated ======
+translate U FindCurrentGame {Find current game}
+# ====== TODO To be translated ======
+translate U DeleteGame {Delete game}
+# ====== TODO To be translated ======
+translate U UndeleteGame {Undelete game}
+# ====== TODO To be translated ======
+translate U ResetSort {Reset sort}
+# ====== TODO To be translated ======
+translate U ConvertNullMove {Convert null moves to comments}
+# ====== TODO To be translated ======
+translate U SetupBoard {Setup Board}
+# ====== TODO To be translated ======
+translate U Rotate {Rotate}
+# ====== TODO To be translated ======
+translate U SwitchColors {Switch colors}
+# ====== TODO To be translated ======
+translate U FlipBoard {Flip Board}
+# ====== TODO To be translated ======
+translate U ImportPGN {Import PGN game}
+# ====== TODO To be translated ======
+translate U ImportingFiles {Importing PGN files in}
+# ====== TODO To be translated ======
+translate U ImportingFrom {Importing from}
+# ====== TODO To be translated ======
+translate U ImportingIn {Import games in}
+# ====== TODO To be translated ======
+translate U UseLastTag {Use last\ngame's tags}
+# ====== TODO To be translated ======
+translate U Random {Random}
+# ====== TODO To be translated ======
+translate U BackToMainline {Go back to mainline}
+# ====== TODO To be translated ======
+translate U LeaveVariant {Leave variant}
+# ====== TODO To be translated ======
+translate U Autoplay {Autoplay}
+# ====== TODO To be translated ======
+translate U ShowHideCoords {Show/Hide Coord.}
+# ====== TODO To be translated ======
+translate U ShowHideMaterial {Show/Hide Material}
+# ====== TODO To be translated ======
+translate U FullScreen {Full Screen}
+# ====== TODO To be translated ======
+translate U FilterStatistic {Filter Statistics}
+# ====== TODO To be translated ======
+translate U MakeCorrections {Make Corrections}
+# ====== TODO To be translated ======
+translate U Surnames {Surnames}
+# ====== TODO To be translated ======
+translate U Ambiguous {Ambiguous}
+translate U OptionsToolbar "Tykalupalkki"
+translate U OptionsBoard "Shakkilauta"
+# ====== TODO To be translated ======
+translate U OptionsMenuColor "Menu colors"
+translate U OptionsBoardSize "Koko"
+translate U OptionsBoardPieces "Nappulat"
+# ====== TODO To be translated ======
+translate U OptionsInternationalization "Internationalization"
+# ====== TODO To be translated ======
+translate U MenuColorForeground "Textcolor"
+# ====== TODO To be translated ======
+translate U MenuColorBackground "Background"
+# ====== TODO To be translated ======
+translate U MenuColorSelect "Select"
+# ====== TODO To be translated ======
+translate U OptionsTablebaseDir "Select up to 4 table base folders:"
+# ====== TODO To be translated ======
+translate U BestMoveArrow "Best move arrow"
+# ====== TODO To be translated ======
+translate U NewLocalEngine "+ New engine ..."
 }
 # end of suomi.tcl
