@@ -137,8 +137,7 @@ proc updateTitle {} {
 #   Updates the main Scid window status bar.
 #
 proc updateStatusBar {} {
-    # Check if translations have not been set up yet:
-    if {! [info exists ::tr(Database)]} { return }
+    if {! [winfo exists .main]} { return }
 
     if {$::menuHelpMessage != ""} {
         ::board::setInfoAlert .main.board "[tr Help]:" "$::menuHelpMessage" "black" ""
@@ -163,6 +162,7 @@ proc updateStatusBar {} {
     # show [%clk] command (if we are not playing)
     set toMove  [sc_pos side]
     set comment [sc_pos getComment]
+    ::board::updateEvalBar .main.board [getScorefromComment $comment 10]
     if { ![gameclock::isRunning] } {
         set ::gamePlayers(clockW) ""
         set ::gamePlayers(clockB) ""
@@ -179,7 +179,7 @@ proc updateStatusBar {} {
 
     if {[info exists ::guessedAddMove]} {
         set ::gameLastMove [lindex $::guessedAddMove 1]
-        ::board::setInfoAlert .main.board [lindex $::guessedAddMove 0] "\[click to change\]" "blue" ".main.menuaddchoice"
+        ::board::setInfoAlert .main.board [lindex $::guessedAddMove 0] "\[click to change\]" "DodgerBlue3" ".main.menuaddchoice"
         unset ::guessedAddMove
         return
     }
@@ -190,7 +190,7 @@ proc updateStatusBar {} {
         foreach thisMove $moveEntry(List) {
             append msg "$thisMove "
         }
-        ::board::setInfoAlert .main.board "Enter Move:" "$msg" "blue" ""
+        ::board::setInfoAlert .main.board "Enter Move:" "$msg" "DodgerBlue3" ""
         return
     }
 
@@ -198,7 +198,8 @@ proc updateStatusBar {} {
     regsub -all {\[%.*\]} $comment {} comment
 
     if {$comment != ""} {
-        ::board::setInfoAlert .main.board "Comment:" "$comment" "green" "makeCommentWin"
+        ::board::setInfoAlert .main.board "[tr Comment]" "$comment" "green" "::makeCommentWin"
+        ::board::addInfo .main.board [sc_game info ECO]
         return
     }
     
@@ -216,31 +217,35 @@ proc updateStatusBar {} {
         incr number -1
         append number ".."
       }
-      append statusBar "Last move"
+      append statusBar [tr LastMove]
       if {[sc_var level] != 0} { append statusBar " (var)" }
-      append statusBar ": $number.$move\n"
+      append statusBar ": $number.$move"
+      ::board::setInfo .main.board "$statusBar"
+    } else {
+      set msg "[sc_game info date] - [sc_game info event]"
+      ::board::setInfoAlert .main.board "[tr Event]:" $msg "DodgerBlue3" "::crosstab::Open"
     }
-
-    set result [sc_game info result]
-    if {$result == "=-="} { set result "\u00BD-\u00BD" }
-    append statusBar "[sc_game info date] - [sc_game info event] ($result)"
-    ::board::setInfo .main.board "$statusBar"
+    ::board::addInfo .main.board [sc_game info ECO]
 }
 
 proc updateMainToolbar {} {
   if {[sc_pos isAt start]} {
+    ::board::setButtonCmd .main.board leavevar ""
     ::board::setButtonCmd .main.board back ""
     catch { unset ::gameInfoBar(tb_BD_Start) }
   } else {
+    ::board::setButtonCmd .main.board leavevar "::move::ExitVarOrStart"
     ::board::setButtonCmd .main.board back "::move::Back"
     set ::gameInfoBar(tb_BD_Start) "::move::Start"
   }
   if {[sc_pos isAt end] || [sc_pos isAt vend]} {
     ::board::setButtonCmd .main.board forward ""
+    ::board::setButtonCmd .main.board endvar ""
     catch { unset ::gameInfoBar(tb_BD_End) }
     catch { unset ::gameInfoBar(tb_BD_Autoplay) }
   } else {
     ::board::setButtonCmd .main.board forward "::move::Forward"
+    ::board::setButtonCmd .main.board endvar "::move::EndVar"
     set ::gameInfoBar(tb_BD_End) "::move::End"
     set ::gameInfoBar(tb_BD_Autoplay) "startAutoplay"
   }
@@ -250,38 +255,172 @@ proc updateMainToolbar {} {
     catch { unset ::gameInfoBar(tb_BD_VarPromote) }
     catch { unset ::gameInfoBar(tb_BD_VarLeave) }
     catch { unset ::gameInfoBar(tb_BD_BackToMainline) }
+    ::board::setButtonImg .main.board leavevar tb_BD_BackStart
   } else {
-    set ::gameInfoBar(tb_BD_VarDelete) { ::pgn::deleteVar [sc_var number] }
+    set ::gameInfoBar(tb_BD_VarDelete) { ::pgn::deleteVar }
     set ::gameInfoBar(tb_BD_VarPromote) { ::pgn::mainVar }
     set ::gameInfoBar(tb_BD_VarLeave) { ::move::ExitVar }
     set ::gameInfoBar(tb_BD_BackToMainline) { while {[sc_var level] != 0} {::move::ExitVar} }
-  }
-
-  set canChange [expr {![sc_base isReadOnly $::curr_db]}]
-  if {$canChange && [sc_game number] != 0} {
-    set ::gameInfoBar(tb_BD_Save) "gameReplace"
-  } else {
-    catch { unset ::gameInfoBar(tb_BD_Save) }
-  }
-  set ::gameInfoBar(tb_BD_SaveAs) "gameSave 0"
-
-  if {[sc_game undo size] > 0} {
-    set ::gameInfoBar(tb_BD_Undo) "undoFeature undo"
-    set ::gameInfoBar(tb_BD_Revert) "undoFeature undoAll"
-  } else {
-    catch { unset ::gameInfoBar(tb_BD_Undo) }
-    catch { unset ::gameInfoBar(tb_BD_Revert) }
-  }
-  if {[sc_game redo size] > 0} {
-    set ::gameInfoBar(tb_BD_Redo) "undoFeature redo"
-  } else {
-    catch { unset ::gameInfoBar(tb_BD_Redo) }
+    ::board::setButtonImg .main.board leavevar tb_BD_exitvar
   }
 
   set ::gameInfoBar(tb_BD_SetupBoard) "setupBoard"
 }
 
+# Update the "tree" filter of databases that have a view (gamelist or tree windows)
+# which depends on the current position.
+proc ::updateTreeFilter {{base ""}} {
+    if { [info exists ::treeFilterUpdating_] } {
+        set ::treeFilterUpdating_ {}
+        ::progressBarCancel
+        return
+    }
 
+    set ::treeFilterUpdating_ {}
+    set ::treeFilterUpdatingBases_ [::windows::gamelist::listTreeBases $base]
+    lappend ::treeFilterUpdatingBases_ {*}[::tree::listTreeBases $base]
+    foreach elem [lsort -unique -index 0 $::treeFilterUpdatingBases_] {
+        lassign $elem base filter progressbar
+
+        set ::treeFilterUpdating_ [lsearch -all -inline -exact -index 0 $::treeFilterUpdatingBases_ $base]
+        if { [llength $::treeFilterUpdating_] == 0 } {
+            # canceled while updating another base
+            continue
+        }
+
+        #TODO: don't do a full database search if there is only one filter.
+        #set n_filters [llength [lsort -unique -index 1 $::treeFilterUpdating_]]
+
+        eval progressBarSet $progressbar
+        set err [catch {sc_filter search $base "tree" board}]
+        if {$err && $::errorCode != $::ERROR::UserCancel} {
+            ERROR::MessageBox
+        }
+        if { [llength $::treeFilterUpdating_] == 0 } {
+            # Restart if the position changed before the update finished.
+            after idle {
+                unset ::treeFilterUpdating_
+                ::updateTreeFilter
+            }
+            return
+        }
+        ::notify::DatabaseModified $base tree
+    }
+    unset ::treeFilterUpdating_
+}
+
+proc ::cancelUpdateTreeFilter {progressbar} {
+    if {![info exists ::treeFilterUpdating_]} {
+        return
+    }
+    set idx [lsearch -exact -index 2 $::treeFilterUpdating_ $progressbar]
+    if {$idx != -1} {
+        if {[llength $::treeFilterUpdating_] == 1} {
+            ::progressBarCancel
+        } else {
+            set ::treeFilterUpdating_ [lreplace $::treeFilterUpdating_ $idx $idx]
+        }
+    } else {
+        set idx [lsearch -exact -index 2 $::treeFilterUpdatingBases_ $progressbar]
+        if {$idx != -1} {
+            set ::treeFilterUpdatingBases_ [lreplace $::treeFilterUpdatingBases_ $idx $idx]
+        }
+    }
+}
+
+# Update the main eval bar to reflect the engine's evaluation.
+# If there is only one engine running, il will show that evaluation in the bar.
+# If there are multiple engines running, the eval bar will remain associated
+# with the first engine that send its evaluation until it stops running.
+proc ::updateMainEvalBar {engineID bestmove evaluation} {
+    if {! $::showEvalBar(.main) } { return }
+
+    if {![info exists ::mainEvalBarEngineID_]} {
+        set ::mainEvalBarEngineID_ $engineID
+    }
+    if {$engineID == $::mainEvalBarEngineID_} {
+        ::board::updateEvalBar .main.board $evaluation
+        if {$::showMainEvalBarArrow} {
+            set bestmove [string map {"\u2654" K "\u2655" Q "\u2656" R "\u2657" B "\u2658" N} [::untrans $bestmove]]
+            catch { sc_game SANtoUCI $bestmove } moveUCI
+            ::board::mark::DrawBestMove .main.board $moveUCI
+        }
+        if {$bestmove eq "" && $evaluation eq ""} {
+            unset ::mainEvalBarEngineID_
+        }
+    }
+}
+
+# Create a menu containing:
+# - the engine currently associated with the evaluation bar
+# - engines open in enginewin windows
+# - the configured engines that can be started
+# - a command to add a new local engine
+# - a command to show/hide the best move arrow
+# - the command to hide the evaluation bar
+# Behavior:
+# - if the currently associated engine is selected, stop it
+# - if a different engine is selected, stop the current engine and start the new one.
+# Returns the name of the created menu.
+proc ::createMainEvalBarMenu {w} {
+    if {[winfo exists $w.evalbar_menu]} {
+        $w.evalbar_menu delete 0 end
+    } else {
+        ttk_menu $w.evalbar_menu
+    }
+
+    set engines {}
+    set enginewins [enginewin::listEngines]
+    foreach {elem} $enginewins {
+        lassign $elem engID engName running
+        if {!$running} {
+            lappend engines [list $engID $engName]
+            continue
+        }
+        if {[info exists ::mainEvalBarEngineID_] && $engID == $::mainEvalBarEngineID_} {
+            set ::mainEvalBarCheckbutton 1
+            $w.evalbar_menu add checkbutton -variable ::mainEvalBarCheckbutton -label $engName -command {
+                ::enginewin::stop $::mainEvalBarEngineID_
+                unset ::mainEvalBarEngineID_
+            }
+        } else {
+            $w.evalbar_menu add command -label $engName \
+                -command "set ::mainEvalBarEngineID_ \[::enginewin::start $engID\]"
+        }
+    }
+    foreach {engName} [enginecfg::names] {
+        if {[lsearch -exact -index 1 $enginewins $engName] == -1} {
+            lappend engines [list "" $engName]
+        }
+    }
+    $w.evalbar_menu add separator
+    foreach {elem} $engines {
+        lassign $elem engID engName
+        $w.evalbar_menu add command -label $engName -command [list apply {{engID engName} {
+            if {[info exists ::mainEvalBarEngineID_]} {
+                ::enginewin::stop $::mainEvalBarEngineID_
+            }
+            set ::mainEvalBarEngineID_ [::enginewin::start $engID $engName]
+        }} $engID $engName]
+    }
+
+    #TODO: improve and translate label
+    $w.evalbar_menu add command -label [tr NewLocalEngine] -command {
+        lassign [::enginecfg::dlgNewLocal] newEngName
+        if {$newEngName ne ""} {
+            ::enginewin::start "" $newEngName
+        }
+    }
+    $w.evalbar_menu add separator
+    $w.evalbar_menu add checkbutton -variable ::showMainEvalBarArrow -label [tr BestMoveArrow] -command {
+        ::board::mark::DrawBestMove ".main.board" ""
+    }
+    $w.evalbar_menu add separator
+    $w.evalbar_menu add command -label [tr Hide] \
+        -command { {*}$::gameInfoBar(tb_BD_Scorebar) }
+
+    return $w.evalbar_menu
+}
 
 proc toggleRotateBoard {} {
     ::board::flip .main.board
@@ -351,15 +490,19 @@ proc showVars {} {
     setWinLocation $w
     set h [expr $numVars + 1]
     if { $h> 19} { set h 19 }
-    listbox $w.lbVar -selectmode browse -height $h -width 20
-    pack $w.lbVar -expand yes -fill both -side top
+    ttk::treeview $w.lbVar -columns {0} -show {} -selectmode browse
+    $w.lbVar configure -height $h
+    $w.lbVar column 0 -width 250
+    pack $w.lbVar -side left -fill both -expand 1
     
     #insert main line
     set move [sc_game info nextMove]
+    set j 0
     if {$move == ""} {
         set move "($::tr(empty))"
     } else  {
-        $w.lbVar insert end "0: [getNextMoves 5]"
+        $w.lbVar insert {} end -id $j -values [list "0: [getNextMoves 5]"]
+        incr j
     }
     
     # insert variations
@@ -373,7 +516,8 @@ proc showVars {} {
             sc_var exit
         }
         set str "[expr {$i + 1}]: $move"
-        $w.lbVar insert end $str
+        $w.lbVar insert {} end -id $j -values [list "$str"]
+        incr j
     }
     $w.lbVar selection set 0
     # bindings
@@ -381,7 +525,7 @@ proc showVars {} {
     bind .variations <Return> {catch { event generate .variations <Right> } }
     bind .variations <ButtonRelease-1> {catch { event generate .variations <Right> } }
     bind .variations <Right> {
-        set cur [.variations.lbVar curselection]
+        set cur [.variations.lbVar selection]
         destroy .variations
         if {$cur == 0} {
             sc_move forward; updateBoard -animate
@@ -389,13 +533,13 @@ proc showVars {} {
             sc_var moveInto [expr $cur - 1]; updateBoard -animate
         }
     }
-    bind .variations <Up> { set cur [.variations.lbVar curselection] ; .variations.lbVar selection clear $cur
+    bind .variations <Up> { set cur [.variations.lbVar selection]
         set sel [expr $cur - 1]
         if {$sel < 0} { set sel 0 }
         .variations.lbVar selection set $sel ; .variations.lbVar see $sel}
-    bind .variations <Down> { set cur [.variations.lbVar curselection] ; .variations.lbVar selection clear $cur
+    bind .variations <Down> { set cur [.variations.lbVar selection]
+        if {[.variations.lbVar next $cur] == {} } { return }
         set sel [expr $cur + 1]
-        if {$sel >= [.variations.lbVar index end]} { set sel end }
         .variations.lbVar selection set $sel ; .variations.lbVar see $sel}
     bind .variations <Left> { destroy .variations }
     bind .variations <Escape> { catch { event generate .variations <Destroy> } }
@@ -412,9 +556,7 @@ proc showVars {} {
     }
     
     # Needed or the main window loses the focus
-    if { $::docking::USE_DOCKING } {
-        bind .variations <Destroy> { focus -force .main }
-    }
+    bind .variations <Destroy> { focus -force .main }
 
     catch { focus .variations }
     catch { grab $w }
@@ -706,9 +848,6 @@ proc confirmReplaceMove {} {
     if {[winfo exists $::reviewgame::window]} {
         return "var"
     }
-    if {! $::askToReplaceMoves} {
-        return "replace"
-    }
 
     option add *Dialog.msg.wrapLength 4i interactive
     catch {tk_dialog .dialog "Scid: $::tr(ReplaceMove)?" \
@@ -806,10 +945,6 @@ proc addMoveUCI {{moveUCI} {action ""} {animate "-animate"}} {
     }
 
     undoFeature save
-    if {[winfo exists .commentWin]} {
-        ::commenteditor::storeComment
-        .commentWin.cf.text delete 0.0 end
-    }
     if {($action == "mainline" || $action == "var") && ![sc_pos isAt vend]} {
         sc_var create
     }
@@ -824,10 +959,7 @@ proc addMoveUCI {{moveUCI} {action ""} {animate "-animate"}} {
         sc_move forward 1
     }
 
-    set ::sergame::lastPlayerMoveUci ""
-    if {[winfo exists ".serGameWin"]} {
-        set ::sergame::lastPlayerMoveUci "$moveUCI"
-    }
+    set ::sergame::lastPlayerMoveUci "$moveUCI"
 
     if {[winfo exists .fics]} {
         if { [::fics::playerCanMove] } {
@@ -836,6 +968,7 @@ proc addMoveUCI {{moveUCI} {action ""} {animate "-animate"}} {
                 ::fics::writechan "promote $promoletter"
             }
             ::fics::writechan [ string range [sc_game info previousMoveUCI] 0 3 ]
+            ::fics::storeTime
         }
     }
 
@@ -997,6 +1130,48 @@ proc backSquare {} {
     ::utils::sound::AnnounceBack
 }
 
+# addMarker:
+#   add/delete square markers and arrows to the current position
+#
+proc addMarker {w x y} {
+    set sq [::board::getSquare $w $x $y]
+    if {! [info exists ::markStartSq]} {
+        set ::markStartSq [::board::san $sq]
+        return
+    }
+
+    set from $::markStartSq
+    unset ::markStartSq
+    set to [::board::san $sq]
+    if {$from == "" || $to == ""} { return }
+
+    if {$from == $to } {
+        set cmd "$::markType,$to,$::markColor"
+        set cmd_erase "\[a-z\]*,$to,\[a-z\]*"
+    } else {
+        set cmd "arrow,$from,$to,$::markColor"
+        set cmd_erase "arrow,$from,$to,\[a-z\]*"
+    }
+    set oldComment [sc_pos getComment]
+    regsub -all " *\\\[%draw $cmd\\\]" $oldComment "" newComment
+    if {$newComment == $oldComment} {
+        regsub -all " *\\\[%draw $cmd_erase\\\]" $oldComment "" newComment
+        append newComment " \[%draw $cmd\]"
+    }
+
+    sc_pos setComment $newComment
+    ::notify::PosChanged -pgn
+}
+
+# addNag:
+#   add a Nag to the current position
+#
+proc addNag {nag} {
+    undoFeature save
+    sc_pos addNag "$nag"
+    ::notify::PosChanged -pgn
+}
+
 ################################################################################
 #
 ################################################################################
@@ -1025,8 +1200,6 @@ proc setPlayMode { callback } {
 # In docked mode, resize board automatically
 ################################################################################
 proc resizeMainBoard {} {
-  if { ! $::docking::USE_DOCKING } { return }
-
   if { $::autoResizeBoard } {
     update idletasks
     set availw [winfo width .fdockmain]
@@ -1049,24 +1222,36 @@ proc toggleGameInfo {} {
     grid forget .main.gameInfo
   }
   updateGameInfo
-  update idletasks
 }
 ################################################################################
 
 proc CreateMainBoard { {w} } {
+  createToplevel $w
   setTitle $w [ ::tr "Board" ]
-  keyboardShortcuts $w
+
+  CreateGameInfo
 
   ::board::new $w.board $::boardSize
-  ::board::showMarks $w.board 1
-  for {set i 0} {$i < $::boardCoords} {incr i} { ::board::coords $w.board }
+  ::board::showMarks $w.board $::gameInfo(showMarks)
+  ::board::coords $w.board $::boardCoords
+  ::board::bindEvalBar $w.board <ButtonRelease-1> "
+    tk_popup \[::createMainEvalBarMenu $w.board \] %X %Y
+  "
+  options.persistent ::showEvalBar($w) 1
+  options.persistent ::showMainEvalBarArrow 1
+  if {$::showEvalBar($w)} { ::board::toggleEvalBar $w.board }
   if {$::gameInfo(showMaterial)} { ::board::toggleMaterial $w.board }
 
   ::board::addNamesBar $w.board gamePlayers
   ::board::addInfoBar $w.board gameInfoBar
 
-  set ::gameInfoBar(tb_BD_Coords) "set ::boardCoords \[::board::coords $w.board\]"
   set ::gameInfoBar(tb_BD_Material) "set ::gameInfo(showMaterial) \[::board::toggleMaterial $w.board\]"
+  set ::gameInfoBar(tb_BD_Scorebar) [list apply {{w} {
+    set ::showEvalBar($w) [::board::toggleEvalBar $w.board]
+    unset -nocomplain ::mainEvalBarEngineID_
+    ::board::updateEvalBar .main.board ""
+    ::board::mark::DrawBestMove $w.board ""
+  }} $w]
 
   menu .main.menuaddchoice -bg white -font font_Regular
   .main.menuaddchoice add command -label " Undo" -image tb_BD_Undo -compound left \
@@ -1084,12 +1269,8 @@ proc CreateMainBoard { {w} } {
     ::board::bind $w.board $i <Enter> "enterSquare $i"
     ::board::bind $w.board $i <Leave> "leaveSquare $i"
     ::board::bind $w.board $i <ButtonPress-1> "pressSquare $i"
-    ::board::bind $w.board $i <Control-ButtonPress-1> "drawArrow $i green"
-    ::board::bind $w.board $i <Control-ButtonPress-$::MB2> "drawArrow $i yellow"
-    ::board::bind $w.board $i <Control-ButtonPress-$::MB3> "drawArrow $i red"
-    ::board::bind $w.board $i <Shift-ButtonPress-1> "addMarker $i green"
-    ::board::bind $w.board $i <Shift-ButtonPress-$::MB2> "addMarker $i yellow"
-    ::board::bind $w.board $i <Shift-ButtonPress-$::MB3> "addMarker $i red"
+    ::board::bind $w.board $i <Control-ButtonPress-1> "addMarker $w.board %X %Y"
+    ::board::bind $w.board $i <Control-ButtonRelease-1> "addMarker $w.board %X %Y"
     ::board::bind $w.board $i <B1-Motion> "::board::dragPiece $w.board %X %Y"
     ::board::bind $w.board $i <ButtonRelease-1> "releaseSquare $w.board %X %Y"
     ::board::bind $w.board $i <ButtonPress-$::MB3> backSquare
@@ -1120,17 +1301,11 @@ proc CreateMainBoard { {w} } {
 
   bindMouseWheel $w "main_mousewheelHandler"
 
-  if { $::docking::USE_DOCKING} {
-    ttk::frame $w.space
-    grid $w.space -row 4 -column 0 -columnspan 3 -sticky nsew
-    grid rowconfigure $w 3 -weight 0
-    grid rowconfigure $w 4 -weight 1
-  } else {
-    grid rowconfigure $w 3 -weight 1
-    wm resizable $w 0 1
-    wm withdraw .
-    bind $w <Destroy> { destroy . }
-  }
+  ttk::frame $w.space
+  grid $w.space -row 4 -column 0 -columnspan 3 -sticky nsew
+  grid rowconfigure $w 3 -weight 0
+  grid rowconfigure $w 4 -weight 1
+
   grid columnconfigure $w 0 -weight 1
   grid $w.board -row 2 -column 0 -sticky we ;# -padx 5 -pady 5
 
@@ -1143,89 +1318,89 @@ proc CreateMainBoard { {w} } {
 proc CreateGameInfo {} {
   # .gameInfo is the game information widget:
   #
-  autoscrollframe .main.gameInfo text .main.gameInfo.text
-  .main.gameInfo.text configure -width 20 -height 6 -fg black -bg white -wrap none -state disabled -cursor top_left_arrow -setgrid 1
+  autoscrollText y .main.gameInfo .main.gameInfo.text Treeview
+  .main.gameInfo.text configure -width 20 -height 6 -wrap none -state disabled -cursor top_left_arrow -setgrid 1
   ::htext::init .main.gameInfo.text
-  
+
   # Set up player photos:
-  label .main.photoW -background white -image photoW -anchor ne
-  label .main.photoB -background white -image photoB -anchor ne
+  ttk::label .main.photoW -image photoW -anchor ne
+  ttk::label .main.photoB -image photoB -anchor ne
   bind .main.photoW <ButtonPress-1> "togglePhotosSize"
   bind .main.photoB <ButtonPress-1> "togglePhotosSize"
-  
+
   # Right-mouse button menu for gameInfo frame:
   menu .main.gameInfo.menu -tearoff 0
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoHideNext \
           -variable gameInfo(hideNextMove) -offvalue 0 -onvalue 1 -command updateBoard
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoMaterial -variable gameInfo(showMaterial) -offvalue 0 -onvalue 1 \
           -command { toggleShowMaterial }
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoFEN \
           -variable gameInfo(showFEN) -offvalue 0 -onvalue 1 -command updateBoard
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoMarks \
-          -variable gameInfo(showMarks) -offvalue 0 -onvalue 1 -command updateBoard
-  
+          -variable gameInfo(showMarks) -offvalue 0 -onvalue 1 -command {
+              ::board::showMarks .main.board $gameInfo(showMarks)
+              updateBoard }
+
   .main.gameInfo.menu add checkbutton -label GInfoWrap \
           -variable gameInfo(wrap) -offvalue 0 -onvalue 1 -command updateBoard
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoFullComment \
           -variable gameInfo(fullComment) -offvalue 0 -onvalue 1 -command updateBoard
-  
+
   .main.gameInfo.menu add checkbutton -label GInfoPhotos \
           -variable gameInfo(photos) -offvalue 0 -onvalue 1 \
           -command {togglePhotosSize 0}
-  
+
   .main.gameInfo.menu add separator
-  
+
   .main.gameInfo.menu add radiobutton -label GInfoTBNothing \
           -variable gameInfo(showTB) -value 0 -command updateBoard
-  
+
   .main.gameInfo.menu add radiobutton -label GInfoTBResult \
           -variable gameInfo(showTB) -value 1 -command updateBoard
-  
+
   .main.gameInfo.menu add radiobutton -label GInfoTBAll \
           -variable gameInfo(showTB) -value 2 -command updateBoard
-  
+
   .main.gameInfo.menu add separator
-  
+
   .main.gameInfo.menu add command -label GInfoDelete -command {
       sc_base gameflag [sc_base current] [sc_game number] invert del
       ::notify::DatabaseModified [sc_base current]
   }
-  
-  menu .main.gameInfo.menu.mark
-  .main.gameInfo.menu add cascade -label GInfoMark -menu .main.gameInfo.menu.mark
 
   bind .main.gameInfo.text <ButtonPress-$::MB3> {
-    .main.gameInfo.menu.mark delete 0 end
-    set ::curr_db [sc_base current]
-    set ::curr_game [sc_game number]
-    set i 0
-    foreach flag $::maintFlaglist {
-      if {$i < 12} {
-        set tmp "$::tr($::maintFlags($flag)) ($flag)"
-      } else  {
-        set tmp [sc_base extra $::curr_db flag$flag]
-        if {$tmp == "" } { set tmp $::maintFlags($flag) }
-      }
-      incr i
-      .main.gameInfo.menu.mark add command -label "$tmp" \
-      -command "sc_base gameflag $::curr_db $::curr_game invert $flag; ::notify::DatabaseModified $::curr_db"
-    }
     tk_popup .main.gameInfo.menu %X %Y
   }
 
-  storeMenuLabels .main.gameInfo.menu
+  translateMenuLabels .main.gameInfo.menu
+}
+
+# Set toolbar help status messages:
+proc setToolbarTooltips { tb } {
+    foreach {b m} {
+	newdb FileNew open FileOpen finder FileFinder
+	save GameReplace closedb FileClose bkm FileBookmarks
+	gprev GamePrev gnext GameNext
+	newgame GameNew copy EditCopy paste EditPaste
+	boardsearch SearchCurrent
+	headersearch SearchHeader materialsearch SearchMaterial
+	switcher WindowsSwitcher glist WindowsGList pgn WindowsPGN tmt WindowsTmt
+	maint WindowsMaint eco WindowsECO tree WindowsTree crosstab ToolsCross
+	engine ToolsAnalysis } {
+	::utils::tooltip::Set $tb.$b $::helpMessage($::language,$m)
+    }
 }
 
 proc InitToolbar {{tb}} {
 	ttk::frame $tb -relief raised -border 1
-	button $tb.new -image tb_new -command ::file::New
-	button .main.tb.open -image tb_open -command ::file::Open
-	button .main.tb.save -image tb_save -command {
+	ttk::button $tb.newdb -image tb_newdb -command ::file::New -padding {2 0}
+	ttk::button .main.tb.open -image tb_open -command ::file::Open -padding {2 0}
+	ttk::button .main.tb.save -image tb_save  -padding {2 0} -command {
 	  if {[sc_game number] != 0} {
 		#busyCursor .
 		gameReplace
@@ -1235,128 +1410,96 @@ proc InitToolbar {{tb}} {
 		gameAdd
 	  }
 	}
-	button .main.tb.close -image tb_close -command ::file::Close
-	button .main.tb.finder -image tb_finder -command ::file::finder::Open
-	menubutton .main.tb.bkm -image tb_bkm -menu .main.tb.bkm.menu
+	ttk::button .main.tb.closedb -image tb_closedb -command ::file::Close -padding {2 0}
+	ttk::button .main.tb.finder -image tb_finder -command ::file::finder::Open -padding {2 0}
+	ttk::menubutton .main.tb.bkm -image tb_bkm -menu .main.tb.bkm.menu -padding {2 0}
 	menu .main.tb.bkm.menu
-	bind .main.tb.bkm <ButtonPress-1> "+.main.tb.bkm configure -relief flat"
+	::bookmarks::RefreshMenu .main.tb.bkm.menu
 
-	ttk::frame .main.tb.space1 -width 12
-	button .main.tb.cut -image tb_cut -command ::game::Clear
-	button .main.tb.copy -image tb_copy -command ::gameAddToClipbase
-	button .main.tb.paste -image tb_paste \
-		-command {catch {sc_clipbase paste}; updateBoard -pgn}
-	ttk::frame .main.tb.space2 -width 12
-	button .main.tb.gprev -image tb_gprev -command {::game::LoadNextPrev previous}
-	button .main.tb.gnext -image tb_gnext -command {::game::LoadNextPrev next}
-	ttk::frame .main.tb.space3 -width 12
-	button .main.tb.rfilter -image tb_rfilter -command ::search::filter::reset
-	button .main.tb.bsearch -image tb_bsearch -command ::search::board
-	button .main.tb.hsearch -image tb_hsearch -command ::search::header
-	button .main.tb.msearch -image tb_msearch -command ::search::material
-	ttk::frame .main.tb.space4 -width 12
-	button .main.tb.switcher -image tb_switcher -command ::windows::switcher::Open
-	button .main.tb.glist -image tb_glist -command ::windows::gamelist::Open
-	button .main.tb.pgn -image tb_pgn -command ::pgn::OpenClose
-	button .main.tb.tmt -image tb_tmt -command ::tourney::toggle
-	button .main.tb.maint -image tb_maint -command ::maint::OpenClose
-	button .main.tb.eco -image tb_eco -command ::windows::eco::OpenClose
-	button .main.tb.tree -image tb_tree -command ::tree::make
-	button .main.tb.crosst -image tb_crosst -command toggleCrosstabWin
-	button .main.tb.engine -image tb_engine -command makeAnalysisWin
-	button .main.tb.help -image tb_help -command {helpWindow Index}
+	ttk::frame .main.tb.space1 -width 4
+	ttk::button .main.tb.newgame -image tb_newgame -command ::game::Clear -padding {2 0}
+	ttk::button .main.tb.copy -image tb_copy -command ::gameAddToClipbase -padding {2 0}
+	ttk::button .main.tb.paste -image tb_paste \
+		-command {catch {sc_clipbase paste}; updateBoard -pgn} -padding {2 0}
+	ttk::frame .main.tb.space2 -width 4
+	ttk::button .main.tb.gprev -image tb_gprev -command {::game::LoadNextPrev previous} -padding {2 0}
+	ttk::button .main.tb.gnext -image tb_gnext -command {::game::LoadNextPrev next} -padding {2 0}
+	ttk::frame .main.tb.space3 -width 4
+	ttk::button .main.tb.boardsearch -image tb_boardsearch -command ::search::board -padding {2 0}
+	ttk::button .main.tb.headersearch -image tb_headersearch -command ::search::header -padding {2 0}
+	ttk::button .main.tb.materialsearch -image tb_materialsearch -command ::search::material -padding {2 0}
+	ttk::frame .main.tb.space4 -width 4
+	ttk::button .main.tb.switcher -image tb_switcher -command ::windows::switcher::Open -padding {2 0}
+	ttk::button .main.tb.glist -image tb_glist -command ::windows::gamelist::Open -padding {2 0}
+	ttk::button .main.tb.pgn -image tb_pgn -command ::pgn::OpenClose -padding {2 0}
+	ttk::button .main.tb.tmt -image tb_tmt -command ::tourney::toggle -padding {2 0}
+	ttk::button .main.tb.maint -image tb_maint -command ::maint::OpenClose -padding {2 0}
+	ttk::button .main.tb.eco -image tb_eco -command ::windows::eco::OpenClose -padding {2 0}
+	ttk::button .main.tb.tree -image tb_tree -command ::tree::make -padding {2 0}
+	ttk::button .main.tb.crosstab -image tb_crosstab -command ::crosstab::OpenClose -padding {2 0}
+	ttk::button .main.tb.engine -image tb_engine -command makeAnalysisWin -padding {2 0}
+	ttk::button .main.tb.help -image tb_help -command {helpWindow Index} -padding {2 0}
 
-	foreach i {new open save close finder bkm cut copy paste gprev gnext \
-		  rfilter bsearch hsearch msearch \
-		  switcher glist pgn tmt maint eco tree crosst engine help} {
-	  .main.tb.$i configure -takefocus 0 -relief flat -border 1 -anchor n -highlightthickness 0
-	  bind .main.tb.$i <Any-Enter> "+.main.tb.$i configure -relief groove"
-	  bind .main.tb.$i <Any-Leave> "+.main.tb.$i configure -relief flat; break"
+	foreach i {newdb open save closedb finder bkm newgame copy paste gprev gnext \
+		  boardsearch headersearch materialsearch \
+		  switcher glist pgn tmt maint eco tree crosstab engine help} {
+	  .main.tb.$i configure -takefocus 0
 	}
 
-	# Set toolbar help status messages:
-	foreach {b m} {
-	  new FileNew open FileOpen finder FileFinder
-	  save GameReplace close FileClose bkm FileBookmarks
-	  gprev GamePrev gnext GameNext
-	  cut GameNew copy EditCopy paste EditPaste
-	  bsearch SearchCurrent
-	  hsearch SearchHeader msearch SearchMaterial
-	  switcher WindowsSwitcher glist WindowsGList pgn WindowsPGN tmt WindowsTmt
-	  maint WindowsMaint eco WindowsECO tree WindowsTree crosst ToolsCross
-	  engine ToolsAnalysis
-	} {
-	  set helpMessage(.main.tb.$b) $m
-	  ::utils::tooltip::Set $tb.$b $m
-	}
+    setToolbarTooltips $tb
 	redrawToolbar
 }
 
-proc configToolbar {} {
-  set w .tbconfig
-  toplevel $w
-  wm title $w "Scid: [tr OptionsToolbar]"
+proc toggleToolbarButton { b i } {
+    if { $::toolbar_temp($i) } {
+	set ::toolbar_temp($i) 0
+	$b.$i state !pressed
+    } else {
+	set ::toolbar_temp($i) 1
+	$b.$i state pressed
+    }
+    array set ::toolbar_state [array get ::toolbar_temp]
+    redrawToolbar
+}
 
-  array set ::toolbar_temp [array get ::toolbar]
-  pack [ttk::frame $w.f1] -side top -fill x
-  foreach i {new open save close finder bkm} {
-    checkbutton $w.f1.$i -indicatoron 1 -image tb_$i -height 20 -width 22 \
-        -variable toolbar_temp($i) -relief solid -borderwidth 1
-    pack $w.f1.$i -side left -ipadx 2 -ipady 2
-  }
-  pack [ttk::frame $w.f2] -side top -fill x
-  foreach i {gprev gnext} {
-    checkbutton $w.f2.$i -indicatoron 1 -image tb_$i -height 20 -width 22 \
-        -variable toolbar_temp($i) -relief solid -borderwidth 1
-    pack $w.f2.$i -side left -ipadx 1 -ipady 1
-  }
-  pack [ttk::frame $w.f3] -side top -fill x
-  foreach i {cut copy paste} {
-    checkbutton $w.f3.$i -indicatoron 1 -image tb_$i -height 20 -width 22 \
-        -variable toolbar_temp($i) -relief solid -borderwidth 1
-    pack $w.f3.$i -side left -ipadx 1 -ipady 1
-  }
-  pack [ttk::frame $w.f4] -side top -fill x
-  foreach i {bsearch hsearch msearch} {
-    checkbutton $w.f4.$i -indicatoron 1 -image tb_$i -height 20 -width 22 \
-        -variable toolbar_temp($i) -relief solid -borderwidth 1
-    pack $w.f4.$i -side left -ipadx 1 -ipady 1
-  }
-  pack [ttk::frame $w.f5] -side top -fill x
-  foreach i {switcher glist pgn tmt maint eco tree crosst engine} {
-    checkbutton $w.f5.$i -indicatoron 1 -image tb_$i -height 20 -width 22 \
-        -variable toolbar_temp($i) -relief solid -borderwidth 1
-    pack $w.f5.$i -side left -ipadx 1 -ipady 1
-  }
+proc toggleAllToolbarButtons { b state } {
+    foreach i [array names ::toolbar_temp] {
+	set ::toolbar_temp($i) $state
+	if { $state } { $b.$i state pressed } else { $b.$i state !pressed }
+    }
+    array set ::toolbar_state [array get ::toolbar_temp]
+    redrawToolbar
+}
 
+proc ConfigToolbar { w } {
+  array set ::toolbar_temp [array get ::toolbar_state]
+  pack [ttk::frame $w.f] -side top -fill x
+  set col 0
+  set row 0
+  foreach i {newdb open closedb finder save bkm row gprev gnext row newgame copy paste row boardsearch headersearch \
+		 materialsearch row switcher glist pgn tmt maint eco tree crosstab engine } {
+      if { $i eq "row" } { incr row; set col 0 } else {
+	  ttk::button $w.f.$i -image tb_$i -command "toggleToolbarButton $w.f $i"
+	  if { $::toolbar_temp($i) } { $w.f.$i state pressed }
+	  grid $w.f.$i -row $row -column $col -sticky news -padx 4 -pady "0 8"
+	  incr col
+      }
+  }
+  setToolbarTooltips $w.f
   addHorizontalRule $w
   pack [ttk::frame $w.b] -side bottom -fill x
-  button $w.on -text "+ [::utils::string::Capital $::tr(all)]" -command {
-    foreach i [array names toolbar_temp] { set toolbar_temp($i) 1 }
-  }
-  button $w.off -text "- [::utils::string::Capital $::tr(all)]" -command {
-    foreach i [array names toolbar_temp] { set toolbar_temp($i) 0 }
-  }
-  ttk::button $w.ok -text "OK" -command {
-    array set toolbar [array get toolbar_temp]
-    catch {grab release .tbconfig}
-    destroy .tbconfig
-    redrawToolbar
-  }
-  ttk::button $w.cancel -text $::tr(Cancel) \
-      -command "catch {grab release $w}; destroy $w"
-  pack $w.cancel $w.ok -side right -padx 2
-  pack $w.on $w.off -side left -padx 2
-  catch {grab $w}
+  ttk::button $w.on -text "+ [::utils::string::Capital $::tr(all)]" -command "toggleAllToolbarButtons $w.f 1"
+  ttk::button $w.off -text "- [::utils::string::Capital $::tr(all)]" -command "toggleAllToolbarButtons $w.f 0"
+
+  pack $w.on $w.off -side left -padx 2 -pady "5 0"
 }
 
 proc redrawToolbar {} {
-  global toolbar
   foreach i [winfo children .main.tb] { pack forget $i }
   set seenAny 0
   set seen 0
-  foreach i {new open save close finder bkm} {
-    if {$toolbar($i)} {
+  foreach i {newdb open closedb finder save bkm} {
+    if {$::toolbar_state($i)} {
       set seen 1; set seenAny 1
       pack .main.tb.$i -side left -pady 1 -padx 0 -ipadx 0 -pady 0 -ipady 0
     }
@@ -1364,31 +1507,31 @@ proc redrawToolbar {} {
   if {$seen} { pack .main.tb.space1 -side left }
   set seen 0
   foreach i {gprev gnext} {
-    if {$toolbar($i)} {
+    if {$::toolbar_state($i)} {
       set seen 1; set seenAny 1
       pack .main.tb.$i -side left -pady 1 -padx 0 -ipadx 0 -pady 0 -ipady 0
     }
   }
   if {$seen} { pack .main.tb.space2 -side left }
   set seen 0
-  foreach i {cut copy paste} {
-    if {$toolbar($i)} {
+  foreach i {newgame copy paste} {
+    if {$::toolbar_state($i)} {
       set seen 1; set seenAny 1
       pack .main.tb.$i -side left -pady 1 -padx 0 -ipadx 0 -pady 0 -ipady 0
     }
   }
   if {$seen} { pack .main.tb.space3 -side left }
   set seen 0
-  foreach i {bsearch hsearch msearch} {
-    if {$toolbar($i)} {
+  foreach i {boardsearch headersearch materialsearch} {
+    if {$::toolbar_state($i)} {
       set seen 1; set seenAny 1
       pack .main.tb.$i -side left -pady 1 -padx 0 -ipadx 0 -pady 0 -ipady 0
     }
   }
   if {$seen} { pack .main.tb.space4 -side left }
   set seen 0
-  foreach i {switcher glist pgn tmt maint eco tree crosst engine} {
-    if {$toolbar($i)} {
+  foreach i {switcher glist pgn tmt maint eco tree crosstab engine} {
+    if {$::toolbar_state($i)} {
       set seen 1; set seenAny 1
       pack .main.tb.$i -side left -pady 1 -padx 0 -ipadx 0 -pady 0 -ipady 0
     }
