@@ -6,8 +6,6 @@
 ############################################################
 ### Main window menus:
 
-option add *Menu*TearOff 0
-
 menu .menu
 
 ## Mac Application menu has to be before any call to configure.
@@ -53,9 +51,14 @@ $m add command -label FileExit -accelerator "Ctrl+Q" -command ::file::Exit
 
 ### Database menu:
 set m .menu.db
-menu $m
+menu $m -postcommand "updateMenuStates $m"
 .menu add cascade -label Database -menu $m
 $m add command -label FileClose -acc "Ctrl+W" -command ::file::Close
+$m add checkbutton -label LoadatStartup -variable ::autoLoadBases_currdb -command {
+  if {[::file::autoLoadBases.remove $::curr_db] == -1} {
+    ::file::autoLoadBases.add $::curr_db
+  }
+}
 $m add separator
 menu $m.exportfilter
   $m.exportfilter add command -label ToolsExpFilterPGN \
@@ -76,9 +79,12 @@ menu $m.utils
   $m.utils add command -label FileMaintCompact -command compactDB
   $m.utils add command -label FileMaintClass -command classifyAllGames
   $m.utils add checkbutton -label FileMaintNameEditor -command nameEditor -variable nameEditorWin -accelerator "Ctrl+Shift+N"
+  $m.utils add command -label StripTags -command stripTags
   $m.utils add separator
   $m.utils add command -label FileMaintDelete -state disabled -command markTwins
   $m.utils add command -label FileMaintTwin -command updateTwinChecker
+  $m.utils add separator
+  $m.utils add command -label Cleaner -command cleanerWin
 $m add cascade -label FileMaint -menu $m.utils
 menu $m.spell
   $m.spell add command -label FileMaintNamePlayer -command {openSpellCheckWin Player}
@@ -208,13 +214,14 @@ $m add cascade -label CorrespondenceChess -menu $m.correspondence
 set m .menu.windows
 menu $m
 .menu add cascade -label Windows -menu $m
-$m add checkbutton -label WindowsComment -var commentWin -command makeCommentWin -accelerator "Ctrl+E"
+$m add checkbutton -label WindowsComment -var ::windows::commenteditor::isOpen -command "::makeCommentWin toggle" -accelerator "Ctrl+E"
 $m add checkbutton -label WindowsPGN -variable pgnWin -command ::pgn::OpenClose  -accelerator "Ctrl+P"
 $m add checkbutton -label OptionsWindowsShowGameInfo -variable showGameInfo -command ::toggleGameInfo
 $m add separator
 $m add command -label WindowsGList -command ::windows::gamelist::Open  -accelerator "Ctrl+L"
+$m add command -label "Engine" -command ::enginewin::Open
 $m add checkbutton -label WindowsSwitcher -variable baseWin -accelerator "Ctrl+D" -command ::windows::switcher::Open
-$m add command -label ToolsCross -accelerator "Ctrl+Shift+X" -command crosstabWin
+$m add command -label ToolsCross -accelerator "Ctrl+Shift+X" -command ::crosstab::Open
 $m add checkbutton -label WindowsECO -accelerator "Ctrl+Y" -variable ::windows::eco::isOpen -command {::windows::eco::OpenClose}
 $m add checkbutton -label WindowsStats -variable ::windows::stats::isOpen -accelerator "Ctrl+I" -command ::windows::stats::Open
 $m add checkbutton -label WindowsTree -variable treeWin -command ::tree::make -accelerator "Ctrl+T"
@@ -274,123 +281,28 @@ menu $m.language
           -command setLanguage
   }
 $m add cascade -label OptionsLanguage -menu $m.language
-menu $m.board
-  menu $m.board.bdsize
-  $m.board add cascade -label OptionsBoardSize -menu $m.board.bdsize
-  menu $m.board.pieces -tearoff 1
-  $m.board add cascade -label OptionsBoardPieces -menu $m.board.pieces
-  $m.board add command -label OptionsBoardColors -command chooseBoardColors
-$m add cascade -label OptionsBoard -menu $m.board
-menu $m.fonts
-  $m.fonts add command -label OptionsFontsRegular -command {chooseFont Regular}
-  $m.fonts add command -label OptionsFontsMenu    -command {chooseFont Menu}
-  $m.fonts add command -label OptionsFontsSmall   -command {chooseFont Small}
-  $m.fonts add command -label OptionsFontsTiny    -command {chooseFont Tiny}
-  $m.fonts add command -label OptionsFontsFixed   -command {chooseFont Fixed}
-$m add cascade -label OptionsFonts -menu $m.fonts
-menu $m.numbers
-  foreach numeric {".,"   ". "   "."   ",."   ", "   ","} \
-          underline {  0     1      2     4      5      6} {
-      set decimal [string index $numeric 0]
-      set thousands [string index $numeric 1]
-      $m.numbers add radiobutton -label "12${thousands}345${decimal}67" \
-          -underline $underline \
-          -variable locale(numeric) -value $numeric -command updateLocale
-  }
-$m add cascade -label OptionsNumbers -menu $m.numbers
-menu $m.theme
-  foreach i [ttk::style theme names] {
-      $m.theme add radiobutton -label "$i" -value $i -variable ::lookTheme \
-          -command {ttk::style theme use $::lookTheme}
-  }
+menu $m.theme -tearoff 1
+set ::menuThemeListIdx [expr [$m.theme index end] +1]
 $m add cascade -label OptionsTheme -menu $m.theme
-menu $m.windows
-  $m.windows add checkbutton -label OptionsWindowsIconify -variable autoIconify
-  $m.windows add checkbutton -label OptionsWindowsRaise -variable autoRaise
-  $m.windows add checkbutton -label OptionsWindowsDock -variable windowsDock
-  if {$::docking::USE_DOCKING} {
-    menu $m.windows.savelayout
-    menu $m.windows.restorelayout
+menu $m.savelayout
+menu $m.restorelayout
     foreach i {"1 (default)" "2" "3"} slot {1 2 3} {
-      $m.windows.savelayout add command -label $i -command "::docking::layout_save $slot"
-      $m.windows.restorelayout add command -label $i -command "::docking::layout_restore $slot"
+      $m.savelayout add command -label $i -command "::docking::layout_save $slot"
+      $m.restorelayout add command -label $i -command "::docking::layout_restore $slot"
     }
-    $m.windows add cascade -label OptionsWindowsSaveLayout -menu $m.windows.savelayout
-    $m.windows add cascade -label OptionsWindowsRestoreLayout -menu $m.windows.restorelayout
-  }
-  menu $m.windows.startup
-    $m.windows.startup add checkbutton -label HelpTip -variable startup(tip)
-    $m.windows.startup add checkbutton -label FileFinder -variable startup(finder)
-    $m.windows.startup add checkbutton -label WindowsStats -variable startup(stats)
-    if {! $::docking::USE_DOCKING} {
-      $m.windows.startup add checkbutton -label ToolsCross -variable startup(crosstable)
-      $m.windows.startup add checkbutton -label WindowsSwitcher -variable startup(switcher)
-      $m.windows.startup add checkbutton -label WindowsGList -variable startup(gamelist)
-      $m.windows.startup add checkbutton -label WindowsPGN -variable startup(pgn)
-      $m.windows.startup add checkbutton -label WindowsTree -variable startup(tree)
-      $m.windows.startup add checkbutton -label WindowsBook -variable startup(book)
-    }
-  $m.windows add cascade -label OptionsStartup -menu $m.windows.startup
-$m add cascade -label OptionsWindows -menu $m.windows
-$m add command -label OptionsSounds -command ::utils::sound::OptionsDialog
-$m add command -label OptionsToolbar -command configToolbar
-$m add separator
-$m add command -label OptionsRecent -command ::recentFiles::configure
-$m add command -label GInfoInformant -command configInformant
+$m add command -label ConfigureScid -command { ::preferences::Open toggle }
+$m add command -label OptionsResources -command ::preferences::resources
 menu $m.export
   $m.export add command -label "PGN file text" -underline 0 -command "setExportText PGN"
   $m.export add command -label "HTML file text" -underline 0 -command "setExportText HTML"
   $m.export add command -label "LaTeX file text" -underline 0 -command "setExportText LaTeX"
 $m add cascade -label OptionsExport -menu $m.export
-menu $m.entry
-  $m.entry add checkbutton -label OptionsMovesAsk \
-      -variable askToReplaceMoves -offvalue 0 -onvalue 1
-  menu $m.entry.animate
-    foreach i {0 100 150 200 250 300 400 500 600 800 1000} {
-        $m.entry.animate add radiobutton -label "$i ms" \
-            -variable animateDelay -value $i
-    }
-  $m.entry add cascade -label OptionsMovesAnimate -menu $m.entry.animate
-  $m.entry add command -label OptionsMovesDelay -command setAutoplayDelay
-  $m.entry add checkbutton -label OptionsMovesCoord \
-      -variable moveEntry(Coord) -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesKey \
-      -variable moveEntry(AutoExpand) -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesSuggest \
-      -variable suggestMoves -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsShowVarPopup \
-      -variable showVarPopup -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesSpace \
-      -variable ::pgn::moveNumberSpaces -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesTranslatePieces \
-      -variable ::translatePieces -offvalue 0 -onvalue 1 -command setLanguage
-  menu $m.entry.highlightlastmove
-    $m.entry.highlightlastmove add checkbutton -label OptionsMovesHighlightLastMoveDisplay \
-        -variable ::highlightLastMove -command updateBoard
-    menu $m.entry.highlightlastmove.width
-      foreach i {1 2 3 4 5} {
-          $m.entry.highlightlastmove.width add radiobutton -label $i -value $i \
-              -variable ::highlightLastMoveWidth -command updateBoard
-      }
-    $m.entry.highlightlastmove add cascade -label OptionsMovesHighlightLastMoveWidth -menu $m.entry.highlightlastmove.width
-    $m.entry.highlightlastmove add command -label OptionsMovesHighlightLastMoveColor -command chooseHighlightColor
-    $m.entry.highlightlastmove add checkbutton -label OptionsMovesHighlightLastMoveArrow \
-        -variable ::arrowLastMove -command updateBoard
-  $m.entry add cascade -label OptionsMovesHighlightLastMove -menu  $m.entry.highlightlastmove
-  $m.entry add checkbutton -label OptionsMovesShowVarArrows \
-      -variable showVarArrows -offvalue 0 -onvalue 1
-  $m.entry add checkbutton -label OptionsMovesGlossOfDanger \
-      -variable glossOfDanger -offvalue 0 -onvalue 1 -command updateBoard
-$m add cascade -label OptionsMoves -menu $m.entry
 $m add separator
-$m add command -label OptionsECO -command ::readECOFile
-$m add command -label OptionsSpell -command readSpellCheckFile
-$m add command -label OptionsTable -command setTableBaseDir \
-    -state [expr {[sc_info tb] ? "normal" : "disabled"}]
-$m add command -label OptionsBooksDir -command setBooksDir
-$m add command -label OptionsTacticsBasesDir -command setTacticsBasesDir
-#TODO: translate
-$m add command -label "Photos directory..." -command setPhotoDir
+$m add checkbutton -label FullScreen -variable optionFullScreen \
+  -command { wm attributes . -fullscreen [expr ![wm attributes . -fullscreen]] }
+$m add checkbutton -label OptionsWindowsDock -variable windowsDock
+$m add cascade -label OptionsWindowsSaveLayout -menu $m.savelayout
+$m add cascade -label OptionsWindowsRestoreLayout -menu $m.restorelayout
 $m add separator
 $m add command -label OptionsSave -command options.write
 $m add checkbutton -label OptionsAutoSave -variable optionsAutoSave \
@@ -416,9 +328,8 @@ $m  add command -label HelpAbout -command helpAbout
 ##################################################
 # Store menu labels for translations and help messages
 set ::menuHelpMessage {}
-proc storeMenuLabels {m} {
+proc translateMenuLabels {m} {
     bind $m <<MenuSelect>> {
-        set ::menuHelpMessage {}
         set idx [%W index active]
         if {$idx != "none"} {
             # Tcl/Tk seems to generate strange window names for menus that
@@ -428,22 +339,30 @@ proc storeMenuLabels {m} {
             # I have no idea why it does this, but to avoid it we
             # convert a window paths with hashes to its true value:
             regsub -all "\#" [winfo name %W] . win
+            set ::menuHelpMessage {}
             catch {
                 set lbl $::MenuLabels($win,$idx)
                 set ::menuHelpMessage $::helpMessage($::language,$lbl)
             }
+            updateStatusBar
+        } elseif {$::menuHelpMessage ne ""} {
+            set ::menuHelpMessage {}
+            updateStatusBar
         }
-        updateStatusBar
     }
 
     set n [$m index end]
     for {set i 0} {$n != "none" && $i <= $n} {incr i} {
         set type [$m type $i]
         if {$type != "separator" && $type != "tearoff"} {
-            set ::MenuLabels($m,$i) [$m entrycget $i -label]
+            set lbl [$m entrycget $i -label]
+            set ::MenuLabels($m,$i) $lbl
+            set under 0
+            catch { set under $::menuUnder($::language,$lbl) }
+            $m entryconfig $i -label [tr $lbl] -underline $under
         }
         if {$type == "cascade"} {
-            storeMenuLabels [$m entrycget $i -menu]
+            translateMenuLabels [$m entrycget $i -menu]
         }
     }
 }
@@ -457,7 +376,7 @@ proc menuConfig {{m} {label} {cmd} args} {
         }
     }
 }
-storeMenuLabels .menu
+translateMenuLabels .menu
 set fileExitHack [.menu.file index end]
 set ::MenuLabels(.menu.file,end) $::MenuLabels(.menu.file,$fileExitHack)
 array unset ::MenuLabels ".menu.file,$fileExitHack"
@@ -484,6 +403,9 @@ proc updateMenuStates {{menuname}} {
         $m.file insert [expr $::menuFileRecentIdx + $nrecent] separator
       }
     }
+  {.menu.db} {
+      set ::autoLoadBases_currdb [expr {[::file::autoLoadBases.find $::curr_db] >= 0}]
+    }
   {.menu.play} {
       set n [$m.play index end]
       set st normal
@@ -526,6 +448,9 @@ proc updateMenuStates {{menuname}} {
     }
     $m.game entryconfig [tr GameReplace] -state $state
   }
+  {.menu.options} {
+    set ::optionsFullScreen [wm attributes . -fullscreen]
+  }
   }
 }
 
@@ -556,8 +481,11 @@ proc menuUpdateBases {} {
   set notEmpty    [expr {[sc_base numGames $::curr_db] != 0 ? "normal" : "disabled"}]
 
   menuConfig .menu.db FileClose entryconfig -state $notClipbase
+  menuConfig .menu.db LoadatStartup entryconfig -state $notClipbase
   menuConfig .menu.db ToolsExpFilter entryconfig -state $notEmpty
   menuConfig .menu.db FileMaintName entryconfig -state $canChange
+  menuConfig .menu.db.utils Cleaner          entryconfig -state $canChange
+  menuConfig .menu.db.utils StripTags        entryconfig -state $canChange
   menuConfig .menu.db.utils FileMaintDelete  entryconfig -state $canChange
   menuConfig .menu.db.utils FileMaintClass   entryconfig -state $canChange
   menuConfig .menu.db.utils FileMaintTwin    entryconfig -state $canChange
@@ -565,39 +493,15 @@ proc menuUpdateBases {} {
   menuConfig .menu.db.utils FileMaintNameEditor entryconfig -state $canChange
 }
 
-proc menuUpdateBoardSizes {} {
-  set count 0
-  set m .menu.options.board
-  $m.bdsize delete 0 end
-  set st normal
-  if {$::docking::USE_DOCKING } {
-    $m.bdsize add checkbutton -label "Auto" -variable ::autoResizeBoard \
-        -command "::resizeMainBoard; menuUpdateBoardSizes"
-    if {$::autoResizeBoard} { set st disabled }
-  }
-  foreach i $::boardSizes {
-    incr count
-    if {$count <= 9} {
-      set lbl "  $count"
-    } else {
-      set lbl " $count"
-    }
-    $m.bdsize add radio -label "$lbl" -variable boardSize -value $i -state $st\
-      -command "::board::resize .main.board $i "
+proc menuUpdateThemes {} {
+  set m .menu.options.theme
+  $m delete $::menuThemeListIdx end
+  foreach i [lsort [ttk::style theme names]] {
+      $m add radiobutton -label "$i" -value $i -variable ::lookTheme \
+      -command {ttk::style theme use $::lookTheme}
   }
 }
 
-proc menuUpdatePieces {} {
-  set m .menu
-  $m.options.board.pieces delete 0 end
-  foreach i $::boardStyles {
-    $m.options.board.pieces add radio -label $i \
-      -variable boardStyle -value $i \
-      -underline 0 -command "setPieceFont \"$i\"; updateBoard"
-  }
-}
-
-
 ##############################
 # Multiple-language menu support functions.
 
@@ -616,21 +520,18 @@ proc configMenuText {menu entry tag lang} {
 proc setLanguageMenus {} {
   set lang $::language
   foreach {key lbl} [array get ::MenuLabels] {
-    foreach {m idx} [split $key ","] {
+      lassign [split $key ","] m idx
+      if {![winfo exists $m]} { continue }
       set under 0
       catch { set under $::menuUnder($lang,$lbl) }
       $m entryconfig $idx -label [tr $lbl] -underline $under
-    }
   }
 
-  ::pgn::ConfigMenus
-  ::windows::stats::ConfigMenus
-  ::tree::ConfigMenus
-  ::crosstab::ConfigMenus
   ::optable::ConfigMenus
   ::preport::ConfigMenus
-  ::tourney::ConfigMenus
-  
+  ::tools::graphs::score::ConfigMenus
+  ::tools::graphs::rating::ConfigMenus
+
   # Check for duplicate menu underline characters in this language:
   # set ::verifyMenus 1
   if {[info exists ::verifyMenus] && $::verifyMenus} {
@@ -673,116 +574,47 @@ proc checkMenuUnderline {menu} {
 ################################################################################
 #
 ################################################################################
-proc configInformant {} {
+proc configInformant { w } {
   global informant
   
-  set w .configInformant
-  if {[winfo exists $w]} {
-    destroy $w
-  }
-  
-  toplevel $w
-  ::setTitle $w $::tr(ConfigureInformant)
-  setWinLocation $w
-  frame $w.spinF
+  ttk::frame $w.spinF
   set idx 0
   set row 0
   
   foreach i [lsort [array names informant]] {
-    label $w.spinF.labelExpl$idx -text [ ::tr "Informant[ string trim $i "\""]" ]
-    label $w.spinF.label$idx -text $i
+    ttk::label $w.spinF.labelExpl$idx -text [ ::tr "Informant[ string trim $i "\""]" ]
+    ttk::label $w.spinF.label$idx -text $i
      # Allow the configuration of "won game" up to "Mate found"
      if {$i == "\"++-\""} {
-         spinbox $w.spinF.sp$idx -textvariable informant($i) -width 5 -from 0.0 -to 328.0 -increment 1.0 -validate all -vcmd { regexp {^[0-9]\.[0-9]$} %P }
+         ttk::spinbox $w.spinF.sp$idx -textvariable informant($i) -width 5 -from 0.0 -to 328.0 -increment 1.0 -validate all -validatecommand { regexp {^[0-9]\.[0-9]$} %P }
      } else {
-         spinbox $w.spinF.sp$idx -textvariable informant($i) -width 5 -from 0.0 -to 9.9 -increment 0.1 -validate all -vcmd { regexp {^[0-9]\.[0-9]$} %P }
+         ttk::spinbox $w.spinF.sp$idx -textvariable informant($i) -width 5 -from 0.0 -to 9.9 -increment 0.1 -validate all -validatecommand { regexp {^[0-9]\.[0-9]$} %P }
      }
     grid $w.spinF.labelExpl$idx -row $row -column 0 -sticky w
     incr row
     grid $w.spinF.label$idx -row $row -column 0 -sticky w
-    grid $w.spinF.sp$idx -row $row -column 1 -sticky w
+    grid $w.spinF.sp$idx -row $row -column 1 -sticky w -padx "0 5" -pady "0 5"
     incr row
     incr idx
   }
-  
-  button $w.close -textvar ::tr(Close) -command "destroy $w"
-  pack $w.spinF $w.close
-  bind $w <Configure> "recordWinSize $w"
+  pack $w.spinF
 }
 
-# ################################################################################
-# Set the delay between moves in options menu
-################################################################################
-proc setAutoplayDelay {} {
-    global autoplayDelay tempdelay
-    set tempdelay [expr {int($autoplayDelay / 1000.0)}]
-    set w .apdialog
-    if { [winfo exists $w] } { focus $w ; return }
-    toplevel $w
-    ::setTitle $w "Scid"
-    wm resizable $w 0 0
-    ttk::label $w.label -text $::tr(AnnotateTime:)
-    pack $w.label -side top -pady 5 -padx 5
-    ttk::spinbox $w.spDelay -background white -width 4 -textvariable tempdelay -from 1 -to 999 -increment 1 \
-        -validate key -validatecommand { return [string is digit %S] }
-    pack $w.spDelay -side top -pady 5
-    
-    set b [ttk::frame $w.buttons]
-    pack $b -side top -fill x
-    ttk::button $b.cancel -text $::tr(Cancel) -command {
-        destroy .apdialog
-        focus .
-    }
-    ttk::button $b.ok -text "OK" -command {
-        if {$tempdelay < 0.1} { set tempdelay 0.1 }
-        set autoplayDelay [expr {int($tempdelay * 1000)}]
-        destroy .apdialog
-        focus .
-    }
-    pack $b.cancel $b.ok -side right -padx 5 -pady 5
-    bind $w <Escape> { .apdialog.buttons.cancel invoke }
-    bind $w <Return> { .apdialog.buttons.ok invoke }
-    focus $w.spDelay
-}
-
-# setTableBaseDir:
-#    Prompt user to select a tablebase file; all the files in its
-#    directory will be used.
-#
-proc setTableBaseDir {} {
-  global initialDir tempDir
-  set ftype { { "Tablebase files" {".emd" ".nbw" ".nbb"} } }
-
-  set w .tbDialog
-  toplevel $w
-  ::setTitle $w Scid
-  label $w.title -text "Select up to 4 table base directories:"
-  pack $w.title -side top
-  foreach i {1 2 3 4} {
-    set tempDir(tablebase$i) $initialDir(tablebase$i)
-    pack [frame $w.f$i] -side top -pady 3 -fill x -expand yes
-    entry $w.f$i.e -width 30 -textvariable tempDir(tablebase$i)
-    bindFocusColors $w.f$i.e
-    button $w.f$i.b -text "..." -pady 2 -command [list chooseTableBaseDir $i]
-    pack $w.f$i.b -side right -padx 2
-    pack $w.f$i.e -side left -padx 2 -fill x -expand yes
+proc openTableBaseDirs {nr widget} {
+  set dirname [$widget get]
+  if {$dirname ne "" && ![file isdirectory $dirname]} {
+    $widget configure -style Error.TEntry
+    return
   }
-  addHorizontalRule $w
-  pack [frame $w.b] -side top -fill x
-  button $w.b.ok -text "OK" \
-      -command "catch {grab release $w; destroy $w}; openTableBaseDirs"
-  button $w.b.cancel -text $::tr(Cancel) \
-      -command "catch {grab release $w; destroy $w}"
-  pack $w.b.cancel $w.b.ok -side right -padx 2
-  bind $w <Escape> "$w.b.cancel invoke"
-  wm resizable $w 1 0
-  grab $w
-}
-proc openTableBaseDirs {} {
-  global initialDir tempDir
+  $widget configure -style TEntry
+  if {$dirname eq $::initialDir(tablebase$nr)} {
+    return
+  }
+  set ::initialDir(tablebase$nr) $dirname
+
   set tableBaseDirs ""
   foreach i {1 2 3 4} {
-    set tbDir [string trim $tempDir(tablebase$i)]
+    set tbDir [string trim $::initialDir(tablebase$i)]
     if {$tbDir != ""} {
       if {$tableBaseDirs != ""} { append tableBaseDirs ";" }
       append tableBaseDirs [file nativename $tbDir]
@@ -790,9 +622,6 @@ proc openTableBaseDirs {} {
   }
 
   set npieces [sc_info tb $tableBaseDirs]
-  foreach i {1 2 3 4} {
-    set initialDir(tablebase$i) $tempDir(tablebase$i)
-  }
   if {$npieces == 0} {
     set msg "No tablebases were found."
   } else {
@@ -802,71 +631,126 @@ proc openTableBaseDirs {} {
     append msg "Options menu before you exit Scid."
   }
   tk_messageBox -type ok -icon info -title "Scid: Tablebase results" \
-      -message $msg
+      -message $msg -parent [winfo toplevel $widget]
+
+  grab [winfo toplevel $widget]
 }
-proc chooseTableBaseDir {i} {
-  global tempDir
 
-  set idir $tempDir(tablebase$i)
-  if {$idir == ""} { set idir [pwd] }
-
-  set fullname [tk_chooseDirectory -initialdir $idir -mustexist 1 \
-      -title "Scid: Select a Tablebase directory"]
-  if {$fullname == ""} { return }
-
-  set tempDir(tablebase$i) $fullname
+proc chooseTableBaseDir {widget} {
+  set fullname [tk_chooseDirectory -initialdir [$widget get] -mustexist 1 \
+      -title "Scid: Select a Tablebase directory" -parent [winfo toplevel $widget] ]
+  if {$fullname ne ""} {
+    $widget delete 0 end
+    $widget insert end [file nativename $fullname]
+  }
 }
 ################################################################################
 
-proc setBooksDir {} {
+proc getBooksDir { widget } {
   global scidBooksDir
-  set dir [tk_chooseDirectory -initialdir $scidBooksDir -mustexist 1]
-  if {$dir == ""} {
-    return
-  } else {
-    set scidBooksDir $dir
+  set dir [tk_chooseDirectory -initialdir $scidBooksDir -parent [winfo toplevel $widget] -mustexist 1]
+  if {$dir != ""} {
+      setBooksDir $dir
+      $widget delete 0 end
+      $widget insert end $dir
   }
 }
 
-proc setTacticsBasesDir {} {
+proc setBooksDir { dir } {
+  global scidBooksDir
+  set scidBooksDir $dir
+}
+
+proc getTacticsBasesDir { widget } {
   global scidBasesDir
-  set dir [tk_chooseDirectory -initialdir $scidBasesDir -mustexist 1]
-  if {$dir == ""} {
-    return
-  } else {
-    set scidBasesDir $dir
+  set dir [tk_chooseDirectory -initialdir $scidBasesDir -parent [winfo toplevel $widget] -mustexist 1]
+  if {$dir != ""} {
+      setTacticsBasesDir $dir
+      $widget delete 0 end
+      $widget insert end $dir
   }
 }
 
-proc setPhotoDir {} {
-  set dir [tk_chooseDirectory -initialdir $::scidExeDir -mustexist 1]
-  if {$dir == ""} {
-    return
-  } else {
+proc setTacticsBasesDir { dir } {
+  global scidBasesDir
+  set scidBasesDir $dir
+}
+
+proc getPhotoDir { widget } {
+  set idir [pwd]
+  if { [info exists ::scidPhotoDir] } { set idir $::scidPhotoDir }
+  set dir [tk_chooseDirectory -initialdir $idir -parent [winfo toplevel $widget] -mustexist 1]
+  if {$dir != ""} {
+      if { [setPhotoDir $dir] } {
+          $widget delete 0 end
+          $widget insert end $dir
+      }
+  }
+}
+
+proc setPhotoDir { dir } {
     set ::scidPhotoDir $dir
     options.save ::scidPhotoDir
     set n [loadPlayersPhoto]
-    tk_messageBox -message "Found [lindex $n 0] images in [lindex $n 1] file(s)"
+    set ret [lindex $n 0]
+    tk_messageBox -parent .resDialog -message "Found $ret images in [lindex $n 1] file(s)"
     ::notify::GameChanged
+    return $ret
+}
+
+proc getThemePkgFile { widget} {
+  global initialDir
+  set fullname [tk_getOpenFile -parent [winfo toplevel $widget] -title "Select a pkgIndex.tcl file for themes" -initialdir [file dirname $::ThemePackageFile] -initialfile $::ThemePackageFile \
+	       -filetypes { {Theme "pkgIndex.tcl"} }]
+  if { $fullname != "" && $fullname != $::ThemePackageFile && ! [readThemePkgFile $fullname] } {
+      $widget delete 0 end
+      $widget insert end $fullname
   }
 }
 
-proc readECOFile {} {
+proc readThemePkgFile { fullname } {
+    if {$fullname ne "" && $fullname != $::ThemePackageFile } {
+        set count [llength [ttk::style theme names]]
+        set ret [ catch { ::safeSourceStyle $fullname } ]
+        set newthemes [expr [llength [ttk::style theme names]] - $count]
+        if { $ret == 0 && $newthemes > 0  } {
+            menuUpdateThemes
+            set ::ThemePackageFile $fullname
+        }
+        tk_messageBox -parent .resDialog -message "$newthemes new theme(s) found."
+    } else {
+        set ::ThemePackageFile $fullname
+        tk_messageBox -parent .resDialog -message "No new themes loaded."
+        set ret 0
+    }
+    return $ret
+}
+
+proc getECOFile { widget } {
+  global ecoFile
   set ftype { { "Scid ECO files" {".eco"} } }
-  if {[sc_info gzip]} {
-    set ftype { { "Scid ECO files" {".eco" ".eco.gz"} } }
+  set fullname [tk_getOpenFile -parent [winfo toplevel $widget] -initialdir [file dirname $ecoFile] -filetypes $ftype -title "Load ECO file"]
+  if { [readECOFile $fullname] } {
+      $widget delete 0 end
+      $widget insert end $fullname
   }
-  set fullname [tk_getOpenFile -initialdir [pwd] -filetypes $ftype -title "Load ECO file"]
+}
+
+proc readECOFile { fullname } {
+  global ecoFile
   if {[string compare $fullname ""]} {
     if {[catch {sc_eco read $fullname} result]} {
-      tk_messageBox -title "Scid" -type ok \
-          -icon warning -message $result
+      tk_messageBox -title "Scid" -type ok -icon warning -message $result -parent .resDialog
     } else {
       set ecoFile $fullname
-      tk_messageBox -title "Scid: ECO file loaded." -type ok -icon info \
+      tk_messageBox -title "Scid: ECO file loaded." -type ok -icon info -parent .resDialog \
           -message "ECO file $fullname loaded: $result positions.\n\nTo have this file automatically loaded when you start Scid, select \"Save Options\" from the Options menu before exiting."
+      return 1
     }
+  } else {
+      set ecoFile $fullname
   }
+  return 0
 }
 
 proc updateLocale {} {
@@ -898,6 +782,7 @@ proc chooseFont {fType} {
       set fontsize [font configure font_Small -size]
       font configure font_SmallBold -family $font -size $fontsize
       font configure font_SmallItalic -family $font -size $fontsize
+      calculateGlistRowHeight
     }
   }
 }
