@@ -166,13 +166,6 @@ proc autoscrollframe {args} {
   return $retval
 }
 
-proc autoscrollText {bars frame widget style} {
-  ttk::frame $frame
-  text $widget -cursor arrow -state disabled -highlightthickness 0
-  applyThemeStyle $style $widget
-  autoscrollBars $bars $frame $widget
-}
-
 proc autoscrollBars {bars frame w} {
   global _autoscroll
 
@@ -323,7 +316,7 @@ proc progressWindow { title text {button ""} {command "progressBarCancel"} } {
   ttk::label $w.f.t -text $text
   autoscrollframe -bars y $w.f.cmsg text $w.f.cmsg.text -width 70 -height 14 -wrap word -font font_Regular
   canvas $w.f.c -width 400 -height 20 -bg white -relief solid -border 1 -highlightthickness 0
-  $w.f.c create rectangle 0 0 0 0 -fill blue -outline blue -tags bar
+  $w.f.c create rectangle 0 0 0 0 -fill DodgerBlue3 -outline DodgerBlue3 -tags bar
   $w.f.c create text 395 10 -anchor e -font font_Regular -tags time -fill black -text "0:00 / 0:00"
   ttk::button $w.f.cancel -text $button -command "$command"
 
@@ -344,7 +337,6 @@ proc progressWindow { title text {button ""} {command "progressBarCancel"} } {
   grab $w
   wm withdraw $w
 
-  set ::progressWin_time [clock seconds]
   progressBarSet $w.f.c 401 21
 
   set ::progressCanvas(show) "catch {wm deiconify $w}"
@@ -358,6 +350,7 @@ proc progressBarSet { canvasname width height } {
   set ::progressCanvas(cancel) 0
   set ::progressCanvas(init) 1
   set ::progressCanvas(show) {}
+  set ::progressCanvas(time) [clock milliseconds]
   after idle { unset ::progressCanvas(init) }
 }
 
@@ -366,7 +359,7 @@ proc progressBarCancel { } {
 }
 
 
-proc progressCallBack {done {total 1} {elapsed 0} {estimated 0} {msg ""}} {
+proc progressCallBack {done {msg ""}} {
   if {$done == "init"} {
     if {[info exists ::progressCanvas(init)]} {
       return $::progressCanvas(init)
@@ -380,16 +373,22 @@ proc progressCallBack {done {total 1} {elapsed 0} {estimated 0} {msg ""}} {
     return -code break
   }
 
+  set elapsed [expr { [clock milliseconds] - $::progressCanvas(time) }]
+  if {$done != 0} {
+    set estimated [expr { int($elapsed / double($done) / 1000) }]
+    set elapsed [expr { $elapsed / 1000 }]
+  } else {
+    set elapsed [expr { $elapsed / 1000 }]
+    set estimated $elapsed
+  }
+
   if {$::progressCanvas(show) != ""} {
     if {$elapsed == 0 && $estimated < 2 && $msg == ""} { return }
     eval $::progressCanvas(show)
     set ::progressCanvas(show) {}
   }
 
-  set width $::progressCanvas(w)
-  if {$total > 0} {
-    set width [expr {int(double($width) * double($done) / double($total))}]
-  }
+  set width [expr { int(double($::progressCanvas(w)) * double($done)) }]
   $::progressCanvas(name) coords bar 0 0 $width $::progressCanvas(h)
 
   set t [format "%d:%02d / %d:%02d" \
@@ -407,6 +406,11 @@ proc progressCallBack {done {total 1} {elapsed 0} {estimated 0} {msg ""}} {
   }
 
   update
+
+  if {! [winfo exists $::progressCanvas(name)] || $::progressCanvas(cancel)} {
+    #Interrupted
+    return -code break
+  }
 }
 
 proc changeProgressWindow {newtext} {
@@ -420,12 +424,12 @@ proc changeProgressWindow {newtext} {
 proc updateProgressWindow {done total} {
   set w .progressWin
   if {! [winfo exists $w]} { return }
-  set elapsed [expr {[clock seconds] - $::progressWin_time}]
-  set estimated $elapsed
-  if {$done != 0} {
-    set estimated [expr {int(double($elapsed) * double($total) / double($done))}]
+  if {$total != 0} {
+    set done [expr { double($done) / double($total) }]
+  } else {
+    set done 1
   }
-  ::progressCallBack "$done" "$total" "$elapsed" "$estimated"
+  ::progressCallBack $done
 }
 
 proc closeProgressWindow {{force false}} {
