@@ -130,11 +130,28 @@ proc InitDefaultGListLayouts {} {
   set ::glist_FindBar(Full) 0
 }
 
+proc InitDefaultAnnotate {} {
+  set ::isBatchOpening 0
+  set ::isBatchOpeningMoves 12
+  set ::isBatch 0
+  set ::markTacticalExercises 0
+  set ::isAnnotateVar 0
+  set ::isShortAnnotation 0
+  set ::addScoreToShortAnnotations 0
+  set ::addAnnotatorTag 0
+  set ::annotateMoves all
+  set ::annotateBlunders blundersonly
+  set ::scoreAllMoves 0
+  # Blunder Threshold
+  set ::blunderThreshold 1.0
+}
+
 InitDefaultFonts
 InitWinsDefaultGeometry
 InitDefaultToolbar
 InitDefaultStats
 InitDefaultGListLayouts
+InitDefaultAnnotate
 
 #Default textures for lite and dark squares
 set boardfile_dark "LightWood3-d"
@@ -145,16 +162,13 @@ set boardSize 40
 
 # boardStyle: Default board piece set.
 set boardStyle Merida1
-if { $macOS } { set boardStyle Merida }
 
-# Colors: dark and lite are square colors
+# Colors: squareColor_dark and squareColor_lite are square colors
 #     whitecolor/blackcolor are piece colors
 #     highcolor is the color when something is selected.
 #     bestcolor is used to indicate a suggested move square.
-# set dark        "\#70a070"
-# set lite        "\#e0d070"
-set lite "\#f3f3f3"
-set dark "\#7389b6"
+set squareColor_lite "\#f3f3f3"
+set squareColor_dark "\#7389b6"
 set whitecolor  "\#ffffff"
 set blackcolor  "\#000000"
 set whiteborder "\#000000"
@@ -168,7 +182,7 @@ set borderwidth 0
 set ::markColor green
 set ::markType full
 
-# boardCoords: 1 to show board Coordinates, 0 to hide them.
+# boardCoords: 1-4 to show board Coordinates, 0 to hide them.
 set boardCoords 0
 
 # autoResizeBoard:
@@ -206,9 +220,6 @@ set highlightLastMovePattern {} ; # this option is not saved
 # Gloss Of Danger
 set glossOfDanger 0
 
-# Ask before replacing existing moves: on by default
-set askToReplaceMoves 1
-
 # Show suggested moves: on by default
 set suggestMoves 1
 
@@ -273,13 +284,10 @@ set ::pgn::boldMainLine 1
 set ::pgn::columnFormat 0
 set ::pgn::stripMarks 0
 set ::pgn::showPhoto 1
-set pgnColor(Header) "\#00008b"
-set pgnColor(Main) "\#000000"
-set pgnColor(Var) "\#0000ee"
+set pgnColor(Var) ""
 set pgnColor(Nag) "\#ee0000"
 set pgnColor(Comment) "\#008b00"
-set pgnColor(Current) lightSteelBlue
-set pgnColor(Background) "\#ffffff"
+set pgnColor(Current) steelBlue
 
 # Defaults for FICS
 set ::fics::use_timeseal 0
@@ -365,17 +373,12 @@ set autoplayDelay 5000
 set animateDelay 200
 set autoplayMode 0
 
-# Blunder Threshold
-set blunderThreshold 1.0
-
 # Geometry of windows:
 array set geometry {}
 
 # startup:
 #   Stores which windows should be opened on startup.
 set startup(tip) 1
-set startup(finder) 0
-set startup(stats) 0
 
 
 # Game information area options:
@@ -537,15 +540,6 @@ proc raiseWin {w} {
   return
 }
 
-# autoIconify:
-#   Specified whether Scid should iconify all other Scid windows when
-#   the main window is iconified. Most people like this behaviour but
-#   some window managers send an "UnMap" event when the user switches
-#   to another virtual window without iconifying the Scid window so
-#   users of such managers will probably want to turn this off.
-
-set autoIconify 1
-
 # Email configuration:
 set email(logfile) [file join $scidLogDir "scidmail.log"]
 set email(oldlogfile) [file join $scidUserDir "scidmail.log"]
@@ -669,8 +663,8 @@ proc options.write {} {
           blunderThreshold autoplayDelay animateDelay boardCoords \
           moveEntry(AutoExpand) moveEntry(Coord) \
           translatePieces arrowLastMove highlightLastMove highlightLastMoveWidth highlightLastMoveColor \
-          glossOfDanger askToReplaceMoves locale(numeric) \
-          spellCheckFile autoRaise autoIconify windowsDock showGameInfo \
+          glossOfDanger locale(numeric) \
+          spellCheckFile autoRaise windowsDock showGameInfo \
           exportFlags(comments) exportFlags(vars) \
           exportFlags(indentc) exportFlags(indentv) \
           exportFlags(column) exportFlags(symbols) \
@@ -694,7 +688,11 @@ proc options.write {} {
           ::uci::uciInfo(wtime3) ::uci::uciInfo(winc3) ::uci::uciInfo(btime3) ::uci::uciInfo(binc3) \
           boardfile_lite boardfile_dark \
           FilterMaxMoves FilterMinMoves FilterStepMoves FilterMaxElo FilterMinElo FilterStepElo \
-          FilterMaxYear FilterMinYear FilterStepYear FilterGuessELO lookTheme ThemePackageFile autoResizeBoard } {
+          FilterMaxYear FilterMinYear FilterStepYear FilterGuessELO lookTheme ThemePackageFile autoResizeBoard \
+          isBatchOpening isBatchOpeningMoves isBatch \
+          markTacticalExercises scoreAllMoves \
+          isAnnotateVar isShortAnnotation addScoreToShortAnnotations annotateBlunders\
+          addAnnotatorTag annotateMoves } {
       puts $optionF "set $i [list [set $i]]"
     }
     
@@ -718,10 +716,10 @@ proc options.write {} {
     puts $optionF "set analysisCommand [list $analysisCommand]"
     puts $optionF "set analysisChoices [list $analysisChoices]"
     puts $optionF ""
-    foreach i {lite dark whitecolor blackcolor highcolor bestcolor \
+    foreach i {squareColor_lite squareColor_dark whitecolor blackcolor highcolor bestcolor \
           whiteborder blackborder borderwidth \
-          pgnColor(Header) pgnColor(Main) pgnColor(Var) \
-          pgnColor(Nag) pgnColor(Comment) pgnColor(Background) \
+          pgnColor(Var) \
+          pgnColor(Nag) pgnColor(Comment) \
           pgnColor(Current) } {
       puts $optionF "set $i [list [set $i]]"
     }
@@ -799,8 +797,11 @@ proc options.write {} {
       puts $optionF ""
       puts $optionF "set ::autosave_opt [list $::autosave_opt]"
       foreach {var} $::autosave_opt {
-        upvar #0 $var a
-        puts $optionF "set $var [list $a]"
+        if {[array exists $var]} {
+            puts $optionF "array set $var [list [array get $var]]"
+        } else {
+            puts $optionF "set $var [list [set $var]]"
+        }
       }
     }
     
@@ -818,22 +819,19 @@ proc options.autoSaveHack {} {
   }
 }
 
-# For better modularity default value can be set in a module with:
-# if {![info exists varname]} { set varname defaultvalue }
-# options.save varname
-#
+# Sets an option whose value is restored when the program starts
+proc options.persistent {varname default_value} {
+  if {![info exists $varname]} {
+    set $varname $default_value
+  }
+  options.save $varname
+}
+
 proc options.save {varname} {
   if {![info exists ::autosave_opt] || [lsearch -exact $::autosave_opt $varname] == -1} {
     lappend ::autosave_opt $varname
   }
 }
-proc options.save_cancel {varname} {
-  set idx [lsearch -exact $::autosave_opt $varname]
-  if {$idx != -1} {
-    set ::autosave_opt [lreplace $::autosave_opt $idx $idx]
-  }
-}
-
 
 ###
 ### End of file: options.tcl
