@@ -18,6 +18,9 @@ set sHeaderCustomFlagList {  CustomFlag1 CustomFlag2 CustomFlag3 CustomFlag4 Cus
 
 set sHeaderFlagChars {S X _ _ _ D W B M E N P T K Q ! ? U 1 2 3 4 5 6}
 
+set sVariantStd 1
+set sVariant960 1
+
 set sPgntext(1) ""
 set sPgntext(2) ""
 set sPgntext(3) ""
@@ -177,7 +180,7 @@ proc search::headerCreateFrame { w } {
   ttk::label $f.dl2 -text "-"
   ttk::label $f.dl3 -text " "
   ttk::entry $f.demin -textvariable sEventDateMin -width 10
-  button $f.deminCal -image tb_calendar -padx 0 -pady 0 -command {
+  ttk::button $f.deminCal -image tb_calendar -style Pad0.Small.TButton -command {
     regsub -all {[.]} $sEventDateMin "-" newdate
     set ndate [::utils::date::chooser $newdate]
     if {[llength $ndate] == 3} {
@@ -185,7 +188,7 @@ proc search::headerCreateFrame { w } {
     }
   }
   ttk::entry $f.demax -textvariable sEventDateMax -width 10
-  button $f.demaxCal -image tb_calendar -padx 0 -pady 0 -command {
+  ttk::button $f.demaxCal -image tb_calendar -style Pad0.Small.TButton -command {
     regsub -all {[.]} $sEventDateMax "-" newdate
     set ndate [::utils::date::chooser $newdate]
     if {[llength $ndate] == 3} {
@@ -216,7 +219,7 @@ proc search::headerCreateFrame { w } {
   ttk::label $f.l2 -text "-"
   ttk::label $f.l3 -text " "
   ttk::entry $f.emin -textvariable sDateMin -width 10
-  button $f.eminCal -image tb_calendar -padx 0 -pady 0 -command {
+  ttk::button $f.eminCal -image tb_calendar -style Pad0.Small.TButton -command {
     regsub -all {[.]} $sDateMin "-" newdate
     set ndate [::utils::date::chooser $newdate]
     if {[llength $ndate] == 3} {
@@ -224,7 +227,7 @@ proc search::headerCreateFrame { w } {
     }
   }
   ttk::entry $f.emax -textvariable sDateMax -width 10
-  button $f.emaxCal -image tb_calendar -padx 0 -pady 0 -command {
+  ttk::button $f.emaxCal -image tb_calendar -style Pad0.Small.TButton -command {
     regsub -all {[.]} $sDateMax "-" newdate
     set ndate [::utils::date::chooser $newdate]
     if {[llength $ndate] == 3} {
@@ -279,7 +282,7 @@ proc search::headerCreateFrame { w } {
   pack $w.ano.aname $w.ano.a2 -side right -padx "5 0"
 
   addHorizontalRule $w
-  
+
   ttk::label $w.eco.l1 -textvar ::tr(ECOCode:)
   ttk::label $w.eco.l2 -text "-"
   ttk::label $w.eco.l3 -text " "
@@ -324,6 +327,13 @@ proc search::headerCreateFrame { w } {
   }
   pack $f.l3 $f.all $f.first $f.last -side left -padx 2
   
+  pack [ttk::frame $w.variant] -side top -fill x
+  ttk::label $w.variant.label -text "Variant:"
+  ttk::checkbutton $w.variant.std -text "standard" -variable sVariantStd -offvalue 0 -onvalue 1
+  ttk::checkbutton $w.variant.960 -text "960" -variable sVariant960 -offvalue 0 -onvalue 1
+  pack $w.variant.label -side left -pady "0 5" -padx "0 5"
+  pack $w.variant.std $w.variant.960 -side left -pady "0 5" -padx 5
+
   set f [ttk::frame $w.pgntext]
   pack $f -side top -fill x
   ttk::label $f.l1 -textvar ::tr(PgnContains:)
@@ -494,6 +504,9 @@ proc ::search::getSearchOptions {dest_list} {
 
 	if {$::sAnnotator ne ""} { lappend search "-annotator" $::sAnnotator }
 
+    if {! $::sVariantStd} { lappend search "-variant!" "std"}
+    if {! $::sVariant960} { lappend search "-variant!" "960"}
+
     global sHeaderFlags
     global sResWin sResLoss sResDraw sResOther sPgntext
 
@@ -667,15 +680,19 @@ proc chooseEcoRange {} {
   wm title $w "Scid: Choose ECO Range"
   wm minsize $w 30 5
   
-  listbox $w.list -yscrollcommand "$w.ybar set" -height 20 -width 60 -background white -setgrid 1
-  foreach i $ecoCommonRanges { $w.list insert end $i }
+  ttk::treeview $w.list -yscrollcommand "$w.ybar set" -columns {0} -show {} -selectmode browse
+  $w.list column 0 -width 400
+  set i -1
+  foreach elem $ecoCommonRanges {
+    $w.list insert {} end -id [incr i] -values [list $elem]
+  }
   ttk::scrollbar $w.ybar -command "$w.list yview" -takefocus 0
   pack [ttk::frame $w.b] -side bottom -fill x
   pack $w.ybar -side right -fill y
   pack $w.list -side left -fill both -expand yes
   
   ttk::button $w.b.ok -text "OK" -command {
-    set sel [.ecoRangeWin.list curselection]
+    set sel [.ecoRangeWin.list selection]
     if {[llength $sel] > 0} {
       set scid_ecoRangeChosen [lindex $ecoCommonRanges [lindex $sel 0]]
       set ::sEco No
