@@ -39,7 +39,7 @@ if {$tcl_version == 8.5} { catch {package require img::png} }
 
 set scidVersion [sc_info version]
 set scidVersionDate [sc_info version date]
-set scidVersionExpected "4.6.4"
+set scidVersionExpected "4.7.4"
 
 # Check that the version of c++ code matches the version of tcl code
 #
@@ -180,6 +180,7 @@ foreach ns {
   ::windows
   ::windows::gamelist ::windows::stats ::tree ::tree::mask ::windows::tree
   ::windows::switcher ::windows::eco ::crosstab ::pgn ::book
+  ::windows::commenteditor
   ::tools
   ::tools::analysis ::tools::email
   ::tools::graphs
@@ -189,7 +190,6 @@ foreach ns {
   ::tacgame ::sergame ::opening ::tactics ::calvar ::uci ::fics ::reviewgame ::novag
   ::config ::docking
   ::pinfo
-  ::commenteditor
   ::unsafe
   ::utils::tooltip
 } {
@@ -200,6 +200,15 @@ proc ::splash::add {text} {
 #TODO: decide what to do with all the splash messages (delete?)
 }
 
+# Platform specific operations
+if { $unixOS } {
+  # adds a checkbox to show hidden files
+  catch {tk_getOpenFile -with-invalid-argument}
+  namespace eval ::tk::dialog::file {
+    variable showHiddenBtn 1
+    variable showHiddenVar 0
+  }
+}
 
 # Reversed mouse buttons in mac (::MB2 and ::MB3 are middle and right mouse buttons respectively.):
 if { $macOS } {
@@ -232,10 +241,12 @@ proc safeSource {filename args} {
   set f [file nativename "$filename"]
   set d [file dirname $f]
   set n [file tail $f]
+  set vdir [::safe::interpAddToAccessPath $::safeInterp $d]
+  interp alias $::safeInterp image {} ::safeImage $::safeInterp [list $vdir $d]
   foreach {varname value} $args {
     $::safeInterp eval [list set $varname $value]
   }
-  $::safeInterp eval [list set vdir [::safe::interpAddToAccessPath $::safeInterp $d]]
+  $::safeInterp eval [list set vdir $vdir]
   $::safeInterp eval "source \$vdir/$n"
   foreach {varname value} $args {
     $::safeInterp eval [list unset $varname]
@@ -250,6 +261,91 @@ proc safeSet {i args} {
   interp invokehidden $i set {*}$args
 }
 
+# Use a ::safe::interp to evaluate a file containing ttk::style and image commands.
+# The evaluated script can only read the files inside its directory or direct subdirectories.
+# @param filename:  the absolute path to the file
+
+# recursiv identify all subdirs
+proc safeAddSubDirsToAccessPath { safeInterp dir } {
+  foreach subdir [glob -nocomplain -directory $dir -type d *] {
+    ::safe::interpAddToAccessPath $safeInterp $subdir
+    safeAddSubDirsToAccessPath $safeInterp $subdir
+  }
+}
+
+proc safeSourceStyle {filename} {
+  set filename [file nativename "$filename"]
+  set dir [file dirname $filename]
+
+  set safeInterp [::safe::interpCreate]
+
+  set vdir [::safe::interpAddToAccessPath $safeInterp $dir]
+  safeAddSubDirsToAccessPath $safeInterp $dir
+
+  interp alias $safeInterp pwd {} ::safePwd
+  interp alias $safeInterp package {} ::safePackage $safeInterp
+  interp alias $safeInterp image {} ::safeImage $safeInterp [list $vdir $dir]
+  interp alias $safeInterp ttk::style {} ::safeStyle $safeInterp
+  interp alias $safeInterp ::styleOption {} ::safeStyleOption $safeInterp
+
+  $safeInterp eval [list set vdir $vdir]
+  $safeInterp eval "source \$vdir/[file tail $filename]"
+  ::safe::interpDelete $safeInterp
+}
+
+proc safePwd {} {}
+
+proc safePackage { interp args } {
+    set args [lassign $args command]
+    catch {
+	switch -- $command {
+	    "require" { package require {*}$args }
+	    "vsatisfies" { package vsatisfies {*}$args }
+	    "provide" { package provide {*}$args }
+	}
+    }
+}
+
+proc safeImage {interp dir_map args} {
+	set filename [lsearch -exact $args -file]
+	if {$filename != -1} {
+		incr filename
+		set real_filename [string map $dir_map [lindex $args $filename]]
+		set args [lreplace $args $filename $filename $real_filename]
+	}
+	return [image {*}$args]
+}
+
+proc safeStyleOption {interp args} {
+    styleOption {*}$args
+}
+
+# Evaluate ttk::style commands invoked inside the restricted script.
+# If the command includes a script (ttk::style theme settings or ttk::style theme create)
+# it is evaluated using the safe interpreter.
+proc safeStyle {interp args} {
+	lassign $args theme settings themeName script
+	if {$theme eq "theme"} {
+		if { $settings eq "settings"} {
+			set curr_theme [ttk::style theme use]
+			ttk::style theme use $themeName
+			$interp eval $script
+			ttk::style theme use $curr_theme
+			return
+		}
+
+		set script_i [lsearch -exact $args -settings]
+		if {$script_i != -1} {
+			set script_j [expr $script_i + 1]
+			ttk::style {*}[lreplace $args $script_i $script_j]
+			$interp eval [list ttk::style theme settings $themeName [lindex $args $script_j]]
+			return
+		}
+	}
+
+	return [ttk::style {*}$args]
+}
+
 ####################################################
 # Load default/saved values
 source [file nativename [file join $::scidTclDir "options.tcl"]]
@@ -260,8 +356,6 @@ if {[info exists initialDir(tablebase)]} {
   set initialDir(tablebase1) $initialDir(tablebase)
 }
 
-set ::docking::USE_DOCKING $windowsDock
-
 proc createFonts {} {
   foreach name {Regular Menu Small Tiny Fixed} {
     set opts $::fontOptions($name)
@@ -290,18 +384,46 @@ proc createFonts {} {
 }
 createFonts
 
-# Load theme
-ttk::style theme use $::lookTheme
+# Workaround: set the options of ttkEntry.c widgets that don't work with ttk::style
+set ::themeOptions {}
+proc styleOption {themeName pattern value} {
+  lappend ::themeOptions [list $themeName $pattern $value]
+}
 
+# Load darktheme, must load here to have it in place if used
+source -encoding utf-8 [file nativename [file join $::scidTclDir "darktheme.tcl"]]
+# Load more theme
+if { [file exists $::ThemePackageFile] } {
+  catch { ::safeSourceStyle $::ThemePackageFile }
+}
+
+# The font for ttkEntry.c widgets cannot be set with ttk::style
+option add *TCombobox*font font_Regular
+option add *TEntry.font font_Regular
+option add *TSpinbox.font font_Regular
+
+# Set the menu options
+option add *Menu*TearOff 0
+option add *Menu*Font font_Menu
+foreach col [array names ::menuColor] {
+  option add *Menu.$col $::menuColor($col)
+}
+
+# Add the theme's options only when the theme is in use
+bind . <<ThemeChanged>> {
+  if {[string equal %W "."]} {
+    foreach elem [lsearch -all -inline -exact -index 0 $::themeOptions [ttk::style theme use]] {
+      option add [lindex $elem 1] [lindex $elem 2]
+    }
+  }
+}
+
+catch { ttk::style theme use $::lookTheme }
+
+#TODO: all the style configurations should be re-applied when the theme is changed
 # Use default font everywhere
-ttk::style configure TLabel -font font_Regular
-ttk::style configure TButton -font font_Regular
-ttk::style configure TRadiobutton -font font_Regular
-ttk::style configure TCheckbutton -font font_Regular
-ttk::style configure TMenubutton -font font_Regular
-ttk::style configure TCombobox -font font_Regular
-ttk::style configure TEntry -font font_Regular
-ttk::style configure TNotebook.Tab -font font_Regular
+ttk::style configure . -font font_Regular
+ttk::style configure Heading -font font_Regular
 
 # Style definitions
 ttk::style configure Bold.TCheckbutton -font font_Bold
@@ -312,17 +434,103 @@ ttk::style configure Bold.TButton -font font_Bold
 ttk::style configure Pad0.Small.TButton -padding 0
 
 ttk::style configure Small.TRadiobutton -font font_Small
-ttk::style configure Regular.TRadiobutton -font font_Regular
 ttk::style configure Bold.TRadiobutton -font font_Bold
 ttk::style configure SmallBold.TRadiobutton -font font_SmallBold
 
 ttk::style configure pad0.TMenubutton -padding 0 -indicatorwidth 0 -indicatorheight 0  -font font_Small
 
-# font_Regular is the default font for widgets:
-option add *Font font_Regular
+# Some themes (e.g. vista and xpnative) use custom field elements and ignore -fieldbackground
+if {[regexp {(Combobox|Entry|Spinbox)\.(field|background)} [ttk::style element names]]} {
+    ttk::style configure Error.TCombobox -foreground #b80f0a
+    ttk::style configure Error.TEntry -foreground #b80f0a
+    ttk::style configure Error.TSpinbox -foreground #b80f0a
+} else {
+    ttk::style configure Error.TCombobox -fieldbackground #b80f0a
+    ttk::style configure Error.TEntry -fieldbackground #b80f0a
+    ttk::style configure Error.TSpinbox -fieldbackground #b80f0a
+}
 
-# Use font_Menu for menu entries:
-option add *Menu*Font font_Menu
+proc calculateGlistRowHeight { } {
+    set ::glistRowHeight [expr { round(1.4 * [font metrics font_Small -linespace]) }]
+    ttk::style configure Gamelist.Treeview -rowheight $::glistRowHeight
+}
+calculateGlistRowHeight
+
+proc autoscrollText {bars frame widget style} {
+  ttk::frame $frame
+  text $widget -cursor arrow -state disabled -highlightthickness 0 -font font_Regular
+  $widget tag configure header -font font_Bold
+  applyThemeStyle $style $widget
+  autoscrollBars $bars $frame $widget
+}
+
+# Create a canvas and apply to it the current ttk style.
+proc ttk_canvas {pathName args} {
+  canvas $pathName {*}$args
+  ::applyThemeStyle Treeview $pathName
+}
+
+# Create an item into a widget (i.e. a canvas) and apply to it the current ttk style.
+# TODO: find a better way to do this and re-apply when <<ThemeChanged>>
+proc ttk_create {pathName type x y args} {
+  if {"-fill" ni $args} {
+    lappend args "-fill"
+    lappend args [ttk::style lookup Treeview -foreground "" black]
+  }
+  $pathName create $type $x $y {*}$args
+}
+
+# Create a menu and apply to it the ttk style.
+proc ttk_menu {pathName args} {
+  menu $pathName {*}$args
+  ::applyThemeStyle . $pathName
+}
+
+# Apply the theme's background color to a widget
+proc applyThemeColor_background { widget } {
+  set bgcolor [ttk::style lookup . -background "" #d9d9d9]
+  $widget configure -background $bgcolor
+  bind $widget <<ThemeChanged>> "::applyThemeColor_background $widget"
+}
+
+# Apply a ttk style to a tk widget
+proc applyThemeStyle {style widget} {
+  set exclude [list "-font"]
+  set options [ttk::style configure .]
+  lappend options {*}[ttk::style configure $style]
+
+  foreach {option value} $options {
+    if {$option in $exclude} { continue }
+    catch { $widget configure $option $value }
+  }
+  bind $widget <<ThemeChanged>> "::applyThemeStyle $style $widget"
+}
+
+image create photo flag_unknown -data {
+      iVBORw0KGgoAAAANSUhEUgAAABgAAAAMCAYAAAB4MH11AAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAC4jAAAuIw
+      F4pT92AAAAB3RJTUUH4wQHCTMzcDliXAAAABJJREFUOMtjYBgFo2AUjIKBBwAEjAABIobxpQAAAABJRU5ErkJggg==
+}
+
+proc getFlagImage { countryID { returnUnknowFlag no } } {
+  set cflag "flag_[string tolower [string range $countryID 0 2]]"
+  # preset unkown flag (empty transparent image 24x12)
+  set country flag_unknown
+  if { $cflag eq [info commands $cflag] } {
+    # flag exists, use it
+    set country $cflag
+  } else {
+    # flag does not exist, try to load it
+    set dname [file join $::scidImgDir flags $cflag.gif]
+    if { [file exists $dname] } {
+      image create photo $cflag -file $dname
+      set country $cflag
+    } elseif { $returnUnknowFlag == "no" } {
+      #no flag is needed, return nothing
+      set country ""
+    }
+  }
+  return $country
+}
 
 proc InitImg {} {
 	global scidImgDir boardStyle boardStyles textureSquare
@@ -357,7 +565,7 @@ proc InitImg {} {
 			lappend textureSquare [string range $iname 0 end-2]
 		}
 	}
-	
+
 	#Search available piece sets
 	set boardStyles {}
 	set dname [file join $::scidImgDir pieces]
@@ -366,13 +574,6 @@ proc InitImg {} {
 			lappend boardStyles [file tail $piecetype]
 		}
 	}
-
-	#Load all img/flags/_filename_.gif
-	set dname [file join $::scidImgDir flags]
-	foreach {fname} [glob -directory $dname *.gif] {
-		set iname [string range [file tail $fname] 0 end-4]
-		image create photo $iname -file $fname
-	}
 }
 if {[catch {InitImg}]} {
 	tk_messageBox -type ok -icon error -title "Scid: Error" \
@@ -403,7 +604,9 @@ utils/string.tcl
 utils/tooltip.tcl
 utils/validate.tcl
 utils/win.tcl
-misc/misc.tcl
+enginecfg.tcl
+enginecomm.tcl
+misc.tcl
 htext.tcl
 file.tcl
 file/finder.tcl
@@ -413,13 +616,15 @@ file/spellchk.tcl
 file/maint.tcl
 edit.tcl
 game.tcl
-game/browser.tcl
 windows.tcl
+windows/browser.tcl
 windows/gamelist.tcl
 windows/pgn.tcl
+windows/preferences.tcl
 windows/book.tcl
 windows/comment.tcl
 windows/eco.tcl
+windows/engine.tcl
 windows/stats.tcl
 windows/tree.tcl
 windows/crosstab.tcl
@@ -443,6 +648,7 @@ tools/tablebase.tcl
 tools/ptracker.tcl
 help/help.tcl
 help/tips.tcl
+appearance.tcl
 keyboard.tcl
 menus.tcl
 board.tcl
