@@ -19,7 +19,8 @@ namespace eval sergame {
   array set engineListBox {}
   set engineName ""
   set bookSlot 2
-  
+  set storeEval 0
+
   # list of fen positions played to detect 3 fold repetition
   set lFen {}
   set lastPlayerMoveUci ""
@@ -30,58 +31,56 @@ namespace eval sergame {
   proc config {} {
     global ::sergame::configWin ::sergame::chosenOpening
     
-    # check if game window is already opened. If yes abort previous game
-    set w ".serGameWin"
-    if {[winfo exists $w]} {
-      focus .
-      destroy $w
-    }
-    
     set w ".configSerGameWin"
     if {[winfo exists $w]} {
       focus $w
       return
     }
     
-    toplevel $w
+    win::createDialog $w
     wm title $w "$::tr(configuregame)"
     
     bind $w <F1> { helpWindow SeriousGame }
     setWinLocation $w
     
-    ttk::labelframe $w.fengines -text $::tr(Engine)
-    ttk::frame $w.fbook -relief groove -borderwidth 1
-    ttk::labelframe $w.ftime -text $::tr(TimeMode)
-    ttk::frame $w.fconfig -relief groove -borderwidth 1
-    ttk::frame $w.fopening -relief groove -borderwidth 1
+    ttk::frame $w.fconfig -padding 10
     ttk::frame $w.fbuttons
+    ttk::labelframe $w.fengines -text $::tr(Engine)
+    ttk::labelframe $w.ftime -text $::tr(TimeMode)
+    ttk::labelframe $w.fopening -text $::tr(Opening)
     
-    pack $w.fengines $w.fbook $w.ftime $w.fconfig -side top -fill x
-    pack $w.fopening -side top -fill both -expand 1
-    pack $w.fbuttons -side top -fill x
+    grid $w.fengines -row 0 -column 0 -pady { 0 10 } -sticky we -padx { 0 10 }
+    grid $w.fopening -row 0 -column 1 -pady { 0 10 } -sticky nswe -padx { 10 0 }
+    grid $w.ftime -row 1 -column 0 -pady { 10 0 } -sticky nswe -padx { 0 10 }
+    grid $w.fconfig -row 1 -column 1 -pady { 10 0 } -sticky we -padx { 10 0 }
+    grid $w.fbuttons -row 2 -column 1 -sticky we
     
     # builds the list of UCI engines
-    ttk::frame $w.fengines.fEnginesList -relief raised -borderwidth 1
-    listbox $w.fengines.fEnginesList.lbEngines -yscrollcommand "$w.fengines.fEnginesList.ybar set" \
-        -height 5 -width 50 -exportselection 0
+    ttk::frame $w.fengines.fEnginesList
+    ttk::treeview $w.fengines.fEnginesList.lbEngines -columns {0} -show {} -selectmode browse \
+        -yscrollcommand "$w.fengines.fEnginesList.ybar set"
+    $w.fengines.fEnginesList.lbEngines column 0 -width 100
+    $w.fengines.fEnginesList.lbEngines configure -height 5
     ttk::scrollbar $w.fengines.fEnginesList.ybar -command "$w.fengines.fEnginesList.lbEngines yview"
-    pack $w.fengines.fEnginesList.ybar -side left -fill y
-    pack $w.fengines.fEnginesList.lbEngines -side left -fill both -expand yes
-    pack $w.fengines.fEnginesList -expand yes -fill both -side top
+    pack $w.fengines.fEnginesList.ybar -side right -fill y
+    pack $w.fengines.fEnginesList.lbEngines -side left -fill x -expand 1
+    pack $w.fengines.fEnginesList -expand yes -fill x -side top
+
+
     set i 0
     set idx 0
     foreach e $::engines(list) {
       if { [lindex $e 7] != 1} { incr idx ; continue }
       set ::sergame::engineListBox($i) $idx
       set name [lindex $e 0]
-      $w.fengines.fEnginesList.lbEngines insert end $name
+      $w.fengines.fEnginesList.lbEngines insert {} end -id $idx -values [list $name]
       incr i
       incr idx
     }
     
     # Engine configuration (limit strength for example)
     ttk::button $w.fengines.bEngineConfig -text $::tr(ConfigureUCIengine) -command {
-      set sel [.configSerGameWin.fengines.fEnginesList.lbEngines curselection]
+      set sel [.configSerGameWin.fengines.fEnginesList.lbEngines selection]
       set index $::sergame::engineListBox($sel)
       set engineData [lindex $::engines(list) $index]
       set name [lindex $engineData 0]
@@ -93,7 +92,7 @@ namespace eval sergame {
       set ::uci::autoSaveOptions 1
       ::uci::uciConfig 3 [ toAbsPath $cmd ] $args [ toAbsPath $dir ] $options
     }
-    pack $w.fengines.bEngineConfig -side top
+    pack $w.fengines.bEngineConfig -side top -pady 5 -anchor e -padx 4
     
     # if no engines defined, bail out
     if {$i == 0} {
@@ -106,11 +105,11 @@ namespace eval sergame {
     $w.fengines.fEnginesList.lbEngines see $::sergame::chosenEngine
     
     # load book names
-    ttk::checkbutton $w.fbook.cbUseBook -text $::tr(UseBook) -variable ::sergame::useBook
+    ttk::checkbutton $w.fconfig.cbUseBook -text $::tr(UseBook) -variable ::sergame::useBook
     set bookPath $::scidBooksDir
     set bookList [ lsort -dictionary [ glob -nocomplain -directory $bookPath *.bin ] ]
     if { [llength $bookList] == 0 } {
-      $w.fbook.cbUseBook configure -state disabled
+      $w.fconfig.cbUseBook configure -state disabled
       set ::sergame::useBook 0
     }
     set i 0
@@ -124,28 +123,25 @@ namespace eval sergame {
       incr i
     }
     
-    ttk::combobox $w.fbook.combo -width 12 -values $tmp
-    catch { ch$w.fbook.combo current $idx }
+    ttk::combobox $w.fconfig.combo -width 12 -values $tmp
+    catch { ch$w.fconfig.combo current $idx }
     
     set row 0
     
-    pack $w.fbook.cbUseBook -side left
-    pack $w.fbook.combo -side right -expand yes -fill both
-    
     # Time bonus frame
     ttk::frame $w.ftime.timebonus
-    pack  $w.ftime.timebonus -side top -fill x -expand 1
+    pack  $w.ftime.timebonus -side top -fill x
     
     ttk::radiobutton $w.ftime.timebonus.rb1 -text $::tr(TimeBonus) -value "timebonus" -variable ::sergame::timeMode
     grid $w.ftime.timebonus.rb1 -row $row -column 0 -sticky w -rowspan 2
     
     ttk::label $w.ftime.timebonus.whitelabel -text $::tr(White)
     grid $w.ftime.timebonus.whitelabel -row $row -column 1
-    spinbox $w.ftime.timebonus.whitespminutes -background white -width 4 -from 1 -to 120 -increment 1 -validate all -vcmd { regexp {^[0-9]+$} %P }
+    ttk::spinbox $w.ftime.timebonus.whitespminutes -background white -width 2 -from 1 -to 120 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     grid $w.ftime.timebonus.whitespminutes -row $row -column 2
     ttk::label $w.ftime.timebonus.whitelminutes -text $::tr(TimeMin)
     grid $w.ftime.timebonus.whitelminutes -row $row -column 3
-    spinbox $w.ftime.timebonus.whitespseconds -background white -width 4 -from 0 -to 60 -increment 1 -validate all -vcmd { regexp {^[0-9]+$} %P }
+    ttk::spinbox $w.ftime.timebonus.whitespseconds -background white -width 2 -from 0 -to 60 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     grid $w.ftime.timebonus.whitespseconds -row $row -column 4
     ttk::label $w.ftime.timebonus.whitelseconds -text $::tr(TimeSec)
     grid $w.ftime.timebonus.whitelseconds -row $row -column 5
@@ -153,11 +149,11 @@ namespace eval sergame {
     incr row
     ttk::label $w.ftime.timebonus.blacklabel -text $::tr(Black)
     grid $w.ftime.timebonus.blacklabel -row $row -column 1
-    spinbox $w.ftime.timebonus.blackspminutes -background white -width 4 -from 1 -to 120 -increment 1 -validate all -vcmd { regexp {^[0-9]+$} %P }
+    ttk::spinbox $w.ftime.timebonus.blackspminutes -background white -width 2 -from 1 -to 120 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     grid $w.ftime.timebonus.blackspminutes -row $row -column 2
     ttk::label $w.ftime.timebonus.blacklminutes -text $::tr(TimeMin)
     grid $w.ftime.timebonus.blacklminutes -row $row -column 3
-    spinbox $w.ftime.timebonus.blackspseconds -background white -width 4 -from 0 -to 60 -increment 1 -validate all -vcmd { regexp {^[0-9]+$} %P }
+    ttk::spinbox $w.ftime.timebonus.blackspseconds -background white -width 2 -from 0 -to 60 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     grid $w.ftime.timebonus.blackspseconds -row $row -column 4
     ttk::label $w.ftime.timebonus.blacklseconds -text $::tr(TimeSec)
     grid $w.ftime.timebonus.blacklseconds -row $row -column 5
@@ -169,8 +165,8 @@ namespace eval sergame {
     
     # Fixed depth
     ttk::frame $w.ftime.depth
-    ttk::radiobutton $w.ftime.depth.button -text $::tr(FixedDepth) -value "depth" -variable ::sergame::timeMode
-    spinbox $w.ftime.depth.value -background white -width 4 -from 1 -to 20 -increment 1 -validate all -vcmd { regexp {^[0-9]+$} %P }
+    ttk::radiobutton $w.ftime.depth.button -text $::tr(FixedDepth) -value "depth" -variable ::sergame::timeMode -width 16
+    ttk::spinbox $w.ftime.depth.value -background white -width 3 -from 1 -to 20 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     $w.ftime.depth.value set $::sergame::depth
     
     pack $w.ftime.depth -side top -fill x
@@ -178,8 +174,8 @@ namespace eval sergame {
     pack $w.ftime.depth.value -side left
     
     ttk::frame $w.ftime.nodes
-    ttk::radiobutton $w.ftime.nodes.button -text "$::tr(Nodes) (x1000)" -value "nodes" -variable ::sergame::timeMode
-    spinbox $w.ftime.nodes.value -background white -width 4 -from 5 -to 10000 -increment 5 -validate all -vcmd { regexp {^[0-9]+$} %P }
+    ttk::radiobutton $w.ftime.nodes.button -text "$::tr(Nodes) (x1000)" -value "nodes" -variable ::sergame::timeMode  -width 16
+    ttk::spinbox $w.ftime.nodes.value -background white -width 3 -from 5 -to 10000 -increment 5 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     $w.ftime.nodes.value set [ expr $::sergame::nodes /1000]
     
     pack $w.ftime.nodes -side top -fill x
@@ -187,13 +183,16 @@ namespace eval sergame {
     pack $w.ftime.nodes.value -side left
     
     ttk::frame $w.ftime.movetime
-    ttk::radiobutton $w.ftime.movetime.button -text $::tr(SecondsPerMove) -value "movetime" -variable ::sergame::timeMode
-    spinbox $w.ftime.movetime.value -background white -width 4 -from 1 -to 120 -increment 1 -validate all -vcmd { regexp {^[0-9]+$} %P }
+    ttk::radiobutton $w.ftime.movetime.button -text $::tr(SecondsPerMove) -value "movetime" -variable ::sergame::timeMode -width 16
+    ttk::spinbox $w.ftime.movetime.value -background white -width 3 -from 1 -to 120 -increment 1 -validate all -validatecommand { regexp {^[0-9]+$} %P }
     $w.ftime.movetime.value set [ expr $::sergame::movetime /1000]
     
     pack $w.ftime.movetime -side top -fill x
     pack $w.ftime.movetime.button -side left
     pack $w.ftime.movetime.value -side left
+
+    pack $w.fconfig.cbUseBook -side top -anchor w
+    pack $w.fconfig.combo -side top -anchor w -padx 20 -fill x
     
     # New game or use current position ?
     ttk::checkbutton $w.fconfig.cbPosition -text $::tr(StartFromCurrentPosition) -variable ::sergame::startFromCurrent
@@ -206,28 +205,39 @@ namespace eval sergame {
     # Warn if the user makes weak/bad moves
     ttk::checkbutton $w.fconfig.cbCoach -text $::tr(CoachIsWatching) -variable ::sergame::coachIsWatching
     pack $w.fconfig.cbCoach -side top -anchor w
+    #Should the evaluation of the position stored in the comment?
+    ttk::checkbutton $w.fconfig.storeEval -text $::tr(AddScoreToShortAnnotations) -variable ::sergame::storeEval
+    pack $w.fconfig.storeEval -side top -anchor w
     
     # choose a specific opening
     ttk::checkbutton $w.fopening.cbOpening -text $::tr(SpecificOpening) -variable ::sergame::isOpening
-    ttk::frame $w.fopening.fOpeningList -relief raised -borderwidth 1
-    listbox $w.fopening.fOpeningList.lbOpening -yscrollcommand "$w.fopening.fOpeningList.ybar set" \
-        -height 5 -width 50 -list ::tacgame::openingList -exportselection 0
+    ttk::frame $w.fopening.fOpeningList
+    ttk::treeview $w.fopening.fOpeningList.lbOpening -columns {0} -show {} -selectmode browse \
+        -yscrollcommand "$w.fopening.fOpeningList.ybar set"
+    $w.fopening.fOpeningList.lbOpening column 0 -width 250
+    $w.fopening.fOpeningList.lbOpening configure -height 5
+    set idx 0
+    foreach o $::tacgame::openingList {
+        $w.fopening.fOpeningList.lbOpening insert {} end -id $idx -values [list $o]
+        incr idx
+    }
+
     $w.fopening.fOpeningList.lbOpening selection set $::sergame::chosenOpening
     $w.fopening.fOpeningList.lbOpening see $::sergame::chosenOpening
     
     ttk::scrollbar $w.fopening.fOpeningList.ybar -command "$w.fopening.fOpeningList.lbOpening yview"
-    pack $w.fopening.fOpeningList.lbOpening -side right -fill both -expand 1
     pack $w.fopening.fOpeningList.ybar -side right -fill y
+    pack $w.fopening.fOpeningList.lbOpening -side left -fill both -expand 1
+    pack $w.fopening.fOpeningList -fill both -side top
     pack $w.fopening.cbOpening -fill x -side top
-    pack $w.fopening.fOpeningList -expand yes -fill both -side top -expand 1
     
     ttk::button $w.fbuttons.close -text $::tr(Play) -command {
       focus .
-      set ::sergame::chosenEngine [.configSerGameWin.fengines.fEnginesList.lbEngines curselection]
-      set ::sergame::engineName [.configSerGameWin.fengines.fEnginesList.lbEngines get $::sergame::chosenEngine]
-      set ::sergame::chosenOpening [.configSerGameWin.fopening.fOpeningList.lbOpening curselection]
+      set ::sergame::chosenEngine [.configSerGameWin.fengines.fEnginesList.lbEngines selection]
+      set ::sergame::engineName [.configSerGameWin.fengines.fEnginesList.lbEngines set $::sergame::chosenEngine 0]
+      set ::sergame::chosenOpening [.configSerGameWin.fopening.fOpeningList.lbOpening selection]
       if {$::sergame::useBook} {
-        set ::sergame::bookToUse [.configSerGameWin.fbook.combo get]
+        set ::sergame::bookToUse [.configSerGameWin.fconfig.combo get]
         if {$::sergame::bookToUse == "" } {
           set ::sergame::useBook 0
         }
@@ -239,20 +249,19 @@ namespace eval sergame {
       set ::uci::uciInfo(fixeddepth3) [.configSerGameWin.ftime.depth.value get]
       set ::uci::uciInfo(fixednodes3) [expr [.configSerGameWin.ftime.nodes.value get]*1000]
       set ::uci::uciInfo(movetime3) [expr [.configSerGameWin.ftime.movetime.value get]*1000]
-      
+
       destroy .configSerGameWin
       ::sergame::play $::sergame::chosenEngine
     }
     ttk::button $w.fbuttons.cancel -textvar ::tr(Cancel) -command "focus .; destroy $w"
     
-    pack $w.fbuttons.close $w.fbuttons.cancel -expand yes -side left
-    
+    packbuttons right $w.fbuttons.cancel $w.fbuttons.close
     bind $w <Escape> { .configSerGameWin.fbuttons.cancel invoke }
     bind $w <Return> { .configSerGameWin.fbuttons.close invoke }
     bind $w <F1> { helpWindow SeriousGame }
     bind $w <Destroy> ""
     bind $w <Configure> "recordWinSize $w"
-    wm minsize $w 45 0
+    wm resizable $w 0 0
   }
   
   ################################################################################
@@ -262,11 +271,18 @@ namespace eval sergame {
     global ::sergame::chosenOpening ::sergame::isOpening ::tacgame::openingList ::sergame::openingMovesList \
         ::sergame::openingMovesHash ::sergame::openingMoves ::sergame::outOfOpening
     
+    if {$::sergame::isOpening || !$::sergame::startFromCurrent} {
+      if {[::game::Clear] eq "cancel"} { return }
+    }
+
     set ::sergame::lFen {}
     
     ::uci::startEngine $::sergame::engineListBox($engine) $n
     set engineData [lindex $::engines(list) $::sergame::engineListBox($engine)]
-    ::uci::sendUCIoptions $n [ lindex $engineData 8 ]
+    foreach {option} [lindex $engineData 8] {
+      array set ::uciOptions$n $option
+    }
+    ::uci::sendUCIoptions $n
     
     set ::uci::uciInfo(prevscore$n) 0.0
     set ::uci::uciInfo(score$n) 0.0
@@ -300,94 +316,105 @@ namespace eval sergame {
         lappend openingMovesList [string trim [regsub {^[1-9]+\.} $p ""] ]
       }
       
-      sc_game new
       lappend openingMovesHash [sc_pos hash]
       foreach m  $openingMovesList {
         if {[catch {sc_move addSan $m}]} { }
         lappend openingMovesHash [sc_pos hash]
       }
     }
+
+    # Engine plays for the upper side
+    if {[::board::isFlipped .main.board]} {
+      set ::sergame::playerColor "black"
+      set ::sergame::engineColor "white"
+    } else {
+      set ::sergame::playerColor "white"
+      set ::sergame::engineColor "black"
+    }
+
     if {!$::sergame::startFromCurrent} {
       # create a new game if a DB is opened
-      sc_game new
       sc_game tags set -event "Serious game"
-      if { [::board::isFlipped .main.board] } {
-        sc_game tags set -white "$::sergame::engineName"
-      } else  {
-        sc_game tags set -black "$::sergame::engineName"
-      }
+      sc_game tags set -$::sergame::playerColor "Player"
+      sc_game tags set -$::sergame::engineColor "$::sergame::engineName"
       sc_game tags set -date [::utils::date::today]
-      if {[sc_base inUse [sc_base current]]} { catch {sc_game save 0}  }
     }
-    
-    updateBoard -pgn
-    ::windows::gamelist::Refresh
-    updateTitle
-    set w ".serGameWin"
-    if {[winfo exists $w]} {
-      focus .
-      destroy $w
-      return
-    }
-    
-    createToplevel $w
-    setTitle $w "$::tr(coachgame) ($::sergame::engineName)"
-    
-    setWinLocation $w
-    
-    ttk::frame $w.fclocks -relief raised -borderwidth 1
-    ttk::frame $w.fbuttons
-    
-    ::gameclock::new $w.fclocks 2 80 1
-    ::gameclock::new $w.fclocks 1 80 1
-    ::gameclock::reset 1
-    ::gameclock::start 1
-    
-    ttk::button $w.fbuttons.close -textvar ::tr(Abort) -command "destroy .serGameWin"
-    pack $w.fbuttons.close -expand yes
-    
-    pack $w.fclocks -side top -expand yes -fill both
-    pack $w.fbuttons -side top -expand yes -fill both
-    
-    bind $w <F1> { helpWindow TacticalGame }
-    bind $w <Destroy> "if {\[string equal $w %W\]} {::sergame::abortGame}"
-    bind $w <Escape> "destroy .serGameWin"
-    bind $w <Configure> "recordWinSize $w"
-    wm minsize $w 45 0
-    createToplevelFinalize $w
 
-    # setup clocks
-    if { [::sergame::getEngineColor] == "white" } {
-      ::gameclock::setSec 2 [expr 0 - $::uci::uciInfo(wtime$n)/1000]
-      ::gameclock::setSec 1 [expr 0 - $::uci::uciInfo(btime$n)/1000]
-    } else  {
-      ::gameclock::setSec 1 [expr 0 - $::uci::uciInfo(wtime$n)/1000]
-      ::gameclock::setSec 2 [expr 0 - $::uci::uciInfo(btime$n)/1000]
-    }
-    
-    set ::playMode "::sergame::callback"
+    set ::sergame::waitPlayerMove 0
     set ::sergame::wentOutOfBook 0
+    set ::playMode "::sergame::callback"
+    ::notify::GameChanged
+
+    clocks init $n
+    clocks start
+
     ::sergame::engineGo $n
   }
 
   proc callback {cmd} {
     switch $cmd {
-        stop { destroy .serGameWin }
+        stop { ::sergame::abortGame }
     }
     return 0
   }
 
   proc abortGame { { n 3 } } {
     unset ::playMode
-    set ::sergame::lFen {}
-    if { $::uci::uciInfo(pipe$n) == ""} { return }
     after cancel ::sergame::engineGo $n
-    ::uci::closeUCIengine $n
-    ::gameclock::stop 1
-    ::gameclock::stop 2
-    set ::uci::uciInfo(bestmove$n) "abort"
+    clocks stop
+    set ::sergame::lFen {}
+    if { $::uci::uciInfo(pipe$n) != ""} {
+      ::uci::closeUCIengine $n
+      set ::uci::uciInfo(bestmove$n) "abort"
+    }
     ::notify::GameChanged
   }
+
+  proc clocks {cmd {n 3}} {
+    if {$::sergame::timeMode != "timebonus"} { return }
+
+    switch $cmd {
+      init {
+          ::gameclock::new "" 1
+          ::gameclock::new "" 2
+          ::gameclock::setSec 1 [expr 0 - $::uci::uciInfo(wtime$n)/1000]
+          ::gameclock::setSec 2 [expr 0 - $::uci::uciInfo(btime$n)/1000]
+      }
+      start {
+          if { [sc_pos side] == "white" } {
+            ::gameclock::start 1
+          } else {
+            ::gameclock::start 2
+          }
+      }
+      stop {
+          ::gameclock::stop 1
+          ::gameclock::stop 2
+      }
+      toggle {
+          if {[::gameclock::stop 1]} {
+            ::gameclock::add 1 [expr $::uci::uciInfo(winc$n)/1000]
+            ::gameclock::storeTimeComment 1
+            ::gameclock::start 2
+          } elseif {[::gameclock::stop 2]} {
+            ::gameclock::add 2 [expr $::uci::uciInfo(binc$n)/1000]
+            ::gameclock::storeTimeComment 2
+            ::gameclock::start 1
+          }
+          ::notify::PosChanged -pgn
+      }
+    }
+  }
+
+  proc takeBack {takebackClockW takebackClockB} {
+    sc_move back 1
+    if {$takebackClockW != ""} {
+      ::gameclock::setSec 1 [expr 0 - $takebackClockW]
+      ::gameclock::setSec 2 [expr 0 - $takebackClockB]
+      clocks start
+    }
+    ::notify::PosChanged -pgn
+  }
   
   ################################################################################
   #
@@ -402,8 +429,7 @@ namespace eval sergame {
   proc endOfGame {} {
     set move_done [sc_game info previousMove]
     if { [string index [sc_game info previousMove] end ] == "#"} {
-      ::gameclock::stop 1
-      ::gameclock::stop 2
+      clocks stop
       return 1
     }
     return 0
@@ -419,22 +445,24 @@ namespace eval sergame {
     
     if { [::sergame::endOfGame] } { return }
     
-    if { [sc_pos side] != [::sergame::getEngineColor] } {
+    if { [sc_pos side] != $::sergame::engineColor } {
+      set ::sergame::waitPlayerMove 1
       after 1000 ::sergame::engineGo $n
       return
     }
     
-    # The player moved : add clock time
-    if {!([::sergame::getEngineColor] == "black" && [sc_pos moveNumber] == 1)} {
-      if { [::sergame::getEngineColor] == "white" } {
-        ::gameclock::add 1 [expr $::uci::uciInfo(binc$n)/1000]
-      } else  {
-        ::gameclock::add 1 [expr $::uci::uciInfo(winc$n)/1000]
+    set takebackClockW ""
+    set takebackClockB ""
+    if {$::sergame::waitPlayerMove} {
+      # The player moved
+      set ::sergame::waitPlayerMove 0
+      if {$::sergame::timeMode == "timebonus"} {
+        set takebackClockW [::gameclock::getSec 1]
+        set takebackClockB [::gameclock::getSec 2]
+        clocks toggle $n
       }
+      repetition
     }
-    ::gameclock::stop 1
-    ::gameclock::start 2
-    repetition
     
     # make a move corresponding to a specific opening, (it is engine's turn)
     if {$isOpening && !$outOfOpening} {
@@ -447,18 +475,17 @@ namespace eval sergame {
         }
         
         if { [lsearch $openingMovesHash [sc_pos hash]] == -1 && [llength $openingMovesList] >= $ply} {
+          clocks stop
           set answer [tk_messageBox -icon question -parent .main -title $::tr(OutOfOpening) -type yesno \
               -message "$::tr(NotFollowedLine) $openingMoves\n $::tr(DoYouWantContinue)" ]
           if {$answer == no} {
-            sc_move back 1
-            updateBoard -pgn
-            ::gameclock::stop 2
-            ::gameclock::start 1
+            takeBack $takebackClockW $takebackClockB
             after 1000 ::sergame::engineGo $n
             return
           }  else  {
             set outOfOpening 1
           }
+          clocks start
         }
       }
       
@@ -485,15 +512,9 @@ namespace eval sergame {
             sc_move forward 1
           }
           
+          clocks toggle $n
           updateBoard -pgn -animate
-          ::gameclock::stop 2
-          ::gameclock::start 1
           repetition
-          if { [::sergame::getEngineColor] == "white" } {
-            ::gameclock::add 2 [expr $::uci::uciInfo(winc$n)/1000]
-          } else  {
-            ::gameclock::add 2 [expr $::uci::uciInfo(binc$n)/1000]
-          }
           after 1000 ::sergame::engineGo $n
           return
         }
@@ -510,17 +531,9 @@ namespace eval sergame {
         ::utils::sound::AnnounceNewMove $move
         # we made a book move so assume a score = 0
         set ::uci::uciInfo(prevscore$n) 0.0
+        clocks toggle $n
         updateBoard -pgn -animate
-        ::gameclock::stop 2
-        ::gameclock::start 1
         repetition
-        if {$timeMode == "timebonus"} {
-          if { [::sergame::getEngineColor] == "white" } {
-            ::gameclock::add 2 [expr $::uci::uciInfo(winc$n)/1000]
-          } else  {
-            ::gameclock::add 2 [expr $::uci::uciInfo(binc$n)/1000]
-          }
-        }
         after 1000 ::sergame::engineGo $n
         return
       }
@@ -539,14 +552,9 @@ namespace eval sergame {
       ::sergame::sendToEngine $n "isready"
       vwait ::analysis(waitForReadyOk$n)
       ::sergame::sendToEngine $n "position fen [sc_pos fen]"
-      if { [::sergame::getEngineColor] == "white" } {
-        set wtime [expr [::gameclock::getSec 2] * 1000 ]
-        set btime [expr [::gameclock::getSec 1] * 1000 ]
-      } else  {
+      if {$timeMode == "timebonus"} {
         set wtime [expr [::gameclock::getSec 1] * 1000 ]
         set btime [expr [::gameclock::getSec 2] * 1000 ]
-      }
-      if {$timeMode == "timebonus"} {
         ::sergame::sendToEngine $n "go wtime $wtime btime $btime winc $::uci::uciInfo(winc$n) binc $::uci::uciInfo(binc$n)"
       } elseif {$timeMode == "depth"} {
         ::sergame::sendToEngine $n "go depth $::uci::uciInfo(fixeddepth$n)"
@@ -565,18 +573,18 @@ namespace eval sergame {
     if { $::sergame::coachIsWatching && $::uci::uciInfo(prevscore$n) != "" } {
       set blunder 0
       set delta [expr $::uci::uciInfo(score$n) - $::uci::uciInfo(prevscore$n)]
-      if {$delta > $::informant("?!") && [getEngineColor] == "white" ||
-        $delta < [expr 0.0 - $::informant("?!")] && [getEngineColor] == "black" } {
+      if {$delta > $::informant("?!") && $::sergame::engineColor == "white" ||
+        $delta < [expr 0.0 - $::informant("?!")] && $::sergame::engineColor == "black" } {
         set blunder 1
       }
       
-      if {$delta > $::informant("?") && [getEngineColor] == "white" ||
-        $delta < [expr 0.0 - $::informant("?")] && [getEngineColor] == "black" } {
+      if {$delta > $::informant("?") && $::sergame::engineColor == "white" ||
+        $delta < [expr 0.0 - $::informant("?")] && $::sergame::engineColor == "black" } {
         set blunder 2
       }
       
-      if {$delta > $::informant("??") && [getEngineColor] == "white" ||
-        $delta < [expr 0.0 - $::informant("??")] && [getEngineColor] == "black" } {
+      if {$delta > $::informant("??") && $::sergame::engineColor == "white" ||
+        $delta < [expr 0.0 - $::informant("??")] && $::sergame::engineColor == "black" } {
         set blunder 3
       }
       
@@ -589,15 +597,14 @@ namespace eval sergame {
       }
       
       if {$blunder != 0} {
+        clocks stop
         set answer [tk_messageBox -icon question -parent .main -title "Scid" -type yesno -message $::tr($tBlunder) ]
         if {$answer == yes} {
-          sc_move back 1
-          updateBoard -pgn
-          ::gameclock::stop 2
-          ::gameclock::start 1
+          takeBack $takebackClockW $takebackClockB
           after 1000 ::sergame::engineGo $n
           return
         }
+        clocks start
       }
     }
     
@@ -609,30 +616,19 @@ namespace eval sergame {
     ::uci::sc_move_add $::uci::uciInfo(bestmove$n)
     ::utils::sound::AnnounceNewMove $::uci::uciInfo(bestmove$n)
     set ::uci::uciInfo(prevscore$n) $::uci::uciInfo(score$n)
+    if { $::sergame::storeEval == 1 } {
+      storeEvalComment $::uci::uciInfo(score$n)
+    }
     updateBoard -pgn -animate
     repetition
     
-    # add time after a move played
-    if {$timeMode == "timebonus"} {
-      if { [::sergame::getEngineColor] == "white" } {
-        ::gameclock::add 2 [expr $::uci::uciInfo(winc$n)/1000]
-      } else  {
-        ::gameclock::add 2 [expr $::uci::uciInfo(binc$n)/1000]
-      }
-    }
-    ::gameclock::stop 2
-    ::gameclock::start 1
-    
+    clocks toggle $n
+
     # ponder mode (the engine just played its move)
     if {$::sergame::ponder && $::uci::uciInfo(ponder$n) != ""} {
       ::sergame::sendToEngine $n "position fen [sc_pos fen] moves $::uci::uciInfo(ponder$n)"
-      if { [::sergame::getEngineColor] == "white" } {
-        set wtime [expr [::gameclock::getSec 2] * 1000 ]
-        set btime [expr [::gameclock::getSec 1] * 1000 ]
-      } else  {
-        set wtime [expr [::gameclock::getSec 1] * 1000 ]
-        set btime [expr [::gameclock::getSec 2] * 1000 ]
-      }
+      set wtime [expr [::gameclock::getSec 1] * 1000 ]
+      set btime [expr [::gameclock::getSec 2] * 1000 ]
       if {$timeMode == "timebonus"} {
         ::sergame::sendToEngine $n "go ponder wtime $wtime btime $btime winc $::uci::uciInfo(winc$n) binc $::uci::uciInfo(binc$n)"
       } elseif {$timeMode == "depth"} {
@@ -664,18 +660,6 @@ namespace eval sergame {
     }
     return 0
   }
-  ################################################################################
-  #
-  ################################################################################
-  proc getEngineColor {} {
-    # Engine always plays for the upper side
-    if { [::board::isFlipped .main.board] == 0 } {
-      return "black"
-    } else  {
-      return "white"
-    }
-  }
-  
   ################################################################################
   #
   ################################################################################
