@@ -124,7 +124,8 @@ namespace eval uci {
             } else {
                 set uciInfo(ponder$n) ""
             }
-            set analysis(waitForBestMove$n) 0
+            after cancel "::uci::onReady_ $n"
+            ::uci::onReady_ $n
             return
         }
         
@@ -296,7 +297,8 @@ namespace eval uci {
         
         # the UCI engine answers to <isready> command
         if { $line == "readyok"} {
-            set analysis(waitForReadyOk$n) 0
+            after cancel "::uci::onReady_ $n"
+            ::uci::onReady_ $n
             return
         }
         
@@ -642,22 +644,90 @@ namespace eval uci {
         
         ::enginelist::write
     }
-    ################################################################################
-    # The engine replied readyok, so it's time to configure it (sends the options to the engine)
-    # It seems necessary to ask first if engine is ready
-    ################################################################################
-    proc sendUCIoptions { n uci_options} {
-        global analysis
-        foreach opt $uci_options {
-            set name [lindex $opt 0]
-            set value [lindex $opt 1]
-            set analysis(waitForReadyOk$n) 1
+
+    # Send the options in the array ::uciOptions$n to the engine.
+    # If the engine is analyzing, send "stop" and wait for "bestmove" (max 5 sec).
+    # Send "isready" after the options.
+    proc sendUCIoptions {n} {
+        ::uci::sendStop $n
+        ::uci::whenReady $n [list ::uci::sendOptions_ $n] 5000
+    }
+
+    # Send the current position and "go" to the engine.
+    # If the engine is analyzing, send "stop" and wait for "bestmove".
+    # Send the position when the engine is ready, or after 5 seconds send it anyway.
+    proc sendPositionGo {n go_time} {
+        ::uci::sendStop $n
+        ::uci::whenReady $n [list ::uci::sendPositionGo_ $n $go_time] 5000
+    }
+
+    # If the engine is analyzing, send "stop" to ask it to stop as soon as possible.
+    proc sendStop {n} {
+        if {[info exists ::analysis(thinking$n)] && ! $::analysis(waitForBestMove$n)} {
+            set ::analysis(waitForBestMove$n) 1
+            ::sendToEngine $n "stop"
+        }
+        set ::analysis(fen$n) {}
+    }
+
+    # Send "isready" if we are not already waiting for "readyok".
+    proc sendIsReady {n} {
+        if { ! $::analysis(waitForReadyOk$n) } {
+            set ::analysis(waitForReadyOk$n) 1
             ::sendToEngine $n "isready"
-            vwait analysis(waitForReadyOk$n)
-            ::sendToEngine $n "setoption name $name value $value"
-            if { $name == "MultiPV" } { set analysis(multiPVCount$n) $value }
         }
     }
+
+    # Execute $cmd when the engine is ready (not waiting for bestmove or readyok).
+    proc whenReady {n cmd {max_wait -1}} {
+        if { $::analysis(waitForBestMove$n) || $::analysis(waitForReadyOk$n) } {
+            set idx [lsearch  -index 0 $::analysis(whenReady$n) [lindex $cmd 0]]
+            if {$idx == -1} {
+                lappend ::analysis(whenReady$n) $cmd
+            } else {
+                lreplace $::analysis(whenReady$n) $idx $idx $cmd
+            }
+            if {$max_wait > 0} {
+                after cancel "::uci::onReady_ $n"
+                after $max_wait "::uci::onReady_ $n"
+            }
+        } else {
+            eval {*}$cmd
+        }
+    }
+
+    proc sendOptions_ {n} {
+        if {[array exists ::uciOptions$n]} {
+            foreach {name value} [array get ::uciOptions$n] {
+                ::sendToEngine $n "setoption name $name value $value"
+                if { $name == "MultiPV" } { set ::analysis(multiPVCount$n) $value }
+            }
+            array unset ::uciOptions$n
+
+            ::uci::sendIsReady $n
+        }
+    }
+
+    proc sendPositionGo_ {engine_n time} {
+        set ::analysis(thinking$engine_n) 1
+        ::sendToEngine $engine_n "$::analysis(movelist$engine_n)"
+        ::sendToEngine $engine_n "go $time"
+    }
+
+    proc onReady_ {n} {
+        unset -nocomplain ::analysis(thinking$n)
+        set ::analysis(waitForBestMove$n) 0
+        set ::analysis(waitForReadyOk$n) 0
+        while { [llength $::analysis(whenReady$n)] } {
+            set cmd [lindex $::analysis(whenReady$n) 0]
+            set ::analysis(whenReady$n) [lrange $::analysis(whenReady$n) 1 end]
+            eval {*}$cmd
+            if { $::analysis(waitForReadyOk$n) || \
+                 $::analysis(waitForBestMove$n) || \
+                 [info exists ::analysis(thinking$n)] } {  break }
+        }
+    }
+
     ################################################################################
     # will start an engine for playing (not analysis)
     ################################################################################
@@ -797,14 +867,12 @@ namespace eval uci {
             set s2 [::board::sq $s2]
             if {[string length $m] > 4} {
                 set promo [string range $m 4 end]
-                # inverse transformation : const char PIECE_CHAR [] = "xKQRBNP.xkqrbnpxMm";
-                # it seems capitalisation does not matter (see addMove proc in main.tcl)
                 switch -- $promo {
                     q { set p 2}
                     r { set p 3}
                     b { set p 4}
                     n { set p 5}
-                    default {puts "Promo error $promo for moves $moves"}
+                    default { return 1 }
                 }
                 if { [catch { sc_move add $s1 $s2 $p } ] } { return 1 }
             } else  {
