@@ -83,62 +83,30 @@ proc ::windows::gamelist::DatabaseModified {{dbase} {filter -1}} {
 		if {$::gamelistBase($w) == $dbase} {
 			if {$filter == -1} {
 				::windows::gamelist::update_ $w 0
+				::windows::gamelist::updateStats_ $w
 			} elseif {$filter == $::gamelistFilter($w) || \
-			          $filter == [sc_filter compose $::gamelistBase($w) $::gamelistFilter($w) ""]} {
+			          [lsearch -exact [sc_filter components $::gamelistBase($w) $::gamelistFilter($w)] $filter] != -1} {
 				::windows::gamelist::update_ $w 1
+				::windows::gamelist::updateStats_ $w
 			}
-			::windows::gamelist::updateStats_ $w
 		}
 	}
 }
 
-proc ::windows::gamelist::PosMaskProgress {} {
-	update
-	if { $::gamelistUpdating != 1 } { break }
-}
-
-proc ::windows::gamelist::PosChanged {{wlist ""}} {
-	if { [info exists ::gamelistUpdating] } {
-		incr ::gamelistUpdating
-		return
-	}
-	set ::gamelistUpdating 1
-
+# Returns the list of databases whose tree filter needs to be updated when
+# the position of the main board changes.
+# It must also disable commands that depend on the current position.
+proc ::windows::gamelist::listTreeBases {{base ""}} {
 	set bases {}
-	if {$wlist == ""} { set wlist $::windows::gamelist::wins }
-	foreach w $wlist {
-		if { $::gamelistPosMask($w) != 0 } {
+	foreach w $::windows::gamelist::wins {
+		if { $::gamelistPosMask($w) != 0 && ($base == "" || $base == $::gamelistBase($w)) } {
 			$w.games.glist tag configure fsmall -foreground #bababa
 			$w.buttons.boardFilter configure -image tb_BoardMaskBusy
-			if { [lsearch -exact $bases $::gamelistBase($w)] == -1 } {
-				lappend bases $::gamelistBase($w)
-			}
+			set progressbar "$w.progress 100 100"
+			lappend bases [list $::gamelistBase($w) $::gamelistFilter($w) $progressbar]
 		}
 	}
-
-	foreach base $bases {
-		update idletasks
-		#TODO: [sc_filter release $base $f]
-		set f [sc_filter new $base FEN]
-		if { $::gamelistUpdating != 1 } {
-			after idle {
-				unset ::gamelistUpdating
-				::windows::gamelist::PosChanged
-			}
-			return
-		}
-		if {$f != ""} {
-			foreach w $::windows::gamelist::wins {
-				if { $::gamelistBase($w) == $base && $::gamelistPosMask($w) != 0 } {
-					$w.games.glist tag configure fsmall -foreground ""
-					$w.buttons.boardFilter configure -image tb_BoardMask
-					set ::gamelistFilter($w) [sc_filter compose $::gamelistBase($w) $::gamelistFilter($w) $f]
-					::notify::DatabaseModified $base $::gamelistFilter($w)
-				}
-			}
-		}
-	}
-	unset ::gamelistUpdating
+	return $bases
 }
 
 proc ::windows::gamelist::FilterReset {{w} {base}} {
@@ -213,14 +181,13 @@ proc ::windows::gamelist::SetBase {{w} {base} {filter "dbfilter"}} {
 	after idle "::windows::gamelist::filterRelease_ $::gamelistBase($w) $::gamelistFilter($w)"
 	set ::gamelistBase($w) $base
 	set ::gamelistFilter($w) $filter
-	busyCursor $w
-	update idletasks
 	if { $::gamelistPosMask($w) != 0 } {
-		::windows::gamelist::PosChanged $w
+		#hack: set gamelistPosMask to trick searchpos_
+		set ::gamelistPosMask($w) 0
+		::windows::gamelist::searchpos_ $w
 	} else {
 		::windows::gamelist::DatabaseModified $::gamelistBase($w) $::gamelistFilter($w)
 	}
-	unbusyCursor $w
 }
 
 #Examples
@@ -452,6 +419,9 @@ proc ::windows::gamelist::createWin_ { {w} {base} {filter} } {
 		if {$idx != -1} { set ::glist_Sort(ly$w) [lindex $::recentSort [expr $idx +1]] }
 	}
 	::windows::gamelist::createGList_ $w
+	#TODO:
+	canvas $w.progress
+
 	grid rowconfigure $w 0 -weight 1
 	grid columnconfigure $w 0 -weight 0
 	grid columnconfigure $w 1 -weight 0
@@ -536,7 +506,7 @@ proc ::windows::gamelist::createMenu_ {w} {
 	grid $w.stats.b -sticky news
 	grid rowconfigure $w.stats 0 -weight 1
 	grid columnconfigure $w.stats 0 -weight 1
-	autoscrollframe -bars y $w.stats.b canvas $w.stats.b.c -highlightthickness 0 -background white
+	autoscrollframe -bars y $w.stats.b ttk_canvas $w.stats.b.c -highlightthickness 0
 }
 
 proc ::windows::gamelist::createGList_ {{w}} {
@@ -544,19 +514,23 @@ proc ::windows::gamelist::createGList_ {{w}} {
 	ttk::frame $w.games -borderwidth 0 -padding {8 5 5 2}
 	glist.create $w.games "ly$w"
 	grid $w.games -row 0 -column 2 -sticky news
+	# TODO: always show the find bar instead of toggling between show/hide
+	bind [winfo toplevel $w] <Control-f> "
+		event generate $w.buttons.filter <<Invoke>>
+	"
 }
 
 proc ::windows::gamelist::menu_ {{w} {button}} {
 	if {$::gamelistMenu($w) != ""} {
 		$w.buttons.$::gamelistMenu($w) state !pressed
 		grid forget $w.$::gamelistMenu($w)
-		if {$button == "filter"} { event generate $w.games.find.hide <ButtonPress-1> }
+		if {$button == "filter"} { event generate $w.games <<FindBarHide>> }
 	}
 	if {$::gamelistMenu($w) != $button} {
 		$w.buttons.$button state pressed
 		set ::gamelistMenu($w) $button
 		grid $w.$button -row 0 -column 1 -sticky news
-		if {$button == "filter"} { event generate $w <Control-f> }
+		if {$button == "filter"} { event generate $w.games <<FindBarShow>> }
 	} else {
 		set ::gamelistMenu($w) ""
 	}
@@ -576,7 +550,10 @@ proc ::windows::gamelist::filter_ {{w} {type}} {
 
 proc ::windows::gamelist::update_ {{w} {moveUp}} {
 	set f $::gamelistFilter($w)
-	foreach {filterSz gameSz mainSz} [sc_filter sizes $::gamelistBase($w) $f] {}
+	lassign [sc_filter sizes $::gamelistBase($w) $f] filterSz gameSz mainSz
+
+	$w.games.glist tag configure fsmall -foreground ""
+	$w.buttons.boardFilter configure -image tb_BoardMask
 
 	if {$gameSz == $mainSz} {
 		$w.buttons.filter configure -image tb_search_on
@@ -598,13 +575,13 @@ proc ::windows::gamelist::searchpos_ {{w}} {
 	if {$::gamelistPosMask($w) == 0} {
 		set ::gamelistPosMask($w) 1
 		$w.buttons.boardFilter state pressed
-		::windows::gamelist::PosChanged $w
+		set ::gamelistFilter($w) [sc_filter compose $::gamelistBase($w) $::gamelistFilter($w) "tree"]
+		::updateTreeFilter $::gamelistBase($w)
 	} else {
 		set ::gamelistPosMask($w) 0
 		$w.buttons.boardFilter state !pressed
 		set ::gamelistFilter($w) [sc_filter compose $::gamelistBase($w) $::gamelistFilter($w) ""]
-		$w.games.glist tag configure fsmall -foreground ""
-		$w.buttons.boardFilter configure -image tb_BoardMask
+		::cancelUpdateTreeFilter "$w.progress 100 100"
 		::notify::DatabaseModified $::gamelistBase($w) $::gamelistFilter($w)
 	}
 }
@@ -655,41 +632,35 @@ proc ::windows::gamelist::updateStats_ { {w} } {
 	$w.stats.b.c delete all
 	set i_add 0
 	foreach move $stats {
-		set performance [lindex $move 5]
-		set n_ratedgames [lindex $move 6]
-		set toMove [lindex $move 7]
+		lassign $move moveSAN n_totgames n_white n_draw	n_black	avgElo performance n_ratedgames toMove
+
 		set pColor "#707070"
 		set perfCmd ""
 		if { $n_ratedgames > 5 } {
-			if { $toMove == "B" } { set performance [expr { $performance * -1 }] }
-			set rate [expr { $performance / $n_ratedgames }]
-			if { $rate > 0.1 } { set pColor "#47a148" }
-			if { $rate < -0.1 } { set pColor "#f40000" }
-			#TODO:
-			set perfCmd "tk_messageBox -message \"$rate   ($performance / $n_ratedgames)\" "
+			set rate [expr { $performance - $avgElo }]
+			if { $rate > 150 } { set pColor "#47a148" }
+			if { $rate < -150 } { set pColor "#f40000" }
+			set perfCmd "tk_messageBox -message"
+			lappend perfCmd [format {Performance: %.0f (%+.0f)} $performance $rate]
 		}
 		$w.stats.b.c create rectangle 4 [expr { $line - $rectH }] $rectW [expr { $line -$rectB }] \
 		    -fill $pColor -outline "" -tag perf$i_add
 		$w.stats.b.c bind perf$i_add <ButtonPress-1> "$perfCmd"
 
-		set moveSAN [lindex $move 0]
 		$w.stats.b.c bind add$i_add <ButtonPress-1> "
 			if {\[addSanMove \{$moveSAN\}\] && \$::gamelistPosMask($w) == 0} {
 				$w.buttons.boardFilter invoke
 			}
 		"
 		if { $toMove == "B" } { set moveSAN "..$moveSAN" }
-		$w.stats.b.c create text [expr int($rectW*1.5)] $line -anchor sw \
-		    -text $moveSAN -fill black -font font_Regular -tag add$i_add
+		ttk_create $w.stats.b.c text [expr int($rectW*1.5)] $line -anchor sw \
+		    -text $moveSAN -font font_Regular -tag add$i_add
 
 		incr i_add
-		$w.stats.b.c create text $moveW $line -anchor se \
-		    -text [lindex $move 1] -fill #707070 -font font_Italic
+		ttk_create $w.stats.b.c text $moveW $line -anchor se \
+		    -text $n_totgames -fill #707070 -font font_Italic
 		set barh1 [expr { $line - 2*$rectB }]
 		set barh2 [expr { $line - $rectB }]
-		set n_white [lindex $move 2]
-		set n_draw [lindex $move 3]
-		set n_black [lindex $move 4]
 		set n_tot [expr { $n_white + $n_draw + $n_black }]
 		if {$n_tot != 0} {
 			set p_white [expr { 100.0 * $n_white / $n_tot }]
@@ -714,12 +685,12 @@ proc ::windows::gamelist::updateStats_ { {w} } {
 
 			$w.stats.b.c create rectangle $barW $barh1 $loss $barh2
 
-			$w.stats.b.c create text [expr { $barW + $percW * 3 }] $barh1 \
-				-font font_Small -anchor se -fill black -text "$t_white"
-			$w.stats.b.c create text [expr { $barW + $percW * 6 }] $barh1 \
-				-font font_Small -anchor se -fill black -text "$t_draw"
-			$w.stats.b.c create text [expr { $barW + $percW * 9 }] $barh1 \
-				-font font_Small -anchor se -fill black -text "$t_black"
+			ttk_create $w.stats.b.c text [expr { $barW + $percW * 3 }] $barh1 \
+				-font font_Small -anchor se -text "$t_white"
+			ttk_create $w.stats.b.c text [expr { $barW + $percW * 6 }] $barh1 \
+				-font font_Small -anchor se -text "$t_draw"
+			ttk_create $w.stats.b.c text [expr { $barW + $percW * 9 }] $barh1 \
+				-font font_Small -anchor se -text "$t_black"
 		}
 
 		incr line $lineH
@@ -767,11 +738,6 @@ namespace eval ::glist_Ly {
 	proc New_ {w} {
 		set newLy $::gamelistNewLayout
 		Copy_ $newLy ly$w
-		options.save ::glist_ColOrder($newLy)
-		options.save ::glist_ColWidth($newLy)
-		options.save ::glist_ColAnchor($newLy)
-		options.save ::glist_Sort($newLy)
-		options.save ::glist_FindBar($newLy)
 		set replaced [lsearch -exact $::glist_Layouts $newLy]
 		if {$replaced == -1 }  { lappend ::glist_Layouts $newLy }
 		set ::gamelistNewLayout [::glist_Ly::createName_]
@@ -779,11 +745,6 @@ namespace eval ::glist_Ly {
 	}
 	proc Del_ {w idx} {
 		set old_layout [lindex $::glist_Layouts $idx]
-		options.save_cancel ::glist_ColOrder($old_layout)
-		options.save_cancel ::glist_ColWidth($old_layout)
-		options.save_cancel ::glist_ColAnchor($old_layout)
-		options.save_cancel ::glist_Sort($old_layout)
-		options.save_cancel ::glist_FindBar($old_layout)
   		set ::glist_Layouts [lreplace $::glist_Layouts $idx $idx]
 		::glist_Ly::UpdateAll_
 	}
@@ -842,7 +803,7 @@ proc glist.create {{w} {layout}} {
   }
 
   ttk::treeview $w.glist -style Gamelist.Treeview -columns $::glist_Headers -show headings -selectmode browse
-  $w.glist tag configure current -background lightSteelBlue
+  $w.glist tag configure current -background steelBlue
   $w.glist tag configure fsmall -font font_Small
   $w.glist tag configure deleted -foreground #a5a2ac
   menu $w.glist.header_menu
@@ -916,17 +877,15 @@ proc glist.create {{w} {layout}} {
 
   # Find widget
   ttk::frame $w.find
-  ttk::label $w.find.hide -image "tb_close hover tb_close_hover"
-  bind $w.find.hide <ButtonPress-1> "set ::glist_FindBar($layout) 0; glist.showfindbar_ $w.glist $layout"
   ttk::frame $w.find.t
   ttk::label $w.find.t_text -text $::tr(Search)
-  entry $w.find.text -width 20 -bg white
+  ttk::entry $w.find.text -width 20
   ttk::button $w.find.filter -image tb_search16 -command "glist.findgame_ $w awe"
   ttk::button $w.find.b1_text -image tb_down -command \
     "after cancel glist.findgame_ $w 1; after idle glist.findgame_ $w 1"
   ttk::button $w.find.b2_text -image tb_up -command \
     "after cancel glist.findgame_ $w 0; after idle glist.findgame_ $w 0"
-  bind $w.find.text <Escape> "set ::glist_FindBar($layout) 0; glist.showfindbar_ $w.glist $layout"
+  bind $w.find.text <Escape> "glist.showfindbar_ $w.glist $layout 0"
   bind $w.find.text <Return> "$w.find.filter invoke"
   bind $w.find.text <KeyPress-Down> "$w.find.b1_text invoke; break"
   bind $w.find.text <KeyPress-Up> "$w.find.b2_text invoke; break"
@@ -934,20 +893,20 @@ proc glist.create {{w} {layout}} {
   #TODO: set scale position when normal ybar is used
   ttk::scale $w.find.scale -command "glist.ybar_ $w.glist moveto"
   grid $w.find.t_text $w.find.text $w.find.filter $w.find.b2_text $w.find.b1_text -in $w.find.t -padx 2
-  grid $w.find.hide
   grid $w.find.t -row 0 -column 1 -padx 6
   grid $w.find.scale -row 0 -column 3 -sticky ew
   grid columnconfigure $w.find 3 -weight 1
   set ::glistFindBar($w.glist) $w.find
   glist.showfindbar_ $w.glist $layout
-  bind [winfo toplevel $w] <Control-f> "set ::glist_FindBar($layout) 1; glist.showfindbar_ $w.glist $layout"
+  bind $w <<FindBarHide>> "glist.showfindbar_ $w.glist $layout 0"
+  bind $w <<FindBarShow>> "glist.showfindbar_ $w.glist $layout 1"
 
   # On exit save layout in options.dat
-  options.save ::glist_ColOrder($layout)
-  options.save ::glist_ColWidth($layout)
-  options.save ::glist_ColAnchor($layout)
-  options.save ::glist_Sort($layout)
-  options.save ::glist_FindBar($layout)
+  options.save ::glist_ColOrder
+  options.save ::glist_ColWidth
+  options.save ::glist_ColAnchor
+  options.save ::glist_Sort
+  options.save ::glist_FindBar
 
   set ::glistLoaded($w.glist) 0
   set ::glistTotal($w.glist) 0
@@ -1049,7 +1008,10 @@ proc glist.loadvalues_ {{w}} {
   glist.ybarupdate_ $w
 }
 
-proc glist.showfindbar_ {{w} {layout}} {
+proc glist.showfindbar_ {{w} {layout} {show ""}} {
+  if {$show ne ""} {
+    set ::glist_FindBar($layout) $show
+  }
   if {$::glist_FindBar($layout) == 0} {
     grid forget $::glistFindBar($w)
     focus $w
@@ -1072,7 +1034,7 @@ proc glist.findgame_ {{w_parent} {dir}} {
   set w $w_parent.glist
   set w_entryT $w_parent.find.text
   set txt [$w_entryT get]
-  $w_entryT configure -bg white
+  $w_entryT configure -style {}
   if { $dir == "awe" } {
     ::windows::gamelist::Awesome [winfo toplevel $w_parent] "$txt"
     $w_entryT selection range 0 end
@@ -1096,7 +1058,7 @@ proc glist.findgame_ {{w_parent} {dir}} {
             $txt $gstart $dir]
   }
   if {$r == "none"} {
-    $w_entryT configure -bg red
+    $w_entryT configure -style Error.TEntry
   } else {
     if {$r >= [expr $::glistFirst($w) + $::glistVisibleLn($w)] || $r < $::glistFirst($w)} {
       set ::glistFirst($w) $r
@@ -1185,6 +1147,7 @@ proc glist.popupmenu_ {{w} {x} {y} {abs_x} {abs_y} {layout}} {
       if { [winfo exists $w.game_menu.merge] } { destroy $w.game_menu.merge }
       if { [winfo exists $w.game_menu.copy] } { destroy $w.game_menu.copy }
       if { [winfo exists $w.game_menu.filter] } { destroy $w.game_menu.filter }
+      if { [winfo exists $w.game_menu.export] } { destroy $w.game_menu.export }
       $w.game_menu delete 0 end
       #LOAD/BROWSE/MERGE GAME
       $w.game_menu add command -label $::tr(LoadGame) \
@@ -1195,28 +1158,13 @@ proc glist.popupmenu_ {{w} {x} {y} {abs_x} {abs_y} {layout}} {
          -command "mergeGame $::glistBase($w) $idx"
       menu $w.game_menu.merge
       menu $w.game_menu.copy
-      foreach i [sc_base list] {
-          if { $i == $::glistBase($w) || [sc_base isReadOnly $i] } { continue }
-          set fname [file tail [sc_base filename $i]]
-          $w.game_menu.merge add command -label "$i $fname" -command "::game::mergeInBase $::glistBase($w) $i $idx"
-          $w.game_menu.copy add command -label "$i $fname" \
-              -command "sc_base copygames $::glistBase($w) $idx $i; ::notify::DatabaseModified $i"
-      }
       $w.game_menu add cascade -label $::tr(GlistMergeGameInBase) -menu $w.game_menu.merge
       $w.game_menu add cascade -label $::tr(CopyGameTo) -menu $w.game_menu.copy
+      $w.game_menu add command -label [expr {[sc_base gameflag $::glistBase($w) $idx get del] ? $::tr(UndeleteGame) : $::tr(DeleteGame) }] \
+        -command "glist.delflag_ $w $idx; $w selection set {};"
 
-      #GOTO GAME
-      $w.game_menu add separator
-      $w.game_menu add checkbutton -variable ::glist_FindBar($layout) \
-                   -label $::tr(FindBar) -command "glist.showfindbar_ $w $layout"
-      if {$::glistBase($w) == [sc_base current] && [sc_game number] != 0} {
-        $w.game_menu add command -label $::tr(FindCurrentGame) -command "glist.findcurrentgame_ $w [sc_game number]"
-      } else {
-        $w.game_menu add command -label $::tr(FindCurrentGame) -state disabled
-      }
       $w.game_menu add separator
       menu $w.game_menu.filter
-      $w.game_menu.filter add command -label $::tr(Export) -command "::windows::gamelist::FilterExport [winfo toplevel $w]"
       $w.game_menu.filter add separator
       $w.game_menu.filter add command -label [tr SearchReset] \
         -command "::windows::gamelist::FilterReset [winfo toplevel $w] $::glistBase($w)"
@@ -1235,10 +1183,32 @@ proc glist.popupmenu_ {{w} {x} {y} {abs_x} {abs_y} {layout}} {
       $w.game_menu.filter add command -label $::tr(GlistUndeleteAllGames) \
         -command "sc_base gameflag $::glistBase($w) $::glistFilter($w) unset del; ::notify::DatabaseModified $::glistBase($w)"
       $w.game_menu add cascade -label $::tr(Filter) -menu $w.game_menu.filter
+      menu $w.game_menu.export
+      $w.game_menu.export add command -label [tr ToolsExpFilter] \
+        -command "::windows::gamelist::FilterExport [winfo toplevel $w]"
+      $w.game_menu.export add separator
+      $w.game_menu add cascade -label [tr CopyGames] -menu $w.game_menu.export
+
+      foreach i [sc_base list] {
+        if { $i == $::glistBase($w) || [sc_base isReadOnly $i] } { continue }
+        set fname [file tail [sc_base filename $i]]
+        $w.game_menu.merge add command -label "$i $fname" \
+          -command "::game::mergeInBase $::glistBase($w) $i $idx"
+        $w.game_menu.copy add command -label "$i $fname" \
+          -command "sc_base copygames $::glistBase($w) $idx $i; ::notify::DatabaseModified $i"
+        $w.game_menu.export add command -label "$i $fname" \
+          -command "::windows::gamelist::CopyGames [winfo toplevel $w] $::glistBase($w) $i"
+      }
+
       $w.game_menu add separator
-      set dellabel $::tr(DeleteGame)
-      if {[sc_base gameflag $::glistBase($w) $idx get del]} { set dellabel $::tr(UndeleteGame) }
-      $w.game_menu add command -label $dellabel -command "glist.delflag_ $w $idx; $w selection set {};"
+      $w.game_menu add checkbutton -variable ::glist_FindBar($layout) \
+                   -label $::tr(FindBar) -command "glist.showfindbar_ $w $layout"
+      if {$::glistBase($w) == [sc_base current] && [sc_game number] != 0} {
+        $w.game_menu add command -label $::tr(FindCurrentGame) -command "glist.findcurrentgame_ $w [sc_game number]"
+      } else {
+        $w.game_menu add command -label $::tr(FindCurrentGame) -state disabled
+      }
+
       tk_popup $w.game_menu $abs_x $abs_y
     }
   } else {
@@ -1433,126 +1403,126 @@ proc glist.release_ {{w} {x} {y} {layout}} {
   ttk::treeview::Release $w $x $y
 }
 
-image create bitmap ::glist_Arrows(0) -foreground blue -data {
+image create bitmap ::glist_Arrows(0) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x00, 0x03, 0x00, 0x02, 0x00, 0x02, 0x00, 0x02, 0x10, 0x02,
        0x38, 0x07, 0x7c, 0x00, 0xfe, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(1) -foreground blue -data {
+image create bitmap ::glist_Arrows(1) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x00, 0x03, 0x00, 0x02, 0x00, 0x02, 0x00, 0x02, 0xfe, 0x02,
        0x7c, 0x07, 0x38, 0x00, 0x10, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(2) -foreground blue -data {
+image create bitmap ::glist_Arrows(2) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x80, 0x03, 0x00, 0x04, 0x00, 0x04, 0x00, 0x02, 0x08, 0x01,
        0x9c, 0x07, 0x3e, 0x00, 0x7f, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(3) -foreground blue -data {
+image create bitmap ::glist_Arrows(3) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x80, 0x03, 0x00, 0x04, 0x00, 0x04, 0x00, 0x02, 0x7f, 0x01,
        0xbe, 0x07, 0x1c, 0x00, 0x08, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(4) -foreground blue -data {
+image create bitmap ::glist_Arrows(4) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x80, 0x03, 0x00, 0x04, 0x00, 0x04, 0x00, 0x03, 0x08, 0x04,
        0x9c, 0x07, 0x3e, 0x00, 0x7f, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(5) -foreground blue -data {
+image create bitmap ::glist_Arrows(5) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x80, 0x03, 0x00, 0x04, 0x00, 0x04, 0x00, 0x03, 0x7f, 0x04,
        0xbe, 0x03, 0x1c, 0x00, 0x08, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(6) -foreground blue -data {
+image create bitmap ::glist_Arrows(6) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x00, 0x02, 0x00, 0x03, 0x00, 0x03, 0x80, 0x02, 0x88, 0x07,
        0x1c, 0x02, 0x3e, 0x00, 0x7f, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(7) -foreground blue -data {
+image create bitmap ::glist_Arrows(7) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x00, 0x02, 0x00, 0x03, 0x00, 0x03, 0x80, 0x02, 0xff, 0x07,
        0x3e, 0x02, 0x1c, 0x00, 0x08, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(8) -foreground blue -data {
+image create bitmap ::glist_Arrows(8) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x80, 0x07, 0x80, 0x00, 0x80, 0x03, 0x00, 0x04, 0x08, 0x04,
        0x9c, 0x03, 0x3e, 0x00, 0x7f, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(9) -foreground blue -data {
+image create bitmap ::glist_Arrows(9) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x80, 0x07, 0x80, 0x00, 0x80, 0x03, 0x00, 0x04, 0x7f, 0x04,
        0xbe, 0x03, 0x1c, 0x00, 0x08, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(10) -foreground blue -data {
+image create bitmap ::glist_Arrows(10) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x00, 0x07, 0x80, 0x00, 0x80, 0x00, 0x80, 0x03, 0x88, 0x04,
        0x1c, 0x07, 0x3e, 0x00, 0x7f, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(11) -foreground blue -data {
+image create bitmap ::glist_Arrows(11) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x00, 0x07, 0x80, 0x01, 0x80, 0x00, 0x80, 0x07, 0xff, 0x04,
        0x3e, 0x03, 0x1c, 0x00, 0x08, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(12) -foreground blue -data {
+image create bitmap ::glist_Arrows(12) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x80, 0x07, 0x00, 0x04, 0x00, 0x02, 0x00, 0x02, 0x08, 0x02,
        0x1c, 0x01, 0x3e, 0x00, 0x7f, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(13) -foreground blue -data {
+image create bitmap ::glist_Arrows(13) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x80, 0x07, 0x00, 0x04, 0x00, 0x02, 0x00, 0x02, 0x7f, 0x02,
        0x3e, 0x01, 0x1c, 0x00, 0x08, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(14) -foreground blue -data {
+image create bitmap ::glist_Arrows(14) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x00, 0x03, 0x80, 0x04, 0x80, 0x04, 0x00, 0x03, 0x88, 0x04,
        0x9c, 0x07, 0x3e, 0x00, 0x7f, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(15) -foreground blue -data {
+image create bitmap ::glist_Arrows(15) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x00, 0x03, 0x80, 0x04, 0x80, 0x04, 0x00, 0x03, 0xff, 0x04,
        0xbe, 0x07, 0x1c, 0x00, 0x08, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(16) -foreground blue -data {
+image create bitmap ::glist_Arrows(16) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
        0x00, 0x00, 0x00, 0x03, 0x80, 0x04, 0x80, 0x07, 0x00, 0x04, 0x08, 0x06,
        0x9c, 0x03, 0x3e, 0x00, 0x7f, 0x00, 0x00, 0x00 };
 }
-image create bitmap ::glist_Arrows(17) -foreground blue -data {
+image create bitmap ::glist_Arrows(17) -foreground DodgerBlue3 -data {
     #define arrows_width 12
     #define arrows_height 10
     static unsigned char arrows_bits[] = {
