@@ -10,37 +10,7 @@ namespace eval ::tree {
   set scoreHighlight_WhiteExpectedScoreBonus 3.8 ; # on average white achieves a score of 53.8
   set scoreHighlight_Margin 3.0 ; # if +/- this value, something special happened
 }
-# ################################################################################
-proc ::tree::doConfigMenus { baseNumber  { lang "" } } {
-  if {! [winfo exists .treeWin$baseNumber]} { return }
-  if {$lang == ""} { set lang $::language }
-  set m .treeWin$baseNumber.menu
-  foreach idx {0 1 2 3 4} tag {File Mask Sort Opt Help} {
-    configMenuText $m $idx Tree$tag $lang
-  }
-  foreach idx {0 1 2 3 5 7 9} tag {FillWithBase FillWithGame SetCacheSize CacheInfo Graph Copy Close} {
-    configMenuText $m.file $idx TreeFile$tag $lang
-  }
-  foreach idx {0 1 2 3 4 5 6 7 8 9} tag {New Open OpenRecent Save Close FillWithGame FillWithBase Search Info Display} {
-    configMenuText $m.mask $idx TreeMask$tag $lang
-  }
-  foreach idx {0 1 2 3} tag {Alpha ECO Freq Score } {
-    configMenuText $m.sort $idx TreeSort$tag $lang
-  }
-  foreach idx {0 1} tag {Lock Training } {
-    configMenuText $m.opt $idx TreeOpt$tag $lang
-  }
-  foreach idx {0 1} tag {Tree Index} {
-    configMenuText $m.helpmenu $idx TreeHelp$tag $lang
-  }
-}
 
-# ################################################################################
-proc ::tree::ConfigMenus { { lang "" } } {
-  for {set i [sc_info limit bases] } {$i > 0} {incr i -1} {
-    ::tree::doConfigMenus $i $lang
-  }
-}
 ################################################################################
 proc ::tree::menuCopyToSelection { baseNumber } {
   clipboard clear
@@ -61,8 +31,6 @@ proc ::tree::make { { baseNumber -1 } {locked 0} } {
   set w .treeWin$baseNumber
   
   ::createToplevel .treeWin$baseNumber
-  setWinLocation $w
-  setWinSize $w
   
   # Set the tree window title now:
   ::setTitle $w "Scid: [tr WindowsTree] $baseNumber"
@@ -76,14 +44,10 @@ proc ::tree::make { { baseNumber -1 } {locked 0} } {
   set tree(allgames$baseNumber) 1
   
   bind $w <Destroy> "::tree::closeTree $baseNumber"
-  bind $w <F1> { helpWindow Tree } 
-  bind $w <Escape> "::tree::hideCtxtMenu $baseNumber ; .treeWin$baseNumber.buttons.stop invoke "
   
   # Bind left button to close ctxt menu:
   bind $w <ButtonPress-1> "::tree::hideCtxtMenu $baseNumber"
   
-  keyboardShortcuts $w
-  
   menu $w.menu
   ::setMenu $w $w.menu
   $w.menu add cascade -label TreeFile -menu $w.menu.file
@@ -95,12 +59,6 @@ proc ::tree::make { { baseNumber -1 } {locked 0} } {
     menu $w.menu.$i -tearoff 0
   }
   
-  #TODO: remove this
-  $w.menu.file add command -label TreeFileFillWithBase
-  set helpMessage($w.menu.file,0) TreeFileFillWithBase
-  $w.menu.file add command -label TreeFileFillWithGame
-  set helpMessage($w.menu.file,1) TreeFileFillWithGame
-  
   menu $w.menu.file.size
   foreach i { 250 500 1000 2000 5000 10000 } {
     $w.menu.file.size add radiobutton -label "$i" -value $i -variable ::tree::cachesize($baseNumber) -command "::tree::setCacheSize $baseNumber $i"
@@ -108,17 +66,11 @@ proc ::tree::make { { baseNumber -1 } {locked 0} } {
   
   $w.menu.file add cascade -menu $w.menu.file.size -label TreeFileSetCacheSize
   set helpMessage($w.menu.file,2) TreeFileSetCacheSize
-  
-  $w.menu.file add command -label TreeFileCacheInfo -command "::tree::getCacheInfo $baseNumber"
-  set helpMessage($w.menu.file,3) TreeFileCacheInfo
-  
-  $w.menu.file add separator
+
   $w.menu.file add command -label TreeFileGraph -command "::tree::graph $baseNumber 1"
   set helpMessage($w.menu.file,5) TreeFileGraph
-  $w.menu.file add separator
   $w.menu.file add command -label TreeFileCopy -command "::tree::menuCopyToSelection $baseNumber"
   set helpMessage($w.menu.file,7) TreeFileCopy
-  $w.menu.file add separator
   $w.menu.file add command -label TreeFileClose -command ".treeWin$baseNumber.buttons.close invoke"
   set helpMessage($w.menu.file,9) TreeFileClose
   
@@ -161,27 +113,20 @@ proc ::tree::make { { baseNumber -1 } {locked 0} } {
   $w.menu.opt add checkbutton -label TreeOptTraining -variable tree(training$baseNumber) -command "::tree::toggleTraining $baseNumber"
   set helpMessage($w.menu.opt,1) TreeOptTraining
   
-  $w.menu.opt add separator
-
   $w.menu.helpmenu add command -label TreeHelpTree -accelerator F1 -command {helpWindow Tree}
   $w.menu.helpmenu add command -label TreeHelpIndex -command {helpWindow Index}
   
-  ::tree::doConfigMenus $baseNumber
+  translateMenuLabels $w.menu
   
-  autoscrollframe $w.f text $w.f.tl \
-      -width $::winWidth(.treeWin) -height $::winHeight(.treeWin) -wrap none -selectbackground lightgrey -selectforeground black \
-      -font font_Fixed -foreground black -background white -setgrid 1 -exportselection 1
+  autoscrollText y $w.f $w.f.tl Treeview
+  $w.f.tl configure -wrap none  -setgrid 1 -exportselection 1 -font font_Fixed
   #define default tags
-  $w.f.tl tag configure greybg -background gray95
-  $w.f.tl tag configure whitebg -background white
-  $w.f.tl tag configure bluefg -foreground blue
+  $w.f.tl tag configure bluefg -foreground DodgerBlue3
   $w.f.tl tag configure greenfg -foreground SeaGreen
   $w.f.tl tag configure redfg -foreground red
   
   selection handle $w.f.tl "::tree::copyToSelection $baseNumber"
 
-  bind $w <Configure> "recordWinSize $w"
-
   ttk::frame $w.statusframe
   pack $w.statusframe -side bottom -fill x
   grid rowconfigure $w.statusframe 0 -weight 1
@@ -206,7 +151,7 @@ proc ::tree::make { { baseNumber -1 } {locked 0} } {
     set helpMessage($w.buttons.$b) $t
   }
   
-  dialogbutton $w.buttons.stop -textvar ::tr(Stop) -command { progressBarCancel }
+  dialogbutton $w.buttons.stop -textvar ::tr(Stop)
   dialogbutton $w.buttons.close -textvar ::tr(Close) -command "::tree::closeTree $baseNumber"
   
   pack $w.buttons.best $w.buttons.graph $w.buttons.bStartStop $w.buttons.allgames $w.buttons.training \
@@ -217,9 +162,8 @@ proc ::tree::make { { baseNumber -1 } {locked 0} } {
   wm minsize $w 40 5
   ::createToplevelFinalize $w
   
-  wm protocol $w WM_DELETE_WINDOW " .treeWin$baseNumber.buttons.close invoke "
   ::tree::refresh $baseNumber
-  set ::tree::cachesize($baseNumber) [lindex [sc_tree cacheinfo $baseNumber] 1]
+  set ::tree::cachesize($baseNumber) [sc_tree cacheinfo $baseNumber]
 }
 ################################################################################
 proc ::tree::hideCtxtMenu { baseNumber } {
@@ -231,11 +175,6 @@ proc ::tree::hideCtxtMenu { baseNumber } {
 }
 ################################################################################
 proc ::tree::selectCallback { baseNumber move } {
-  
-  if { $::tree(refresh) } {
-    return
-  }
-  
   if {$::tree(autorefresh$baseNumber)} {
     tree::select $move $baseNumber
   }
@@ -255,7 +194,6 @@ proc ::tree::closeTree {baseNumber} {
   
   if {[winfo exists .treeGraph$baseNumber]} { destroy .treeGraph$baseNumber }
   destroy .treeBest$baseNumber
-  ::docking::cleanup .treeWin$baseNumber
   destroy .treeWin$baseNumber
   if {$::tree(locked$baseNumber)} { ::file::Close $baseNumber }
   set curr_base [sc_base current]
@@ -341,8 +279,23 @@ proc ::tree::doTraining { { n 0 } } {
     }
   }
   
-  set move [sc_tree move $::tree::trainingBase random]
-  addSanMove $move
+  set moves [sc_filter treestats $::tree::trainingBase "tree"]
+  set tot_freq 0
+  foreach move $moves {
+      lassign $move san freq
+      if { $san ne {[end]} } { incr tot_freq $freq }
+  }
+  set random_move [expr {int( rand()*$tot_freq )}]
+  set freq_move 0
+  foreach move $moves {
+      lassign $move san freq
+      if { $san ne {[end]} } {
+          incr freq_move $freq
+          if {$random_move <= $freq_move } {
+              return [addSanMove $move]
+          }
+      }
+  }
 }
 
 ################################################################################
@@ -359,20 +312,62 @@ proc ::tree::select { move baseNumber } {
   catch { addSanMove $move }
 }
 
-set tree(refresh) 0
-
 ################################################################################
-proc ::tree::refresh { { baseNumber "" }} {
-  set tree(refresh) 1
-  if {$baseNumber == "" } {
-    sc_tree search -cancel all
-    foreach i [sc_base list] {
-      if { [::tree::dorefresh $i] == "canceled" } { break }
+
+# Returns the list of databases whose tree filter needs to be updated when
+# the position of the main board changes.
+# It must also disable commands that depend on the current position.
+proc ::tree::listTreeBases {{base ""}} {
+    if { $base == "" } {
+        set base [sc_base list]
     }
-  } else {
-    ::tree::dorefresh $baseNumber
-  }
-  set tree(refresh) 0
+    set bases {}
+    foreach baseNumber $base {
+        set w .treeWin$baseNumber
+        if { [winfo exists $w] && $::tree(autorefresh$baseNumber) } {
+            $w.buttons.best configure -state disabled
+            $w.buttons.graph configure -state disabled
+            $w.buttons.bStartStop configure -state disabled
+            $w.buttons.training configure -state disabled
+            $w.buttons.allgames configure -state disabled
+            $w.buttons.close configure -state disabled
+            $w.buttons.stop configure -state normal
+            $w.progress coords bar 0 0 0 0
+            grid $w.progress -in $w.statusframe -column 0 -row 0 -sticky nsew
+            set progress "$w.progress [lindex [grid bbox $w.statusframe] 2] 100"
+            $w.buttons.stop configure -command "
+                ::cancelUpdateTreeFilter [list $progress]
+                ::tree::restoreButtons $w
+            "
+
+            set filter "tree"
+            if { $::tree(allgames$baseNumber) == 0 } {
+                set filter [sc_filter compose $baseNumber "dbfilter" "tree"]
+            }
+
+            lappend bases [list $baseNumber $filter $progress]
+        }
+    }
+    return $bases
+}
+
+proc ::tree::restoreButtons {w} {
+    grid forget $w.progress
+    $w.buttons.best configure -state normal
+    $w.buttons.graph configure -state normal
+    $w.buttons.bStartStop configure -state normal
+    $w.buttons.training configure -state normal
+    $w.buttons.allgames configure -state normal
+    $w.buttons.close configure -state normal
+    $w.buttons.stop configure -state disabled -command {}
+}
+
+proc ::tree::refresh { { baseNumber "" }} {
+    if { $baseNumber != "" && [lsearch -exact [sc_base list] $baseNumber] == -1 } {
+        displayLines $baseNumber "Error: the file is not open."
+        return
+    }
+    ::updateTreeFilter $baseNumber
 }
 
 ################################################################################
@@ -383,41 +378,24 @@ proc ::tree::dorefresh { baseNumber } {
   if {![winfo exists $w]} { return }
   if { ! $tree(autorefresh$baseNumber) } { return }
 
-  grid $w.progress -in $w.statusframe -column 0 -row 0 -sticky nsew
-  
-  progressBarSet $w.progress [$w.progress cget -width] 100
-  foreach button {best graph training allgames close} {
-    $w.buttons.$button configure -state disabled
-  }
-  $w.buttons.stop configure -state normal
-  
-  set filtered 0
+  set filter "tree"
   if { $tree(allgames$baseNumber) == 0 } {
-    set filtered 1
+    set filter [sc_filter compose $baseNumber "dbfilter" "tree"]
   }
-  
-  set err [ catch { sc_tree search -hide $tree(training$baseNumber) \
-                                   -sort $tree(order$baseNumber) \
-                                   -base $baseNumber \
-                                   -filtered $filtered } moves]
+  set err [ catch { sc_tree stats $baseNumber $filter $tree(training$baseNumber) \
+                                  $tree(order$baseNumber) } moves]
   if { $err } {
     set tree(status$baseNumber) ""
     set moves [ERROR::getErrorMsg]
   }
   catch {$w.f.tl itemconfigure 0 -foreground darkBlue}
 
-  foreach button {best graph training allgames close} {
-    $w.buttons.$button configure -state normal
-  }
-  $w.buttons.stop configure -state disabled
-
+  ::tree::restoreButtons $w
   ::tree::status "" $baseNumber
   if {[winfo exists .treeGraph$baseNumber]} { ::tree::graph $baseNumber }
-  
-  if { $moves == "canceled" } { return "canceled"}
+
   displayLines $baseNumber $moves  
 
-  grid forget $w.progress
   if {$::tree::trainingBase != 0 && $::tree::trainingColor == [sc_pos side]} {
     ::tree::doTraining
   }
@@ -508,11 +486,7 @@ proc ::tree::displayLines { baseNumber moves } {
     }
     
     # Move and stats
-    if {[expr $i % 2] && $i < [expr $len -3] } {
-      $w.f.tl insert end "$line" [list greybg $tagfg tagtooltip$i]
-    } else  {
-      $w.f.tl insert end "$line" [list whitebg $tagfg tagtooltip$i]
-    }
+    $w.f.tl insert end "$line" [list $tagfg tagtooltip$i]
     if {$colorScore != ""} {
       $w.f.tl tag add $colorScore end-31c end-26c
     }
@@ -845,7 +819,7 @@ proc ::tree::graph { baseNumber {bpress 0}} {
     bind $w <F1> {helpWindow Tree Graph}
     
     menu $w.menu
-    $w configure -menu $w.menu
+    ::setMenu $w $w.menu
     $w.menu add cascade -label GraphFile -menu $w.menu.file
     menu $w.menu.file
     $w.menu.file add command -label GraphFileColor -command "::tools::graphs::Save color $w.c"
@@ -853,7 +827,7 @@ proc ::tree::graph { baseNumber {bpress 0}} {
     $w.menu.file add separator
     $w.menu.file add command -label GraphFileClose -command "destroy $w"
     
-    canvas $w.c -width 500 -height 300
+    canvas $w.c -width 500 -height 300 -selectforeground [ttk::style lookup . -foreground] -background [ttk::style lookup . -background]
     pack $w.c -side top -fill both -expand yes
     $w.c create text 25 10 -tag text -justify center -width 1 -font font_Regular -anchor n
     update
@@ -990,12 +964,6 @@ proc ::tree::setCacheSize { base size } {
 ################################################################################
 #
 ################################################################################
-proc ::tree::getCacheInfo { base } {
-  set ci [sc_tree cacheinfo $base]
-  tk_messageBox -title "Scid" -type ok -icon info \
-      -message "Cache used : [lindex $ci 0] / [lindex $ci 1]"
-  
-}
 
 
 ################################################################################
@@ -1029,7 +997,7 @@ namespace eval ::tree::mask {
   
   array set marker2image { Include tb_tick Exclude tb_cross MainLine tb_mainline Bookmark tb_bkm \
         White tb_white Black tb_black \
-        NewLine tb_new ToBeVerified tb_rfilter ToTrain tb_msearch Dubious tb_help ToRemove tb_cut }
+        NewLine tb_new ToBeVerified tb_rfilter ToTrain tb_msearch Dubious tb_help_small ToRemove tb_cut }
   set maxRecent 10
 }
 ################################################################################
@@ -1530,11 +1498,12 @@ proc ::tree::mask::addComment { { move "" } } {
     ::setTitle $w [::tr CommentMove]
   }
   set oldComment [ string trim $oldComment ]
-  autoscrollframe $w.f text $w.f.e -width 40 -height 5 -wrap word -setgrid 1
+  autoscrollText y $w.f $w.f.e Treeview
+  $w.f.e configure -width 40 -height 5 -wrap word -state normal -setgrid 1
   $w.f.e insert end $oldComment
   ttk::button $w.ok -text OK -command "::tree::mask::updateComment $move ; destroy $w ; ::tree::refresh"
   pack  $w.f  -side top -expand 1 -fill both
-  pack  $w.ok -side bottom
+  pack  $w.ok -side bottom -fill x
   focus $w.f.e
 }
 ################################################################################
@@ -1711,18 +1680,15 @@ proc ::tree::mask::displayMask {} {
   setWinLocation $w
   setWinSize $w
   
-  ttk::button $w.bupdate -text [::tr "Update"] -command ::tree::mask::updateDisplayMask
   ttk::frame $w.f
-  
-  
+  pack $w.f -fill both -expand 1
+
   ttk::frame $w.fcb
   pack $w.fcb -fill x
+  ttk::button $w.fcb.bupdate -text [::tr "Update"] -command ::tree::mask::updateDisplayMask
   ttk::checkbutton $w.fcb.nag -text [::tr "Nag"] -variable ::tree::mask::displayMask_showNag -command ::tree::mask::updateDisplayMask
   ttk::checkbutton $w.fcb.comment -text [::tr "Comments"] -variable ::tree::mask::displayMask_showComment -command ::tree::mask::updateDisplayMask
-  pack $w.fcb.nag $w.fcb.comment -side left
-  
-  pack $w.bupdate -fill x
-  pack $w.f -fill both -expand 1
+  pack $w.fcb.bupdate $w.fcb.nag $w.fcb.comment -side right -padx 5 -pady "2 5"
   
   ttk::treeview $w.f.tree -yscrollcommand "$w.f.ybar set" -xscrollcommand "$w.f.xbar set" -show tree -selectmode browse
   # workaround for a bug in treeview (xscrollbar does not get view size)
@@ -1921,9 +1887,9 @@ proc ::tree::mask::searchMask { baseNumber } {
   toplevel $w
   wm title $w [::tr SearchMask]
   ttk::frame $w.f1
-  ttk::frame $w.f2
-  pack $w.f1 -side top -fill both -expand 1
-  pack $w.f2 -side top -fill both -expand 1
+  autoscrollText y $w.f2 $w.f2.text Treeview
+  pack $w.f1 -side top -fill both -expand 1 -anchor e
+  pack $w.f2 -side top -fill both -expand 1 -anchor e
   
   # NAG selection
   ttk::checkbutton $w.f1.nagl -text [tr Nag] -variable ::tree::mask::searchMask_usenag
@@ -1933,8 +1899,8 @@ proc ::tree::mask::searchMask { baseNumber } {
   foreach nag [ list "!!" " !" "!?" "?!" " ?" "??" " ~" [::tr "None"]  ] {
     $w.f1.nagmenu add command -label $nag -command "set ::tree::mask::searchMask_nag $nag"
   }
-  grid $w.f1.nagl -column 0 -row 0
-  grid $w.f1.nag -column 0 -row 1
+  grid $w.f1.nagl -column 0 -row 0 -sticky w -padx 10
+  grid $w.f1.nag -column 0 -row 1 -sticky w -padx 10
   
   # Markers 1 & 2
   foreach j { 0 1 } {
@@ -1948,8 +1914,8 @@ proc ::tree::mask::searchMask { baseNumber } {
       $w.f1.menum$j add command -label [ tr $e ] -image $i -compound left \
           -command "set ::tree::mask::searchMask_trm$j \"[tr $e ]\" ; set ::tree::mask::searchMask_m$j $i"
     }
-    grid $w.f1.ml$j -column [expr 1 + $j] -row 0
-    grid $w.f1.m$j -column [expr 1 + $j] -row 1
+      grid $w.f1.ml$j -column [expr 1 + $j] -row 0 -sticky w -padx [expr $j*10]
+    grid $w.f1.m$j -column [expr 1 + $j] -row 1 -sticky w -padx [expr $j*10]
   }
   
   # Color
@@ -1962,29 +1928,26 @@ proc ::tree::mask::searchMask { baseNumber } {
     $w.f1.colormenu add command -label [ tr "${c}Mark" ] \
         -command "set ::tree::mask::searchMask_trcolor [ tr ${c}Mark ] ; set ::tree::mask::searchMask_color $c"
   }
-  grid $w.f1.colorl -column 3 -row 0
-  grid $w.f1.color -column 3 -row 1
+  grid $w.f1.colorl -column 3 -row 0 -sticky w
+  grid $w.f1.color -column 3 -row 1 -sticky w
   
   # Move annotation
   ttk::checkbutton $w.f1.movecommentl -text "Move comment" -variable ::tree::mask::searchMask_usemovecomment
   ttk::entry $w.f1.movecomment -textvariable ::tree::mask::searchMask_movecomment -width 12
-  grid $w.f1.movecommentl -column 4 -row 0
-  grid $w.f1.movecomment -column 4 -row 1
+  grid $w.f1.movecommentl -column 4 -row 0 -sticky w -padx 10
+  grid $w.f1.movecomment -column 4 -row 1 -sticky w -padx 10
   
   # Position annotation
   ttk::checkbutton $w.f1.poscommentl -text "Position comment" -variable ::tree::mask::searchMask_useposcomment
   ttk::entry $w.f1.poscomment -textvariable ::tree::mask::searchMask_poscomment -width 12
-  grid $w.f1.poscommentl -column 5 -row 0
-  grid $w.f1.poscomment -column 5 -row 1
+  grid $w.f1.poscommentl -column 5 -row 0 -sticky w
+  grid $w.f1.poscomment -column 5 -row 1 -sticky w
   
   ttk::button $w.f1.search -text [tr "Search"] -command " ::tree::mask::performSearch $baseNumber "
-  grid $w.f1.search -column 6 -row 0 -rowspan 2
+  grid $w.f1.search -column 5 -row 2 -sticky e -pady "2 5" -padx "0 5"
   
   # display search result
-  text $w.f2.text -yscrollcommand "$w.f2.ybar set" -height 50
-  ttk::scrollbar $w.f2.ybar -command "$w.f2.text yview"
-  pack $w.f2.ybar -side left -fill y
-  pack $w.f2.text -side left -fill both -expand yes
+  $w.f2.text configure -height 40 -state normal
   
   setWinLocation $w
   setWinSize $w
